from typing import Any, Optional, List, Dict, Tuple, Callable, Union

A80_addc: int  # 171
A80_addcix: int  # 172
A80_addciy: int  # 173
A80_addix: int  # 169
A80_addiy: int  # 170
A80_cmpd: int  # 182
A80_cmpi: int  # 181
A80_im0: int  # 183
A80_im1: int  # 184
A80_im2: int  # 185
A80_jrc: int  # 177
A80_jrnc: int  # 178
A80_jrnz: int  # 180
A80_jrz: int  # 179
A80_lbcd: int  # 149
A80_lded: int  # 150
A80_lixd: int  # 152
A80_liyd: int  # 153
A80_lspd: int  # 151
A80_mvai: int  # 168
A80_mvar: int  # 167
A80_mvia: int  # 166
A80_mvra: int  # 165
A80_otd: int  # 186
A80_oti: int  # 187
A80_pcix: int  # 163
A80_pciy: int  # 164
A80_sbcd: int  # 154
A80_sded: int  # 155
A80_sixd: int  # 157
A80_siyd: int  # 158
A80_spix: int  # 161
A80_spiy: int  # 162
A80_sspd: int  # 156
A80_subc: int  # 174
A80_subcix: int  # 175
A80_subciy: int  # 176
A80_xtix: int  # 159
A80_xtiy: int  # 160
AD218X_alu_00: int  # 48
AD218X_alu_01: int  # 49
AD218X_alu_02: int  # 50
AD218X_alu_03: int  # 51
AD218X_alu_04: int  # 52
AD218X_alu_05: int  # 53
AD218X_alu_06: int  # 54
AD218X_alu_07: int  # 55
AD218X_alu_08: int  # 56
AD218X_alu_09: int  # 57
AD218X_alu_0a: int  # 58
AD218X_alu_0b: int  # 59
AD218X_alu_0c: int  # 60
AD218X_alu_0d: int  # 61
AD218X_alu_0e: int  # 62
AD218X_alu_0f: int  # 63
AD218X_alu_10: int  # 64
AD218X_alu_11: int  # 65
AD218X_alu_12: int  # 66
AD218X_alu_13: int  # 67
AD218X_alu_14: int  # 68
AD218X_alu_15: int  # 69
AD218X_alu_16: int  # 70
AD218X_alu_17: int  # 71
AD218X_alu_18: int  # 72
AD218X_alu_19: int  # 73
AD218X_alu_1a: int  # 74
AD218X_alu_1b: int  # 75
AD218X_alu_1c: int  # 76
AD218X_alu_1d: int  # 77
AD218X_amf: int  # 90
AD218X_amf_01: int  # 1
AD218X_amf_02: int  # 3
AD218X_amf_03: int  # 2
AD218X_amf_04: int  # 4
AD218X_amf_05: int  # 5
AD218X_amf_06: int  # 6
AD218X_amf_07: int  # 7
AD218X_amf_08: int  # 8
AD218X_amf_09: int  # 9
AD218X_amf_0a: int  # 10
AD218X_amf_0b: int  # 11
AD218X_amf_0c: int  # 12
AD218X_amf_0d: int  # 13
AD218X_amf_0e: int  # 14
AD218X_amf_0f: int  # 15
AD218X_amf_10: int  # 16
AD218X_amf_11: int  # 17
AD218X_amf_12: int  # 18
AD218X_amf_13: int  # 19
AD218X_amf_14: int  # 20
AD218X_amf_15: int  # 21
AD218X_amf_16: int  # 22
AD218X_amf_17: int  # 23
AD218X_amf_18: int  # 24
AD218X_amf_19: int  # 25
AD218X_amf_1a: int  # 26
AD218X_amf_1b: int  # 27
AD218X_amf_1c: int  # 28
AD218X_amf_1d: int  # 29
AD218X_amf_1e: int  # 30
AD218X_amf_1f: int  # 31
AD218X_amf_move_0: int  # 137
AD218X_amf_move_1: int  # 138
AD218X_amf_move_2: int  # 139
AD218X_amf_move_3: int  # 140
AD218X_amf_move_4: int  # 141
AD218X_amf_move_5: int  # 142
AD218X_amf_move_6: int  # 143
AD218X_amf_move_7: int  # 144
AD218X_amf_move_8: int  # 145
AD218X_amf_move_9: int  # 146
AD218X_amf_move_a: int  # 147
AD218X_call: int  # 117
AD218X_call_1: int  # 118
AD218X_call_2: int  # 119
AD218X_do: int  # 125
AD218X_double_move: int  # 136
AD218X_flag_out: int  # 128
AD218X_idle: int  # 126
AD218X_idle_1: int  # 127
AD218X_ints_dis: int  # 133
AD218X_ints_ena: int  # 134
AD218X_jump: int  # 112
AD218X_jump_1: int  # 113
AD218X_jump_2: int  # 114
AD218X_jump_3: int  # 115
AD218X_jump_4: int  # 116
AD218X_last: int  # 148
AD218X_mac_0: int  # 78
AD218X_mac_1: int  # 79
AD218X_mac_2: int  # 80
AD218X_mac_3: int  # 81
AD218X_mac_4: int  # 82
AD218X_mac_5: int  # 83
AD218X_mac_6: int  # 84
AD218X_mac_7: int  # 85
AD218X_mac_8: int  # 86
AD218X_mac_9: int  # 87
AD218X_mac_a: int  # 88
AD218X_mac_b: int  # 89
AD218X_mode_ctl: int  # 130
AD218X_modify: int  # 135
AD218X_move_0: int  # 100
AD218X_move_1: int  # 101
AD218X_move_2: int  # 102
AD218X_move_3: int  # 103
AD218X_move_4: int  # 104
AD218X_move_5: int  # 105
AD218X_move_6: int  # 106
AD218X_move_7: int  # 107
AD218X_move_8: int  # 108
AD218X_move_9: int  # 109
AD218X_move_a: int  # 110
AD218X_move_b: int  # 111
AD218X_nop: int  # 124
AD218X_null: int  # 0
AD218X_rti: int  # 122
AD218X_rti_cond: int  # 123
AD218X_rts: int  # 120
AD218X_rts_cond: int  # 121
AD218X_shft: int  # 91
AD218X_shft_0: int  # 32
AD218X_shft_1: int  # 33
AD218X_shft_2: int  # 34
AD218X_shft_3: int  # 35
AD218X_shft_4: int  # 36
AD218X_shft_5: int  # 37
AD218X_shft_6: int  # 38
AD218X_shft_7: int  # 39
AD218X_shft_8: int  # 40
AD218X_shft_9: int  # 41
AD218X_shft_a: int  # 42
AD218X_shft_b: int  # 43
AD218X_shft_c: int  # 44
AD218X_shft_d: int  # 45
AD218X_shft_e: int  # 46
AD218X_shft_f: int  # 47
AD218X_shifter_0: int  # 92
AD218X_shifter_1: int  # 93
AD218X_shifter_2: int  # 94
AD218X_shifter_3: int  # 95
AD218X_shifter_4: int  # 96
AD218X_shifter_5: int  # 97
AD218X_shifter_6: int  # 98
AD218X_shifter_7: int  # 99
AD218X_stack_ctl: int  # 129
AD218X_tops_r: int  # 132
AD218X_tops_w: int  # 131
ALPHA_addf: int  # 1
ALPHA_addg: int  # 2
ALPHA_addl: int  # 3
ALPHA_addl_v: int  # 4
ALPHA_addq: int  # 5
ALPHA_addq_v: int  # 6
ALPHA_adds: int  # 7
ALPHA_addt: int  # 8
ALPHA_amask: int  # 9
ALPHA_and: int  # 10
ALPHA_andnot: int  # 220
ALPHA_beq: int  # 11
ALPHA_bge: int  # 12
ALPHA_bgt: int  # 13
ALPHA_bic: int  # 14
ALPHA_bis: int  # 15
ALPHA_blbc: int  # 16
ALPHA_blbs: int  # 17
ALPHA_ble: int  # 18
ALPHA_blt: int  # 19
ALPHA_bne: int  # 20
ALPHA_br: int  # 21
ALPHA_br0: int  # 222
ALPHA_bsr: int  # 22
ALPHA_call_pal: int  # 23
ALPHA_clr: int  # 203
ALPHA_cmoveq: int  # 24
ALPHA_cmovge: int  # 25
ALPHA_cmovgt: int  # 26
ALPHA_cmovlbc: int  # 27
ALPHA_cmovlbs: int  # 28
ALPHA_cmovle: int  # 29
ALPHA_cmovlt: int  # 30
ALPHA_cmovne: int  # 31
ALPHA_cmpbge: int  # 32
ALPHA_cmpeq: int  # 33
ALPHA_cmpgeq: int  # 34
ALPHA_cmpgle: int  # 35
ALPHA_cmpglt: int  # 36
ALPHA_cmple: int  # 37
ALPHA_cmplt: int  # 38
ALPHA_cmpteq: int  # 39
ALPHA_cmptle: int  # 40
ALPHA_cmptlt: int  # 41
ALPHA_cmptun: int  # 42
ALPHA_cmpule: int  # 43
ALPHA_cmpult: int  # 44
ALPHA_cpys: int  # 45
ALPHA_cpyse: int  # 46
ALPHA_cpysn: int  # 47
ALPHA_ctlz: int  # 48
ALPHA_ctpop: int  # 49
ALPHA_cttz: int  # 50
ALPHA_cvtdg: int  # 51
ALPHA_cvtgd: int  # 52
ALPHA_cvtgf: int  # 53
ALPHA_cvtgq: int  # 54
ALPHA_cvtlq: int  # 55
ALPHA_cvtqf: int  # 56
ALPHA_cvtqg: int  # 57
ALPHA_cvtql: int  # 58
ALPHA_cvtqs: int  # 59
ALPHA_cvtqt: int  # 60
ALPHA_cvtst: int  # 61
ALPHA_cvttq: int  # 62
ALPHA_cvtts: int  # 63
ALPHA_divf: int  # 64
ALPHA_divg: int  # 65
ALPHA_divs: int  # 66
ALPHA_divt: int  # 67
ALPHA_ecb: int  # 68
ALPHA_eqv: int  # 69
ALPHA_excb: int  # 70
ALPHA_extbl: int  # 71
ALPHA_extlh: int  # 72
ALPHA_extll: int  # 73
ALPHA_extqh: int  # 74
ALPHA_extql: int  # 75
ALPHA_extwh: int  # 76
ALPHA_extwl: int  # 77
ALPHA_fabs: int  # 204
ALPHA_fbeq: int  # 78
ALPHA_fbge: int  # 79
ALPHA_fbgt: int  # 80
ALPHA_fble: int  # 81
ALPHA_fblt: int  # 82
ALPHA_fbne: int  # 83
ALPHA_fclr: int  # 205
ALPHA_fcmoveq: int  # 84
ALPHA_fcmovge: int  # 85
ALPHA_fcmovgt: int  # 86
ALPHA_fcmovle: int  # 87
ALPHA_fcmovlt: int  # 88
ALPHA_fcmovne: int  # 89
ALPHA_fetch: int  # 90
ALPHA_fetch_m: int  # 91
ALPHA_fmov: int  # 206
ALPHA_fneg: int  # 207
ALPHA_fnop: int  # 202
ALPHA_ftois: int  # 92
ALPHA_ftoit: int  # 93
ALPHA_implver: int  # 94
ALPHA_insbl: int  # 95
ALPHA_inslh: int  # 96
ALPHA_insll: int  # 97
ALPHA_insqh: int  # 98
ALPHA_insql: int  # 99
ALPHA_inswh: int  # 100
ALPHA_inswl: int  # 101
ALPHA_itoff: int  # 102
ALPHA_itofs: int  # 103
ALPHA_itoft: int  # 104
ALPHA_jmp: int  # 105
ALPHA_jsr: int  # 106
ALPHA_jsr_coroutine: int  # 107
ALPHA_last: int  # 223
ALPHA_lda: int  # 108
ALPHA_ldah: int  # 109
ALPHA_ldbu: int  # 110
ALPHA_ldf: int  # 112
ALPHA_ldg: int  # 113
ALPHA_ldl: int  # 114
ALPHA_ldl_l: int  # 115
ALPHA_ldq: int  # 116
ALPHA_ldq_l: int  # 117
ALPHA_ldq_u: int  # 118
ALPHA_lds: int  # 119
ALPHA_ldt: int  # 120
ALPHA_ldwu: int  # 111
ALPHA_maxsb8: int  # 121
ALPHA_maxsw4: int  # 122
ALPHA_maxub8: int  # 123
ALPHA_maxuw4: int  # 124
ALPHA_mb: int  # 125
ALPHA_mf_fpcr: int  # 126
ALPHA_minsb8: int  # 127
ALPHA_minsw4: int  # 128
ALPHA_minub8: int  # 129
ALPHA_minuw4: int  # 130
ALPHA_mov: int  # 208
ALPHA_mskbl: int  # 131
ALPHA_msklh: int  # 132
ALPHA_mskll: int  # 133
ALPHA_mskqh: int  # 134
ALPHA_mskql: int  # 135
ALPHA_mskwh: int  # 136
ALPHA_mskwl: int  # 137
ALPHA_mt_fpcr: int  # 138
ALPHA_mulf: int  # 139
ALPHA_mulg: int  # 140
ALPHA_mull: int  # 141
ALPHA_mull_v: int  # 142
ALPHA_mulq: int  # 143
ALPHA_mulq_v: int  # 144
ALPHA_muls: int  # 145
ALPHA_mult: int  # 146
ALPHA_negf: int  # 213
ALPHA_negg: int  # 214
ALPHA_negl: int  # 209
ALPHA_negl_v: int  # 210
ALPHA_negq: int  # 211
ALPHA_negq_v: int  # 212
ALPHA_negs: int  # 215
ALPHA_negt: int  # 216
ALPHA_nop: int  # 201
ALPHA_not: int  # 217
ALPHA_null: int  # 0
ALPHA_or: int  # 219
ALPHA_ornot: int  # 147
ALPHA_perr: int  # 148
ALPHA_pklb: int  # 149
ALPHA_pkwb: int  # 150
ALPHA_rc: int  # 151
ALPHA_ret: int  # 152
ALPHA_rpcc: int  # 153
ALPHA_rs: int  # 154
ALPHA_s4addl: int  # 155
ALPHA_s4addq: int  # 156
ALPHA_s4subl: int  # 157
ALPHA_s4subq: int  # 158
ALPHA_s8addl: int  # 159
ALPHA_s8addq: int  # 160
ALPHA_s8subl: int  # 161
ALPHA_s8subq: int  # 162
ALPHA_sextb: int  # 163
ALPHA_sextl: int  # 218
ALPHA_sextw: int  # 164
ALPHA_sll: int  # 165
ALPHA_sqrtf: int  # 166
ALPHA_sqrtg: int  # 167
ALPHA_sqrts: int  # 168
ALPHA_sqrtt: int  # 169
ALPHA_sra: int  # 170
ALPHA_srl: int  # 171
ALPHA_stb: int  # 172
ALPHA_stf: int  # 173
ALPHA_stg: int  # 174
ALPHA_stl: int  # 176
ALPHA_stl_c: int  # 177
ALPHA_stq: int  # 178
ALPHA_stq_c: int  # 179
ALPHA_stq_u: int  # 180
ALPHA_sts: int  # 175
ALPHA_stt: int  # 181
ALPHA_stw: int  # 182
ALPHA_subf: int  # 183
ALPHA_subg: int  # 184
ALPHA_subl: int  # 185
ALPHA_subl_v: int  # 186
ALPHA_subq: int  # 187
ALPHA_subq_v: int  # 188
ALPHA_subs: int  # 189
ALPHA_subt: int  # 190
ALPHA_trapb: int  # 191
ALPHA_umulh: int  # 192
ALPHA_unop: int  # 200
ALPHA_unpkbl: int  # 193
ALPHA_unpkbw: int  # 194
ALPHA_wh64: int  # 195
ALPHA_wmb: int  # 196
ALPHA_xor: int  # 197
ALPHA_xornot: int  # 221
ALPHA_zap: int  # 198
ALPHA_zapnot: int  # 199
ARC_abs: int  # 46
ARC_abss: int  # 73
ARC_abssh: int  # 74
ARC_abssw: int  # 74
ARC_acm: int  # 104
ARC_adc: int  # 20
ARC_adcs: int  # 202
ARC_add: int  # 19
ARC_add1: int  # 47
ARC_add2: int  # 48
ARC_add3: int  # 49
ARC_addqbs: int  # 105
ARC_adds: int  # 75
ARC_addsdw: int  # 76
ARC_aex: int  # 141
ARC_and: int  # 23
ARC_asl: int  # 34
ARC_aslacc: int  # 248
ARC_asls: int  # 77
ARC_aslsacc: int  # 249
ARC_asr: int  # 6
ARC_asr16: int  # 216
ARC_asr8: int  # 217
ARC_asrs: int  # 78
ARC_asrsr: int  # 162
ARC_avgqb: int  # 106
ARC_b: int  # 14
ARC_bbit0: int  # 41
ARC_bbit1: int  # 42
ARC_bclr: int  # 50
ARC_bi: int  # 138
ARC_bic: int  # 25
ARC_bih: int  # 139
ARC_bl: int  # 15
ARC_bmsk: int  # 51
ARC_bmskn: int  # 142
ARC_br: int  # 43
ARC_brk: int  # 31
ARC_bset: int  # 52
ARC_bspeek: int  # 244
ARC_bspop: int  # 245
ARC_bspush: int  # 212
ARC_btst: int  # 53
ARC_bxor: int  # 54
ARC_cbflyhf0r: int  # 281
ARC_cbflyhf1r: int  # 300
ARC_clamp: int  # 107
ARC_clri: int  # 155
ARC_cmacchfr: int  # 261
ARC_cmacchnfr: int  # 260
ARC_cmachfr: int  # 259
ARC_cmachnfr: int  # 258
ARC_cmp: int  # 55
ARC_cmpychfr: int  # 254
ARC_cmpychnfr: int  # 257
ARC_cmpyhfmr: int  # 280
ARC_cmpyhfr: int  # 253
ARC_cmpyhnfr: int  # 252
ARC_daddh11: int  # 108
ARC_daddh12: int  # 109
ARC_daddh21: int  # 110
ARC_daddh22: int  # 111
ARC_dexcl1: int  # 112
ARC_dexcl2: int  # 113
ARC_div: int  # 158
ARC_divaw: int  # 79
ARC_divf: int  # 268
ARC_divu: int  # 159
ARC_dmach: int  # 169
ARC_dmachbl: int  # 277
ARC_dmachbm: int  # 278
ARC_dmachf: int  # 209
ARC_dmachfr: int  # 210
ARC_dmachu: int  # 170
ARC_dmpyh: int  # 167
ARC_dmpyhbl: int  # 275
ARC_dmpyhbm: int  # 276
ARC_dmpyhf: int  # 207
ARC_dmpyhfr: int  # 208
ARC_dmpyhu: int  # 168
ARC_dmpyhwf: int  # 204
ARC_dmulh11: int  # 114
ARC_dmulh12: int  # 115
ARC_dmulh21: int  # 116
ARC_dmulh22: int  # 117
ARC_drsubh11: int  # 122
ARC_drsubh12: int  # 123
ARC_drsubh21: int  # 124
ARC_drsubh22: int  # 125
ARC_dsubh11: int  # 118
ARC_dsubh12: int  # 119
ARC_dsubh21: int  # 120
ARC_dsubh22: int  # 121
ARC_ei: int  # 309
ARC_enter: int  # 156
ARC_ex: int  # 56
ARC_extb: int  # 10
ARC_exth: int  # 11
ARC_extw: int  # 11
ARC_fadd: int  # 126
ARC_fcvt32: int  # 306
ARC_ffs: int  # 222
ARC_flag: int  # 5
ARC_flagacc: int  # 250
ARC_fls: int  # 223
ARC_fmul: int  # 127
ARC_fsadd: int  # 126
ARC_fscmp: int  # 301
ARC_fscmpf: int  # 302
ARC_fsdiv: int  # 305
ARC_fsmadd: int  # 303
ARC_fsmsub: int  # 304
ARC_fsmul: int  # 127
ARC_fssqrt: int  # 307
ARC_fssub: int  # 128
ARC_fsub: int  # 128
ARC_fxtr: int  # 129
ARC_getacc: int  # 224
ARC_iaddr: int  # 130
ARC_j: int  # 17
ARC_jl: int  # 18
ARC_jli: int  # 308
ARC_kflag: int  # 310
ARC_last: int  # 312
ARC_ld: int  # 1
ARC_ldi: int  # 140
ARC_leave: int  # 157
ARC_llock: int  # 152
ARC_lp: int  # 16
ARC_lr: int  # 2
ARC_lsl: int  # 29
ARC_lsl16: int  # 214
ARC_lsl8: int  # 219
ARC_lsr: int  # 7
ARC_lsr16: int  # 215
ARC_lsr8: int  # 218
ARC_mac: int  # 165
ARC_macd: int  # 181
ARC_macdf: int  # 272
ARC_macdu: int  # 182
ARC_macdw: int  # 90
ARC_macf: int  # 264
ARC_macflw: int  # 98
ARC_macfr: int  # 265
ARC_machflw: int  # 101
ARC_machlw: int  # 100
ARC_machulw: int  # 99
ARC_maclw: int  # 97
ARC_macrdw: int  # 92
ARC_macu: int  # 166
ARC_macudw: int  # 91
ARC_macwhfl: int  # 292
ARC_macwhflr: int  # 293
ARC_macwhfm: int  # 288
ARC_macwhfmr: int  # 289
ARC_macwhkl: int  # 294
ARC_macwhkul: int  # 295
ARC_macwhl: int  # 283
ARC_macwhul: int  # 285
ARC_max: int  # 37
ARC_min: int  # 38
ARC_modif: int  # 251
ARC_mov: int  # 27
ARC_mpy: int  # 57
ARC_mpyd: int  # 179
ARC_mpydf: int  # 271
ARC_mpydu: int  # 180
ARC_mpyf: int  # 262
ARC_mpyfr: int  # 263
ARC_mpyh: int  # 58
ARC_mpyhm: int  # 59
ARC_mpyhu: int  # 59
ARC_mpym: int  # 58
ARC_mpyqb: int  # 131
ARC_mpyu: int  # 60
ARC_mpyuw: int  # 137
ARC_mpyw: int  # 136
ARC_mpywhfl: int  # 290
ARC_mpywhflr: int  # 291
ARC_mpywhfm: int  # 286
ARC_mpywhfmr: int  # 287
ARC_mpywhkl: int  # 296
ARC_mpywhkul: int  # 297
ARC_mpywhl: int  # 282
ARC_mpywhul: int  # 284
ARC_msubdf: int  # 274
ARC_msubdw: int  # 93
ARC_msubf: int  # 266
ARC_msubfr: int  # 267
ARC_msubwhfl: int  # 273
ARC_msubwhflr: int  # 279
ARC_msubwhfm: int  # 298
ARC_msubwhfmr: int  # 299
ARC_mul64: int  # 35
ARC_muldw: int  # 87
ARC_mulflw: int  # 96
ARC_mulhflw: int  # 103
ARC_mulhlw: int  # 102
ARC_mullw: int  # 95
ARC_mulrdw: int  # 89
ARC_mulu64: int  # 36
ARC_muludw: int  # 88
ARC_mululw: int  # 94
ARC_neg: int  # 61
ARC_negs: int  # 80
ARC_negsh: int  # 81
ARC_negsw: int  # 81
ARC_nop: int  # 28
ARC_norm: int  # 40
ARC_normacc: int  # 225
ARC_normh: int  # 82
ARC_normw: int  # 82
ARC_not: int  # 62
ARC_null: int  # 0
ARC_or: int  # 24
ARC_pkqb: int  # 133
ARC_pop: int  # 44
ARC_push: int  # 45
ARC_rcmp: int  # 63
ARC_rem: int  # 160
ARC_remu: int  # 161
ARC_rlc: int  # 30
ARC_rnd16: int  # 83
ARC_rndh: int  # 83
ARC_rol: int  # 151
ARC_rol8: int  # 220
ARC_ror: int  # 12
ARC_ror8: int  # 221
ARC_rrc: int  # 13
ARC_rsub: int  # 64
ARC_rtie: int  # 65
ARC_sat16: int  # 84
ARC_satf: int  # 226
ARC_sath: int  # 84
ARC_sbc: int  # 22
ARC_sbcs: int  # 203
ARC_scond: int  # 153
ARC_setacc: int  # 164
ARC_seteq: int  # 143
ARC_setge: int  # 146
ARC_setgt: int  # 150
ARC_seths: int  # 148
ARC_seti: int  # 154
ARC_setle: int  # 149
ARC_setlo: int  # 147
ARC_setlt: int  # 145
ARC_setne: int  # 144
ARC_sexb: int  # 8
ARC_sexh: int  # 9
ARC_sexw: int  # 9
ARC_sfxtr: int  # 132
ARC_sleep: int  # 32
ARC_sqrt: int  # 246
ARC_sqrtf: int  # 247
ARC_sr: int  # 4
ARC_st: int  # 3
ARC_store_instructions: int  # 4
ARC_sub: int  # 21
ARC_sub1: int  # 66
ARC_sub2: int  # 67
ARC_sub3: int  # 68
ARC_subs: int  # 85
ARC_subsdw: int  # 86
ARC_swap: int  # 39
ARC_swape: int  # 213
ARC_swi: int  # 33
ARC_sync: int  # 69
ARC_trap: int  # 70
ARC_tst: int  # 71
ARC_unimp: int  # 72
ARC_upkqb: int  # 134
ARC_vabs2h: int  # 239
ARC_vabss2h: int  # 240
ARC_vadd2h: int  # 171
ARC_vadd4b: int  # 198
ARC_vadds2h: int  # 172
ARC_vaddsub2h: int  # 175
ARC_vaddsubs2h: int  # 176
ARC_valgn2h: int  # 163
ARC_vasl2h: int  # 192
ARC_vasls2h: int  # 193
ARC_vasr2h: int  # 194
ARC_vasrs2h: int  # 195
ARC_vasrsr2h: int  # 197
ARC_vext2bhl: int  # 235
ARC_vext2bhlf: int  # 231
ARC_vext2bhm: int  # 236
ARC_vext2bhmf: int  # 232
ARC_vlsr2h: int  # 196
ARC_vmac2h: int  # 187
ARC_vmac2hf: int  # 188
ARC_vmac2hfr: int  # 190
ARC_vmac2hnfr: int  # 269
ARC_vmac2hu: int  # 189
ARC_vmax2h: int  # 199
ARC_vmin2h: int  # 201
ARC_vmpy2h: int  # 183
ARC_vmpy2hf: int  # 184
ARC_vmpy2hfr: int  # 186
ARC_vmpy2hu: int  # 185
ARC_vmpy2hwf: int  # 191
ARC_vmsub2hf: int  # 255
ARC_vmsub2hfr: int  # 256
ARC_vmsub2hnfr: int  # 270
ARC_vneg2h: int  # 241
ARC_vnegs2h: int  # 242
ARC_vnorm2h: int  # 243
ARC_vpack2hbl: int  # 227
ARC_vpack2hblf: int  # 229
ARC_vpack2hbm: int  # 228
ARC_vpack2hbmf: int  # 230
ARC_vpack2hl: int  # 205
ARC_vpack2hm: int  # 206
ARC_vperm: int  # 211
ARC_vrep2hl: int  # 233
ARC_vrep2hm: int  # 234
ARC_vsext2bhl: int  # 237
ARC_vsext2bhm: int  # 238
ARC_vsub2h: int  # 173
ARC_vsub4b: int  # 200
ARC_vsubadd2h: int  # 177
ARC_vsubadds2h: int  # 178
ARC_vsubs2h: int  # 174
ARC_wevt: int  # 311
ARC_xor: int  # 26
ARC_xpkqb: int  # 135
ARM_abs: int  # 556
ARM_adc: int  # 15
ARM_add: int  # 14
ARM_addg: int  # 895
ARM_addhn: int  # 563
ARM_addhn2: int  # 564
ARM_addp: int  # 678
ARM_addv: int  # 793
ARM_adr: int  # 44
ARM_adrl: int  # 81
ARM_adrp: int  # 497
ARM_aesd: int  # 449
ARM_aese: int  # 450
ARM_aesimc: int  # 451
ARM_aesmc: int  # 452
ARM_amx: int  # 959
ARM_and: int  # 10
ARM_asr: int  # 5
ARM_asrl: int  # 1087
ARM_at: int  # 539
ARM_aut: int  # 869
ARM_autg: int  # 1098
ARM_axflag: int  # 894
ARM_b: int  # 3
ARM_bcax: int  # 918
ARM_bf: int  # 1109
ARM_bfc: int  # 273
ARM_bfcsel: int  # 1113
ARM_bfcvt: int  # 951
ARM_bfcvtn: int  # 949
ARM_bfcvtn2: int  # 950
ARM_bfdot: int  # 948
ARM_bfi: int  # 272
ARM_bfl: int  # 1111
ARM_bflx: int  # 1112
ARM_bfm: int  # 498
ARM_bfmlalb: int  # 946
ARM_bfmlalt: int  # 947
ARM_bfmmla: int  # 945
ARM_bfx: int  # 1110
ARM_bfxil: int  # 501
ARM_bic: int  # 24
ARM_bif: int  # 573
ARM_bit: int  # 574
ARM_bkpt: int  # 45
ARM_bl: int  # 4
ARM_blr: int  # 471
ARM_blx1: int  # 46
ARM_blx2: int  # 47
ARM_br: int  # 470
ARM_brk: int  # 542
ARM_bsl: int  # 575
ARM_bti: int  # 910
ARM_bx: int  # 41
ARM_bxaut: int  # 1099
ARM_bxj: int  # 166
ARM_cas: int  # 856
ARM_casa: int  # 858
ARM_casal: int  # 859
ARM_casl: int  # 857
ARM_casp: int  # 860
ARM_caspa: int  # 862
ARM_caspal: int  # 863
ARM_caspl: int  # 861
ARM_cbnz: int  # 283
ARM_cbz: int  # 282
ARM_ccmn: int  # 521
ARM_ccmp: int  # 522
ARM_cdp: int  # 83
ARM_cdp2: int  # 84
ARM_cfinv: int  # 889
ARM_chka: int  # 292
ARM_cinc: int  # 517
ARM_cinv: int  # 518
ARM_clrex: int  # 256
ARM_cls: int  # 509
ARM_clz: int  # 48
ARM_cmeq: int  # 576
ARM_cmge: int  # 579
ARM_cmgt: int  # 582
ARM_cmhi: int  # 581
ARM_cmhs: int  # 578
ARM_cmle: int  # 585
ARM_cmlo: int  # 587
ARM_cmls: int  # 584
ARM_cmlt: int  # 588
ARM_cmn: int  # 21
ARM_cmp: int  # 20
ARM_cmpp: int  # 898
ARM_cmtst: int  # 788
ARM_cneg: int  # 519
ARM_cnt: int  # 595
ARM_cps: int  # 169
ARM_cpsid: int  # 170
ARM_cpsie: int  # 171
ARM_crc32: int  # 873
ARM_crc32c: int  # 874
ARM_csel: int  # 511
ARM_cset: int  # 515
ARM_csetm: int  # 516
ARM_csinc: int  # 512
ARM_csinv: int  # 513
ARM_csneg: int  # 514
ARM_cx1: int  # 1114
ARM_cx1A: int  # 1115
ARM_cx1d: int  # 1116
ARM_cx1dA: int  # 1117
ARM_cx2: int  # 1118
ARM_cx2A: int  # 1119
ARM_cx2d: int  # 1120
ARM_cx2dA: int  # 1121
ARM_cx3: int  # 1122
ARM_cx3A: int  # 1123
ARM_cx3d: int  # 1124
ARM_cx3dA: int  # 1125
ARM_dbg: int  # 287
ARM_dc: int  # 538
ARM_dcps1: int  # 463
ARM_dcps2: int  # 464
ARM_dcps3: int  # 465
ARM_dls: int  # 1103
ARM_dlstp: int  # 1105
ARM_dmb: int  # 285
ARM_drps: int  # 534
ARM_dsb: int  # 284
ARM_dup: int  # 627
ARM_enterx: int  # 290
ARM_eon: int  # 507
ARM_eor: int  # 11
ARM_eor3: int  # 919
ARM_eret: int  # 429
ARM_esb: int  # 1101
ARM_ext: int  # 629
ARM_extr: int  # 504
ARM_fabd: int  # 551
ARM_fabs: int  # 557
ARM_fabsd: int  # 95
ARM_fabss: int  # 96
ARM_facge: int  # 558
ARM_facgt: int  # 559
ARM_facle: int  # 560
ARM_faclt: int  # 561
ARM_fadd: int  # 562
ARM_faddd: int  # 97
ARM_faddp: int  # 679
ARM_fadds: int  # 98
ARM_fccmp: int  # 592
ARM_fccmpe: int  # 593
ARM_fcmeq: int  # 577
ARM_fcmge: int  # 580
ARM_fcmgt: int  # 583
ARM_fcmle: int  # 586
ARM_fcmlt: int  # 589
ARM_fcmp: int  # 590
ARM_fcmpd: int  # 99
ARM_fcmpe: int  # 591
ARM_fcmped: int  # 101
ARM_fcmpes: int  # 102
ARM_fcmpezd: int  # 103
ARM_fcmpezs: int  # 104
ARM_fcmps: int  # 100
ARM_fcmpzd: int  # 105
ARM_fcmpzs: int  # 106
ARM_fcpyd: int  # 107
ARM_fcpys: int  # 108
ARM_fcsel: int  # 594
ARM_fcvt: int  # 596
ARM_fcvtas: int  # 598
ARM_fcvtau: int  # 603
ARM_fcvtds: int  # 110
ARM_fcvtl: int  # 611
ARM_fcvtl2: int  # 612
ARM_fcvtms: int  # 601
ARM_fcvtmu: int  # 606
ARM_fcvtn: int  # 609
ARM_fcvtn2: int  # 610
ARM_fcvtns: int  # 599
ARM_fcvtnu: int  # 604
ARM_fcvtps: int  # 600
ARM_fcvtpu: int  # 605
ARM_fcvtsd: int  # 109
ARM_fcvtxn: int  # 613
ARM_fcvtxn2: int  # 614
ARM_fcvtzs: int  # 597
ARM_fcvtzu: int  # 602
ARM_fdiv: int  # 626
ARM_fdivd: int  # 111
ARM_fdivs: int  # 112
ARM_fjcvtzs: int  # 886
ARM_fldd: int  # 113
ARM_fldmd: int  # 115
ARM_fldms: int  # 116
ARM_fldmx: int  # 117
ARM_flds: int  # 114
ARM_fmacd: int  # 118
ARM_fmacs: int  # 119
ARM_fmadd: int  # 622
ARM_fmax: int  # 644
ARM_fmaxnm: int  # 645
ARM_fmaxnmp: int  # 685
ARM_fmaxnmv: int  # 799
ARM_fmaxp: int  # 684
ARM_fmaxv: int  # 798
ARM_fmdhr: int  # 154
ARM_fmdlr: int  # 156
ARM_fmdrr: int  # 162
ARM_fmin: int  # 648
ARM_fminnm: int  # 649
ARM_fminnmp: int  # 689
ARM_fminnmv: int  # 803
ARM_fminp: int  # 688
ARM_fminv: int  # 802
ARM_fmla: int  # 650
ARM_fmlal: int  # 941
ARM_fmlal2: int  # 942
ARM_fmls: int  # 653
ARM_fmlsl: int  # 943
ARM_fmlsl2: int  # 944
ARM_fmov: int  # 660
ARM_fmrdh: int  # 155
ARM_fmrdl: int  # 157
ARM_fmrrd: int  # 163
ARM_fmrrs: int  # 165
ARM_fmrs: int  # 161
ARM_fmrx: int  # 159
ARM_fmscd: int  # 120
ARM_fmscs: int  # 121
ARM_fmsr: int  # 160
ARM_fmsrr: int  # 164
ARM_fmstat: int  # 122
ARM_fmsub: int  # 623
ARM_fmul: int  # 667
ARM_fmuld: int  # 123
ARM_fmuls: int  # 124
ARM_fmulx: int  # 669
ARM_fmxr: int  # 158
ARM_fneg: int  # 675
ARM_fnegd: int  # 125
ARM_fnegs: int  # 126
ARM_fnmacd: int  # 127
ARM_fnmacs: int  # 128
ARM_fnmadd: int  # 624
ARM_fnmscd: int  # 129
ARM_fnmscs: int  # 130
ARM_fnmsub: int  # 625
ARM_fnmul: int  # 670
ARM_fnmuld: int  # 131
ARM_fnmuls: int  # 132
ARM_frecpe: int  # 732
ARM_frecps: int  # 733
ARM_frecpx: int  # 734
ARM_frint32x: int  # 914
ARM_frint32z: int  # 915
ARM_frint64x: int  # 916
ARM_frint64z: int  # 917
ARM_frinta: int  # 615
ARM_frinti: int  # 616
ARM_frintm: int  # 617
ARM_frintn: int  # 618
ARM_frintp: int  # 619
ARM_frintx: int  # 620
ARM_frintz: int  # 621
ARM_frsqrte: int  # 745
ARM_frsqrts: int  # 746
ARM_fsitod: int  # 133
ARM_fsitos: int  # 134
ARM_fsqrt: int  # 765
ARM_fsqrtd: int  # 135
ARM_fsqrts: int  # 136
ARM_fstd: int  # 137
ARM_fstmd: int  # 139
ARM_fstms: int  # 140
ARM_fstmx: int  # 141
ARM_fsts: int  # 138
ARM_fsub: int  # 773
ARM_fsubd: int  # 142
ARM_fsubs: int  # 143
ARM_ftosid: int  # 144
ARM_ftosis: int  # 145
ARM_ftosizd: int  # 146
ARM_ftosizs: int  # 147
ARM_ftouid: int  # 148
ARM_ftouis: int  # 149
ARM_ftouizd: int  # 150
ARM_ftouizs: int  # 151
ARM_fuitod: int  # 152
ARM_fuitos: int  # 153
ARM_genter: int  # 954
ARM_gexit: int  # 955
ARM_gmi: int  # 900
ARM_hb: int  # 293
ARM_hbl: int  # 294
ARM_hblp: int  # 295
ARM_hbp: int  # 296
ARM_hint: int  # 541
ARM_hlt: int  # 466
ARM_hvc: int  # 430
ARM_ic: int  # 537
ARM_ins: int  # 628
ARM_irg: int  # 899
ARM_isb: int  # 286
ARM_it: int  # 278
ARM_last: int  # 1134
ARM_lctp: int  # 1095
ARM_ld1: int  # 634
ARM_ld1r: int  # 638
ARM_ld2: int  # 635
ARM_ld2r: int  # 639
ARM_ld3: int  # 636
ARM_ld3r: int  # 640
ARM_ld4: int  # 637
ARM_ld4r: int  # 641
ARM_lda: int  # 431
ARM_ldadd: int  # 808
ARM_ldadda: int  # 810
ARM_ldaddal: int  # 811
ARM_ldaddl: int  # 809
ARM_ldaex: int  # 433
ARM_ldapr: int  # 807
ARM_ldapur: int  # 887
ARM_ldar: int  # 484
ARM_ldaxp: int  # 488
ARM_ldaxr: int  # 486
ARM_ldc: int  # 85
ARM_ldc2: int  # 86
ARM_ldclr: int  # 814
ARM_ldclra: int  # 816
ARM_ldclral: int  # 817
ARM_ldclrl: int  # 815
ARM_ldeor: int  # 820
ARM_ldeora: int  # 822
ARM_ldeoral: int  # 823
ARM_ldeorl: int  # 821
ARM_ldg: int  # 908
ARM_ldgm: int  # 909
ARM_ldlar: int  # 864
ARM_ldm: int  # 33
ARM_ldnp: int  # 476
ARM_ldp: int  # 474
ARM_ldr: int  # 30
ARM_ldrd: int  # 49
ARM_ldrd2: int  # 871
ARM_ldrex: int  # 172
ARM_ldrexb: int  # 257
ARM_ldrexd: int  # 258
ARM_ldrexh: int  # 259
ARM_ldrpc: int  # 31
ARM_ldset: int  # 826
ARM_ldseta: int  # 828
ARM_ldsetal: int  # 829
ARM_ldsetl: int  # 827
ARM_ldsmax: int  # 832
ARM_ldsmaxa: int  # 834
ARM_ldsmaxal: int  # 835
ARM_ldsmaxl: int  # 833
ARM_ldsmin: int  # 838
ARM_ldsmina: int  # 840
ARM_ldsminal: int  # 841
ARM_ldsminl: int  # 839
ARM_ldtr: int  # 478
ARM_ldumax: int  # 844
ARM_ldumaxa: int  # 846
ARM_ldumaxal: int  # 847
ARM_ldumaxl: int  # 845
ARM_ldumin: int  # 850
ARM_ldumina: int  # 852
ARM_lduminal: int  # 853
ARM_lduminl: int  # 851
ARM_ldur: int  # 472
ARM_ldxp: int  # 482
ARM_ldxr: int  # 480
ARM_le1: int  # 1106
ARM_le2: int  # 1107
ARM_leavex: int  # 291
ARM_letp: int  # 1108
ARM_lsl: int  # 6
ARM_lsll: int  # 1085
ARM_lsr: int  # 7
ARM_lsrl: int  # 1086
ARM_madd: int  # 523
ARM_mcr: int  # 91
ARM_mcr2: int  # 92
ARM_mcrr: int  # 93
ARM_mcrr2: int  # 167
ARM_mla: int  # 29
ARM_mls: int  # 279
ARM_mneg: int  # 525
ARM_mov: int  # 23
ARM_movi: int  # 492
ARM_movk: int  # 496
ARM_movl: int  # 80
ARM_movn: int  # 495
ARM_movt: int  # 269
ARM_movz: int  # 494
ARM_mrc: int  # 89
ARM_mrc2: int  # 90
ARM_mrrc: int  # 94
ARM_mrrc2: int  # 168
ARM_mrs: int  # 26
ARM_msr: int  # 27
ARM_msub: int  # 524
ARM_mul: int  # 28
ARM_mul53hi: int  # 961
ARM_mul53lo: int  # 960
ARM_mvn: int  # 25
ARM_mvni: int  # 493
ARM_neg: int  # 9
ARM_ngc: int  # 520
ARM_nop: int  # 2
ARM_not: int  # 508
ARM_null: int  # 0
ARM_orn: int  # 268
ARM_orr: int  # 22
ARM_pac: int  # 868
ARM_pacbti: int  # 1097
ARM_pacg: int  # 1100
ARM_pkhbt: int  # 173
ARM_pkhtb: int  # 174
ARM_pld: int  # 50
ARM_pldw: int  # 880
ARM_pli: int  # 276
ARM_pmul: int  # 668
ARM_pmull: int  # 673
ARM_pmull2: int  # 674
ARM_pop: int  # 42
ARM_prfm: int  # 490
ARM_prfum: int  # 491
ARM_pssbb: int  # 913
ARM_push: int  # 43
ARM_qadd: int  # 51
ARM_qadd16: int  # 175
ARM_qadd8: int  # 176
ARM_qaddsubx: int  # 177
ARM_qasx: int  # 177
ARM_qdadd: int  # 52
ARM_qdsub: int  # 53
ARM_qsax: int  # 180
ARM_qsub: int  # 54
ARM_qsub16: int  # 178
ARM_qsub8: int  # 179
ARM_qsubaddx: int  # 180
ARM_raddhn: int  # 729
ARM_raddhn2: int  # 730
ARM_rax1: int  # 920
ARM_rbit: int  # 277
ARM_ret: int  # 1
ARM_rev: int  # 181
ARM_rev16: int  # 182
ARM_rev32: int  # 510
ARM_rev64: int  # 735
ARM_revsh: int  # 183
ARM_rfe: int  # 184
ARM_rmif: int  # 890
ARM_ror: int  # 8
ARM_rrx: int  # 289
ARM_rsb: int  # 13
ARM_rsc: int  # 17
ARM_rshrn: int  # 742
ARM_rshrn2: int  # 743
ARM_rsubhn: int  # 749
ARM_rsubhn2: int  # 750
ARM_saba: int  # 544
ARM_sabal: int  # 547
ARM_sabal2: int  # 548
ARM_sabd: int  # 550
ARM_sabdl: int  # 554
ARM_sabdl2: int  # 555
ARM_sadalp: int  # 677
ARM_sadd16: int  # 185
ARM_sadd8: int  # 186
ARM_saddl: int  # 567
ARM_saddl2: int  # 568
ARM_saddlp: int  # 681
ARM_saddlv: int  # 795
ARM_saddsubx: int  # 187
ARM_saddw: int  # 571
ARM_saddw2: int  # 572
ARM_sasx: int  # 187
ARM_sb: int  # 911
ARM_sbc: int  # 16
ARM_sbdc: int  # 1021
ARM_sbfiz: int  # 502
ARM_sbfm: int  # 499
ARM_sbfx: int  # 270
ARM_scvtf: int  # 608
ARM_sdiv: int  # 280
ARM_sdot: int  # 939
ARM_sdsb: int  # 958
ARM_sel: int  # 188
ARM_setend: int  # 189
ARM_setf16: int  # 892
ARM_setf8: int  # 891
ARM_sev: int  # 264
ARM_sevl: int  # 467
ARM_sg: int  # 877
ARM_sha1c: int  # 453
ARM_sha1h: int  # 456
ARM_sha1m: int  # 454
ARM_sha1p: int  # 455
ARM_sha1su0: int  # 457
ARM_sha1su1: int  # 458
ARM_sha256h: int  # 459
ARM_sha256h2: int  # 460
ARM_sha256su0: int  # 461
ARM_sha256su1: int  # 462
ARM_sha512h: int  # 922
ARM_sha512h2: int  # 923
ARM_sha512su0: int  # 924
ARM_sha512su1: int  # 925
ARM_shadd: int  # 631
ARM_shadd16: int  # 190
ARM_shadd8: int  # 191
ARM_shaddsubx: int  # 192
ARM_shasx: int  # 192
ARM_shl: int  # 761
ARM_shll: int  # 762
ARM_shll2: int  # 763
ARM_shrn: int  # 759
ARM_shrn2: int  # 760
ARM_shsax: int  # 195
ARM_shsub: int  # 633
ARM_shsub16: int  # 193
ARM_shsub8: int  # 194
ARM_shsubaddx: int  # 195
ARM_sli: int  # 764
ARM_sm3partw1: int  # 926
ARM_sm3partw2: int  # 927
ARM_sm3ss1: int  # 928
ARM_sm3tt1a: int  # 929
ARM_sm3tt1b: int  # 930
ARM_sm3tt2a: int  # 931
ARM_sm3tt2b: int  # 932
ARM_sm4e: int  # 933
ARM_sm4ekey: int  # 934
ARM_smaddl: int  # 526
ARM_smax: int  # 643
ARM_smaxp: int  # 683
ARM_smaxv: int  # 797
ARM_smc: int  # 267
ARM_smin: int  # 647
ARM_sminp: int  # 687
ARM_sminv: int  # 801
ARM_smlabb: int  # 55
ARM_smlabt: int  # 57
ARM_smlad: int  # 196
ARM_smladx: int  # 197
ARM_smlal: int  # 38
ARM_smlal2: int  # 652
ARM_smlalbb: int  # 59
ARM_smlalbt: int  # 61
ARM_smlald: int  # 200
ARM_smlaldx: int  # 201
ARM_smlaltb: int  # 60
ARM_smlaltt: int  # 62
ARM_smlatb: int  # 56
ARM_smlatt: int  # 58
ARM_smlawb: int  # 63
ARM_smlawt: int  # 65
ARM_smlsd: int  # 202
ARM_smlsdx: int  # 203
ARM_smlsl: int  # 656
ARM_smlsl2: int  # 657
ARM_smlsld: int  # 206
ARM_smlsldx: int  # 207
ARM_smmla: int  # 208
ARM_smmlar: int  # 209
ARM_smmls: int  # 212
ARM_smmlsr: int  # 213
ARM_smmul: int  # 210
ARM_smmulr: int  # 211
ARM_smnegl: int  # 528
ARM_smov: int  # 659
ARM_smsubl: int  # 527
ARM_smuad: int  # 198
ARM_smuadx: int  # 199
ARM_smulbb: int  # 67
ARM_smulbt: int  # 69
ARM_smulh: int  # 529
ARM_smull: int  # 37
ARM_smull2: int  # 672
ARM_smultb: int  # 68
ARM_smultt: int  # 70
ARM_smulwb: int  # 64
ARM_smulwt: int  # 66
ARM_smusd: int  # 204
ARM_smusdx: int  # 205
ARM_sqabs: int  # 690
ARM_sqadd: int  # 692
ARM_sqdmlal: int  # 695
ARM_sqdmlal2: int  # 696
ARM_sqdmlsl: int  # 697
ARM_sqdmlsl2: int  # 698
ARM_sqdmulh: int  # 699
ARM_sqdmull: int  # 700
ARM_sqdmull2: int  # 701
ARM_sqneg: int  # 708
ARM_sqrdmlah: int  # 866
ARM_sqrdmlsh: int  # 867
ARM_sqrdmulh: int  # 709
ARM_sqrshl: int  # 711
ARM_sqrshr: int  # 1094
ARM_sqrshrl: int  # 1093
ARM_sqrshrn: int  # 714
ARM_sqrshrn2: int  # 715
ARM_sqrshrun: int  # 716
ARM_sqrshrun2: int  # 717
ARM_sqshl: int  # 719
ARM_sqshll: int  # 1088
ARM_sqshlu: int  # 720
ARM_sqshrn: int  # 723
ARM_sqshrn2: int  # 724
ARM_sqshrun: int  # 725
ARM_sqshrun2: int  # 726
ARM_sqsub: int  # 728
ARM_sqxtn: int  # 704
ARM_sqxtn2: int  # 705
ARM_sqxtun: int  # 706
ARM_sqxtun2: int  # 707
ARM_srhadd: int  # 737
ARM_sri: int  # 768
ARM_srs: int  # 214
ARM_srshl: int  # 739
ARM_srshr: int  # 741
ARM_srshrl: int  # 1091
ARM_srsra: int  # 748
ARM_ssat: int  # 215
ARM_ssat16: int  # 216
ARM_ssax: int  # 219
ARM_ssbb: int  # 912
ARM_sshl: int  # 752
ARM_sshll: int  # 755
ARM_sshll2: int  # 756
ARM_sshr: int  # 758
ARM_ssra: int  # 767
ARM_ssub16: int  # 217
ARM_ssub8: int  # 218
ARM_ssubaddx: int  # 219
ARM_ssubl: int  # 778
ARM_ssubl2: int  # 779
ARM_ssubw: int  # 782
ARM_ssubw2: int  # 783
ARM_st1: int  # 769
ARM_st2: int  # 770
ARM_st2g: int  # 904
ARM_st3: int  # 771
ARM_st4: int  # 772
ARM_stadd: int  # 812
ARM_staddl: int  # 813
ARM_stc: int  # 87
ARM_stc2: int  # 88
ARM_stclr: int  # 818
ARM_stclrl: int  # 819
ARM_steor: int  # 824
ARM_steorl: int  # 825
ARM_stg: int  # 901
ARM_stgm: int  # 906
ARM_stgp: int  # 907
ARM_stl: int  # 432
ARM_stlex: int  # 434
ARM_stllr: int  # 865
ARM_stlr: int  # 485
ARM_stlur: int  # 888
ARM_stlxp: int  # 489
ARM_stlxr: int  # 487
ARM_stm: int  # 34
ARM_stnp: int  # 477
ARM_stp: int  # 475
ARM_str: int  # 32
ARM_strd: int  # 71
ARM_strd2: int  # 872
ARM_strex: int  # 220
ARM_strexb: int  # 260
ARM_strexd: int  # 261
ARM_strexh: int  # 262
ARM_stset: int  # 830
ARM_stsetl: int  # 831
ARM_stsmax: int  # 836
ARM_stsmaxl: int  # 837
ARM_stsmin: int  # 842
ARM_stsminl: int  # 843
ARM_sttr: int  # 479
ARM_stumax: int  # 848
ARM_stumaxl: int  # 849
ARM_stumin: int  # 854
ARM_stuminl: int  # 855
ARM_stur: int  # 473
ARM_stxp: int  # 483
ARM_stxr: int  # 481
ARM_stz2g: int  # 905
ARM_stzg: int  # 902
ARM_stzgm: int  # 903
ARM_sub: int  # 12
ARM_subg: int  # 896
ARM_subhn: int  # 774
ARM_subhn2: int  # 775
ARM_subp: int  # 897
ARM_sudot: int  # 935
ARM_suqadd: int  # 693
ARM_svc: int  # 36
ARM_swbkpt: int  # 82
ARM_swp: int  # 35
ARM_swpa: int  # 805
ARM_swpal: int  # 806
ARM_swpl: int  # 804
ARM_sxtab: int  # 221
ARM_sxtab16: int  # 223
ARM_sxtah: int  # 225
ARM_sxtb: int  # 222
ARM_sxtb16: int  # 224
ARM_sxth: int  # 226
ARM_sxtl: int  # 663
ARM_sxtl2: int  # 664
ARM_sxtw: int  # 505
ARM_sys: int  # 535
ARM_sysl: int  # 536
ARM_tbb: int  # 274
ARM_tbh: int  # 275
ARM_tbl: int  # 784
ARM_tbnz: int  # 469
ARM_tbx: int  # 785
ARM_tbz: int  # 468
ARM_teq: int  # 19
ARM_tlbi: int  # 540
ARM_trap: int  # 952
ARM_trap2: int  # 953
ARM_trn1: int  # 786
ARM_trn2: int  # 787
ARM_tst: int  # 18
ARM_tt: int  # 875
ARM_tta: int  # 876
ARM_uaba: int  # 543
ARM_uabal: int  # 545
ARM_uabal2: int  # 546
ARM_uabd: int  # 549
ARM_uabdl: int  # 552
ARM_uabdl2: int  # 553
ARM_uadalp: int  # 676
ARM_uadd16: int  # 227
ARM_uadd8: int  # 228
ARM_uaddl: int  # 565
ARM_uaddl2: int  # 566
ARM_uaddlp: int  # 680
ARM_uaddlv: int  # 794
ARM_uaddsubx: int  # 229
ARM_uaddw: int  # 569
ARM_uaddw2: int  # 570
ARM_uasx: int  # 229
ARM_ubfiz: int  # 503
ARM_ubfm: int  # 500
ARM_ubfx: int  # 271
ARM_ucvtf: int  # 607
ARM_udiv: int  # 281
ARM_udot: int  # 940
ARM_uhadd: int  # 630
ARM_uhadd16: int  # 230
ARM_uhadd8: int  # 231
ARM_uhaddsubx: int  # 232
ARM_uhasx: int  # 232
ARM_uhsax: int  # 235
ARM_uhsub: int  # 632
ARM_uhsub16: int  # 233
ARM_uhsub8: int  # 234
ARM_uhsubaddx: int  # 235
ARM_umaal: int  # 236
ARM_umaddl: int  # 530
ARM_umax: int  # 642
ARM_umaxp: int  # 682
ARM_umaxv: int  # 796
ARM_umin: int  # 646
ARM_uminp: int  # 686
ARM_uminv: int  # 800
ARM_umlal: int  # 40
ARM_umlal2: int  # 651
ARM_umlsl: int  # 654
ARM_umlsl2: int  # 655
ARM_ummla: int  # 936
ARM_umnegl: int  # 532
ARM_umov: int  # 658
ARM_umsubl: int  # 531
ARM_umulh: int  # 533
ARM_umull: int  # 39
ARM_umull2: int  # 671
ARM_und: int  # 288
ARM_uqadd: int  # 691
ARM_uqadd16: int  # 237
ARM_uqadd8: int  # 238
ARM_uqaddsubx: int  # 239
ARM_uqasx: int  # 239
ARM_uqrshl: int  # 710
ARM_uqrshll: int  # 1092
ARM_uqrshrn: int  # 712
ARM_uqrshrn2: int  # 713
ARM_uqsax: int  # 242
ARM_uqshl: int  # 718
ARM_uqshll: int  # 1089
ARM_uqshrn: int  # 721
ARM_uqshrn2: int  # 722
ARM_uqsub: int  # 727
ARM_uqsub16: int  # 240
ARM_uqsub8: int  # 241
ARM_uqsubaddx: int  # 242
ARM_uqxtn: int  # 702
ARM_uqxtn2: int  # 703
ARM_urecpe: int  # 731
ARM_urhadd: int  # 736
ARM_urshl: int  # 738
ARM_urshr: int  # 740
ARM_urshrl: int  # 1090
ARM_ursqrte: int  # 744
ARM_ursra: int  # 747
ARM_usad8: int  # 244
ARM_usada8: int  # 243
ARM_usat: int  # 245
ARM_usat16: int  # 246
ARM_usax: int  # 249
ARM_usdot: int  # 937
ARM_ushl: int  # 751
ARM_ushll: int  # 753
ARM_ushll2: int  # 754
ARM_ushr: int  # 757
ARM_usmmla: int  # 938
ARM_usqadd: int  # 694
ARM_usra: int  # 766
ARM_usub16: int  # 247
ARM_usub8: int  # 248
ARM_usubaddx: int  # 249
ARM_usubl: int  # 776
ARM_usubl2: int  # 777
ARM_usubw: int  # 780
ARM_usubw2: int  # 781
ARM_uxtab: int  # 250
ARM_uxtab16: int  # 252
ARM_uxtah: int  # 254
ARM_uxtb: int  # 251
ARM_uxtb16: int  # 253
ARM_uxth: int  # 255
ARM_uxtl: int  # 661
ARM_uxtl2: int  # 662
ARM_uxtw: int  # 506
ARM_uzp1: int  # 789
ARM_uzp2: int  # 790
ARM_vaba: int  # 297
ARM_vabal: int  # 298
ARM_vabav: int  # 1054
ARM_vabd: int  # 299
ARM_vabdl: int  # 300
ARM_vabs: int  # 301
ARM_vacge: int  # 302
ARM_vacgt: int  # 303
ARM_vacle: int  # 304
ARM_vaclt: int  # 305
ARM_vadc: int  # 1019
ARM_vadcI: int  # 1020
ARM_vadd: int  # 306
ARM_vaddhn: int  # 307
ARM_vaddl: int  # 308
ARM_vaddlv: int  # 1055
ARM_vaddlvA: int  # 1056
ARM_vaddv: int  # 1057
ARM_vaddvA: int  # 1058
ARM_vaddw: int  # 309
ARM_vand: int  # 310
ARM_vbic: int  # 311
ARM_vbif: int  # 312
ARM_vbit: int  # 313
ARM_vbrsr: int  # 962
ARM_vbsl: int  # 314
ARM_vcadd: int  # 1018
ARM_vceq: int  # 315
ARM_vcge: int  # 316
ARM_vcgt: int  # 317
ARM_vcle: int  # 318
ARM_vcls: int  # 319
ARM_vclt: int  # 320
ARM_vclz: int  # 321
ARM_vcmla: int  # 1062
ARM_vcmp: int  # 322
ARM_vcmpe: int  # 323
ARM_vcmpv: int  # 1026
ARM_vcmul: int  # 963
ARM_vcnt: int  # 324
ARM_vctp: int  # 1096
ARM_vcvt: int  # 325
ARM_vcvta: int  # 438
ARM_vcvtb: int  # 327
ARM_vcvtm: int  # 441
ARM_vcvtn: int  # 439
ARM_vcvtp: int  # 440
ARM_vcvtr: int  # 326
ARM_vcvtt: int  # 328
ARM_vcx1: int  # 1126
ARM_vcx1A: int  # 1127
ARM_vcx2: int  # 1128
ARM_vcx2A: int  # 1129
ARM_vcx3: int  # 1130
ARM_vcx3A: int  # 1131
ARM_vddup: int  # 1014
ARM_vdiv: int  # 329
ARM_vdup: int  # 330
ARM_vdwdup: int  # 1016
ARM_veor: int  # 331
ARM_vext: int  # 332
ARM_vfma: int  # 333
ARM_vfmas: int  # 964
ARM_vfms: int  # 334
ARM_vfnma: int  # 335
ARM_vfnms: int  # 336
ARM_vhadd: int  # 337
ARM_vhcadd: int  # 1017
ARM_vhsub: int  # 338
ARM_vidup: int  # 1013
ARM_vins: int  # 884
ARM_viwdup: int  # 1015
ARM_vjcvt: int  # 885
ARM_vld1: int  # 339
ARM_vld2: int  # 340
ARM_vld20: int  # 1064
ARM_vld21: int  # 1065
ARM_vld3: int  # 341
ARM_vld4: int  # 342
ARM_vld40: int  # 1066
ARM_vld41: int  # 1067
ARM_vld42: int  # 1068
ARM_vld43: int  # 1069
ARM_vldm: int  # 343
ARM_vldr: int  # 344
ARM_vldrb: int  # 1076
ARM_vldrd: int  # 1079
ARM_vldrh: int  # 1077
ARM_vldrw: int  # 1078
ARM_vlldm: int  # 878
ARM_vlstm: int  # 879
ARM_vmax: int  # 345
ARM_vmaxa: int  # 965
ARM_vmaxav: int  # 1031
ARM_vmaxnm: int  # 436
ARM_vmaxnma: int  # 966
ARM_vmaxnmav: int  # 1035
ARM_vmaxnmv: int  # 1034
ARM_vmaxv: int  # 1030
ARM_vmin: int  # 346
ARM_vmina: int  # 967
ARM_vminav: int  # 1033
ARM_vminnm: int  # 437
ARM_vminnma: int  # 968
ARM_vminnmav: int  # 1037
ARM_vminnmv: int  # 1036
ARM_vminv: int  # 1032
ARM_vmla: int  # 347
ARM_vmladav: int  # 993
ARM_vmladavA: int  # 995
ARM_vmladavAX: int  # 996
ARM_vmladavX: int  # 994
ARM_vmlal: int  # 348
ARM_vmlaldav: int  # 1001
ARM_vmlaldavA: int  # 1003
ARM_vmlaldavAX: int  # 1004
ARM_vmlaldavX: int  # 1002
ARM_vmlas: int  # 969
ARM_vmls: int  # 349
ARM_vmlsdav: int  # 997
ARM_vmlsdavA: int  # 999
ARM_vmlsdavAX: int  # 1000
ARM_vmlsdavX: int  # 998
ARM_vmlsl: int  # 350
ARM_vmlsldav: int  # 1005
ARM_vmlsldavA: int  # 1007
ARM_vmlsldavAX: int  # 1008
ARM_vmlsldavX: int  # 1006
ARM_vmov: int  # 351
ARM_vmov2: int  # 1084
ARM_vmovl: int  # 352
ARM_vmovlb: int  # 1060
ARM_vmovlt: int  # 1061
ARM_vmovn: int  # 353
ARM_vmovnb: int  # 970
ARM_vmovnt: int  # 971
ARM_vmovx: int  # 883
ARM_vmrs: int  # 354
ARM_vmsr: int  # 355
ARM_vmul: int  # 356
ARM_vmulh: int  # 972
ARM_vmull: int  # 357
ARM_vmullb: int  # 974
ARM_vmullt: int  # 975
ARM_vmvn: int  # 358
ARM_vneg: int  # 359
ARM_vnmla: int  # 360
ARM_vnmls: int  # 361
ARM_vnmul: int  # 362
ARM_vorn: int  # 363
ARM_vorr: int  # 364
ARM_vpadal: int  # 365
ARM_vpadd: int  # 366
ARM_vpaddl: int  # 367
ARM_vpmax: int  # 368
ARM_vpmin: int  # 369
ARM_vpnot: int  # 1028
ARM_vpop: int  # 370
ARM_vpsel: int  # 1025
ARM_vpst: int  # 1029
ARM_vpt: int  # 1027
ARM_vpush: int  # 371
ARM_vqabs: int  # 372
ARM_vqadd: int  # 373
ARM_vqdmladh: int  # 976
ARM_vqdmladhX: int  # 977
ARM_vqdmlah: int  # 980
ARM_vqdmlal: int  # 374
ARM_vqdmlash: int  # 981
ARM_vqdmlsdh: int  # 983
ARM_vqdmlsdhX: int  # 984
ARM_vqdmlsl: int  # 375
ARM_vqdmulh: int  # 376
ARM_vqdmull: int  # 377
ARM_vqdmullb: int  # 1023
ARM_vqdmullt: int  # 1024
ARM_vqmovn: int  # 378
ARM_vqmovnb: int  # 987
ARM_vqmovnt: int  # 988
ARM_vqmovun: int  # 379
ARM_vqmovunb: int  # 989
ARM_vqmovunt: int  # 990
ARM_vqneg: int  # 380
ARM_vqrdmladh: int  # 978
ARM_vqrdmladhX: int  # 979
ARM_vqrdmlah: int  # 881
ARM_vqrdmlash: int  # 982
ARM_vqrdmlsdh: int  # 985
ARM_vqrdmlsdhX: int  # 986
ARM_vqrdmlsh: int  # 882
ARM_vqrdmulh: int  # 381
ARM_vqrshl: int  # 382
ARM_vqrshrn: int  # 383
ARM_vqrshrnb: int  # 1040
ARM_vqrshrnt: int  # 1041
ARM_vqrshrun: int  # 384
ARM_vqrshrunb: int  # 1044
ARM_vqrshrunt: int  # 1045
ARM_vqshl: int  # 385
ARM_vqshlu: int  # 386
ARM_vqshrn: int  # 387
ARM_vqshrnb: int  # 1038
ARM_vqshrnt: int  # 1039
ARM_vqshrun: int  # 388
ARM_vqshrunb: int  # 1042
ARM_vqshrunt: int  # 1043
ARM_vqsub: int  # 389
ARM_vraddhn: int  # 390
ARM_vrecpe: int  # 391
ARM_vrecps: int  # 392
ARM_vrev16: int  # 393
ARM_vrev32: int  # 394
ARM_vrev64: int  # 395
ARM_vrhadd: int  # 396
ARM_vrinta: int  # 445
ARM_vrintm: int  # 448
ARM_vrintn: int  # 446
ARM_vrintp: int  # 447
ARM_vrintr: int  # 443
ARM_vrintx: int  # 442
ARM_vrintz: int  # 444
ARM_vrmlaldavh: int  # 1050
ARM_vrmlaldavhA: int  # 1052
ARM_vrmlaldavhAX: int  # 1053
ARM_vrmlaldavhX: int  # 1051
ARM_vrmlsldavh: int  # 1009
ARM_vrmlsldavhA: int  # 1011
ARM_vrmlsldavhAX: int  # 1012
ARM_vrmlsldavhX: int  # 1010
ARM_vrmulh: int  # 973
ARM_vrshl: int  # 397
ARM_vrshr: int  # 398
ARM_vrshrn: int  # 399
ARM_vrshrnb: int  # 1048
ARM_vrshrnt: int  # 1049
ARM_vrsqrte: int  # 400
ARM_vrsqrts: int  # 401
ARM_vrsra: int  # 402
ARM_vrsubhn: int  # 403
ARM_vsbcI: int  # 1022
ARM_vscclrm: int  # 1063
ARM_vsel: int  # 435
ARM_vshl: int  # 404
ARM_vshlc: int  # 1059
ARM_vshll: int  # 405
ARM_vshllb: int  # 991
ARM_vshllt: int  # 992
ARM_vshr: int  # 406
ARM_vshrn: int  # 407
ARM_vshrnb: int  # 1046
ARM_vshrnt: int  # 1047
ARM_vsli: int  # 408
ARM_vsqrt: int  # 409
ARM_vsra: int  # 410
ARM_vsri: int  # 411
ARM_vst1: int  # 412
ARM_vst2: int  # 413
ARM_vst20: int  # 1070
ARM_vst21: int  # 1071
ARM_vst3: int  # 414
ARM_vst4: int  # 415
ARM_vst40: int  # 1072
ARM_vst41: int  # 1073
ARM_vst42: int  # 1074
ARM_vst43: int  # 1075
ARM_vstm: int  # 416
ARM_vstr: int  # 417
ARM_vstrb: int  # 1080
ARM_vstrd: int  # 1083
ARM_vstrh: int  # 1081
ARM_vstrw: int  # 1082
ARM_vsub: int  # 418
ARM_vsubhn: int  # 419
ARM_vsubl: int  # 420
ARM_vsubw: int  # 421
ARM_vswp: int  # 422
ARM_vtbl: int  # 423
ARM_vtbx: int  # 424
ARM_vtrn: int  # 425
ARM_vtst: int  # 426
ARM_vuzp: int  # 427
ARM_vzip: int  # 428
ARM_wfe: int  # 265
ARM_wfet: int  # 1132
ARM_wfi: int  # 266
ARM_wfit: int  # 1133
ARM_wkdmc: int  # 956
ARM_wkdmd: int  # 957
ARM_wls: int  # 1102
ARM_wlstp: int  # 1104
ARM_xaflag: int  # 893
ARM_xar: int  # 921
ARM_xpac: int  # 870
ARM_xtn: int  # 665
ARM_xtn2: int  # 666
ARM_yield: int  # 263
ARM_zip1: int  # 791
ARM_zip2: int  # 792
AVR_adc: int  # 2
AVR_add: int  # 1
AVR_adiw: int  # 3
AVR_and: int  # 9
AVR_andi: int  # 10
AVR_asr: int  # 77
AVR_bclr: int  # 80
AVR_bld: int  # 84
AVR_brbc: int  # 41
AVR_brbs: int  # 40
AVR_brcc: int  # 45
AVR_brcs: int  # 44
AVR_breq: int  # 42
AVR_brge: int  # 50
AVR_brhc: int  # 53
AVR_brhs: int  # 52
AVR_brid: int  # 59
AVR_brie: int  # 58
AVR_brlo: int  # 47
AVR_brlt: int  # 51
AVR_brmi: int  # 48
AVR_brne: int  # 43
AVR_brpl: int  # 49
AVR_brsh: int  # 46
AVR_brtc: int  # 55
AVR_brts: int  # 54
AVR_brvc: int  # 57
AVR_brvs: int  # 56
AVR_bset: int  # 79
AVR_bst: int  # 83
AVR_call: int  # 32
AVR_cbi: int  # 82
AVR_cbr: int  # 17
AVR_clc: int  # 86
AVR_clh: int  # 100
AVR_cli: int  # 92
AVR_cln: int  # 88
AVR_clr: int  # 21
AVR_cls: int  # 94
AVR_clt: int  # 98
AVR_clv: int  # 96
AVR_clz: int  # 90
AVR_com: int  # 14
AVR_cp: int  # 23
AVR_cpc: int  # 24
AVR_cpi: int  # 25
AVR_cpse: int  # 35
AVR_dec: int  # 19
AVR_des: int  # 115
AVR_eicall: int  # 113
AVR_eijmp: int  # 114
AVR_elpm: int  # 104
AVR_eor: int  # 13
AVR_espm: int  # 105
AVR_fmul: int  # 106
AVR_fmuls: int  # 107
AVR_fmulsu: int  # 108
AVR_icall: int  # 31
AVR_ijmp: int  # 28
AVR_in: int  # 69
AVR_inc: int  # 18
AVR_jmp: int  # 29
AVR_lac: int  # 116
AVR_las: int  # 117
AVR_last: int  # 120
AVR_lat: int  # 118
AVR_ld: int  # 63
AVR_ldd: int  # 64
AVR_ldi: int  # 61
AVR_lds: int  # 62
AVR_lpm: int  # 68
AVR_lsl: int  # 73
AVR_lsr: int  # 74
AVR_mov: int  # 60
AVR_movw: int  # 109
AVR_mul: int  # 26
AVR_muls: int  # 110
AVR_mulsu: int  # 111
AVR_neg: int  # 15
AVR_nop: int  # 101
AVR_null: int  # 0
AVR_or: int  # 11
AVR_ori: int  # 12
AVR_out: int  # 70
AVR_pop: int  # 72
AVR_push: int  # 71
AVR_rcall: int  # 30
AVR_ret: int  # 33
AVR_reti: int  # 34
AVR_rjmp: int  # 27
AVR_rol: int  # 75
AVR_ror: int  # 76
AVR_sbc: int  # 6
AVR_sbci: int  # 7
AVR_sbi: int  # 81
AVR_sbic: int  # 38
AVR_sbis: int  # 39
AVR_sbiw: int  # 8
AVR_sbr: int  # 16
AVR_sbrc: int  # 36
AVR_sbrs: int  # 37
AVR_sec: int  # 85
AVR_seh: int  # 99
AVR_sei: int  # 91
AVR_sen: int  # 87
AVR_ser: int  # 22
AVR_ses: int  # 93
AVR_set: int  # 97
AVR_sev: int  # 95
AVR_sez: int  # 89
AVR_sleep: int  # 102
AVR_spm: int  # 112
AVR_st: int  # 66
AVR_std: int  # 67
AVR_sts: int  # 65
AVR_sub: int  # 4
AVR_subi: int  # 5
AVR_swap: int  # 78
AVR_tst: int  # 20
AVR_wdr: int  # 103
AVR_xch: int  # 119
C166_add: int  # 1
C166_addb: int  # 2
C166_addc: int  # 3
C166_addcb: int  # 4
C166_and: int  # 5
C166_andb: int  # 6
C166_ashr: int  # 7
C166_atomic: int  # 8
C166_band: int  # 9
C166_bclr: int  # 10
C166_bcmp: int  # 11
C166_bfldh: int  # 12
C166_bfldl: int  # 13
C166_bmov: int  # 14
C166_bmovn: int  # 15
C166_bor: int  # 16
C166_bset: int  # 17
C166_bxor: int  # 18
C166_calla: int  # 19
C166_calli: int  # 20
C166_callr: int  # 21
C166_calls: int  # 22
C166_cmp: int  # 23
C166_cmpb: int  # 24
C166_cmpd1: int  # 25
C166_cmpd2: int  # 26
C166_cmpi1: int  # 27
C166_cmpi2: int  # 28
C166_cpl: int  # 29
C166_cplb: int  # 30
C166_diswdt: int  # 31
C166_div: int  # 32
C166_divl: int  # 33
C166_divlu: int  # 34
C166_divu: int  # 35
C166_einit: int  # 36
C166_enwdt: int  # 103
C166_extp: int  # 38
C166_extpr: int  # 39
C166_extr: int  # 37
C166_exts: int  # 40
C166_extsr: int  # 41
C166_idle: int  # 42
C166_jb: int  # 43
C166_jbc: int  # 44
C166_jmpa: int  # 45
C166_jmpi: int  # 46
C166_jmpr: int  # 47
C166_jmps: int  # 48
C166_jnb: int  # 49
C166_jnbs: int  # 50
C166_last: int  # 105
C166_mov: int  # 51
C166_movb: int  # 52
C166_movbs: int  # 53
C166_movbz: int  # 54
C166_mul: int  # 55
C166_mulu: int  # 56
C166_neg: int  # 57
C166_negb: int  # 58
C166_nop: int  # 59
C166_null: int  # 0
C166_or: int  # 60
C166_orb: int  # 61
C166_pcall: int  # 62
C166_pop: int  # 63
C166_prior: int  # 64
C166_push: int  # 65
C166_pwrdn: int  # 66
C166_ret: int  # 67
C166_reti: int  # 68
C166_retp: int  # 69
C166_rets: int  # 70
C166_rol: int  # 71
C166_ror: int  # 72
C166_sbrk: int  # 104
C166_scxt: int  # 73
C166_shl: int  # 74
C166_shr: int  # 75
C166_srst: int  # 76
C166_srvwdt: int  # 77
C166_sub: int  # 78
C166_subb: int  # 79
C166_subc: int  # 80
C166_subcb: int  # 81
C166_trap: int  # 82
C166_xor: int  # 83
C166_xorb: int  # 84
C39_adc: int  # 1
C39_add: int  # 2
C39_anc: int  # 3
C39_and: int  # 4
C39_ane: int  # 5
C39_arr: int  # 6
C39_asl: int  # 7
C39_asr: int  # 8
C39_bar: int  # 9
C39_bas: int  # 10
C39_bbr: int  # 11
C39_bbs: int  # 12
C39_bcc: int  # 13
C39_bcs: int  # 14
C39_beq: int  # 15
C39_bit: int  # 16
C39_bmi: int  # 17
C39_bne: int  # 18
C39_bpl: int  # 19
C39_bra: int  # 20
C39_brk: int  # 21
C39_bvc: int  # 22
C39_bvs: int  # 23
C39_clc: int  # 24
C39_cld: int  # 25
C39_cli: int  # 26
C39_clv: int  # 27
C39_clw: int  # 28
C39_cmp: int  # 29
C39_cpx: int  # 30
C39_cpy: int  # 31
C39_dcp: int  # 32
C39_dec: int  # 33
C39_dex: int  # 34
C39_dey: int  # 35
C39_eor: int  # 36
C39_exc: int  # 37
C39_inc: int  # 38
C39_ini: int  # 39
C39_inx: int  # 40
C39_iny: int  # 41
C39_isb: int  # 42
C39_jmp: int  # 43
C39_jpi: int  # 44
C39_jsb: int  # 45
C39_jsr: int  # 46
C39_lab: int  # 47
C39_lae: int  # 48
C39_lai: int  # 49
C39_lan: int  # 50
C39_last: int  # 115
C39_lax: int  # 51
C39_lda: int  # 52
C39_ldx: int  # 53
C39_ldy: int  # 54
C39_lii: int  # 55
C39_lsr: int  # 56
C39_lxa: int  # 57
C39_mpa: int  # 58
C39_mpy: int  # 59
C39_neg: int  # 60
C39_nop: int  # 61
C39_null: int  # 0
C39_nxt: int  # 62
C39_ora: int  # 63
C39_pha: int  # 64
C39_phi: int  # 65
C39_php: int  # 66
C39_phw: int  # 67
C39_phx: int  # 68
C39_phy: int  # 69
C39_pia: int  # 70
C39_pla: int  # 71
C39_pli: int  # 72
C39_plp: int  # 73
C39_plw: int  # 74
C39_plx: int  # 75
C39_ply: int  # 76
C39_psh: int  # 77
C39_pul: int  # 78
C39_rba: int  # 79
C39_rla: int  # 80
C39_rmb: int  # 81
C39_rnd: int  # 82
C39_rol: int  # 83
C39_ror: int  # 84
C39_rra: int  # 85
C39_rti: int  # 86
C39_rts: int  # 87
C39_sax: int  # 88
C39_sba: int  # 89
C39_sbc: int  # 90
C39_sbx: int  # 91
C39_sec: int  # 92
C39_sed: int  # 93
C39_sei: int  # 94
C39_sha: int  # 95
C39_shs: int  # 96
C39_shx: int  # 97
C39_shy: int  # 98
C39_slo: int  # 99
C39_smb: int  # 100
C39_sre: int  # 101
C39_sta: int  # 102
C39_sti: int  # 103
C39_stx: int  # 104
C39_sty: int  # 105
C39_taw: int  # 108
C39_tax: int  # 106
C39_tay: int  # 107
C39_tip: int  # 109
C39_tsx: int  # 110
C39_twa: int  # 111
C39_txa: int  # 112
C39_txs: int  # 113
C39_tya: int  # 114
CR16_addb: int  # 1
CR16_addcb: int  # 5
CR16_addcw: int  # 6
CR16_addub: int  # 3
CR16_adduw: int  # 4
CR16_addw: int  # 2
CR16_andb: int  # 7
CR16_andw: int  # 8
CR16_ashub: int  # 9
CR16_ashuw: int  # 10
CR16_bal: int  # 26
CR16_bcc: int  # 14
CR16_bcs: int  # 13
CR16_beq: int  # 11
CR16_beq0b: int  # 31
CR16_beq0w: int  # 32
CR16_beq1b: int  # 29
CR16_beq1w: int  # 30
CR16_bfc: int  # 20
CR16_bfs: int  # 19
CR16_bge: int  # 24
CR16_bgt: int  # 17
CR16_bhi: int  # 15
CR16_bhs: int  # 22
CR16_ble: int  # 18
CR16_blo: int  # 21
CR16_bls: int  # 16
CR16_blt: int  # 23
CR16_bne: int  # 12
CR16_bne0b: int  # 35
CR16_bne0w: int  # 36
CR16_bne1b: int  # 33
CR16_bne1w: int  # 34
CR16_br: int  # 25
CR16_cbitb: int  # 106
CR16_cbitw: int  # 107
CR16_cmpb: int  # 27
CR16_cmpw: int  # 28
CR16_di: int  # 37
CR16_ei: int  # 38
CR16_eiwait: int  # 109
CR16_excp: int  # 39
CR16_jal: int  # 55
CR16_jcc: int  # 43
CR16_jcs: int  # 42
CR16_jeq: int  # 40
CR16_jfc: int  # 49
CR16_jfs: int  # 48
CR16_jge: int  # 53
CR16_jgt: int  # 46
CR16_jhi: int  # 44
CR16_jhs: int  # 51
CR16_jle: int  # 47
CR16_jlo: int  # 50
CR16_jls: int  # 45
CR16_jlt: int  # 52
CR16_jne: int  # 41
CR16_jump: int  # 54
CR16_last: int  # 112
CR16_loadb: int  # 56
CR16_loadm: int  # 58
CR16_loadw: int  # 57
CR16_lpr: int  # 59
CR16_lshb: int  # 60
CR16_lshw: int  # 61
CR16_movb: int  # 62
CR16_movd: int  # 66
CR16_movw: int  # 63
CR16_movxb: int  # 64
CR16_movzb: int  # 65
CR16_mulb: int  # 67
CR16_mulsb: int  # 69
CR16_mulsw: int  # 70
CR16_muluw: int  # 71
CR16_mulw: int  # 68
CR16_nop: int  # 72
CR16_null: int  # 0
CR16_orb: int  # 73
CR16_orw: int  # 74
CR16_pop: int  # 76
CR16_popret: int  # 77
CR16_push: int  # 75
CR16_retx: int  # 78
CR16_sbitb: int  # 104
CR16_sbitw: int  # 105
CR16_scc: int  # 82
CR16_scs: int  # 81
CR16_seq: int  # 79
CR16_sfc: int  # 88
CR16_sfs: int  # 87
CR16_sge: int  # 92
CR16_sgt: int  # 85
CR16_shi: int  # 83
CR16_shs: int  # 90
CR16_sle: int  # 86
CR16_slo: int  # 89
CR16_sls: int  # 84
CR16_slt: int  # 91
CR16_sne: int  # 80
CR16_spr: int  # 93
CR16_storb: int  # 94
CR16_storm: int  # 96
CR16_storw: int  # 95
CR16_subb: int  # 97
CR16_subcb: int  # 99
CR16_subcw: int  # 100
CR16_subw: int  # 98
CR16_tbit: int  # 101
CR16_tbitb: int  # 102
CR16_tbitw: int  # 103
CR16_wait: int  # 108
CR16_xorb: int  # 110
CR16_xorw: int  # 111
DALVIK_ADD_DOUBLE: int  # 163
DALVIK_ADD_DOUBLE_2ADDR: int  # 195
DALVIK_ADD_FLOAT: int  # 158
DALVIK_ADD_FLOAT_2ADDR: int  # 190
DALVIK_ADD_INT: int  # 136
DALVIK_ADD_INT_2ADDR: int  # 168
DALVIK_ADD_INT_LIT16: int  # 200
DALVIK_ADD_INT_LIT8: int  # 208
DALVIK_ADD_LONG: int  # 147
DALVIK_ADD_LONG_2ADDR: int  # 179
DALVIK_AGET: int  # 63
DALVIK_AGET_BOOLEAN: int  # 66
DALVIK_AGET_BYTE: int  # 67
DALVIK_AGET_CHAR: int  # 68
DALVIK_AGET_OBJECT: int  # 65
DALVIK_AGET_SHORT: int  # 69
DALVIK_AGET_WIDE: int  # 64
DALVIK_AND_INT: int  # 141
DALVIK_AND_INT_2ADDR: int  # 173
DALVIK_AND_INT_LIT16: int  # 205
DALVIK_AND_INT_LIT8: int  # 213
DALVIK_AND_LONG: int  # 152
DALVIK_AND_LONG_2ADDR: int  # 184
DALVIK_APUT: int  # 70
DALVIK_APUT_BOOLEAN: int  # 73
DALVIK_APUT_BYTE: int  # 74
DALVIK_APUT_CHAR: int  # 75
DALVIK_APUT_OBJECT: int  # 72
DALVIK_APUT_SHORT: int  # 76
DALVIK_APUT_WIDE: int  # 71
DALVIK_ARRAY_LENGTH: int  # 34
DALVIK_BREAKPOINT: int  # 228
DALVIK_CHECK_CAST: int  # 32
DALVIK_CMPG_DOUBLE: int  # 49
DALVIK_CMPG_FLOAT: int  # 47
DALVIK_CMPL_DOUBLE: int  # 48
DALVIK_CMPL_FLOAT: int  # 46
DALVIK_CMP_LONG: int  # 50
DALVIK_CONST: int  # 21
DALVIK_CONST_16: int  # 20
DALVIK_CONST_4: int  # 19
DALVIK_CONST_CLASS: int  # 29
DALVIK_CONST_HIGH16: int  # 22
DALVIK_CONST_METHOD_HANDLE: int  # 251
DALVIK_CONST_METHOD_TYPE: int  # 252
DALVIK_CONST_STRING: int  # 27
DALVIK_CONST_STRING_JUMBO: int  # 28
DALVIK_CONST_WIDE: int  # 25
DALVIK_CONST_WIDE_16: int  # 23
DALVIK_CONST_WIDE_32: int  # 24
DALVIK_CONST_WIDE_HIGH16: int  # 26
DALVIK_DIV_DOUBLE: int  # 166
DALVIK_DIV_DOUBLE_2ADDR: int  # 198
DALVIK_DIV_FLOAT: int  # 161
DALVIK_DIV_FLOAT_2ADDR: int  # 193
DALVIK_DIV_INT: int  # 139
DALVIK_DIV_INT_2ADDR: int  # 171
DALVIK_DIV_INT_LIT16: int  # 203
DALVIK_DIV_INT_LIT8: int  # 211
DALVIK_DIV_LONG: int  # 150
DALVIK_DIV_LONG_2ADDR: int  # 182
DALVIK_DOUBLE_TO_FLOAT: int  # 132
DALVIK_DOUBLE_TO_INT: int  # 130
DALVIK_DOUBLE_TO_LONG: int  # 131
DALVIK_EXECUTE_INLINE: int  # 230
DALVIK_EXECUTE_INLINE_RANGE: int  # 231
DALVIK_FILLED_NEW_ARRAY: int  # 37
DALVIK_FILLED_NEW_ARRAY_RANGE: int  # 38
DALVIK_FILL_ARRAY_DATA: int  # 39
DALVIK_FLOAT_TO_DOUBLE: int  # 129
DALVIK_FLOAT_TO_INT: int  # 127
DALVIK_FLOAT_TO_LONG: int  # 128
DALVIK_GOTO: int  # 41
DALVIK_GOTO_16: int  # 42
DALVIK_GOTO_32: int  # 43
DALVIK_IF_EQ: int  # 51
DALVIK_IF_EQZ: int  # 57
DALVIK_IF_GE: int  # 54
DALVIK_IF_GEZ: int  # 60
DALVIK_IF_GT: int  # 55
DALVIK_IF_GTZ: int  # 61
DALVIK_IF_LE: int  # 56
DALVIK_IF_LEZ: int  # 62
DALVIK_IF_LT: int  # 53
DALVIK_IF_LTZ: int  # 59
DALVIK_IF_NE: int  # 52
DALVIK_IF_NEZ: int  # 58
DALVIK_IGET: int  # 77
DALVIK_IGET_BOOLEAN: int  # 80
DALVIK_IGET_BYTE: int  # 81
DALVIK_IGET_CHAR: int  # 82
DALVIK_IGET_OBJECT: int  # 79
DALVIK_IGET_OBJECT_QUICK: int  # 236
DALVIK_IGET_OBJECT_VOLATILE: int  # 223
DALVIK_IGET_QUICK: int  # 234
DALVIK_IGET_SHORT: int  # 83
DALVIK_IGET_VOLATILE: int  # 219
DALVIK_IGET_WIDE: int  # 78
DALVIK_IGET_WIDE_QUICK: int  # 235
DALVIK_IGET_WIDE_VOLATILE: int  # 224
DALVIK_INSTANCE_OF: int  # 33
DALVIK_INT_TO_BYTE: int  # 133
DALVIK_INT_TO_CHAR: int  # 134
DALVIK_INT_TO_DOUBLE: int  # 123
DALVIK_INT_TO_FLOAT: int  # 122
DALVIK_INT_TO_LONG: int  # 121
DALVIK_INT_TO_SHORT: int  # 135
DALVIK_INVOKE_CUSTOM: int  # 249
DALVIK_INVOKE_CUSTOM_RANGE: int  # 250
DALVIK_INVOKE_DIRECT: int  # 107
DALVIK_INVOKE_DIRECT_EMPTY: int  # 232
DALVIK_INVOKE_DIRECT_RANGE: int  # 112
DALVIK_INVOKE_INTERFACE: int  # 109
DALVIK_INVOKE_INTERFACE_RANGE: int  # 114
DALVIK_INVOKE_POLYMORPHIC: int  # 247
DALVIK_INVOKE_POLYMORPHIC_RANGE: int  # 248
DALVIK_INVOKE_STATIC: int  # 108
DALVIK_INVOKE_STATIC_RANGE: int  # 113
DALVIK_INVOKE_SUPER: int  # 106
DALVIK_INVOKE_SUPER_QUICK: int  # 242
DALVIK_INVOKE_SUPER_QUICK_RANGE: int  # 243
DALVIK_INVOKE_SUPER_RANGE: int  # 111
DALVIK_INVOKE_VIRTUAL: int  # 105
DALVIK_INVOKE_VIRTUAL_QUICK: int  # 240
DALVIK_INVOKE_VIRTUAL_QUICK_RANGE: int  # 241
DALVIK_INVOKE_VIRTUAL_RANGE: int  # 110
DALVIK_IPUT: int  # 84
DALVIK_IPUT_BOOLEAN: int  # 87
DALVIK_IPUT_BYTE: int  # 88
DALVIK_IPUT_CHAR: int  # 89
DALVIK_IPUT_OBJECT: int  # 86
DALVIK_IPUT_OBJECT_QUICK: int  # 239
DALVIK_IPUT_OBJECT_VOLATILE: int  # 244
DALVIK_IPUT_QUICK: int  # 237
DALVIK_IPUT_SHORT: int  # 90
DALVIK_IPUT_VOLATILE: int  # 220
DALVIK_IPUT_WIDE: int  # 85
DALVIK_IPUT_WIDE_QUICK: int  # 238
DALVIK_IPUT_WIDE_VOLATILE: int  # 225
DALVIK_LAST: int  # 253
DALVIK_LONG_TO_DOUBLE: int  # 126
DALVIK_LONG_TO_FLOAT: int  # 125
DALVIK_LONG_TO_INT: int  # 124
DALVIK_MONITOR_ENTER: int  # 30
DALVIK_MONITOR_EXIT: int  # 31
DALVIK_MOVE: int  # 2
DALVIK_MOVE_16: int  # 4
DALVIK_MOVE_EXCEPTION: int  # 14
DALVIK_MOVE_FROM16: int  # 3
DALVIK_MOVE_OBJECT: int  # 8
DALVIK_MOVE_OBJECT_16: int  # 10
DALVIK_MOVE_OBJECT_FROM16: int  # 9
DALVIK_MOVE_RESULT: int  # 11
DALVIK_MOVE_RESULT_OBJECT: int  # 13
DALVIK_MOVE_RESULT_WIDE: int  # 12
DALVIK_MOVE_WIDE: int  # 5
DALVIK_MOVE_WIDE_16: int  # 7
DALVIK_MOVE_WIDE_FROM16: int  # 6
DALVIK_MUL_DOUBLE: int  # 165
DALVIK_MUL_DOUBLE_2ADDR: int  # 197
DALVIK_MUL_FLOAT: int  # 160
DALVIK_MUL_FLOAT_2ADDR: int  # 192
DALVIK_MUL_INT: int  # 138
DALVIK_MUL_INT_2ADDR: int  # 170
DALVIK_MUL_INT_LIT16: int  # 202
DALVIK_MUL_INT_LIT8: int  # 210
DALVIK_MUL_LONG: int  # 149
DALVIK_MUL_LONG_2ADDR: int  # 181
DALVIK_NEG_DOUBLE: int  # 120
DALVIK_NEG_FLOAT: int  # 119
DALVIK_NEG_INT: int  # 115
DALVIK_NEG_LONG: int  # 117
DALVIK_NEW_ARRAY: int  # 36
DALVIK_NEW_INSTANCE: int  # 35
DALVIK_NOP: int  # 1
DALVIK_NOT_INT: int  # 116
DALVIK_NOT_LONG: int  # 118
DALVIK_OR_INT: int  # 142
DALVIK_OR_INT_2ADDR: int  # 174
DALVIK_OR_INT_LIT16: int  # 206
DALVIK_OR_INT_LIT8: int  # 214
DALVIK_OR_LONG: int  # 153
DALVIK_OR_LONG_2ADDR: int  # 185
DALVIK_PACKED_SWITCH: int  # 44
DALVIK_REM_DOUBLE: int  # 167
DALVIK_REM_DOUBLE_2ADDR: int  # 199
DALVIK_REM_FLOAT: int  # 162
DALVIK_REM_FLOAT_2ADDR: int  # 194
DALVIK_REM_INT: int  # 140
DALVIK_REM_INT_2ADDR: int  # 172
DALVIK_REM_INT_LIT16: int  # 204
DALVIK_REM_INT_LIT8: int  # 212
DALVIK_REM_LONG: int  # 151
DALVIK_REM_LONG_2ADDR: int  # 183
DALVIK_RETURN: int  # 16
DALVIK_RETURN_OBJECT: int  # 18
DALVIK_RETURN_VOID: int  # 15
DALVIK_RETURN_VOID_BARRIER: int  # 233
DALVIK_RETURN_WIDE: int  # 17
DALVIK_RSUB_INT: int  # 201
DALVIK_RSUB_INT_LIT8: int  # 209
DALVIK_SGET: int  # 91
DALVIK_SGET_BOOLEAN: int  # 94
DALVIK_SGET_BYTE: int  # 95
DALVIK_SGET_CHAR: int  # 96
DALVIK_SGET_OBJECT: int  # 93
DALVIK_SGET_OBJECT_VOLATILE: int  # 245
DALVIK_SGET_SHORT: int  # 97
DALVIK_SGET_VOLATILE: int  # 221
DALVIK_SGET_WIDE: int  # 92
DALVIK_SGET_WIDE_VOLATILE: int  # 226
DALVIK_SHL_INT: int  # 144
DALVIK_SHL_INT_2ADDR: int  # 176
DALVIK_SHL_INT_LIT8: int  # 216
DALVIK_SHL_LONG: int  # 155
DALVIK_SHL_LONG_2ADDR: int  # 187
DALVIK_SHR_INT: int  # 145
DALVIK_SHR_INT_2ADDR: int  # 177
DALVIK_SHR_INT_LIT8: int  # 217
DALVIK_SHR_LONG: int  # 156
DALVIK_SHR_LONG_2ADDR: int  # 188
DALVIK_SPARSE_SWITCH: int  # 45
DALVIK_SPUT: int  # 98
DALVIK_SPUT_BOOLEAN: int  # 101
DALVIK_SPUT_BYTE: int  # 102
DALVIK_SPUT_CHAR: int  # 103
DALVIK_SPUT_OBJECT: int  # 100
DALVIK_SPUT_OBJECT_VOLATILE: int  # 246
DALVIK_SPUT_SHORT: int  # 104
DALVIK_SPUT_VOLATILE: int  # 222
DALVIK_SPUT_WIDE: int  # 99
DALVIK_SPUT_WIDE_VOLATILE: int  # 227
DALVIK_SUB_DOUBLE: int  # 164
DALVIK_SUB_DOUBLE_2ADDR: int  # 196
DALVIK_SUB_FLOAT: int  # 159
DALVIK_SUB_FLOAT_2ADDR: int  # 191
DALVIK_SUB_INT: int  # 137
DALVIK_SUB_INT_2ADDR: int  # 169
DALVIK_SUB_LONG: int  # 148
DALVIK_SUB_LONG_2ADDR: int  # 180
DALVIK_THROW: int  # 40
DALVIK_THROW_VERIFICATION_ERROR: int  # 229
DALVIK_UNUSED: int  # 0
DALVIK_USHR_INT: int  # 146
DALVIK_USHR_INT_2ADDR: int  # 178
DALVIK_USHR_INT_LIT8: int  # 218
DALVIK_USHR_LONG: int  # 157
DALVIK_USHR_LONG_2ADDR: int  # 189
DALVIK_XOR_INT: int  # 143
DALVIK_XOR_INT_2ADDR: int  # 175
DALVIK_XOR_INT_LIT16: int  # 207
DALVIK_XOR_INT_LIT8: int  # 215
DALVIK_XOR_LONG: int  # 154
DALVIK_XOR_LONG_2ADDR: int  # 186
DSP56_abs: int  # 1
DSP56_adc: int  # 2
DSP56_add: int  # 3
DSP56_addl: int  # 4
DSP56_addr: int  # 5
DSP56_and: int  # 6
DSP56_andi: int  # 7
DSP56_asl: int  # 8
DSP56_asl4: int  # 9
DSP56_asr: int  # 10
DSP56_asr16: int  # 12
DSP56_asr4: int  # 11
DSP56_bcc: int  # 18
DSP56_bchg: int  # 19
DSP56_bclr: int  # 20
DSP56_bfchg: int  # 13
DSP56_bfclr: int  # 14
DSP56_bfset: int  # 15
DSP56_bftsth: int  # 16
DSP56_bftstl: int  # 17
DSP56_bra: int  # 21
DSP56_brclr: int  # 22
DSP56_brkcc: int  # 23
DSP56_brset: int  # 24
DSP56_bscc: int  # 25
DSP56_bsclr: int  # 26
DSP56_bset: int  # 27
DSP56_bsr: int  # 28
DSP56_bsset: int  # 29
DSP56_btst: int  # 30
DSP56_chkaau: int  # 31
DSP56_clb: int  # 32
DSP56_clr: int  # 33
DSP56_clr24: int  # 34
DSP56_cmp: int  # 35
DSP56_cmpm: int  # 36
DSP56_cmpu: int  # 37
DSP56_debug: int  # 38
DSP56_debugcc: int  # 39
DSP56_dec: int  # 40
DSP56_dec24: int  # 41
DSP56_div: int  # 42
DSP56_dmac: int  # 43
DSP56_do: int  # 44
DSP56_do_f: int  # 45
DSP56_dor: int  # 46
DSP56_dor_f: int  # 47
DSP56_enddo: int  # 48
DSP56_eor: int  # 49
DSP56_ext: int  # 52
DSP56_extract: int  # 50
DSP56_extractu: int  # 51
DSP56_ill: int  # 53
DSP56_imac: int  # 54
DSP56_impy: int  # 55
DSP56_inc: int  # 56
DSP56_inc24: int  # 57
DSP56_insert: int  # 58
DSP56_jcc: int  # 59
DSP56_jclr: int  # 60
DSP56_jmp: int  # 61
DSP56_jscc: int  # 62
DSP56_jsclr: int  # 63
DSP56_jset: int  # 64
DSP56_jsr: int  # 65
DSP56_jsset: int  # 66
DSP56_last: int  # 133
DSP56_lea: int  # 71
DSP56_lra: int  # 67
DSP56_lsl: int  # 68
DSP56_lsr: int  # 69
DSP56_lua: int  # 70
DSP56_mac: int  # 72
DSP56_mac_s_u: int  # 74
DSP56_maci: int  # 73
DSP56_macr: int  # 75
DSP56_macri: int  # 76
DSP56_max: int  # 77
DSP56_maxm: int  # 78
DSP56_merge: int  # 79
DSP56_move: int  # 80
DSP56_movec: int  # 81
DSP56_movei: int  # 82
DSP56_movem: int  # 83
DSP56_movep: int  # 84
DSP56_moves: int  # 85
DSP56_mpy: int  # 86
DSP56_mpy_s_u: int  # 88
DSP56_mpyi: int  # 87
DSP56_mpyr: int  # 89
DSP56_mpyri: int  # 90
DSP56_neg: int  # 91
DSP56_negc: int  # 92
DSP56_nop: int  # 93
DSP56_norm: int  # 94
DSP56_normf: int  # 95
DSP56_not: int  # 96
DSP56_null: int  # 0
DSP56_or: int  # 97
DSP56_ori: int  # 98
DSP56_pflush: int  # 99
DSP56_pflushun: int  # 100
DSP56_pfree: int  # 101
DSP56_plock: int  # 102
DSP56_plockr: int  # 103
DSP56_pmov: int  # 132
DSP56_punlock: int  # 104
DSP56_punlockr: int  # 105
DSP56_rep: int  # 106
DSP56_repcc: int  # 107
DSP56_reset: int  # 108
DSP56_rnd: int  # 109
DSP56_rol: int  # 110
DSP56_ror: int  # 111
DSP56_rti: int  # 112
DSP56_rts: int  # 113
DSP56_sbc: int  # 114
DSP56_stop: int  # 115
DSP56_sub: int  # 116
DSP56_subl: int  # 117
DSP56_subr: int  # 118
DSP56_swap: int  # 119
DSP56_swi: int  # 131
DSP56_tcc: int  # 120
DSP56_tfr: int  # 121
DSP56_tfr2: int  # 122
DSP56_tfr3: int  # 123
DSP56_trap: int  # 124
DSP56_trapcc: int  # 125
DSP56_tst: int  # 126
DSP56_tst2: int  # 127
DSP56_vsl: int  # 128
DSP56_wait: int  # 129
DSP56_zero: int  # 130
DSP96_abs: int  # 1
DSP96_add: int  # 2
DSP96_addc: int  # 3
DSP96_and: int  # 4
DSP96_andc: int  # 5
DSP96_andi: int  # 6
DSP96_asl: int  # 7
DSP96_asr: int  # 8
DSP96_bcc: int  # 9
DSP96_bccd: int  # 10
DSP96_bchg: int  # 11
DSP96_bclr: int  # 12
DSP96_bfind: int  # 13
DSP96_bra: int  # 14
DSP96_brclr: int  # 15
DSP96_brset: int  # 16
DSP96_bscc: int  # 17
DSP96_bsccd: int  # 18
DSP96_bsclr: int  # 19
DSP96_bset: int  # 20
DSP96_bsr: int  # 21
DSP96_bsrd: int  # 22
DSP96_bsset: int  # 23
DSP96_btst: int  # 24
DSP96_clr: int  # 25
DSP96_cmp: int  # 26
DSP96_cmpg: int  # 27
DSP96_debugcc: int  # 28
DSP96_dec: int  # 29
DSP96_do: int  # 30
DSP96_dor: int  # 31
DSP96_enddo: int  # 32
DSP96_eor: int  # 33
DSP96_ext: int  # 34
DSP96_extb: int  # 35
DSP96_fabs: int  # 36
DSP96_fadd: int  # 37
DSP96_faddsub: int  # 38
DSP96_fbcc: int  # 39
DSP96_fbccd: int  # 40
DSP96_fbscc: int  # 41
DSP96_fbsccd: int  # 42
DSP96_fclr: int  # 43
DSP96_fcmp: int  # 44
DSP96_fcmpg: int  # 45
DSP96_fcmpm: int  # 46
DSP96_fcopys: int  # 47
DSP96_fdebugcc: int  # 48
DSP96_fgetman: int  # 49
DSP96_fint: int  # 50
DSP96_fjcc: int  # 51
DSP96_fjccd: int  # 52
DSP96_fjscc: int  # 53
DSP96_fjsccd: int  # 54
DSP96_float: int  # 55
DSP96_floatu: int  # 56
DSP96_floor: int  # 57
DSP96_fmove: int  # 58
DSP96_fmpy: int  # 62
DSP96_fmpyfadd: int  # 59
DSP96_fmpyfaddsub: int  # 60
DSP96_fmpyfsub: int  # 61
DSP96_fneg: int  # 63
DSP96_fscale: int  # 64
DSP96_fseedd: int  # 65
DSP96_fseedr: int  # 66
DSP96_fsub: int  # 67
DSP96_ftfr: int  # 68
DSP96_ftrapcc: int  # 69
DSP96_ftst: int  # 70
DSP96_getexp: int  # 71
DSP96_illegal: int  # 72
DSP96_inc: int  # 73
DSP96_int: int  # 74
DSP96_intrz: int  # 75
DSP96_intu: int  # 76
DSP96_inturz: int  # 77
DSP96_jcc: int  # 78
DSP96_jccd: int  # 79
DSP96_jclr: int  # 80
DSP96_join: int  # 81
DSP96_joinb: int  # 82
DSP96_jscc: int  # 83
DSP96_jsccd: int  # 84
DSP96_jsclr: int  # 85
DSP96_jset: int  # 86
DSP96_jsset: int  # 87
DSP96_last: int  # 125
DSP96_lea: int  # 88
DSP96_lra: int  # 89
DSP96_lsl: int  # 90
DSP96_lsr: int  # 91
DSP96_move: int  # 92
DSP96_movec: int  # 93
DSP96_movei: int  # 94
DSP96_movem: int  # 95
DSP96_movep: int  # 96
DSP96_moves: int  # 97
DSP96_moveta: int  # 98
DSP96_mpys: int  # 99
DSP96_mpyu: int  # 100
DSP96_neg: int  # 101
DSP96_negc: int  # 102
DSP96_nop: int  # 103
DSP96_not: int  # 104
DSP96_null: int  # 0
DSP96_or: int  # 105
DSP96_orc: int  # 106
DSP96_ori: int  # 107
DSP96_rep: int  # 108
DSP96_reset: int  # 109
DSP96_rol: int  # 110
DSP96_ror: int  # 111
DSP96_rti: int  # 112
DSP96_rtr: int  # 113
DSP96_rts: int  # 114
DSP96_setw: int  # 115
DSP96_split: int  # 116
DSP96_splitb: int  # 117
DSP96_stop: int  # 118
DSP96_sub: int  # 119
DSP96_subc: int  # 120
DSP96_tfr: int  # 121
DSP96_trapcc: int  # 122
DSP96_tst: int  # 123
DSP96_wait: int  # 124
F2MC_adb: int  # 120
F2MC_add: int  # 8
F2MC_addc1: int  # 9
F2MC_addc2: int  # 10
F2MC_addcw: int  # 18
F2MC_adddc: int  # 11
F2MC_addl: int  # 22
F2MC_addsp: int  # 118
F2MC_addw1: int  # 16
F2MC_addw2: int  # 17
F2MC_and: int  # 49
F2MC_andl: int  # 60
F2MC_andw1: int  # 53
F2MC_andw2: int  # 54
F2MC_asr: int  # 68
F2MC_asrl: int  # 77
F2MC_asrw1: int  # 71
F2MC_asrw2: int  # 72
F2MC_bbc: int  # 129
F2MC_bbc16: int  # 170
F2MC_bbs: int  # 130
F2MC_bbs16: int  # 171
F2MC_bc: int  # 82
F2MC_bc16: int  # 152
F2MC_bge: int  # 91
F2MC_bge16: int  # 161
F2MC_bgt: int  # 93
F2MC_bgt16: int  # 163
F2MC_bhi: int  # 95
F2MC_bhi16: int  # 165
F2MC_ble: int  # 92
F2MC_ble16: int  # 162
F2MC_bls: int  # 94
F2MC_bls16: int  # 164
F2MC_blt: int  # 90
F2MC_blt16: int  # 160
F2MC_bn: int  # 84
F2MC_bn16: int  # 154
F2MC_bnc: int  # 83
F2MC_bnc16: int  # 153
F2MC_bnt: int  # 89
F2MC_bnt16: int  # 159
F2MC_bnv: int  # 87
F2MC_bnv16: int  # 157
F2MC_bnz: int  # 81
F2MC_bnz16: int  # 151
F2MC_bp: int  # 85
F2MC_bp16: int  # 155
F2MC_bra: int  # 96
F2MC_bt: int  # 88
F2MC_bt16: int  # 158
F2MC_bv: int  # 86
F2MC_bv16: int  # 156
F2MC_bz: int  # 80
F2MC_bz16: int  # 150
F2MC_call: int  # 99
F2MC_callp: int  # 101
F2MC_callv: int  # 100
F2MC_cbne: int  # 102
F2MC_cbne16: int  # 166
F2MC_clrb: int  # 128
F2MC_cmp1: int  # 30
F2MC_cmp2: int  # 31
F2MC_cmpl: int  # 34
F2MC_cmpw1: int  # 32
F2MC_cmpw2: int  # 33
F2MC_cmr: int  # 125
F2MC_cwbne: int  # 103
F2MC_cwbne16: int  # 167
F2MC_dbnz: int  # 104
F2MC_dbnz16: int  # 168
F2MC_dec: int  # 25
F2MC_decl: int  # 29
F2MC_decw: int  # 27
F2MC_div1: int  # 42
F2MC_div2: int  # 43
F2MC_divu1: int  # 35
F2MC_divu2: int  # 36
F2MC_divuw: int  # 37
F2MC_divw: int  # 44
F2MC_dtb: int  # 121
F2MC_dwbnz: int  # 105
F2MC_dwbnz16: int  # 169
F2MC_ext: int  # 136
F2MC_extw: int  # 137
F2MC_filsi: int  # 144
F2MC_filswi: int  # 149
F2MC_inc: int  # 24
F2MC_incl: int  # 28
F2MC_incw: int  # 26
F2MC_int: int  # 106
F2MC_int9: int  # 108
F2MC_intp: int  # 107
F2MC_jctx: int  # 116
F2MC_jmp: int  # 97
F2MC_jmpp: int  # 98
F2MC_last: int  # 173
F2MC_link: int  # 110
F2MC_lsl: int  # 70
F2MC_lsll: int  # 79
F2MC_lslw1: int  # 75
F2MC_lslw2: int  # 76
F2MC_lsr: int  # 69
F2MC_lsrl: int  # 78
F2MC_lsrw1: int  # 73
F2MC_lsrw2: int  # 74
F2MC_mov: int  # 1
F2MC_movb: int  # 126
F2MC_movea: int  # 117
F2MC_movl: int  # 7
F2MC_movn: int  # 2
F2MC_movsd: int  # 141
F2MC_movsi: int  # 140
F2MC_movswd: int  # 146
F2MC_movswi: int  # 145
F2MC_movw: int  # 5
F2MC_movx: int  # 3
F2MC_mul1: int  # 45
F2MC_mul2: int  # 46
F2MC_mulu1: int  # 38
F2MC_mulu2: int  # 39
F2MC_muluw1: int  # 40
F2MC_muluw2: int  # 41
F2MC_mulw1: int  # 47
F2MC_mulw2: int  # 48
F2MC_ncc: int  # 124
F2MC_neg: int  # 63
F2MC_negw: int  # 64
F2MC_nop: int  # 119
F2MC_not: int  # 52
F2MC_notw: int  # 59
F2MC_nrml: int  # 65
F2MC_null: int  # 0
F2MC_or: int  # 50
F2MC_orl: int  # 61
F2MC_orw1: int  # 55
F2MC_orw2: int  # 56
F2MC_pcb: int  # 122
F2MC_popw: int  # 115
F2MC_pushw: int  # 114
F2MC_ret: int  # 112
F2MC_reti: int  # 109
F2MC_retp: int  # 113
F2MC_rolc: int  # 67
F2MC_rorc: int  # 66
F2MC_sbbs: int  # 131
F2MC_sbbs16: int  # 172
F2MC_sceqd: int  # 143
F2MC_sceqi: int  # 142
F2MC_scweqd: int  # 148
F2MC_scweqi: int  # 147
F2MC_setb: int  # 127
F2MC_spb: int  # 123
F2MC_sub: int  # 12
F2MC_subc1: int  # 13
F2MC_subc2: int  # 14
F2MC_subcw: int  # 21
F2MC_subdc: int  # 15
F2MC_subl: int  # 23
F2MC_subw1: int  # 19
F2MC_subw2: int  # 20
F2MC_swap: int  # 134
F2MC_swapw: int  # 135
F2MC_unlink: int  # 111
F2MC_wbtc: int  # 133
F2MC_wbts: int  # 132
F2MC_xch: int  # 4
F2MC_xchw: int  # 6
F2MC_xor: int  # 51
F2MC_xorl: int  # 62
F2MC_xorw1: int  # 57
F2MC_xorw2: int  # 58
F2MC_zext: int  # 138
F2MC_zextw: int  # 139
GB_ldh: int  # 250
GB_stop: int  # 251
H8500_add_g: int  # 13
H8500_add_q: int  # 14
H8500_adds: int  # 16
H8500_addx: int  # 18
H8500_and: int  # 33
H8500_andc: int  # 83
H8500_bcc: int  # 53
H8500_bclr: int  # 46
H8500_bcs: int  # 54
H8500_beq: int  # 56
H8500_bge: int  # 61
H8500_bgt: int  # 63
H8500_bhi: int  # 51
H8500_ble: int  # 64
H8500_bls: int  # 52
H8500_blt: int  # 62
H8500_bmi: int  # 60
H8500_bne: int  # 55
H8500_bnot: int  # 47
H8500_bpl: int  # 59
H8500_bpt: int  # 87
H8500_bra: int  # 49
H8500_brn: int  # 50
H8500_bset: int  # 45
H8500_bsr: int  # 67
H8500_btst: int  # 48
H8500_bvc: int  # 57
H8500_bvs: int  # 58
H8500_clr: int  # 31
H8500_cmp_e: int  # 25
H8500_cmp_g: int  # 24
H8500_cmp_i: int  # 26
H8500_dadd: int  # 20
H8500_divxu: int  # 23
H8500_dsub: int  # 21
H8500_exts: int  # 27
H8500_extu: int  # 28
H8500_jmp: int  # 65
H8500_jsr: int  # 68
H8500_last: int  # 88
H8500_ldc: int  # 81
H8500_ldm: int  # 7
H8500_link: int  # 78
H8500_mov_e: int  # 2
H8500_mov_f: int  # 4
H8500_mov_g: int  # 1
H8500_mov_i: int  # 3
H8500_mov_l: int  # 5
H8500_mov_s: int  # 6
H8500_movfpe: int  # 12
H8500_movtpe: int  # 11
H8500_mulxu: int  # 22
H8500_neg: int  # 30
H8500_nop: int  # 86
H8500_not: int  # 36
H8500_null: int  # 0
H8500_or: int  # 34
H8500_orc: int  # 84
H8500_pjmp: int  # 66
H8500_pjsr: int  # 69
H8500_prtd: int  # 73
H8500_prts: int  # 71
H8500_rotl: int  # 41
H8500_rotr: int  # 42
H8500_rotxl: int  # 43
H8500_rotxr: int  # 44
H8500_rtd: int  # 72
H8500_rte: int  # 77
H8500_rts: int  # 70
H8500_scb: int  # 74
H8500_shal: int  # 37
H8500_shar: int  # 38
H8500_shll: int  # 39
H8500_shlr: int  # 40
H8500_sleep: int  # 80
H8500_stc: int  # 82
H8500_stm: int  # 8
H8500_sub: int  # 15
H8500_subs: int  # 17
H8500_subx: int  # 19
H8500_swap: int  # 10
H8500_tas: int  # 32
H8500_trap_vs: int  # 76
H8500_trapa: int  # 75
H8500_tst: int  # 29
H8500_unlk: int  # 79
H8500_xch: int  # 9
H8500_xor: int  # 35
H8500_xorc: int  # 85
H8_add: int  # 1
H8_adds: int  # 2
H8_addx: int  # 3
H8_and: int  # 4
H8_andc: int  # 5
H8_band: int  # 6
H8_bcc: int  # 11
H8_bclr: int  # 23
H8_bclreq: int  # 98
H8_bclrne: int  # 97
H8_bcs: int  # 12
H8_beq: int  # 14
H8_bfld: int  # 101
H8_bfst: int  # 102
H8_bge: int  # 19
H8_bgt: int  # 21
H8_bhi: int  # 9
H8_biand: int  # 24
H8_bild: int  # 25
H8_bior: int  # 26
H8_bist: int  # 27
H8_bistz: int  # 100
H8_bixor: int  # 28
H8_bld: int  # 29
H8_ble: int  # 22
H8_bls: int  # 10
H8_blt: int  # 20
H8_bmi: int  # 18
H8_bne: int  # 13
H8_bnot: int  # 30
H8_bor: int  # 31
H8_bpl: int  # 17
H8_bra: int  # 7
H8_brabc: int  # 109
H8_brabs: int  # 110
H8_bras: int  # 91
H8_brn: int  # 8
H8_bset: int  # 32
H8_bseteq: int  # 96
H8_bsetne: int  # 95
H8_bsr: int  # 33
H8_bsrbc: int  # 111
H8_bsrbs: int  # 112
H8_bst: int  # 34
H8_bstz: int  # 99
H8_btst: int  # 35
H8_bvc: int  # 15
H8_bvs: int  # 16
H8_bxor: int  # 36
H8_clrmac: int  # 37
H8_cmp: int  # 38
H8_daa: int  # 39
H8_das: int  # 40
H8_dec: int  # 41
H8_divs: int  # 104
H8_divu: int  # 106
H8_divxs: int  # 42
H8_divxu: int  # 43
H8_eepmov: int  # 44
H8_exts: int  # 45
H8_extu: int  # 46
H8_inc: int  # 47
H8_jmp: int  # 48
H8_jsr: int  # 49
H8_last: int  # 113
H8_ldc: int  # 50
H8_ldm: int  # 51
H8_ldmac: int  # 52
H8_mac: int  # 53
H8_mov: int  # 54
H8_movab: int  # 92
H8_moval: int  # 94
H8_movaw: int  # 93
H8_movfpe: int  # 55
H8_movmd: int  # 89
H8_movsd: int  # 90
H8_movtpe: int  # 56
H8_muls: int  # 103
H8_mulsu: int  # 107
H8_mulu: int  # 105
H8_muluu: int  # 108
H8_mulxs: int  # 57
H8_mulxu: int  # 58
H8_neg: int  # 59
H8_nop: int  # 60
H8_not: int  # 61
H8_null: int  # 0
H8_or: int  # 62
H8_orc: int  # 63
H8_pop: int  # 64
H8_push: int  # 65
H8_rotl: int  # 66
H8_rotr: int  # 67
H8_rotxl: int  # 68
H8_rotxr: int  # 69
H8_rte: int  # 70
H8_rtel: int  # 87
H8_rts: int  # 71
H8_rtsl: int  # 88
H8_shal: int  # 72
H8_shar: int  # 73
H8_shll: int  # 74
H8_shlr: int  # 75
H8_sleep: int  # 76
H8_stc: int  # 77
H8_stm: int  # 78
H8_stmac: int  # 79
H8_sub: int  # 80
H8_subs: int  # 81
H8_subx: int  # 82
H8_tas: int  # 83
H8_trapa: int  # 84
H8_xor: int  # 85
H8_xorc: int  # 86
HD_in0: int  # 139
HD_mlt: int  # 140
HD_otdm: int  # 143
HD_otdmr: int  # 144
HD_otim: int  # 141
HD_otimr: int  # 142
HD_out0: int  # 145
HD_slp: int  # 146
HD_tst: int  # 147
HD_tstio: int  # 148
HPPA_add: int  # 1
HPPA_addb: int  # 2
HPPA_addi: int  # 3
HPPA_addib: int  # 4
HPPA_addil: int  # 5
HPPA_and: int  # 6
HPPA_andcm: int  # 7
HPPA_b: int  # 8
HPPA_bb: int  # 9
HPPA_be: int  # 10
HPPA_blr: int  # 11
HPPA_break: int  # 12
HPPA_bv: int  # 13
HPPA_bve: int  # 14
HPPA_call: int  # 134
HPPA_cldd: int  # 15
HPPA_cldw: int  # 16
HPPA_clrbts: int  # 17
HPPA_cmpb: int  # 18
HPPA_cmpclr: int  # 19
HPPA_cmpib: int  # 20
HPPA_cmpiclr: int  # 21
HPPA_copr: int  # 22
HPPA_copy: int  # 141
HPPA_cstd: int  # 23
HPPA_cstw: int  # 24
HPPA_dcor: int  # 25
HPPA_depd: int  # 26
HPPA_depdi: int  # 27
HPPA_depw: int  # 28
HPPA_depwi: int  # 29
HPPA_diag: int  # 30
HPPA_ds: int  # 31
HPPA_extrd: int  # 32
HPPA_extrw: int  # 33
HPPA_fabs: int  # 108
HPPA_fadd: int  # 109
HPPA_fcmp: int  # 110
HPPA_fcnv: int  # 111
HPPA_fcpy: int  # 112
HPPA_fdc: int  # 34
HPPA_fdce: int  # 35
HPPA_fdiv: int  # 113
HPPA_fic: int  # 36
HPPA_fice: int  # 37
HPPA_fid: int  # 114
HPPA_fldd: int  # 115
HPPA_fldw: int  # 116
HPPA_fmpy: int  # 117
HPPA_fmpyadd: int  # 118
HPPA_fmpyfadd: int  # 119
HPPA_fmpynfadd: int  # 120
HPPA_fmpysub: int  # 121
HPPA_fneg: int  # 122
HPPA_fnegabs: int  # 123
HPPA_frem: int  # 124
HPPA_frnd: int  # 125
HPPA_fsqrt: int  # 126
HPPA_fstd: int  # 127
HPPA_fstw: int  # 128
HPPA_fsub: int  # 129
HPPA_ftest: int  # 130
HPPA_hadd: int  # 38
HPPA_havg: int  # 39
HPPA_hshl: int  # 40
HPPA_hshladd: int  # 41
HPPA_hshr: int  # 42
HPPA_hshradd: int  # 43
HPPA_hsub: int  # 44
HPPA_idtlbt: int  # 45
HPPA_iitlbt: int  # 46
HPPA_last: int  # 144
HPPA_lci: int  # 47
HPPA_ldb: int  # 48
HPPA_ldcd: int  # 49
HPPA_ldcw: int  # 50
HPPA_ldd: int  # 51
HPPA_ldda: int  # 52
HPPA_ldh: int  # 53
HPPA_ldi: int  # 140
HPPA_ldil: int  # 54
HPPA_ldo: int  # 55
HPPA_ldsid: int  # 56
HPPA_ldw: int  # 57
HPPA_ldwa: int  # 58
HPPA_lpa: int  # 59
HPPA_mfctl: int  # 60
HPPA_mfia: int  # 61
HPPA_mfsp: int  # 62
HPPA_mixh: int  # 63
HPPA_mixw: int  # 64
HPPA_movb: int  # 65
HPPA_movib: int  # 66
HPPA_mtctl: int  # 67
HPPA_mtsar: int  # 142
HPPA_mtsarcm: int  # 68
HPPA_mtsm: int  # 69
HPPA_mtsp: int  # 70
HPPA_nop: int  # 143
HPPA_null: int  # 0
HPPA_or: int  # 71
HPPA_pdc: int  # 72
HPPA_pdtlb: int  # 73
HPPA_pdtlbe: int  # 74
HPPA_permh: int  # 75
HPPA_pitlb: int  # 76
HPPA_pitlbe: int  # 77
HPPA_pmdis: int  # 132
HPPA_pmenb: int  # 133
HPPA_popbts: int  # 78
HPPA_probe: int  # 79
HPPA_probei: int  # 80
HPPA_pushbts: int  # 81
HPPA_pushnom: int  # 82
HPPA_ret: int  # 135
HPPA_rfi: int  # 83
HPPA_rsm: int  # 84
HPPA_shladd: int  # 85
HPPA_shld: int  # 136
HPPA_shlw: int  # 137
HPPA_shrd: int  # 138
HPPA_shrpd: int  # 86
HPPA_shrpw: int  # 87
HPPA_shrw: int  # 139
HPPA_spop0: int  # 88
HPPA_spop1: int  # 89
HPPA_spop2: int  # 90
HPPA_spop3: int  # 91
HPPA_ssm: int  # 92
HPPA_stb: int  # 93
HPPA_stby: int  # 94
HPPA_std: int  # 95
HPPA_stda: int  # 96
HPPA_stdby: int  # 97
HPPA_sth: int  # 98
HPPA_stw: int  # 99
HPPA_stwa: int  # 100
HPPA_sub: int  # 101
HPPA_subi: int  # 102
HPPA_sync: int  # 103
HPPA_syncdma: int  # 104
HPPA_uaddcm: int  # 105
HPPA_uxor: int  # 106
HPPA_xmpyu: int  # 131
HPPA_xor: int  # 107
I196_add2: int  # 1
I196_add3: int  # 2
I196_addb2: int  # 3
I196_addb3: int  # 4
I196_addc: int  # 5
I196_addcb: int  # 6
I196_and2: int  # 7
I196_and3: int  # 8
I196_andb2: int  # 9
I196_andb3: int  # 10
I196_bmov: int  # 11
I196_bmovi: int  # 12
I196_br: int  # 13
I196_clr: int  # 14
I196_clrb: int  # 15
I196_clrc: int  # 16
I196_clrvt: int  # 17
I196_cmp: int  # 18
I196_cmpb: int  # 19
I196_cmpl: int  # 20
I196_dec: int  # 21
I196_decb: int  # 22
I196_di: int  # 23
I196_div: int  # 24
I196_divb: int  # 25
I196_divu: int  # 26
I196_divub: int  # 27
I196_djnz: int  # 28
I196_djnzw: int  # 29
I196_dpts: int  # 30
I196_ebmovi: int  # 113
I196_ebr: int  # 114
I196_ecall: int  # 115
I196_ei: int  # 31
I196_ejmp: int  # 116
I196_eld: int  # 117
I196_eldb: int  # 118
I196_epts: int  # 32
I196_est: int  # 119
I196_estb: int  # 120
I196_ext: int  # 33
I196_extb: int  # 34
I196_idlpd: int  # 35
I196_inc: int  # 36
I196_incb: int  # 37
I196_jbc: int  # 38
I196_jbs: int  # 39
I196_jc: int  # 40
I196_je: int  # 41
I196_jge: int  # 42
I196_jgt: int  # 43
I196_jh: int  # 44
I196_jle: int  # 45
I196_jlt: int  # 46
I196_jnc: int  # 47
I196_jne: int  # 48
I196_jnh: int  # 49
I196_jnst: int  # 50
I196_jnv: int  # 51
I196_jnvt: int  # 52
I196_jst: int  # 53
I196_jv: int  # 54
I196_jvt: int  # 55
I196_last: int  # 121
I196_lcall: int  # 56
I196_ld: int  # 57
I196_ldb: int  # 58
I196_ldbse: int  # 59
I196_ldbze: int  # 60
I196_ljmp: int  # 61
I196_mul2: int  # 62
I196_mul3: int  # 63
I196_mulb2: int  # 64
I196_mulb3: int  # 65
I196_mulu2: int  # 66
I196_mulu3: int  # 67
I196_mulub2: int  # 68
I196_mulub3: int  # 69
I196_neg: int  # 70
I196_negb: int  # 71
I196_nop: int  # 72
I196_norml: int  # 73
I196_not: int  # 74
I196_notb: int  # 75
I196_null: int  # 0
I196_or: int  # 76
I196_orb: int  # 77
I196_pop: int  # 78
I196_popa: int  # 79
I196_popf: int  # 80
I196_push: int  # 81
I196_pusha: int  # 82
I196_pushf: int  # 83
I196_ret: int  # 84
I196_rst: int  # 85
I196_scall: int  # 86
I196_setc: int  # 87
I196_shl: int  # 88
I196_shlb: int  # 89
I196_shll: int  # 90
I196_shr: int  # 91
I196_shra: int  # 92
I196_shrab: int  # 93
I196_shral: int  # 94
I196_shrb: int  # 95
I196_shrl: int  # 96
I196_sjmp: int  # 97
I196_skip: int  # 98
I196_st: int  # 99
I196_stb: int  # 100
I196_sub2: int  # 101
I196_sub3: int  # 102
I196_subb2: int  # 103
I196_subb3: int  # 104
I196_subc: int  # 105
I196_subcb: int  # 106
I196_tijmp: int  # 107
I196_trap: int  # 108
I196_xch: int  # 109
I196_xchb: int  # 110
I196_xor: int  # 111
I196_xorb: int  # 112
I51_acall: int  # 1
I51_add: int  # 2
I51_addc: int  # 3
I51_ajmp: int  # 4
I51_anl: int  # 5
I51_cjne: int  # 6
I51_clr: int  # 7
I51_cmp: int  # 64
I51_cpl: int  # 8
I51_da: int  # 9
I51_dec: int  # 10
I51_div: int  # 11
I51_djnz: int  # 12
I51_ecall: int  # 55
I51_ejmp: int  # 54
I51_emov: int  # 65
I51_eret: int  # 56
I51_inc: int  # 13
I51_jb: int  # 14
I51_jbc: int  # 15
I51_jc: int  # 16
I51_je: int  # 51
I51_jg: int  # 48
I51_jle: int  # 47
I51_jmp: int  # 17
I51_jnb: int  # 18
I51_jnc: int  # 19
I51_jne: int  # 52
I51_jnz: int  # 20
I51_jsg: int  # 46
I51_jsge: int  # 50
I51_jsl: int  # 49
I51_jsle: int  # 45
I51_jz: int  # 21
I51_last: int  # 66
I51_lcall: int  # 22
I51_ljmp: int  # 23
I51_mov: int  # 24
I51_movc: int  # 25
I51_movh: int  # 57
I51_movs: int  # 59
I51_movx: int  # 26
I51_movz: int  # 58
I51_mul: int  # 27
I51_nop: int  # 28
I51_null: int  # 0
I51_orl: int  # 29
I51_pop: int  # 30
I51_push: int  # 31
I51_ret: int  # 32
I51_reti: int  # 33
I51_rl: int  # 34
I51_rlc: int  # 35
I51_rr: int  # 36
I51_rrc: int  # 37
I51_setb: int  # 38
I51_sjmp: int  # 39
I51_sll: int  # 62
I51_sra: int  # 61
I51_srl: int  # 60
I51_sub: int  # 63
I51_subb: int  # 40
I51_swap: int  # 41
I51_trap: int  # 53
I51_xch: int  # 42
I51_xchd: int  # 43
I51_xrl: int  # 44
I5_aci: int  # 1
I5_adc: int  # 2
I5_add: int  # 3
I5_adi: int  # 4
I5_ana: int  # 5
I5_ani: int  # 6
I5_arhl: int  # 189
I5_call: int  # 7
I5_cc: int  # 11
I5_cm: int  # 15
I5_cma: int  # 19
I5_cmc: int  # 16
I5_cmp: int  # 17
I5_cnc: int  # 10
I5_cnz: int  # 8
I5_cp: int  # 14
I5_cpe: int  # 13
I5_cpi: int  # 18
I5_cpo: int  # 12
I5_cz: int  # 9
I5_daa: int  # 20
I5_dad: int  # 21
I5_dcr: int  # 22
I5_dcx: int  # 23
I5_di: int  # 24
I5_dsub: int  # 188
I5_ei: int  # 25
I5_halt: int  # 26
I5_in: int  # 27
I5_inr: int  # 28
I5_inx: int  # 29
I5_jc: int  # 34
I5_jm: int  # 38
I5_jmp: int  # 30
I5_jnc: int  # 33
I5_jnx5: int  # 197
I5_jnz: int  # 31
I5_jp: int  # 37
I5_jpe: int  # 36
I5_jpo: int  # 35
I5_jx5: int  # 196
I5_jz: int  # 32
I5_last: int  # 252
I5_lda: int  # 39
I5_ldax: int  # 40
I5_ldhi: int  # 191
I5_ldsi: int  # 192
I5_lhld: int  # 41
I5_lhlx: int  # 194
I5_lxi: int  # 42
I5_mov: int  # 43
I5_mvi: int  # 44
I5_nop: int  # 45
I5_null: int  # 0
I5_ora: int  # 46
I5_ori: int  # 47
I5_out: int  # 48
I5_pchl: int  # 49
I5_pop: int  # 50
I5_push: int  # 51
I5_ral: int  # 61
I5_rar: int  # 63
I5_rc: int  # 56
I5_rdel: int  # 190
I5_ret: int  # 52
I5_rim: int  # 79
I5_rlc: int  # 62
I5_rm: int  # 60
I5_rnc: int  # 55
I5_rnz: int  # 53
I5_rp: int  # 59
I5_rpe: int  # 58
I5_rpo: int  # 57
I5_rrc: int  # 64
I5_rst: int  # 65
I5_rstv: int  # 195
I5_rz: int  # 54
I5_sbb: int  # 66
I5_sbi: int  # 67
I5_shld: int  # 72
I5_shlx: int  # 193
I5_sim: int  # 80
I5_sphl: int  # 69
I5_sta: int  # 70
I5_stax: int  # 71
I5_stc: int  # 68
I5_sub: int  # 74
I5_sui: int  # 73
I5_xchg: int  # 77
I5_xra: int  # 75
I5_xri: int  # 76
I5_xthl: int  # 78
I860_adds: int  # 1
I860_addu: int  # 2
I860_and: int  # 3
I860_andh: int  # 4
I860_andnot: int  # 5
I860_andnoth: int  # 6
I860_bc: int  # 7
I860_bc_t: int  # 8
I860_bla: int  # 9
I860_bnc: int  # 10
I860_bnc_t: int  # 11
I860_br: int  # 12
I860_bri: int  # 13
I860_bte: int  # 14
I860_btne: int  # 15
I860_call: int  # 16
I860_calli: int  # 17
I860_fadd: int  # 18
I860_faddp: int  # 19
I860_faddz: int  # 20
I860_famov: int  # 21
I860_fiadd: int  # 22
I860_fisub: int  # 23
I860_fix: int  # 24
I860_fld: int  # 25
I860_flush: int  # 26
I860_fmlow_dd: int  # 27
I860_fmul: int  # 28
I860_form: int  # 29
I860_frcp: int  # 30
I860_frsqr: int  # 31
I860_fst: int  # 32
I860_fsub: int  # 33
I860_ftrunc: int  # 34
I860_fxfr: int  # 35
I860_fzchkl: int  # 36
I860_fzchks: int  # 37
I860_i2ap1: int  # 86
I860_i2apt: int  # 87
I860_i2as1: int  # 102
I860_i2ast: int  # 103
I860_i2p1: int  # 84
I860_i2pt: int  # 85
I860_i2s1: int  # 100
I860_i2st: int  # 101
I860_ia1p2: int  # 94
I860_ia1s2: int  # 110
I860_iat1p2: int  # 92
I860_iat1s2: int  # 108
I860_introvr: int  # 38
I860_ixfr: int  # 39
I860_last: int  # 142
I860_ld: int  # 41
I860_ld_c: int  # 40
I860_ldint: int  # 42
I860_ldio: int  # 43
I860_lock: int  # 44
I860_m12apm: int  # 89
I860_m12asm: int  # 105
I860_m12tpa: int  # 95
I860_m12tpm: int  # 93
I860_m12tsa: int  # 111
I860_m12tsm: int  # 109
I860_m12ttpa: int  # 91
I860_m12ttsa: int  # 107
I860_mi2mp1: int  # 118
I860_mi2mpt: int  # 119
I860_mi2ms1: int  # 133
I860_mi2mst: int  # 134
I860_mi2p1: int  # 116
I860_mi2pt: int  # 117
I860_mi2s1: int  # 131
I860_mi2st: int  # 132
I860_mim1p2: int  # 126
I860_mim1s2: int  # 141
I860_mimt1p2: int  # 124
I860_mimt1s2: int  # 139
I860_mm12mpm: int  # 121
I860_mm12msm: int  # 136
I860_mm12tpm: int  # 125
I860_mm12tsm: int  # 140
I860_mm12ttpm: int  # 123
I860_mm12ttsm: int  # 138
I860_mr2mp1: int  # 114
I860_mr2mpt: int  # 115
I860_mr2ms1: int  # 129
I860_mr2mst: int  # 130
I860_mr2p1: int  # 112
I860_mr2pt: int  # 113
I860_mr2s1: int  # 127
I860_mr2st: int  # 128
I860_mrm1p2: int  # 122
I860_mrm1s2: int  # 137
I860_mrmt1p2: int  # 120
I860_mrmt1s2: int  # 135
I860_null: int  # 0
I860_or: int  # 45
I860_orh: int  # 46
I860_pfadd: int  # 47
I860_pfaddp: int  # 48
I860_pfaddz: int  # 49
I860_pfamov: int  # 50
I860_pfeq: int  # 51
I860_pfgt: int  # 52
I860_pfiadd: int  # 53
I860_pfisub: int  # 54
I860_pfix: int  # 55
I860_pfld: int  # 56
I860_pfle: int  # 57
I860_pfmul: int  # 58
I860_pfmul3_dd: int  # 59
I860_pform: int  # 60
I860_pfsub: int  # 61
I860_pftrunc: int  # 62
I860_pfzchkl: int  # 63
I860_pfzchks: int  # 64
I860_pst_d: int  # 65
I860_r2ap1: int  # 82
I860_r2apt: int  # 83
I860_r2as1: int  # 98
I860_r2ast: int  # 99
I860_r2p1: int  # 80
I860_r2pt: int  # 81
I860_r2s1: int  # 96
I860_r2st: int  # 97
I860_ra1p2: int  # 90
I860_ra1s2: int  # 106
I860_rat1p2: int  # 88
I860_rat1s2: int  # 104
I860_scyc: int  # 66
I860_shl: int  # 67
I860_shr: int  # 68
I860_shra: int  # 69
I860_shrd: int  # 70
I860_st: int  # 72
I860_st_c: int  # 71
I860_stio: int  # 73
I860_subs: int  # 74
I860_subu: int  # 75
I860_trap: int  # 76
I860_unlock: int  # 77
I860_xor: int  # 78
I860_xorh: int  # 79
I960_addc: int  # 1
I960_addi: int  # 2
I960_addie: int  # 180
I960_addig: int  # 175
I960_addige: int  # 185
I960_addil: int  # 190
I960_addile: int  # 200
I960_addine: int  # 195
I960_addino: int  # 170
I960_addio: int  # 205
I960_addo: int  # 3
I960_addoe: int  # 179
I960_addog: int  # 174
I960_addoge: int  # 184
I960_addol: int  # 189
I960_addole: int  # 199
I960_addone: int  # 194
I960_addono: int  # 169
I960_addoo: int  # 204
I960_alterbit: int  # 4
I960_and: int  # 5
I960_andnot: int  # 6
I960_atadd: int  # 7
I960_atmod: int  # 8
I960_b: int  # 9
I960_bal: int  # 10
I960_balx: int  # 11
I960_bbc: int  # 12
I960_bbs: int  # 13
I960_be: int  # 16
I960_bg: int  # 15
I960_bge: int  # 17
I960_bl: int  # 18
I960_ble: int  # 20
I960_bne: int  # 19
I960_bno: int  # 14
I960_bo: int  # 21
I960_bswap: int  # 138
I960_bx: int  # 22
I960_call: int  # 23
I960_calls: int  # 24
I960_callx: int  # 25
I960_chkbit: int  # 26
I960_clrbit: int  # 27
I960_cmpdeci: int  # 28
I960_cmpdeco: int  # 29
I960_cmpi: int  # 30
I960_cmpib: int  # 135
I960_cmpibe: int  # 33
I960_cmpibg: int  # 32
I960_cmpibge: int  # 34
I960_cmpibl: int  # 35
I960_cmpible: int  # 37
I960_cmpibne: int  # 36
I960_cmpibno: int  # 31
I960_cmpibo: int  # 38
I960_cmpinci: int  # 39
I960_cmpinco: int  # 40
I960_cmpis: int  # 137
I960_cmpo: int  # 41
I960_cmpob: int  # 134
I960_cmpobe: int  # 43
I960_cmpobg: int  # 42
I960_cmpobge: int  # 44
I960_cmpobl: int  # 45
I960_cmpoble: int  # 47
I960_cmpobne: int  # 46
I960_cmpos: int  # 136
I960_cmpstr: int  # 144
I960_concmpi: int  # 48
I960_concmpo: int  # 49
I960_condrec: int  # 154
I960_condwait: int  # 165
I960_daddc: int  # 151
I960_dcctl: int  # 158
I960_dcinva: int  # 133
I960_divi: int  # 50
I960_divo: int  # 51
I960_dmovt: int  # 153
I960_dsubc: int  # 152
I960_ediv: int  # 52
I960_emul: int  # 53
I960_eshro: int  # 54
I960_extract: int  # 55
I960_faddr: int  # 209
I960_faddrl: int  # 210
I960_fatanr: int  # 211
I960_fatanrl: int  # 212
I960_faulte: int  # 58
I960_faultg: int  # 57
I960_faultge: int  # 59
I960_faultl: int  # 60
I960_faultle: int  # 62
I960_faultne: int  # 61
I960_faultno: int  # 56
I960_faulto: int  # 63
I960_fclassr: int  # 213
I960_fclassrl: int  # 214
I960_fcmpor: int  # 215
I960_fcmporl: int  # 216
I960_fcmpr: int  # 217
I960_fcmprl: int  # 218
I960_fcosr: int  # 219
I960_fcosrl: int  # 220
I960_fcpyrsre: int  # 221
I960_fcpysre: int  # 222
I960_fcvtilr: int  # 223
I960_fcvtir: int  # 224
I960_fcvtri: int  # 225
I960_fcvtril: int  # 226
I960_fcvtzri: int  # 227
I960_fcvtzril: int  # 228
I960_fdivr: int  # 229
I960_fdivrl: int  # 230
I960_fexpr: int  # 231
I960_fexprl: int  # 232
I960_fill: int  # 150
I960_flogbnr: int  # 233
I960_flogbnrl: int  # 234
I960_flogepr: int  # 235
I960_flogeprl: int  # 236
I960_flogr: int  # 237
I960_flogrl: int  # 238
I960_flushreg: int  # 64
I960_fmark: int  # 65
I960_fmovr: int  # 239
I960_fmovre: int  # 240
I960_fmovrl: int  # 241
I960_fmulr: int  # 242
I960_fmulrl: int  # 243
I960_fp_first: int  # 209
I960_fp_last: int  # 257
I960_fremr: int  # 244
I960_fremrl: int  # 245
I960_froundr: int  # 246
I960_froundrl: int  # 247
I960_fscaler: int  # 248
I960_fscalerl: int  # 249
I960_fsinr: int  # 250
I960_fsinrl: int  # 251
I960_fsqrtr: int  # 252
I960_fsqrtrl: int  # 253
I960_fsubr: int  # 254
I960_fsubrl: int  # 255
I960_ftanr: int  # 256
I960_ftanrl: int  # 257
I960_halt: int  # 159
I960_icctl: int  # 157
I960_inspacc: int  # 147
I960_intctl: int  # 156
I960_intdis: int  # 139
I960_inten: int  # 140
I960_last: int  # 258
I960_ld: int  # 66
I960_lda: int  # 67
I960_ldib: int  # 68
I960_ldis: int  # 69
I960_ldl: int  # 70
I960_ldob: int  # 71
I960_ldos: int  # 72
I960_ldphy: int  # 148
I960_ldq: int  # 73
I960_ldt: int  # 74
I960_ldtime: int  # 168
I960_mark: int  # 75
I960_modac: int  # 76
I960_modi: int  # 77
I960_modify: int  # 78
I960_modpc: int  # 79
I960_modtc: int  # 80
I960_mov: int  # 81
I960_movl: int  # 82
I960_movq: int  # 83
I960_movqstr: int  # 145
I960_movstr: int  # 146
I960_movt: int  # 84
I960_muli: int  # 85
I960_mulo: int  # 86
I960_nand: int  # 87
I960_nor: int  # 88
I960_not: int  # 89
I960_notand: int  # 90
I960_notbit: int  # 91
I960_notor: int  # 92
I960_null: int  # 0
I960_or: int  # 93
I960_ornot: int  # 94
I960_receive: int  # 155
I960_remi: int  # 95
I960_remo: int  # 96
I960_resumprcs: int  # 162
I960_ret: int  # 97
I960_rotate: int  # 98
I960_saveprcs: int  # 164
I960_scanbit: int  # 99
I960_scanbyte: int  # 100
I960_schedprcs: int  # 163
I960_sdma: int  # 130
I960_sele: int  # 183
I960_selg: int  # 178
I960_selge: int  # 188
I960_sell: int  # 193
I960_selle: int  # 203
I960_selne: int  # 198
I960_selno: int  # 173
I960_selo: int  # 208
I960_send: int  # 160
I960_sendserv: int  # 161
I960_setbit: int  # 101
I960_shli: int  # 102
I960_shlo: int  # 103
I960_shrdi: int  # 104
I960_shri: int  # 105
I960_shro: int  # 106
I960_signal: int  # 167
I960_spanbit: int  # 107
I960_st: int  # 108
I960_stib: int  # 109
I960_stis: int  # 110
I960_stl: int  # 111
I960_stob: int  # 112
I960_stos: int  # 113
I960_stq: int  # 114
I960_stt: int  # 115
I960_subc: int  # 116
I960_subi: int  # 117
I960_subie: int  # 182
I960_subig: int  # 177
I960_subige: int  # 187
I960_subil: int  # 192
I960_subile: int  # 202
I960_subine: int  # 197
I960_subino: int  # 172
I960_subio: int  # 207
I960_subo: int  # 118
I960_suboe: int  # 181
I960_subog: int  # 176
I960_suboge: int  # 186
I960_subol: int  # 191
I960_subole: int  # 201
I960_subone: int  # 196
I960_subono: int  # 171
I960_suboo: int  # 206
I960_syncf: int  # 119
I960_synld: int  # 149
I960_synmov: int  # 141
I960_synmovl: int  # 142
I960_synmovq: int  # 143
I960_sysctl: int  # 131
I960_teste: int  # 122
I960_testg: int  # 121
I960_testge: int  # 123
I960_testl: int  # 124
I960_testle: int  # 126
I960_testne: int  # 125
I960_testno: int  # 120
I960_testo: int  # 127
I960_udma: int  # 132
I960_wait: int  # 166
I960_xnor: int  # 128
I960_xor: int  # 129
IA64_0: int  # 1
IA64_1: int  # 2
IA64_a: int  # 3
IA64_acq: int  # 4
IA64_add: int  # 5
IA64_addl: int  # 6
IA64_addp4: int  # 7
IA64_adds: int  # 8
IA64_alloc: int  # 9
IA64_and: int  # 10
IA64_andcm: int  # 11
IA64_b: int  # 12
IA64_bias: int  # 13
IA64_br: int  # 14
IA64_break: int  # 15
IA64_brl: int  # 16
IA64_brp: int  # 17
IA64_bsw: int  # 18
IA64_c: int  # 19
IA64_call: int  # 20
IA64_cexit: int  # 21
IA64_chk: int  # 22
IA64_cloop: int  # 23
IA64_clr: int  # 24
IA64_clrrrb: int  # 25
IA64_cmp: int  # 26
IA64_cmp4: int  # 27
IA64_cmpxchg1: int  # 28
IA64_cmpxchg2: int  # 29
IA64_cmpxchg4: int  # 30
IA64_cmpxchg8: int  # 31
IA64_cond: int  # 32
IA64_cover: int  # 33
IA64_ctop: int  # 34
IA64_czx1: int  # 35
IA64_czx2: int  # 36
IA64_d: int  # 37
IA64_dep: int  # 38
IA64_dpnt: int  # 39
IA64_dptk: int  # 40
IA64_e: int  # 41
IA64_epc: int  # 42
IA64_eq: int  # 43
IA64_excl: int  # 44
IA64_exit: int  # 45
IA64_exp: int  # 46
IA64_extr: int  # 47
IA64_f: int  # 48
IA64_fabs: int  # 49
IA64_fadd: int  # 50
IA64_famax: int  # 51
IA64_famin: int  # 52
IA64_fand: int  # 53
IA64_fandcm: int  # 54
IA64_fault: int  # 55
IA64_fc: int  # 56
IA64_fchkf: int  # 57
IA64_fclass: int  # 58
IA64_fclrf: int  # 59
IA64_fcmp: int  # 60
IA64_fcvt: int  # 61
IA64_fetchadd4: int  # 62
IA64_fetchadd8: int  # 63
IA64_few: int  # 64
IA64_fill: int  # 65
IA64_flushrs: int  # 66
IA64_fma: int  # 67
IA64_fmax: int  # 68
IA64_fmerge: int  # 69
IA64_fmin: int  # 70
IA64_fmix: int  # 71
IA64_fmpy: int  # 72
IA64_fms: int  # 73
IA64_fneg: int  # 74
IA64_fnegabs: int  # 75
IA64_fnma: int  # 76
IA64_fnmpy: int  # 77
IA64_fnorm: int  # 78
IA64_for: int  # 79
IA64_fpabs: int  # 80
IA64_fpack: int  # 81
IA64_fpamax: int  # 82
IA64_fpamin: int  # 83
IA64_fpcmp: int  # 84
IA64_fpcvt: int  # 85
IA64_fpma: int  # 86
IA64_fpmax: int  # 87
IA64_fpmerge: int  # 88
IA64_fpmin: int  # 89
IA64_fpmpy: int  # 90
IA64_fpms: int  # 91
IA64_fpneg: int  # 92
IA64_fpnegabs: int  # 93
IA64_fpnma: int  # 94
IA64_fpnmpy: int  # 95
IA64_fprcpa: int  # 96
IA64_fprsqrta: int  # 97
IA64_frcpa: int  # 98
IA64_frsqrta: int  # 99
IA64_fselect: int  # 100
IA64_fsetc: int  # 101
IA64_fsub: int  # 102
IA64_fswap: int  # 103
IA64_fsxt: int  # 104
IA64_fwb: int  # 105
IA64_fx: int  # 106
IA64_fxor: int  # 107
IA64_fxu: int  # 108
IA64_g: int  # 109
IA64_ga: int  # 110
IA64_ge: int  # 111
IA64_getf: int  # 112
IA64_geu: int  # 113
IA64_gt: int  # 114
IA64_gtu: int  # 115
IA64_h: int  # 116
IA64_hu: int  # 117
IA64_i: int  # 118
IA64_ia: int  # 119
IA64_imp: int  # 120
IA64_invala: int  # 121
IA64_itc: int  # 122
IA64_itr: int  # 123
IA64_l: int  # 124
IA64_last: int  # 284
IA64_ld1: int  # 125
IA64_ld2: int  # 126
IA64_ld4: int  # 127
IA64_ld8: int  # 128
IA64_ldf: int  # 129
IA64_ldf8: int  # 130
IA64_ldfd: int  # 131
IA64_ldfe: int  # 132
IA64_ldfp8: int  # 133
IA64_ldfpd: int  # 134
IA64_ldfps: int  # 135
IA64_ldfs: int  # 136
IA64_le: int  # 137
IA64_leu: int  # 138
IA64_lfetch: int  # 139
IA64_loadrs: int  # 140
IA64_loop: int  # 141
IA64_lr: int  # 142
IA64_lt: int  # 143
IA64_ltu: int  # 144
IA64_lu: int  # 145
IA64_m: int  # 146
IA64_many: int  # 147
IA64_mf: int  # 148
IA64_mix1: int  # 149
IA64_mix2: int  # 150
IA64_mix4: int  # 151
IA64_mov: int  # 152
IA64_movl: int  # 153
IA64_mux1: int  # 154
IA64_mux2: int  # 155
IA64_nc: int  # 156
IA64_ne: int  # 157
IA64_neq: int  # 158
IA64_nge: int  # 159
IA64_ngt: int  # 160
IA64_nl: int  # 161
IA64_nle: int  # 162
IA64_nlt: int  # 163
IA64_nm: int  # 164
IA64_nop: int  # 165
IA64_nr: int  # 166
IA64_ns: int  # 167
IA64_nt1: int  # 168
IA64_nt2: int  # 169
IA64_nta: int  # 170
IA64_null: int  # 0
IA64_nz: int  # 171
IA64_or: int  # 172
IA64_orcm: int  # 173
IA64_ord: int  # 174
IA64_pack2: int  # 175
IA64_pack4: int  # 176
IA64_padd1: int  # 177
IA64_padd2: int  # 178
IA64_padd4: int  # 179
IA64_pavg1: int  # 180
IA64_pavg2: int  # 181
IA64_pavgsub1: int  # 182
IA64_pavgsub2: int  # 183
IA64_pcmp1: int  # 184
IA64_pcmp2: int  # 185
IA64_pcmp4: int  # 186
IA64_pmax1: int  # 187
IA64_pmax2: int  # 188
IA64_pmin1: int  # 189
IA64_pmin2: int  # 190
IA64_pmpy2: int  # 191
IA64_pmpyshr2: int  # 192
IA64_popcnt: int  # 193
IA64_pr: int  # 194
IA64_probe: int  # 195
IA64_psad1: int  # 196
IA64_pshl2: int  # 197
IA64_pshl4: int  # 198
IA64_pshladd2: int  # 199
IA64_pshr2: int  # 200
IA64_pshr4: int  # 201
IA64_pshradd2: int  # 202
IA64_psub1: int  # 203
IA64_psub2: int  # 204
IA64_psub4: int  # 205
IA64_ptc: int  # 206
IA64_ptr: int  # 207
IA64_r: int  # 208
IA64_raz: int  # 209
IA64_rel: int  # 210
IA64_ret: int  # 211
IA64_rfi: int  # 212
IA64_rsm: int  # 213
IA64_rum: int  # 214
IA64_rw: int  # 215
IA64_s: int  # 216
IA64_s0: int  # 217
IA64_s1: int  # 218
IA64_s2: int  # 219
IA64_s3: int  # 220
IA64_sa: int  # 221
IA64_se: int  # 222
IA64_setf: int  # 223
IA64_shl: int  # 224
IA64_shladd: int  # 225
IA64_shladdp4: int  # 226
IA64_shr: int  # 227
IA64_shrp: int  # 228
IA64_sig: int  # 229
IA64_spill: int  # 230
IA64_spnt: int  # 231
IA64_sptk: int  # 232
IA64_srlz: int  # 233
IA64_ssm: int  # 234
IA64_sss: int  # 235
IA64_st1: int  # 236
IA64_st2: int  # 237
IA64_st4: int  # 238
IA64_st8: int  # 239
IA64_stf: int  # 240
IA64_stf8: int  # 241
IA64_stfd: int  # 242
IA64_stfe: int  # 243
IA64_stfs: int  # 244
IA64_sub: int  # 245
IA64_sum: int  # 246
IA64_sxt1: int  # 247
IA64_sxt2: int  # 248
IA64_sxt4: int  # 249
IA64_sync: int  # 250
IA64_tak: int  # 251
IA64_tbit: int  # 252
IA64_thash: int  # 253
IA64_tnat: int  # 254
IA64_tpa: int  # 255
IA64_trunc: int  # 256
IA64_ttag: int  # 257
IA64_u: int  # 258
IA64_unc: int  # 259
IA64_unord: int  # 260
IA64_unpack1: int  # 261
IA64_unpack2: int  # 262
IA64_unpack4: int  # 263
IA64_uss: int  # 264
IA64_uus: int  # 265
IA64_uuu: int  # 266
IA64_w: int  # 267
IA64_wexit: int  # 268
IA64_wtop: int  # 269
IA64_x: int  # 270
IA64_xchg1: int  # 271
IA64_xchg2: int  # 272
IA64_xchg4: int  # 273
IA64_xchg8: int  # 274
IA64_xf: int  # 275
IA64_xma: int  # 276
IA64_xmpy: int  # 277
IA64_xor: int  # 278
IA64_xuf: int  # 279
IA64_z: int  # 280
IA64_zxt1: int  # 281
IA64_zxt2: int  # 282
IA64_zxt4: int  # 283
KR1878_adc: int  # 24
KR1878_add: int  # 3
KR1878_addl: int  # 10
KR1878_and: int  # 5
KR1878_bic: int  # 12
KR1878_bis: int  # 13
KR1878_btg: int  # 14
KR1878_btt: int  # 15
KR1878_cmp: int  # 2
KR1878_cmpl: int  # 9
KR1878_cst: int  # 32
KR1878_ijmp: int  # 43
KR1878_ijsr: int  # 44
KR1878_jc: int  # 42
KR1878_jmp: int  # 35
KR1878_jnc: int  # 41
KR1878_jns: int  # 39
KR1878_jnz: int  # 37
KR1878_js: int  # 40
KR1878_jsr: int  # 36
KR1878_jz: int  # 38
KR1878_last: int  # 53
KR1878_ldr: int  # 26
KR1878_mfpr: int  # 28
KR1878_mov: int  # 1
KR1878_movl: int  # 8
KR1878_mtpr: int  # 27
KR1878_neg: int  # 17
KR1878_nop: int  # 48
KR1878_not: int  # 18
KR1878_null: int  # 0
KR1878_or: int  # 6
KR1878_pop: int  # 30
KR1878_push: int  # 29
KR1878_reset: int  # 51
KR1878_rlc: int  # 22
KR1878_rrc: int  # 23
KR1878_rti: int  # 47
KR1878_rts: int  # 45
KR1878_rtsc: int  # 46
KR1878_sbc: int  # 25
KR1878_shl: int  # 19
KR1878_shr: int  # 20
KR1878_shra: int  # 21
KR1878_sksp: int  # 52
KR1878_sst: int  # 31
KR1878_stop: int  # 50
KR1878_sub: int  # 4
KR1878_subl: int  # 11
KR1878_swap: int  # 16
KR1878_tdc: int  # 34
KR1878_tof: int  # 33
KR1878_wait: int  # 49
KR1878_xor: int  # 7
M16C_abs: int  # 1
M16C_adc: int  # 2
M16C_adcf: int  # 3
M16C_add: int  # 4
M16C_addf: int  # 165
M16C_addx: int  # 123
M16C_adjnz: int  # 5
M16C_adsf: int  # 166
M16C_and: int  # 6
M16C_band: int  # 7
M16C_bclr: int  # 8
M16C_bitindex: int  # 124
M16C_bmcnd: int  # 9
M16C_bmeq: int  # 12
M16C_bmge: int  # 16
M16C_bmgeu: int  # 10
M16C_bmgt: int  # 21
M16C_bmgtu: int  # 11
M16C_bmle: int  # 14
M16C_bmleu: int  # 18
M16C_bmlt: int  # 23
M16C_bmltu: int  # 17
M16C_bmn: int  # 13
M16C_bmne: int  # 19
M16C_bmno: int  # 22
M16C_bmo: int  # 15
M16C_bmpz: int  # 20
M16C_bnand: int  # 24
M16C_bnor: int  # 25
M16C_bnot: int  # 26
M16C_bntst: int  # 27
M16C_bnxor: int  # 28
M16C_bor: int  # 29
M16C_brk: int  # 30
M16C_brk2: int  # 125
M16C_bset: int  # 31
M16C_btst: int  # 32
M16C_btstc: int  # 33
M16C_btsts: int  # 34
M16C_bxor: int  # 35
M16C_clip: int  # 126
M16C_cmp: int  # 36
M16C_cmpf: int  # 167
M16C_cmpx: int  # 127
M16C_cnvif: int  # 168
M16C_dadc: int  # 37
M16C_dadd: int  # 38
M16C_dec: int  # 39
M16C_div: int  # 40
M16C_divf: int  # 169
M16C_divu: int  # 41
M16C_divx: int  # 42
M16C_dsbb: int  # 43
M16C_dsub: int  # 44
M16C_ediv: int  # 170
M16C_edivu: int  # 171
M16C_edivx: int  # 172
M16C_emul: int  # 173
M16C_emulu: int  # 174
M16C_enter: int  # 45
M16C_exitd: int  # 46
M16C_exiti: int  # 175
M16C_exts: int  # 47
M16C_extz: int  # 128
M16C_fclr: int  # 48
M16C_freit: int  # 129
M16C_fset: int  # 49
M16C_inc: int  # 50
M16C_index1: int  # 176
M16C_index2: int  # 177
M16C_indexb: int  # 130
M16C_indexbd: int  # 131
M16C_indexbs: int  # 132
M16C_indexl: int  # 133
M16C_indexld: int  # 134
M16C_indexls: int  # 135
M16C_indexw: int  # 136
M16C_indexwd: int  # 137
M16C_indexws: int  # 138
M16C_int: int  # 51
M16C_into: int  # 52
M16C_jcnd: int  # 53
M16C_jeq: int  # 56
M16C_jge: int  # 60
M16C_jgeu: int  # 54
M16C_jgt: int  # 65
M16C_jgtu: int  # 55
M16C_jle: int  # 58
M16C_jleu: int  # 62
M16C_jlt: int  # 67
M16C_jltu: int  # 61
M16C_jmp: int  # 68
M16C_jmpi: int  # 69
M16C_jmps: int  # 70
M16C_jn: int  # 57
M16C_jne: int  # 63
M16C_jno: int  # 66
M16C_jo: int  # 59
M16C_jpz: int  # 64
M16C_jsr: int  # 71
M16C_jsri: int  # 72
M16C_jsrs: int  # 73
M16C_last: int  # 185
M16C_ldc: int  # 74
M16C_ldctx: int  # 75
M16C_lde: int  # 76
M16C_ldintb: int  # 77
M16C_ldipl: int  # 78
M16C_max: int  # 139
M16C_min: int  # 140
M16C_mov: int  # 79
M16C_mova: int  # 80
M16C_movhh: int  # 81
M16C_movhl: int  # 82
M16C_movlh: int  # 83
M16C_movll: int  # 84
M16C_movx: int  # 141
M16C_mul: int  # 85
M16C_mulex: int  # 142
M16C_mulf: int  # 178
M16C_mulu: int  # 86
M16C_mulx: int  # 179
M16C_neg: int  # 87
M16C_nop: int  # 88
M16C_not: int  # 89
M16C_null: int  # 0
M16C_or: int  # 90
M16C_pop: int  # 91
M16C_popc: int  # 92
M16C_popm: int  # 93
M16C_push: int  # 94
M16C_pusha: int  # 95
M16C_pushc: int  # 96
M16C_pushm: int  # 97
M16C_reit: int  # 98
M16C_rmpa: int  # 99
M16C_rolc: int  # 100
M16C_rorc: int  # 101
M16C_rot: int  # 102
M16C_round: int  # 180
M16C_rts: int  # 103
M16C_sbb: int  # 104
M16C_sbjnz: int  # 105
M16C_sccnd: int  # 143
M16C_sceq: int  # 146
M16C_scge: int  # 150
M16C_scgeu: int  # 144
M16C_scgt: int  # 155
M16C_scgtu: int  # 145
M16C_scle: int  # 148
M16C_scleu: int  # 152
M16C_sclt: int  # 157
M16C_scltu: int  # 151
M16C_scmpu: int  # 158
M16C_scn: int  # 147
M16C_scne: int  # 153
M16C_scno: int  # 156
M16C_sco: int  # 149
M16C_scpz: int  # 154
M16C_sha: int  # 106
M16C_shanc: int  # 163
M16C_shl: int  # 107
M16C_shlnc: int  # 164
M16C_sin: int  # 159
M16C_smovb: int  # 108
M16C_smovf: int  # 109
M16C_smovu: int  # 160
M16C_sout: int  # 161
M16C_sstr: int  # 110
M16C_stc: int  # 111
M16C_stctx: int  # 112
M16C_ste: int  # 113
M16C_stnz: int  # 114
M16C_stop: int  # 181
M16C_stz: int  # 115
M16C_stzx: int  # 116
M16C_sub: int  # 117
M16C_subf: int  # 182
M16C_subx: int  # 162
M16C_suntil: int  # 183
M16C_swhile: int  # 184
M16C_tst: int  # 118
M16C_und: int  # 119
M16C_wait: int  # 120
M16C_xchg: int  # 121
M16C_xor: int  # 122
M65816_adc: int  # 1
M65816_and: int  # 2
M65816_asl: int  # 3
M65816_bcc: int  # 4
M65816_bcs: int  # 5
M65816_beq: int  # 6
M65816_bit: int  # 7
M65816_bmi: int  # 8
M65816_bne: int  # 9
M65816_bpl: int  # 10
M65816_bra: int  # 11
M65816_brk: int  # 12
M65816_brl: int  # 13
M65816_bvc: int  # 14
M65816_bvs: int  # 15
M65816_clc: int  # 16
M65816_cld: int  # 17
M65816_cli: int  # 18
M65816_clv: int  # 19
M65816_cmp: int  # 20
M65816_cop: int  # 21
M65816_cpx: int  # 22
M65816_cpy: int  # 23
M65816_dec: int  # 24
M65816_dex: int  # 25
M65816_dey: int  # 26
M65816_eor: int  # 27
M65816_inc: int  # 28
M65816_inx: int  # 29
M65816_iny: int  # 30
M65816_jml: int  # 31
M65816_jmp: int  # 32
M65816_jsl: int  # 33
M65816_jsr: int  # 34
M65816_last: int  # 93
M65816_lda: int  # 35
M65816_ldx: int  # 36
M65816_ldy: int  # 37
M65816_lsr: int  # 38
M65816_mvn: int  # 39
M65816_mvp: int  # 40
M65816_nop: int  # 41
M65816_null: int  # 0
M65816_ora: int  # 42
M65816_pea: int  # 43
M65816_pei: int  # 44
M65816_per: int  # 45
M65816_pha: int  # 46
M65816_phb: int  # 47
M65816_phd: int  # 48
M65816_phk: int  # 49
M65816_php: int  # 50
M65816_phx: int  # 51
M65816_phy: int  # 52
M65816_pla: int  # 53
M65816_plb: int  # 54
M65816_pld: int  # 55
M65816_plp: int  # 56
M65816_plx: int  # 57
M65816_ply: int  # 58
M65816_rep: int  # 59
M65816_rol: int  # 60
M65816_ror: int  # 61
M65816_rti: int  # 62
M65816_rtl: int  # 63
M65816_rts: int  # 64
M65816_sbc: int  # 65
M65816_sec: int  # 66
M65816_sed: int  # 67
M65816_sei: int  # 68
M65816_sep: int  # 69
M65816_sta: int  # 70
M65816_stp: int  # 71
M65816_stx: int  # 72
M65816_sty: int  # 73
M65816_stz: int  # 74
M65816_tax: int  # 75
M65816_tay: int  # 76
M65816_tcd: int  # 77
M65816_tcs: int  # 78
M65816_tdc: int  # 79
M65816_trb: int  # 80
M65816_tsb: int  # 81
M65816_tsc: int  # 82
M65816_tsx: int  # 83
M65816_txa: int  # 84
M65816_txs: int  # 85
M65816_txy: int  # 86
M65816_tya: int  # 87
M65816_tyx: int  # 88
M65816_wai: int  # 89
M65816_wdm: int  # 90
M65816_xba: int  # 91
M65816_xce: int  # 92
M65_adc: int  # 1
M65_anc: int  # 2
M65_and: int  # 3
M65_ane: int  # 4
M65_arr: int  # 5
M65_asl: int  # 6
M65_asr: int  # 7
M65_bbr0: int  # 77
M65_bbr1: int  # 78
M65_bbr2: int  # 79
M65_bbr3: int  # 80
M65_bbr4: int  # 81
M65_bbr5: int  # 82
M65_bbr6: int  # 83
M65_bbr7: int  # 84
M65_bbs0: int  # 85
M65_bbs1: int  # 86
M65_bbs2: int  # 87
M65_bbs3: int  # 88
M65_bbs4: int  # 89
M65_bbs5: int  # 90
M65_bbs6: int  # 91
M65_bbs7: int  # 92
M65_bcc: int  # 8
M65_bcs: int  # 9
M65_beq: int  # 10
M65_bit: int  # 11
M65_bmi: int  # 12
M65_bne: int  # 13
M65_bpl: int  # 14
M65_bra: int  # 116
M65_brk: int  # 15
M65_bvc: int  # 16
M65_bvs: int  # 17
M65_clc: int  # 18
M65_cld: int  # 19
M65_cli: int  # 20
M65_clv: int  # 21
M65_cmp: int  # 22
M65_cpx: int  # 23
M65_cpy: int  # 24
M65_dcp: int  # 25
M65_dec: int  # 26
M65_dex: int  # 27
M65_dey: int  # 28
M65_eor: int  # 29
M65_inc: int  # 30
M65_inx: int  # 31
M65_iny: int  # 32
M65_isb: int  # 33
M65_jmp: int  # 34
M65_jmpi: int  # 35
M65_jsr: int  # 36
M65_lae: int  # 37
M65_last: int  # 119
M65_lax: int  # 38
M65_lda: int  # 39
M65_ldx: int  # 40
M65_ldy: int  # 41
M65_lsr: int  # 42
M65_lxa: int  # 43
M65_nop: int  # 44
M65_null: int  # 0
M65_ora: int  # 45
M65_pha: int  # 46
M65_php: int  # 47
M65_phx: int  # 114
M65_phy: int  # 112
M65_pla: int  # 48
M65_plp: int  # 49
M65_plx: int  # 115
M65_ply: int  # 113
M65_rla: int  # 50
M65_rmb0: int  # 93
M65_rmb1: int  # 94
M65_rmb2: int  # 95
M65_rmb3: int  # 96
M65_rmb4: int  # 97
M65_rmb5: int  # 98
M65_rmb6: int  # 99
M65_rmb7: int  # 100
M65_rol: int  # 51
M65_ror: int  # 52
M65_rra: int  # 53
M65_rti: int  # 54
M65_rts: int  # 55
M65_sax: int  # 56
M65_sbc: int  # 57
M65_sbx: int  # 58
M65_sec: int  # 59
M65_sed: int  # 60
M65_sei: int  # 61
M65_sha: int  # 62
M65_shs: int  # 63
M65_shx: int  # 64
M65_shy: int  # 65
M65_slo: int  # 66
M65_smb0: int  # 101
M65_smb1: int  # 102
M65_smb2: int  # 103
M65_smb3: int  # 104
M65_smb4: int  # 105
M65_smb5: int  # 106
M65_smb6: int  # 107
M65_smb7: int  # 108
M65_sre: int  # 67
M65_sta: int  # 68
M65_stp: int  # 118
M65_stx: int  # 69
M65_sty: int  # 70
M65_stz: int  # 109
M65_tax: int  # 71
M65_tay: int  # 72
M65_trb: int  # 111
M65_tsb: int  # 110
M65_tsx: int  # 73
M65_txa: int  # 74
M65_txs: int  # 75
M65_tya: int  # 76
M65_wai: int  # 117
MC12XGATE_adc: int  # 282
MC12XGATE_add: int  # 283
MC12XGATE_add16: int  # 354
MC12XGATE_addh: int  # 284
MC12XGATE_addl: int  # 285
MC12XGATE_and: int  # 286
MC12XGATE_and16: int  # 355
MC12XGATE_andh: int  # 287
MC12XGATE_andl: int  # 288
MC12XGATE_asr: int  # 289
MC12XGATE_bcc: int  # 290
MC12XGATE_bcs: int  # 291
MC12XGATE_beq: int  # 292
MC12XGATE_bfext: int  # 293
MC12XGATE_bffo: int  # 294
MC12XGATE_bfins: int  # 295
MC12XGATE_bfinsi: int  # 296
MC12XGATE_bfinsx: int  # 297
MC12XGATE_bge: int  # 298
MC12XGATE_bgt: int  # 299
MC12XGATE_bhi: int  # 300
MC12XGATE_bhs: int  # 301
MC12XGATE_bith: int  # 302
MC12XGATE_bitl: int  # 303
MC12XGATE_ble: int  # 304
MC12XGATE_blo: int  # 305
MC12XGATE_bls: int  # 306
MC12XGATE_blt: int  # 307
MC12XGATE_bmi: int  # 308
MC12XGATE_bne: int  # 309
MC12XGATE_bpl: int  # 310
MC12XGATE_bra: int  # 311
MC12XGATE_brk: int  # 312
MC12XGATE_bvc: int  # 313
MC12XGATE_bvs: int  # 314
MC12XGATE_cmp: int  # 315
MC12XGATE_cmp16: int  # 356
MC12XGATE_cmpl: int  # 316
MC12XGATE_com: int  # 317
MC12XGATE_cpc: int  # 318
MC12XGATE_cpch: int  # 319
MC12XGATE_csem: int  # 320
MC12XGATE_csl: int  # 321
MC12XGATE_csr: int  # 322
MC12XGATE_jal: int  # 323
MC12XGATE_ldb: int  # 324
MC12XGATE_ldh: int  # 325
MC12XGATE_ldl: int  # 326
MC12XGATE_ldw: int  # 327
MC12XGATE_ldw16: int  # 357
MC12XGATE_lsl: int  # 328
MC12XGATE_lsr: int  # 329
MC12XGATE_mov: int  # 330
MC12XGATE_neg: int  # 331
MC12XGATE_nop: int  # 332
MC12XGATE_or: int  # 333
MC12XGATE_or16: int  # 358
MC12XGATE_orh: int  # 334
MC12XGATE_orl: int  # 335
MC12XGATE_par: int  # 336
MC12XGATE_rol: int  # 337
MC12XGATE_ror: int  # 338
MC12XGATE_rts: int  # 339
MC12XGATE_sbc: int  # 340
MC12XGATE_sex: int  # 341
MC12XGATE_sif: int  # 342
MC12XGATE_ssem: int  # 343
MC12XGATE_stb: int  # 344
MC12XGATE_stw: int  # 345
MC12XGATE_sub: int  # 346
MC12XGATE_sub16: int  # 359
MC12XGATE_subh: int  # 347
MC12XGATE_subl: int  # 348
MC12XGATE_tfr: int  # 349
MC12XGATE_tst: int  # 350
MC12XGATE_xnor: int  # 351
MC12XGATE_xnor16: int  # 360
MC12XGATE_xnorh: int  # 352
MC12XGATE_xnorl: int  # 353
MC12X_addx: int  # 211
MC12X_addy: int  # 212
MC12X_aded: int  # 213
MC12X_adex: int  # 214
MC12X_adey: int  # 215
MC12X_andx: int  # 216
MC12X_andy: int  # 217
MC12X_aslw: int  # 218
MC12X_aslx: int  # 219
MC12X_asly: int  # 220
MC12X_asrw: int  # 221
MC12X_asrx: int  # 222
MC12X_asry: int  # 223
MC12X_bitx: int  # 224
MC12X_bity: int  # 225
MC12X_btas: int  # 226
MC12X_clrw: int  # 227
MC12X_clrx: int  # 228
MC12X_clry: int  # 229
MC12X_comw: int  # 230
MC12X_comx: int  # 231
MC12X_comy: int  # 232
MC12X_cped: int  # 233
MC12X_cpes: int  # 234
MC12X_cpex: int  # 235
MC12X_cpey: int  # 236
MC12X_decw: int  # 237
MC12X_decx: int  # 238
MC12X_decy: int  # 239
MC12X_eorx: int  # 240
MC12X_eory: int  # 241
MC12X_gldaa: int  # 242
MC12X_gldab: int  # 243
MC12X_gldd: int  # 244
MC12X_glds: int  # 245
MC12X_gldx: int  # 246
MC12X_gldy: int  # 247
MC12X_gstaa: int  # 248
MC12X_gstab: int  # 249
MC12X_gstd: int  # 250
MC12X_gsts: int  # 251
MC12X_gstx: int  # 252
MC12X_gsty: int  # 253
MC12X_incw: int  # 254
MC12X_incx: int  # 255
MC12X_incy: int  # 256
MC12X_lsrw: int  # 257
MC12X_lsrx: int  # 258
MC12X_lsry: int  # 259
MC12X_negw: int  # 260
MC12X_negx: int  # 261
MC12X_negy: int  # 262
MC12X_orx: int  # 263
MC12X_ory: int  # 264
MC12X_pshcw: int  # 265
MC12X_pulcw: int  # 266
MC12X_rolw: int  # 267
MC12X_rolx: int  # 268
MC12X_roly: int  # 269
MC12X_rorw: int  # 270
MC12X_rorx: int  # 271
MC12X_rory: int  # 272
MC12X_sbed: int  # 273
MC12X_sbex: int  # 274
MC12X_sbey: int  # 275
MC12X_subx: int  # 276
MC12X_suby: int  # 277
MC12X_sys: int  # 281
MC12X_tstw: int  # 278
MC12X_tstx: int  # 279
MC12X_tsty: int  # 280
MC12_aba: int  # 1
MC12_abx: int  # 2
MC12_aby: int  # 3
MC12_adca: int  # 4
MC12_adcb: int  # 5
MC12_adda: int  # 6
MC12_addb: int  # 7
MC12_addd: int  # 8
MC12_anda: int  # 9
MC12_andb: int  # 10
MC12_andcc: int  # 11
MC12_asl: int  # 12
MC12_asla: int  # 13
MC12_aslb: int  # 14
MC12_asld: int  # 15
MC12_asr: int  # 16
MC12_asra: int  # 17
MC12_asrb: int  # 18
MC12_bcc: int  # 19
MC12_bclr: int  # 20
MC12_bcs: int  # 21
MC12_beq: int  # 22
MC12_bge: int  # 23
MC12_bgnd: int  # 24
MC12_bgt: int  # 25
MC12_bhi: int  # 26
MC12_bhs: int  # 27
MC12_bita: int  # 28
MC12_bitb: int  # 29
MC12_ble: int  # 30
MC12_blo: int  # 31
MC12_bls: int  # 32
MC12_blt: int  # 33
MC12_bmi: int  # 34
MC12_bne: int  # 35
MC12_bpl: int  # 36
MC12_bra: int  # 37
MC12_brclr: int  # 38
MC12_brn: int  # 39
MC12_brset: int  # 40
MC12_bset: int  # 41
MC12_bsr: int  # 42
MC12_bvc: int  # 43
MC12_bvs: int  # 44
MC12_call: int  # 45
MC12_cba: int  # 46
MC12_clc: int  # 47
MC12_cli: int  # 48
MC12_clr: int  # 49
MC12_clra: int  # 50
MC12_clrb: int  # 51
MC12_clv: int  # 52
MC12_cmpa: int  # 53
MC12_cmpb: int  # 54
MC12_com: int  # 55
MC12_coma: int  # 56
MC12_comb: int  # 57
MC12_cpd: int  # 58
MC12_cps: int  # 59
MC12_cpx: int  # 60
MC12_cpy: int  # 61
MC12_daa: int  # 62
MC12_dbeq: int  # 63
MC12_dbne: int  # 64
MC12_dec: int  # 65
MC12_deca: int  # 66
MC12_decb: int  # 67
MC12_des: int  # 68
MC12_dex: int  # 69
MC12_dey: int  # 70
MC12_ediv: int  # 71
MC12_edivs: int  # 72
MC12_emacs: int  # 73
MC12_emaxd: int  # 74
MC12_emaxm: int  # 75
MC12_emind: int  # 76
MC12_eminm: int  # 77
MC12_emul: int  # 78
MC12_emuls: int  # 79
MC12_eora: int  # 80
MC12_eorb: int  # 81
MC12_etbl: int  # 82
MC12_exg: int  # 83
MC12_fdiv: int  # 84
MC12_ibeq: int  # 85
MC12_ibne: int  # 86
MC12_idiv: int  # 87
MC12_idivs: int  # 88
MC12_inc: int  # 89
MC12_inca: int  # 90
MC12_incb: int  # 91
MC12_ins: int  # 92
MC12_inx: int  # 93
MC12_iny: int  # 94
MC12_jmp: int  # 95
MC12_jsr: int  # 96
MC12_last: int  # 361
MC12_lbcc: int  # 97
MC12_lbcs: int  # 98
MC12_lbeq: int  # 99
MC12_lbge: int  # 100
MC12_lbgt: int  # 101
MC12_lbhi: int  # 102
MC12_lbhs: int  # 103
MC12_lble: int  # 104
MC12_lblo: int  # 105
MC12_lbls: int  # 106
MC12_lblt: int  # 107
MC12_lbmi: int  # 108
MC12_lbne: int  # 109
MC12_lbpl: int  # 110
MC12_lbra: int  # 111
MC12_lbrn: int  # 112
MC12_lbvc: int  # 113
MC12_lbvs: int  # 114
MC12_ldaa: int  # 115
MC12_ldab: int  # 116
MC12_ldd: int  # 117
MC12_lds: int  # 118
MC12_ldx: int  # 119
MC12_ldy: int  # 120
MC12_leas: int  # 121
MC12_leax: int  # 122
MC12_leay: int  # 123
MC12_lsl: int  # 124
MC12_lsla: int  # 125
MC12_lslb: int  # 126
MC12_lsld: int  # 127
MC12_lsr: int  # 128
MC12_lsra: int  # 129
MC12_lsrb: int  # 130
MC12_lsrd: int  # 131
MC12_maxa: int  # 132
MC12_maxm: int  # 133
MC12_mem: int  # 134
MC12_mina: int  # 135
MC12_minm: int  # 136
MC12_movb: int  # 137
MC12_movw: int  # 138
MC12_mul: int  # 139
MC12_neg: int  # 140
MC12_nega: int  # 141
MC12_negb: int  # 142
MC12_nop: int  # 143
MC12_null: int  # 0
MC12_oraa: int  # 144
MC12_orab: int  # 145
MC12_orcc: int  # 146
MC12_psha: int  # 147
MC12_pshb: int  # 148
MC12_pshc: int  # 149
MC12_pshd: int  # 150
MC12_pshx: int  # 151
MC12_pshy: int  # 152
MC12_pula: int  # 153
MC12_pulb: int  # 154
MC12_pulc: int  # 155
MC12_puld: int  # 156
MC12_pulx: int  # 157
MC12_puly: int  # 158
MC12_rev: int  # 159
MC12_revw: int  # 160
MC12_rol: int  # 161
MC12_rola: int  # 162
MC12_rolb: int  # 163
MC12_ror: int  # 164
MC12_rora: int  # 165
MC12_rorb: int  # 166
MC12_rtc: int  # 167
MC12_rti: int  # 168
MC12_rts: int  # 169
MC12_sba: int  # 170
MC12_sbca: int  # 171
MC12_sbcb: int  # 172
MC12_sec: int  # 173
MC12_sei: int  # 174
MC12_sev: int  # 175
MC12_sex: int  # 176
MC12_skip1: int  # 209
MC12_skip2: int  # 210
MC12_staa: int  # 177
MC12_stab: int  # 178
MC12_std: int  # 179
MC12_stop: int  # 180
MC12_sts: int  # 181
MC12_stx: int  # 182
MC12_sty: int  # 183
MC12_suba: int  # 184
MC12_subb: int  # 185
MC12_subd: int  # 186
MC12_swi: int  # 187
MC12_tab: int  # 188
MC12_tap: int  # 189
MC12_tba: int  # 190
MC12_tbeq: int  # 191
MC12_tbl: int  # 192
MC12_tbne: int  # 193
MC12_tfr: int  # 194
MC12_tpa: int  # 195
MC12_trap: int  # 196
MC12_tst: int  # 197
MC12_tsta: int  # 198
MC12_tstb: int  # 199
MC12_tsx: int  # 200
MC12_tsy: int  # 201
MC12_txs: int  # 202
MC12_tys: int  # 203
MC12_wai: int  # 204
MC12_wav: int  # 205
MC12_wavr: int  # 206
MC12_xgdx: int  # 207
MC12_xgdy: int  # 208
MC6816_aba: int  # 19
MC6816_abx: int  # 177
MC6816_aby: int  # 178
MC6816_abz: int  # 179
MC6816_ace: int  # 242
MC6816_aced: int  # 243
MC6816_adca: int  # 20
MC6816_adcb: int  # 21
MC6816_adcd: int  # 22
MC6816_adce: int  # 23
MC6816_adda: int  # 24
MC6816_addb: int  # 25
MC6816_addd: int  # 26
MC6816_adde: int  # 27
MC6816_ade: int  # 28
MC6816_adx: int  # 180
MC6816_ady: int  # 181
MC6816_adz: int  # 182
MC6816_aex: int  # 183
MC6816_aey: int  # 184
MC6816_aez: int  # 185
MC6816_ais: int  # 226
MC6816_aix: int  # 186
MC6816_aiy: int  # 187
MC6816_aiz: int  # 188
MC6816_anda: int  # 86
MC6816_andb: int  # 87
MC6816_andd: int  # 88
MC6816_ande: int  # 89
MC6816_andp: int  # 236
MC6816_asl: int  # 110
MC6816_asla: int  # 111
MC6816_aslb: int  # 112
MC6816_asld: int  # 113
MC6816_asle: int  # 114
MC6816_aslm: int  # 244
MC6816_aslw: int  # 115
MC6816_asr: int  # 116
MC6816_asra: int  # 117
MC6816_asrb: int  # 118
MC6816_asrd: int  # 119
MC6816_asre: int  # 120
MC6816_asrm: int  # 245
MC6816_asrw: int  # 121
MC6816_bcc: int  # 136
MC6816_bclr: int  # 100
MC6816_bclrw: int  # 101
MC6816_bcs: int  # 137
MC6816_beq: int  # 138
MC6816_bge: int  # 146
MC6816_bgnd: int  # 260
MC6816_bgt: int  # 147
MC6816_bhi: int  # 144
MC6816_bita: int  # 98
MC6816_bitb: int  # 99
MC6816_ble: int  # 148
MC6816_bls: int  # 145
MC6816_blt: int  # 149
MC6816_bmi: int  # 139
MC6816_bne: int  # 140
MC6816_bpl: int  # 141
MC6816_bra: int  # 134
MC6816_brclr: int  # 168
MC6816_brn: int  # 135
MC6816_brset: int  # 169
MC6816_bset: int  # 102
MC6816_bsetw: int  # 103
MC6816_bsr: int  # 171
MC6816_bvc: int  # 142
MC6816_bvs: int  # 143
MC6816_cba: int  # 41
MC6816_clr: int  # 68
MC6816_clra: int  # 69
MC6816_clrb: int  # 70
MC6816_clrd: int  # 71
MC6816_clre: int  # 72
MC6816_clrm: int  # 246
MC6816_clrw: int  # 73
MC6816_cmpa: int  # 42
MC6816_cmpb: int  # 43
MC6816_com: int  # 74
MC6816_coma: int  # 75
MC6816_comb: int  # 76
MC6816_comd: int  # 77
MC6816_come: int  # 78
MC6816_comw: int  # 79
MC6816_cpd: int  # 44
MC6816_cpe: int  # 45
MC6816_cps: int  # 227
MC6816_cpx: int  # 189
MC6816_cpy: int  # 190
MC6816_cpz: int  # 191
MC6816_daa: int  # 39
MC6816_dec: int  # 60
MC6816_deca: int  # 61
MC6816_decb: int  # 62
MC6816_decw: int  # 63
MC6816_ediv: int  # 52
MC6816_edivs: int  # 53
MC6816_emul: int  # 54
MC6816_emuls: int  # 55
MC6816_eora: int  # 90
MC6816_eorb: int  # 91
MC6816_eord: int  # 92
MC6816_eore: int  # 93
MC6816_fdiv: int  # 56
MC6816_fmuls: int  # 57
MC6816_idiv: int  # 58
MC6816_inc: int  # 64
MC6816_inca: int  # 65
MC6816_incb: int  # 66
MC6816_incw: int  # 67
MC6816_jmp: int  # 170
MC6816_jsr: int  # 172
MC6816_last: int  # 262
MC6816_lbcc: int  # 152
MC6816_lbcs: int  # 153
MC6816_lbeq: int  # 154
MC6816_lbev: int  # 155
MC6816_lbge: int  # 164
MC6816_lbgt: int  # 165
MC6816_lbhi: int  # 162
MC6816_lble: int  # 166
MC6816_lbls: int  # 163
MC6816_lblt: int  # 167
MC6816_lbmi: int  # 156
MC6816_lbmv: int  # 157
MC6816_lbne: int  # 158
MC6816_lbpl: int  # 159
MC6816_lbra: int  # 150
MC6816_lbrn: int  # 151
MC6816_lbsr: int  # 173
MC6816_lbvc: int  # 160
MC6816_lbvs: int  # 161
MC6816_ldaa: int  # 1
MC6816_ldab: int  # 2
MC6816_ldd: int  # 3
MC6816_lde: int  # 4
MC6816_lded: int  # 5
MC6816_ldhi: int  # 247
MC6816_lds: int  # 228
MC6816_ldx: int  # 192
MC6816_ldy: int  # 193
MC6816_ldz: int  # 194
MC6816_lpstop: int  # 258
MC6816_lsr: int  # 104
MC6816_lsra: int  # 105
MC6816_lsrb: int  # 106
MC6816_lsrd: int  # 107
MC6816_lsre: int  # 108
MC6816_lsrw: int  # 109
MC6816_mac: int  # 248
MC6816_movb: int  # 6
MC6816_movw: int  # 7
MC6816_mul: int  # 59
MC6816_neg: int  # 80
MC6816_nega: int  # 81
MC6816_negb: int  # 82
MC6816_negd: int  # 83
MC6816_nege: int  # 84
MC6816_negw: int  # 85
MC6816_nop: int  # 261
MC6816_null: int  # 0
MC6816_oraa: int  # 94
MC6816_orab: int  # 95
MC6816_ord: int  # 96
MC6816_ore: int  # 97
MC6816_orp: int  # 237
MC6816_psha: int  # 230
MC6816_pshb: int  # 231
MC6816_pshm: int  # 232
MC6816_pshmac: int  # 249
MC6816_pula: int  # 233
MC6816_pulb: int  # 234
MC6816_pulm: int  # 235
MC6816_pulmac: int  # 250
MC6816_rmac: int  # 251
MC6816_rol: int  # 122
MC6816_rola: int  # 123
MC6816_rolb: int  # 124
MC6816_rold: int  # 125
MC6816_role: int  # 126
MC6816_rolw: int  # 127
MC6816_ror: int  # 128
MC6816_rora: int  # 129
MC6816_rorb: int  # 130
MC6816_rord: int  # 131
MC6816_rore: int  # 132
MC6816_rorw: int  # 133
MC6816_rti: int  # 175
MC6816_rts: int  # 174
MC6816_sba: int  # 29
MC6816_sbca: int  # 30
MC6816_sbcb: int  # 31
MC6816_sbcd: int  # 32
MC6816_sbce: int  # 33
MC6816_sde: int  # 34
MC6816_staa: int  # 8
MC6816_stab: int  # 9
MC6816_std: int  # 10
MC6816_ste: int  # 11
MC6816_sted: int  # 12
MC6816_sts: int  # 229
MC6816_stx: int  # 195
MC6816_sty: int  # 196
MC6816_stz: int  # 197
MC6816_suba: int  # 35
MC6816_subb: int  # 36
MC6816_subd: int  # 37
MC6816_sube: int  # 38
MC6816_swi: int  # 176
MC6816_sxt: int  # 40
MC6816_tab: int  # 13
MC6816_tap: int  # 238
MC6816_tba: int  # 14
MC6816_tbek: int  # 216
MC6816_tbsk: int  # 217
MC6816_tbxk: int  # 218
MC6816_tbyk: int  # 219
MC6816_tbzk: int  # 220
MC6816_tde: int  # 15
MC6816_tdmsk: int  # 252
MC6816_tdp: int  # 239
MC6816_ted: int  # 16
MC6816_tedm: int  # 253
MC6816_tekb: int  # 221
MC6816_tem: int  # 254
MC6816_tmer: int  # 255
MC6816_tmet: int  # 256
MC6816_tmxed: int  # 257
MC6816_tpa: int  # 240
MC6816_tpd: int  # 241
MC6816_tskb: int  # 222
MC6816_tst: int  # 46
MC6816_tsta: int  # 47
MC6816_tstb: int  # 48
MC6816_tstd: int  # 49
MC6816_tste: int  # 50
MC6816_tstw: int  # 51
MC6816_tsx: int  # 198
MC6816_tsy: int  # 199
MC6816_tsz: int  # 200
MC6816_txkb: int  # 223
MC6816_txs: int  # 201
MC6816_txy: int  # 202
MC6816_txz: int  # 203
MC6816_tykb: int  # 224
MC6816_tys: int  # 204
MC6816_tyx: int  # 205
MC6816_tyz: int  # 206
MC6816_tzkb: int  # 225
MC6816_tzs: int  # 207
MC6816_tzx: int  # 208
MC6816_tzy: int  # 209
MC6816_wai: int  # 259
MC6816_xgab: int  # 17
MC6816_xgde: int  # 18
MC6816_xgdx: int  # 210
MC6816_xgdy: int  # 211
MC6816_xgdz: int  # 212
MC6816_xgex: int  # 213
MC6816_xgey: int  # 214
MC6816_xgez: int  # 215
MIPS_R5900_first: int  # 314
MIPS_R5900_last: int  # 429
MIPS_absq_s_ph: int  # 929
MIPS_absq_s_pw: int  # 947
MIPS_absq_s_qb: int  # 928
MIPS_absq_s_qh: int  # 946
MIPS_absq_s_w: int  # 930
MIPS_ac0iu: int  # 734
MIPS_add: int  # 1
MIPS_addi: int  # 30
MIPS_addiu: int  # 31
MIPS_addiupc: int  # 1740
MIPS_addmiu: int  # 737
MIPS_addq_ph: int  # 849
MIPS_addq_pw: int  # 870
MIPS_addq_qh: int  # 869
MIPS_addq_s_ph: int  # 860
MIPS_addq_s_pw: int  # 880
MIPS_addq_s_qh: int  # 879
MIPS_addq_s_w: int  # 861
MIPS_addqh_ph: int  # 1099
MIPS_addqh_r_ph: int  # 1105
MIPS_addqh_r_w: int  # 1106
MIPS_addqh_w: int  # 1100
MIPS_addsc: int  # 845
MIPS_addu: int  # 2
MIPS_addu_ob: int  # 867
MIPS_addu_ph: int  # 844
MIPS_addu_qb: int  # 843
MIPS_addu_s_ob: int  # 873
MIPS_addu_s_ph: int  # 853
MIPS_addu_s_qb: int  # 852
MIPS_adduh_qb: int  # 1098
MIPS_adduh_r_qb: int  # 1104
MIPS_addwc: int  # 848
MIPS_alnv_ps: int  # 507
MIPS_aluipc: int  # 1742
MIPS_and: int  # 3
MIPS_andi: int  # 36
MIPS_append: int  # 1114
MIPS_b: int  # 202
MIPS_baddu: int  # 573
MIPS_bal: int  # 203
MIPS_balc: int  # 1737
MIPS_balign: int  # 1115
MIPS_balrsc: int  # 1758
MIPS_bbeqzc: int  # 1744
MIPS_bbit0: int  # 574
MIPS_bbit032: int  # 575
MIPS_bbit1: int  # 576
MIPS_bbit132: int  # 577
MIPS_bbnezc: int  # 1748
MIPS_bc: int  # 1736
MIPS_bc0f: int  # 82
MIPS_bc0fl: int  # 86
MIPS_bc0t: int  # 90
MIPS_bc0tl: int  # 94
MIPS_bc1any2f: int  # 788
MIPS_bc1any2t: int  # 789
MIPS_bc1any4f: int  # 790
MIPS_bc1any4t: int  # 791
MIPS_bc1f: int  # 83
MIPS_bc1fl: int  # 87
MIPS_bc1t: int  # 91
MIPS_bc1tl: int  # 95
MIPS_bc2f: int  # 84
MIPS_bc2fl: int  # 88
MIPS_bc2t: int  # 92
MIPS_bc2tl: int  # 96
MIPS_bc3f: int  # 85
MIPS_bc3fl: int  # 89
MIPS_bc3t: int  # 93
MIPS_bc3tl: int  # 97
MIPS_bclr: int  # 741
MIPS_beq: int  # 110
MIPS_beqc: int  # 1754
MIPS_beqic: int  # 1743
MIPS_beql: int  # 111
MIPS_beqz: int  # 200
MIPS_beqzc: int  # 832
MIPS_beqzl: int  # 201
MIPS_bext: int  # 744
MIPS_bfins: int  # 736
MIPS_bgec: int  # 1755
MIPS_bgeic: int  # 1745
MIPS_bgeiuc: int  # 1746
MIPS_bgeuc: int  # 1756
MIPS_bgez: int  # 98
MIPS_bgezal: int  # 99
MIPS_bgezall: int  # 100
MIPS_bgezals: int  # 833
MIPS_bgezl: int  # 101
MIPS_bgtz: int  # 102
MIPS_bgtzl: int  # 103
MIPS_bins: int  # 743
MIPS_bitrev: int  # 935
MIPS_bitrevb: int  # 1761
MIPS_bitrevh: int  # 1760
MIPS_bitrevw: int  # 1759
MIPS_blez: int  # 104
MIPS_blezl: int  # 105
MIPS_bltc: int  # 1752
MIPS_bltic: int  # 1749
MIPS_bltiuc: int  # 1750
MIPS_bltuc: int  # 1753
MIPS_bltz: int  # 106
MIPS_bltzal: int  # 107
MIPS_bltzall: int  # 108
MIPS_bltzals: int  # 831
MIPS_bltzl: int  # 109
MIPS_bne: int  # 112
MIPS_bnec: int  # 1751
MIPS_bneic: int  # 1747
MIPS_bnel: int  # 113
MIPS_bnez: int  # 198
MIPS_bnezc: int  # 830
MIPS_bnezl: int  # 199
MIPS_bposge32: int  # 841
MIPS_bposge64: int  # 842
MIPS_break: int  # 80
MIPS_brsc: int  # 1757
MIPS_bs1f: int  # 735
MIPS_bset: int  # 742
MIPS_bteqz: int  # 439
MIPS_btnez: int  # 440
MIPS_btst: int  # 740
MIPS_byterevh: int  # 1763
MIPS_byterevw: int  # 1762
MIPS_cache: int  # 119
MIPS_cachee: int  # 1684
MIPS_cfc0: int  # 312
MIPS_cfc1: int  # 45
MIPS_cfc2: int  # 46
MIPS_cftc1: int  # 768
MIPS_cftc2: int  # 771
MIPS_cins: int  # 578
MIPS_cins32: int  # 579
MIPS_clo: int  # 498
MIPS_clz: int  # 499
MIPS_cmp: int  # 441
MIPS_cmp_eq_ph: int  # 886
MIPS_cmp_eq_pw: int  # 909
MIPS_cmp_eq_qh: int  # 908
MIPS_cmp_le_ph: int  # 892
MIPS_cmp_le_pw: int  # 915
MIPS_cmp_le_qh: int  # 914
MIPS_cmp_lt_ph: int  # 889
MIPS_cmp_lt_pw: int  # 912
MIPS_cmp_lt_qh: int  # 911
MIPS_cmpgdu_eq_qb: int  # 887
MIPS_cmpgdu_le_qb: int  # 893
MIPS_cmpgdu_lt_qb: int  # 890
MIPS_cmpgu_eq_ob: int  # 919
MIPS_cmpgu_eq_qb: int  # 896
MIPS_cmpgu_le_ob: int  # 925
MIPS_cmpgu_le_qb: int  # 902
MIPS_cmpgu_lt_ob: int  # 923
MIPS_cmpgu_lt_qb: int  # 899
MIPS_cmpi: int  # 442
MIPS_cmpu_eq_ob: int  # 907
MIPS_cmpu_eq_qb: int  # 885
MIPS_cmpu_le_ob: int  # 913
MIPS_cmpu_le_qb: int  # 891
MIPS_cmpu_lt_ob: int  # 910
MIPS_cmpu_lt_qb: int  # 888
MIPS_cop0: int  # 77
MIPS_cop1: int  # 78
MIPS_cop2: int  # 79
MIPS_copyw: int  # 1692
MIPS_crc32b: int  # 1700
MIPS_crc32cb: int  # 1703
MIPS_crc32ch: int  # 1704
MIPS_crc32cw: int  # 1705
MIPS_crc32h: int  # 1701
MIPS_crc32w: int  # 1702
MIPS_ctc0: int  # 313
MIPS_ctc1: int  # 47
MIPS_ctc2: int  # 48
MIPS_cttc1: int  # 782
MIPS_cttc2: int  # 785
MIPS_dadd: int  # 4
MIPS_daddi: int  # 32
MIPS_daddiu: int  # 33
MIPS_daddu: int  # 5
MIPS_dbreak: int  # 608
MIPS_dclo: int  # 558
MIPS_dclz: int  # 559
MIPS_ddiv: int  # 65
MIPS_ddivu: int  # 66
MIPS_deret: int  # 508
MIPS_dext: int  # 560
MIPS_dextm: int  # 561
MIPS_dextp: int  # 1081
MIPS_dextpdp: int  # 1082
MIPS_dextpdpv: int  # 1085
MIPS_dextpv: int  # 1084
MIPS_dextr_l: int  # 1078
MIPS_dextr_r_l: int  # 1088
MIPS_dextr_r_w: int  # 1087
MIPS_dextr_rs_l: int  # 1093
MIPS_dextr_rs_w: int  # 1091
MIPS_dextr_s_h: int  # 1092
MIPS_dextr_w: int  # 1077
MIPS_dextrv_l: int  # 1080
MIPS_dextrv_r_l: int  # 1090
MIPS_dextrv_r_w: int  # 1089
MIPS_dextrv_rs_l: int  # 1096
MIPS_dextrv_rs_w: int  # 1094
MIPS_dextrv_s_h: int  # 1095
MIPS_dextrv_w: int  # 1079
MIPS_dextu: int  # 562
MIPS_di: int  # 509
MIPS_dins: int  # 563
MIPS_dinsm: int  # 564
MIPS_dinsu: int  # 565
MIPS_dinsv: int  # 840
MIPS_div: int  # 67
MIPS_div1: int  # 333
MIPS_dive: int  # 745
MIPS_diveu: int  # 746
MIPS_divu: int  # 68
MIPS_divu1: int  # 334
MIPS_dla: int  # 495
MIPS_dli: int  # 838
MIPS_dlsa: int  # 1673
MIPS_dmadd: int  # 1038
MIPS_dmaddu: int  # 1051
MIPS_dmfc0: int  # 49
MIPS_dmfc1: int  # 542
MIPS_dmfc2: int  # 566
MIPS_dmsub: int  # 1039
MIPS_dmsubu: int  # 1059
MIPS_dmt: int  # 755
MIPS_dmtc0: int  # 51
MIPS_dmtc1: int  # 543
MIPS_dmtc2: int  # 567
MIPS_dmthlip: int  # 1097
MIPS_dmul: int  # 580
MIPS_dmult: int  # 69
MIPS_dmultu: int  # 70
MIPS_dneg: int  # 555
MIPS_dnegu: int  # 556
MIPS_dpa_w_ph: int  # 1014
MIPS_dpaq_s_w_ph: int  # 1027
MIPS_dpaq_s_w_qh: int  # 1044
MIPS_dpaq_sa_l_pw: int  # 1045
MIPS_dpaq_sa_l_w: int  # 1028
MIPS_dpaqx_s_w_ph: int  # 1017
MIPS_dpaqx_sa_w_ph: int  # 1023
MIPS_dpau_h_obl: int  # 1041
MIPS_dpau_h_obr: int  # 1056
MIPS_dpau_h_qbl: int  # 1024
MIPS_dpau_h_qbr: int  # 1034
MIPS_dpax_w_ph: int  # 1015
MIPS_dpop: int  # 581
MIPS_dps_w_ph: int  # 1018
MIPS_dpsq_s_w_ph: int  # 1030
MIPS_dpsq_s_w_qh: int  # 1048
MIPS_dpsq_sa_l_pw: int  # 1049
MIPS_dpsq_sa_l_w: int  # 1031
MIPS_dpsqx_s_w_ph: int  # 1020
MIPS_dpsqx_sa_w_ph: int  # 1026
MIPS_dpsu_h_obl: int  # 1042
MIPS_dpsu_h_obr: int  # 1057
MIPS_dpsu_h_qbl: int  # 1025
MIPS_dpsu_h_qbr: int  # 1035
MIPS_dpsx_w_ph: int  # 1019
MIPS_dret: int  # 609
MIPS_drotr: int  # 568
MIPS_drotr32: int  # 569
MIPS_drotrv: int  # 570
MIPS_dsbh: int  # 571
MIPS_dshd: int  # 572
MIPS_dshilo: int  # 1083
MIPS_dshilov: int  # 1086
MIPS_dsll: int  # 15
MIPS_dsll32: int  # 16
MIPS_dsllv: int  # 24
MIPS_dsra: int  # 17
MIPS_dsra32: int  # 18
MIPS_dsrav: int  # 25
MIPS_dsrl: int  # 19
MIPS_dsrl32: int  # 20
MIPS_dsrlv: int  # 26
MIPS_dsub: int  # 6
MIPS_dsubu: int  # 7
MIPS_dvp: int  # 1733
MIPS_dvpe: int  # 753
MIPS_ehb: int  # 510
MIPS_ei: int  # 511
MIPS_emt: int  # 756
MIPS_eret: int  # 153
MIPS_eretnc: int  # 1720
MIPS_evp: int  # 1734
MIPS_evpe: int  # 754
MIPS_ext: int  # 512
MIPS_extend: int  # 458
MIPS_extp: int  # 1062
MIPS_extpdp: int  # 1063
MIPS_extpdpv: int  # 1067
MIPS_extpv: int  # 1066
MIPS_extr_r_w: int  # 1070
MIPS_extr_rs_w: int  # 1072
MIPS_extr_s_h: int  # 1073
MIPS_extr_w: int  # 1060
MIPS_extrv_r_w: int  # 1071
MIPS_extrv_rs_w: int  # 1074
MIPS_extrv_s_h: int  # 1075
MIPS_extrv_w: int  # 1061
MIPS_exts: int  # 582
MIPS_exts32: int  # 583
MIPS_extw: int  # 1715
MIPS_fabs: int  # 162
MIPS_fadd: int  # 158
MIPS_fadda: int  # 318
MIPS_faddr: int  # 787
MIPS_fc_eq: int  # 180
MIPS_fc_f: int  # 178
MIPS_fc_le: int  # 192
MIPS_fc_lt: int  # 190
MIPS_fc_nge: int  # 191
MIPS_fc_ngl: int  # 189
MIPS_fc_ngle: int  # 187
MIPS_fc_ngt: int  # 193
MIPS_fc_ole: int  # 184
MIPS_fc_olt: int  # 182
MIPS_fc_seq: int  # 188
MIPS_fc_sf: int  # 186
MIPS_fc_ueq: int  # 181
MIPS_fc_ule: int  # 185
MIPS_fc_ult: int  # 183
MIPS_fc_un: int  # 179
MIPS_fcabs_eq: int  # 794
MIPS_fcabs_f: int  # 792
MIPS_fcabs_le: int  # 806
MIPS_fcabs_lt: int  # 804
MIPS_fcabs_nge: int  # 805
MIPS_fcabs_ngl: int  # 803
MIPS_fcabs_ngle: int  # 801
MIPS_fcabs_ngt: int  # 807
MIPS_fcabs_ole: int  # 798
MIPS_fcabs_olt: int  # 796
MIPS_fcabs_seq: int  # 802
MIPS_fcabs_sf: int  # 800
MIPS_fcabs_ueq: int  # 795
MIPS_fcabs_ule: int  # 799
MIPS_fcabs_ult: int  # 797
MIPS_fcabs_un: int  # 793
MIPS_fceil_l: int  # 169
MIPS_fceil_w: int  # 173
MIPS_fcvt_d: int  # 164
MIPS_fcvt_l: int  # 166
MIPS_fcvt_ps: int  # 513
MIPS_fcvt_ps_pw: int  # 809
MIPS_fcvt_pw_ps: int  # 808
MIPS_fcvt_s: int  # 163
MIPS_fcvt_s_pl: int  # 514
MIPS_fcvt_s_pu: int  # 515
MIPS_fcvt_w: int  # 165
MIPS_fdiv: int  # 161
MIPS_ffloor_l: int  # 170
MIPS_ffloor_w: int  # 174
MIPS_fmadd: int  # 323
MIPS_fmadda: int  # 321
MIPS_fmax: int  # 325
MIPS_fmin: int  # 326
MIPS_fmov: int  # 175
MIPS_fmovf: int  # 219
MIPS_fmovn: int  # 221
MIPS_fmovt: int  # 220
MIPS_fmovz: int  # 222
MIPS_fmsub: int  # 324
MIPS_fmsuba: int  # 322
MIPS_fmul: int  # 160
MIPS_fmula: int  # 320
MIPS_fmulr: int  # 810
MIPS_fneg: int  # 176
MIPS_fork: int  # 757
MIPS_frecip: int  # 228
MIPS_frecip1: int  # 811
MIPS_frecip2: int  # 812
MIPS_fround_l: int  # 167
MIPS_fround_w: int  # 171
MIPS_frsqrt: int  # 229
MIPS_frsqrt1: int  # 813
MIPS_frsqrt2: int  # 814
MIPS_fsqrt: int  # 177
MIPS_fsub: int  # 159
MIPS_fsuba: int  # 319
MIPS_ftrunc_l: int  # 168
MIPS_ftrunc_w: int  # 172
MIPS_ginvi: int  # 1719
MIPS_ginvt: int  # 1718
MIPS_ins: int  # 516
MIPS_insv: int  # 839
MIPS_j: int  # 115
MIPS_jal: int  # 117
MIPS_jalr: int  # 114
MIPS_jalr_hb: int  # 517
MIPS_jalrc: int  # 546
MIPS_jalrc_hb: int  # 1741
MIPS_jalrs: int  # 835
MIPS_jalrs_hb: int  # 836
MIPS_jals: int  # 821
MIPS_jalx: int  # 118
MIPS_jr: int  # 116
MIPS_jr_hb: int  # 518
MIPS_jraddiusp: int  # 834
MIPS_jrc: int  # 547
MIPS_la: int  # 205
MIPS_laa: int  # 1117
MIPS_laad: int  # 1118
MIPS_lac: int  # 1119
MIPS_lacd: int  # 1120
MIPS_lad: int  # 1121
MIPS_ladd: int  # 1122
MIPS_lai: int  # 1123
MIPS_laid: int  # 1124
MIPS_las: int  # 1125
MIPS_lasd: int  # 1126
MIPS_last: int  # 1766
MIPS_law: int  # 1127
MIPS_lawd: int  # 1128
MIPS_lb: int  # 120
MIPS_lbe: int  # 1674
MIPS_lbu: int  # 121
MIPS_lbue: int  # 1675
MIPS_lbux: int  # 1013
MIPS_lbv: int  # 230
MIPS_lbx: int  # 1129
MIPS_ld: int  # 126
MIPS_ldc1: int  # 128
MIPS_ldc2: int  # 129
MIPS_ldl: int  # 122
MIPS_ldm: int  # 825
MIPS_ldp: int  # 823
MIPS_ldr: int  # 123
MIPS_ldv: int  # 233
MIPS_ldx: int  # 1011
MIPS_ldxc1: int  # 207
MIPS_lfv: int  # 239
MIPS_lh: int  # 133
MIPS_lhe: int  # 1676
MIPS_lhu: int  # 134
MIPS_lhue: int  # 1677
MIPS_lhux: int  # 1130
MIPS_lhuxs: int  # 1712
MIPS_lhv: int  # 238
MIPS_lhx: int  # 1012
MIPS_lhxs: int  # 1711
MIPS_li: int  # 204
MIPS_li_d: int  # 554
MIPS_li_s: int  # 553
MIPS_ll: int  # 130
MIPS_lld: int  # 127
MIPS_lle: int  # 1682
MIPS_llv: int  # 232
MIPS_llwp: int  # 1724
MIPS_llwpe: int  # 1725
MIPS_lpv: int  # 236
MIPS_lq: int  # 424
MIPS_lqc2: int  # 426
MIPS_lqv: int  # 234
MIPS_lrv: int  # 235
MIPS_lsa: int  # 1672
MIPS_lsv: int  # 231
MIPS_ltv: int  # 241
MIPS_lui: int  # 135
MIPS_luv: int  # 237
MIPS_luxc1: int  # 519
MIPS_lw: int  # 131
MIPS_lwc1: int  # 136
MIPS_lwc2: int  # 137
MIPS_lwe: int  # 1678
MIPS_lwl: int  # 124
MIPS_lwle: int  # 1686
MIPS_lwm: int  # 824
MIPS_lwm2: int  # 1764
MIPS_lwp: int  # 822
MIPS_lwpc: int  # 1721
MIPS_lwr: int  # 125
MIPS_lwre: int  # 1687
MIPS_lwu: int  # 132
MIPS_lwux: int  # 1131
MIPS_lwv: int  # 240
MIPS_lwx: int  # 1010
MIPS_lwxc1: int  # 208
MIPS_lwxs: int  # 815
MIPS_madd: int  # 500
MIPS_madd1: int  # 342
MIPS_madd3: int  # 749
MIPS_madd_d: int  # 212
MIPS_madd_ps: int  # 520
MIPS_madd_r5900: int  # 428
MIPS_madd_s: int  # 211
MIPS_maddp: int  # 816
MIPS_maddu: int  # 501
MIPS_maddu1: int  # 343
MIPS_maddu3: int  # 750
MIPS_maddu_r5900: int  # 429
MIPS_maq_s_l_pwl: int  # 1047
MIPS_maq_s_l_pwr: int  # 1055
MIPS_maq_s_w_phl: int  # 1029
MIPS_maq_s_w_phr: int  # 1033
MIPS_maq_s_w_qhll: int  # 1046
MIPS_maq_s_w_qhlr: int  # 1050
MIPS_maq_s_w_qhrl: int  # 1054
MIPS_maq_s_w_qhrr: int  # 1058
MIPS_maq_sa_w_phl: int  # 1016
MIPS_maq_sa_w_phr: int  # 1022
MIPS_maq_sa_w_qhll: int  # 1036
MIPS_maq_sa_w_qhlr: int  # 1037
MIPS_maq_sa_w_qhrl: int  # 1040
MIPS_maq_sa_w_qhrr: int  # 1043
MIPS_max: int  # 748
MIPS_mfc0: int  # 53
MIPS_mfc1: int  # 54
MIPS_mfc2: int  # 55
MIPS_mfdr: int  # 610
MIPS_mfhc0: int  # 1713
MIPS_mfhc1: int  # 521
MIPS_mfhc2: int  # 522
MIPS_mfhi: int  # 75
MIPS_mfhi1: int  # 419
MIPS_mflhxu: int  # 817
MIPS_mflo: int  # 76
MIPS_mflo1: int  # 420
MIPS_mfsa: int  # 315
MIPS_mftacx: int  # 764
MIPS_mftc0: int  # 760
MIPS_mftc1: int  # 767
MIPS_mftc2: int  # 770
MIPS_mftdsp: int  # 765
MIPS_mftgpr: int  # 772
MIPS_mfthc0: int  # 761
MIPS_mfthc1: int  # 766
MIPS_mfthc2: int  # 769
MIPS_mfthi: int  # 763
MIPS_mftlo: int  # 762
MIPS_mftr: int  # 759
MIPS_min: int  # 747
MIPS_mod: int  # 1697
MIPS_modsub: int  # 850
MIPS_modu: int  # 1698
MIPS_mov: int  # 195
MIPS_move: int  # 473
MIPS_move_balc: int  # 1739
MIPS_movep: int  # 837
MIPS_movf: int  # 215
MIPS_movn: int  # 217
MIPS_movt: int  # 216
MIPS_movtn: int  # 1691
MIPS_movtz: int  # 1690
MIPS_movz: int  # 218
MIPS_msa_add_a_b: int  # 1318
MIPS_msa_add_a_d: int  # 1321
MIPS_msa_add_a_h: int  # 1319
MIPS_msa_add_a_w: int  # 1320
MIPS_msa_adds_a_b: int  # 1322
MIPS_msa_adds_a_d: int  # 1325
MIPS_msa_adds_a_h: int  # 1323
MIPS_msa_adds_a_w: int  # 1324
MIPS_msa_adds_s_b: int  # 1326
MIPS_msa_adds_s_d: int  # 1329
MIPS_msa_adds_s_h: int  # 1327
MIPS_msa_adds_s_w: int  # 1328
MIPS_msa_adds_u_b: int  # 1330
MIPS_msa_adds_u_d: int  # 1333
MIPS_msa_adds_u_h: int  # 1331
MIPS_msa_adds_u_w: int  # 1332
MIPS_msa_addv_b: int  # 1206
MIPS_msa_addv_d: int  # 1209
MIPS_msa_addv_h: int  # 1207
MIPS_msa_addv_w: int  # 1208
MIPS_msa_addvi_b: int  # 1210
MIPS_msa_addvi_d: int  # 1213
MIPS_msa_addvi_h: int  # 1211
MIPS_msa_addvi_w: int  # 1212
MIPS_msa_and_v: int  # 1492
MIPS_msa_andi_b: int  # 1493
MIPS_msa_asub_s_b: int  # 1366
MIPS_msa_asub_s_d: int  # 1369
MIPS_msa_asub_s_h: int  # 1367
MIPS_msa_asub_s_w: int  # 1368
MIPS_msa_asub_u_b: int  # 1370
MIPS_msa_asub_u_d: int  # 1373
MIPS_msa_asub_u_h: int  # 1371
MIPS_msa_asub_u_w: int  # 1372
MIPS_msa_ave_s_b: int  # 1334
MIPS_msa_ave_s_d: int  # 1337
MIPS_msa_ave_s_h: int  # 1335
MIPS_msa_ave_s_w: int  # 1336
MIPS_msa_ave_u_b: int  # 1338
MIPS_msa_ave_u_d: int  # 1341
MIPS_msa_ave_u_h: int  # 1339
MIPS_msa_ave_u_w: int  # 1340
MIPS_msa_aver_s_b: int  # 1342
MIPS_msa_aver_s_d: int  # 1345
MIPS_msa_aver_s_h: int  # 1343
MIPS_msa_aver_s_w: int  # 1344
MIPS_msa_aver_u_b: int  # 1346
MIPS_msa_aver_u_d: int  # 1349
MIPS_msa_aver_u_h: int  # 1347
MIPS_msa_aver_u_w: int  # 1348
MIPS_msa_bclr_b: int  # 1166
MIPS_msa_bclr_d: int  # 1169
MIPS_msa_bclr_h: int  # 1167
MIPS_msa_bclr_w: int  # 1168
MIPS_msa_bclri_b: int  # 1170
MIPS_msa_bclri_d: int  # 1173
MIPS_msa_bclri_h: int  # 1171
MIPS_msa_bclri_w: int  # 1172
MIPS_msa_binsl_b: int  # 1190
MIPS_msa_binsl_d: int  # 1193
MIPS_msa_binsl_h: int  # 1191
MIPS_msa_binsl_w: int  # 1192
MIPS_msa_binsli_b: int  # 1194
MIPS_msa_binsli_d: int  # 1197
MIPS_msa_binsli_h: int  # 1195
MIPS_msa_binsli_w: int  # 1196
MIPS_msa_binsr_b: int  # 1198
MIPS_msa_binsr_d: int  # 1201
MIPS_msa_binsr_h: int  # 1199
MIPS_msa_binsr_w: int  # 1200
MIPS_msa_binsri_b: int  # 1202
MIPS_msa_binsri_d: int  # 1205
MIPS_msa_binsri_h: int  # 1203
MIPS_msa_binsri_w: int  # 1204
MIPS_msa_bmnz_v: int  # 1500
MIPS_msa_bmnzi_b: int  # 1501
MIPS_msa_bmz_v: int  # 1502
MIPS_msa_bmzi_b: int  # 1503
MIPS_msa_bneg_b: int  # 1182
MIPS_msa_bneg_d: int  # 1185
MIPS_msa_bneg_h: int  # 1183
MIPS_msa_bneg_w: int  # 1184
MIPS_msa_bnegi_b: int  # 1186
MIPS_msa_bnegi_d: int  # 1189
MIPS_msa_bnegi_h: int  # 1187
MIPS_msa_bnegi_w: int  # 1188
MIPS_msa_bnz_b: int  # 1543
MIPS_msa_bnz_d: int  # 1546
MIPS_msa_bnz_h: int  # 1544
MIPS_msa_bnz_v: int  # 1509
MIPS_msa_bnz_w: int  # 1545
MIPS_msa_bsel_v: int  # 1504
MIPS_msa_bseli_b: int  # 1505
MIPS_msa_bset_b: int  # 1174
MIPS_msa_bset_d: int  # 1177
MIPS_msa_bset_h: int  # 1175
MIPS_msa_bset_w: int  # 1176
MIPS_msa_bseti_b: int  # 1178
MIPS_msa_bseti_d: int  # 1181
MIPS_msa_bseti_h: int  # 1179
MIPS_msa_bseti_w: int  # 1180
MIPS_msa_bz_b: int  # 1547
MIPS_msa_bz_d: int  # 1550
MIPS_msa_bz_h: int  # 1548
MIPS_msa_bz_v: int  # 1510
MIPS_msa_bz_w: int  # 1549
MIPS_msa_ceq_b: int  # 1262
MIPS_msa_ceq_d: int  # 1265
MIPS_msa_ceq_h: int  # 1263
MIPS_msa_ceq_w: int  # 1264
MIPS_msa_ceqi_b: int  # 1266
MIPS_msa_ceqi_d: int  # 1269
MIPS_msa_ceqi_h: int  # 1267
MIPS_msa_ceqi_w: int  # 1268
MIPS_msa_cfcmsa: int  # 1670
MIPS_msa_cle_s_b: int  # 1286
MIPS_msa_cle_s_d: int  # 1289
MIPS_msa_cle_s_h: int  # 1287
MIPS_msa_cle_s_w: int  # 1288
MIPS_msa_cle_u_b: int  # 1294
MIPS_msa_cle_u_d: int  # 1297
MIPS_msa_cle_u_h: int  # 1295
MIPS_msa_cle_u_w: int  # 1296
MIPS_msa_clei_s_b: int  # 1290
MIPS_msa_clei_s_d: int  # 1293
MIPS_msa_clei_s_h: int  # 1291
MIPS_msa_clei_s_w: int  # 1292
MIPS_msa_clei_u_b: int  # 1298
MIPS_msa_clei_u_d: int  # 1301
MIPS_msa_clei_u_h: int  # 1299
MIPS_msa_clei_u_w: int  # 1300
MIPS_msa_clt_s_b: int  # 1270
MIPS_msa_clt_s_d: int  # 1273
MIPS_msa_clt_s_h: int  # 1271
MIPS_msa_clt_s_w: int  # 1272
MIPS_msa_clt_u_b: int  # 1278
MIPS_msa_clt_u_d: int  # 1281
MIPS_msa_clt_u_h: int  # 1279
MIPS_msa_clt_u_w: int  # 1280
MIPS_msa_clti_s_b: int  # 1274
MIPS_msa_clti_s_d: int  # 1277
MIPS_msa_clti_s_h: int  # 1275
MIPS_msa_clti_s_w: int  # 1276
MIPS_msa_clti_u_b: int  # 1282
MIPS_msa_clti_u_d: int  # 1285
MIPS_msa_clti_u_h: int  # 1283
MIPS_msa_clti_u_w: int  # 1284
MIPS_msa_copy_s_b: int  # 1527
MIPS_msa_copy_s_d: int  # 1530
MIPS_msa_copy_s_h: int  # 1528
MIPS_msa_copy_s_w: int  # 1529
MIPS_msa_copy_u_b: int  # 1531
MIPS_msa_copy_u_d: int  # 1534
MIPS_msa_copy_u_h: int  # 1532
MIPS_msa_copy_u_w: int  # 1533
MIPS_msa_ctcmsa: int  # 1669
MIPS_msa_div_s_b: int  # 1386
MIPS_msa_div_s_d: int  # 1389
MIPS_msa_div_s_h: int  # 1387
MIPS_msa_div_s_w: int  # 1388
MIPS_msa_div_u_b: int  # 1390
MIPS_msa_div_u_d: int  # 1393
MIPS_msa_div_u_h: int  # 1391
MIPS_msa_div_u_w: int  # 1392
MIPS_msa_dotp_s_d: int  # 1404
MIPS_msa_dotp_s_h: int  # 1402
MIPS_msa_dotp_s_w: int  # 1403
MIPS_msa_dotp_u_d: int  # 1407
MIPS_msa_dotp_u_h: int  # 1405
MIPS_msa_dotp_u_w: int  # 1406
MIPS_msa_dpadd_s_d: int  # 1410
MIPS_msa_dpadd_s_h: int  # 1408
MIPS_msa_dpadd_s_w: int  # 1409
MIPS_msa_dpadd_u_d: int  # 1413
MIPS_msa_dpadd_u_h: int  # 1411
MIPS_msa_dpadd_u_w: int  # 1412
MIPS_msa_dpsub_s_d: int  # 1416
MIPS_msa_dpsub_s_h: int  # 1414
MIPS_msa_dpsub_s_w: int  # 1415
MIPS_msa_dpsub_u_d: int  # 1419
MIPS_msa_dpsub_u_h: int  # 1417
MIPS_msa_dpsub_u_w: int  # 1418
MIPS_msa_fadd_d: int  # 1588
MIPS_msa_fadd_w: int  # 1587
MIPS_msa_fcaf_d: int  # 1556
MIPS_msa_fcaf_w: int  # 1555
MIPS_msa_fceq_d: int  # 1560
MIPS_msa_fceq_w: int  # 1559
MIPS_msa_fclass_d: int  # 1638
MIPS_msa_fclass_w: int  # 1637
MIPS_msa_fcle_d: int  # 1568
MIPS_msa_fcle_w: int  # 1567
MIPS_msa_fclt_d: int  # 1564
MIPS_msa_fclt_w: int  # 1563
MIPS_msa_fcne_d: int  # 1618
MIPS_msa_fcne_w: int  # 1617
MIPS_msa_fcor_d: int  # 1614
MIPS_msa_fcor_w: int  # 1613
MIPS_msa_fcueq_d: int  # 1562
MIPS_msa_fcueq_w: int  # 1561
MIPS_msa_fcule_d: int  # 1570
MIPS_msa_fcule_w: int  # 1569
MIPS_msa_fcult_d: int  # 1566
MIPS_msa_fcult_w: int  # 1565
MIPS_msa_fcun_d: int  # 1558
MIPS_msa_fcun_w: int  # 1557
MIPS_msa_fcune_d: int  # 1616
MIPS_msa_fcune_w: int  # 1615
MIPS_msa_fdiv_d: int  # 1594
MIPS_msa_fdiv_w: int  # 1593
MIPS_msa_fexdo_h: int  # 1601
MIPS_msa_fexdo_w: int  # 1602
MIPS_msa_fexp2_d: int  # 1600
MIPS_msa_fexp2_w: int  # 1599
MIPS_msa_fexupl_d: int  # 1654
MIPS_msa_fexupl_w: int  # 1653
MIPS_msa_fexupr_d: int  # 1656
MIPS_msa_fexupr_w: int  # 1655
MIPS_msa_ffint_s_d: int  # 1666
MIPS_msa_ffint_s_w: int  # 1665
MIPS_msa_ffint_u_d: int  # 1668
MIPS_msa_ffint_u_w: int  # 1667
MIPS_msa_ffql_d: int  # 1658
MIPS_msa_ffql_w: int  # 1657
MIPS_msa_ffqr_d: int  # 1660
MIPS_msa_ffqr_w: int  # 1659
MIPS_msa_fill_b: int  # 1511
MIPS_msa_fill_d: int  # 1514
MIPS_msa_fill_h: int  # 1512
MIPS_msa_fill_w: int  # 1513
MIPS_msa_flog2_d: int  # 1652
MIPS_msa_flog2_w: int  # 1651
MIPS_msa_fmadd_d: int  # 1596
MIPS_msa_fmadd_w: int  # 1595
MIPS_msa_fmax_a_d: int  # 1612
MIPS_msa_fmax_a_w: int  # 1611
MIPS_msa_fmax_d: int  # 1610
MIPS_msa_fmax_w: int  # 1609
MIPS_msa_fmin_a_d: int  # 1608
MIPS_msa_fmin_a_w: int  # 1607
MIPS_msa_fmin_d: int  # 1606
MIPS_msa_fmin_w: int  # 1605
MIPS_msa_fmsub_d: int  # 1598
MIPS_msa_fmsub_w: int  # 1597
MIPS_msa_fmul_d: int  # 1592
MIPS_msa_fmul_w: int  # 1591
MIPS_msa_frcp_d: int  # 1648
MIPS_msa_frcp_w: int  # 1647
MIPS_msa_frint_d: int  # 1650
MIPS_msa_frint_w: int  # 1649
MIPS_msa_frsqrt_d: int  # 1646
MIPS_msa_frsqrt_w: int  # 1645
MIPS_msa_fsaf_d: int  # 1572
MIPS_msa_fsaf_w: int  # 1571
MIPS_msa_fseq_d: int  # 1576
MIPS_msa_fseq_w: int  # 1575
MIPS_msa_fsle_d: int  # 1584
MIPS_msa_fsle_w: int  # 1583
MIPS_msa_fslt_d: int  # 1580
MIPS_msa_fslt_w: int  # 1579
MIPS_msa_fsne_d: int  # 1630
MIPS_msa_fsne_w: int  # 1629
MIPS_msa_fsor_d: int  # 1626
MIPS_msa_fsor_w: int  # 1625
MIPS_msa_fsqrt_d: int  # 1644
MIPS_msa_fsqrt_w: int  # 1643
MIPS_msa_fsub_d: int  # 1590
MIPS_msa_fsub_w: int  # 1589
MIPS_msa_fsueq_d: int  # 1578
MIPS_msa_fsueq_w: int  # 1577
MIPS_msa_fsule_d: int  # 1586
MIPS_msa_fsule_w: int  # 1585
MIPS_msa_fsult_d: int  # 1582
MIPS_msa_fsult_w: int  # 1581
MIPS_msa_fsun_d: int  # 1574
MIPS_msa_fsun_w: int  # 1573
MIPS_msa_fsune_d: int  # 1628
MIPS_msa_fsune_w: int  # 1627
MIPS_msa_ftint_s_d: int  # 1662
MIPS_msa_ftint_s_w: int  # 1661
MIPS_msa_ftint_u_d: int  # 1664
MIPS_msa_ftint_u_w: int  # 1663
MIPS_msa_ftq_h: int  # 1603
MIPS_msa_ftq_w: int  # 1604
MIPS_msa_ftrunc_s_d: int  # 1640
MIPS_msa_ftrunc_s_w: int  # 1639
MIPS_msa_ftrunc_u_d: int  # 1642
MIPS_msa_ftrunc_u_w: int  # 1641
MIPS_msa_hadd_s_d: int  # 1482
MIPS_msa_hadd_s_h: int  # 1480
MIPS_msa_hadd_s_w: int  # 1481
MIPS_msa_hadd_u_d: int  # 1485
MIPS_msa_hadd_u_h: int  # 1483
MIPS_msa_hadd_u_w: int  # 1484
MIPS_msa_hsub_s_d: int  # 1488
MIPS_msa_hsub_s_h: int  # 1486
MIPS_msa_hsub_s_w: int  # 1487
MIPS_msa_hsub_u_d: int  # 1491
MIPS_msa_hsub_u_h: int  # 1489
MIPS_msa_hsub_u_w: int  # 1490
MIPS_msa_ilvev_b: int  # 1452
MIPS_msa_ilvev_d: int  # 1455
MIPS_msa_ilvev_h: int  # 1453
MIPS_msa_ilvev_w: int  # 1454
MIPS_msa_ilvl_b: int  # 1444
MIPS_msa_ilvl_d: int  # 1447
MIPS_msa_ilvl_h: int  # 1445
MIPS_msa_ilvl_w: int  # 1446
MIPS_msa_ilvod_b: int  # 1456
MIPS_msa_ilvod_d: int  # 1459
MIPS_msa_ilvod_h: int  # 1457
MIPS_msa_ilvod_w: int  # 1458
MIPS_msa_ilvr_b: int  # 1448
MIPS_msa_ilvr_d: int  # 1451
MIPS_msa_ilvr_h: int  # 1449
MIPS_msa_ilvr_w: int  # 1450
MIPS_msa_insert_b: int  # 1535
MIPS_msa_insert_d: int  # 1538
MIPS_msa_insert_h: int  # 1536
MIPS_msa_insert_w: int  # 1537
MIPS_msa_insve_b: int  # 1539
MIPS_msa_insve_d: int  # 1542
MIPS_msa_insve_h: int  # 1540
MIPS_msa_insve_w: int  # 1541
MIPS_msa_ld_b: int  # 1302
MIPS_msa_ld_d: int  # 1305
MIPS_msa_ld_h: int  # 1303
MIPS_msa_ld_w: int  # 1304
MIPS_msa_ldi_b: int  # 1551
MIPS_msa_ldi_d: int  # 1554
MIPS_msa_ldi_h: int  # 1552
MIPS_msa_ldi_w: int  # 1553
MIPS_msa_madd_q_h: int  # 1621
MIPS_msa_madd_q_w: int  # 1622
MIPS_msa_maddr_q_h: int  # 1633
MIPS_msa_maddr_q_w: int  # 1634
MIPS_msa_maddv_b: int  # 1378
MIPS_msa_maddv_d: int  # 1381
MIPS_msa_maddv_h: int  # 1379
MIPS_msa_maddv_w: int  # 1380
MIPS_msa_max_a_b: int  # 1254
MIPS_msa_max_a_d: int  # 1257
MIPS_msa_max_a_h: int  # 1255
MIPS_msa_max_a_w: int  # 1256
MIPS_msa_max_s_b: int  # 1222
MIPS_msa_max_s_d: int  # 1225
MIPS_msa_max_s_h: int  # 1223
MIPS_msa_max_s_w: int  # 1224
MIPS_msa_max_u_b: int  # 1230
MIPS_msa_max_u_d: int  # 1233
MIPS_msa_max_u_h: int  # 1231
MIPS_msa_max_u_w: int  # 1232
MIPS_msa_maxi_s_b: int  # 1226
MIPS_msa_maxi_s_d: int  # 1229
MIPS_msa_maxi_s_h: int  # 1227
MIPS_msa_maxi_s_w: int  # 1228
MIPS_msa_maxi_u_b: int  # 1234
MIPS_msa_maxi_u_d: int  # 1237
MIPS_msa_maxi_u_h: int  # 1235
MIPS_msa_maxi_u_w: int  # 1236
MIPS_msa_min_a_b: int  # 1258
MIPS_msa_min_a_d: int  # 1261
MIPS_msa_min_a_h: int  # 1259
MIPS_msa_min_a_w: int  # 1260
MIPS_msa_min_s_b: int  # 1238
MIPS_msa_min_s_d: int  # 1241
MIPS_msa_min_s_h: int  # 1239
MIPS_msa_min_s_w: int  # 1240
MIPS_msa_min_u_b: int  # 1246
MIPS_msa_min_u_d: int  # 1249
MIPS_msa_min_u_h: int  # 1247
MIPS_msa_min_u_w: int  # 1248
MIPS_msa_mini_s_b: int  # 1242
MIPS_msa_mini_s_d: int  # 1245
MIPS_msa_mini_s_h: int  # 1243
MIPS_msa_mini_s_w: int  # 1244
MIPS_msa_mini_u_b: int  # 1250
MIPS_msa_mini_u_d: int  # 1253
MIPS_msa_mini_u_h: int  # 1251
MIPS_msa_mini_u_w: int  # 1252
MIPS_msa_mod_s_b: int  # 1394
MIPS_msa_mod_s_d: int  # 1397
MIPS_msa_mod_s_h: int  # 1395
MIPS_msa_mod_s_w: int  # 1396
MIPS_msa_mod_u_b: int  # 1398
MIPS_msa_mod_u_d: int  # 1401
MIPS_msa_mod_u_h: int  # 1399
MIPS_msa_mod_u_w: int  # 1400
MIPS_msa_move_v: int  # 1671
MIPS_msa_msub_q_h: int  # 1623
MIPS_msa_msub_q_w: int  # 1624
MIPS_msa_msubr_q_h: int  # 1635
MIPS_msa_msubr_q_w: int  # 1636
MIPS_msa_msubv_b: int  # 1382
MIPS_msa_msubv_d: int  # 1385
MIPS_msa_msubv_h: int  # 1383
MIPS_msa_msubv_w: int  # 1384
MIPS_msa_mul_q_h: int  # 1619
MIPS_msa_mul_q_w: int  # 1620
MIPS_msa_mulr_q_h: int  # 1631
MIPS_msa_mulr_q_w: int  # 1632
MIPS_msa_mulv_b: int  # 1374
MIPS_msa_mulv_d: int  # 1377
MIPS_msa_mulv_h: int  # 1375
MIPS_msa_mulv_w: int  # 1376
MIPS_msa_nloc_b: int  # 1519
MIPS_msa_nloc_d: int  # 1522
MIPS_msa_nloc_h: int  # 1520
MIPS_msa_nloc_w: int  # 1521
MIPS_msa_nlzc_b: int  # 1523
MIPS_msa_nlzc_d: int  # 1526
MIPS_msa_nlzc_h: int  # 1524
MIPS_msa_nlzc_w: int  # 1525
MIPS_msa_nor_v: int  # 1496
MIPS_msa_nori_b: int  # 1497
MIPS_msa_or_v: int  # 1494
MIPS_msa_ori_b: int  # 1495
MIPS_msa_pckev_b: int  # 1436
MIPS_msa_pckev_d: int  # 1439
MIPS_msa_pckev_h: int  # 1437
MIPS_msa_pckev_w: int  # 1438
MIPS_msa_pckod_b: int  # 1440
MIPS_msa_pckod_d: int  # 1443
MIPS_msa_pckod_h: int  # 1441
MIPS_msa_pckod_w: int  # 1442
MIPS_msa_pcnt_b: int  # 1515
MIPS_msa_pcnt_d: int  # 1518
MIPS_msa_pcnt_h: int  # 1516
MIPS_msa_pcnt_w: int  # 1517
MIPS_msa_sat_s_b: int  # 1310
MIPS_msa_sat_s_d: int  # 1313
MIPS_msa_sat_s_h: int  # 1311
MIPS_msa_sat_s_w: int  # 1312
MIPS_msa_sat_u_b: int  # 1314
MIPS_msa_sat_u_d: int  # 1317
MIPS_msa_sat_u_h: int  # 1315
MIPS_msa_sat_u_w: int  # 1316
MIPS_msa_shf_b: int  # 1506
MIPS_msa_shf_h: int  # 1507
MIPS_msa_shf_w: int  # 1508
MIPS_msa_sld_b: int  # 1420
MIPS_msa_sld_d: int  # 1423
MIPS_msa_sld_h: int  # 1421
MIPS_msa_sld_w: int  # 1422
MIPS_msa_sldi_b: int  # 1424
MIPS_msa_sldi_d: int  # 1427
MIPS_msa_sldi_h: int  # 1425
MIPS_msa_sldi_w: int  # 1426
MIPS_msa_sll_b: int  # 1142
MIPS_msa_sll_d: int  # 1145
MIPS_msa_sll_h: int  # 1143
MIPS_msa_sll_w: int  # 1144
MIPS_msa_slli_b: int  # 1146
MIPS_msa_slli_d: int  # 1149
MIPS_msa_slli_h: int  # 1147
MIPS_msa_slli_w: int  # 1148
MIPS_msa_splat_b: int  # 1428
MIPS_msa_splat_d: int  # 1431
MIPS_msa_splat_h: int  # 1429
MIPS_msa_splat_w: int  # 1430
MIPS_msa_splati_b: int  # 1432
MIPS_msa_splati_d: int  # 1435
MIPS_msa_splati_h: int  # 1433
MIPS_msa_splati_w: int  # 1434
MIPS_msa_sra_b: int  # 1150
MIPS_msa_sra_d: int  # 1153
MIPS_msa_sra_h: int  # 1151
MIPS_msa_sra_w: int  # 1152
MIPS_msa_srai_b: int  # 1154
MIPS_msa_srai_d: int  # 1157
MIPS_msa_srai_h: int  # 1155
MIPS_msa_srai_w: int  # 1156
MIPS_msa_srar_b: int  # 1464
MIPS_msa_srar_d: int  # 1467
MIPS_msa_srar_h: int  # 1465
MIPS_msa_srar_w: int  # 1466
MIPS_msa_srari_b: int  # 1468
MIPS_msa_srari_d: int  # 1471
MIPS_msa_srari_h: int  # 1469
MIPS_msa_srari_w: int  # 1470
MIPS_msa_srl_b: int  # 1158
MIPS_msa_srl_d: int  # 1161
MIPS_msa_srl_h: int  # 1159
MIPS_msa_srl_w: int  # 1160
MIPS_msa_srli_b: int  # 1162
MIPS_msa_srli_d: int  # 1165
MIPS_msa_srli_h: int  # 1163
MIPS_msa_srli_w: int  # 1164
MIPS_msa_srlr_b: int  # 1472
MIPS_msa_srlr_d: int  # 1475
MIPS_msa_srlr_h: int  # 1473
MIPS_msa_srlr_w: int  # 1474
MIPS_msa_srlri_b: int  # 1476
MIPS_msa_srlri_d: int  # 1479
MIPS_msa_srlri_h: int  # 1477
MIPS_msa_srlri_w: int  # 1478
MIPS_msa_st_b: int  # 1306
MIPS_msa_st_d: int  # 1309
MIPS_msa_st_h: int  # 1307
MIPS_msa_st_w: int  # 1308
MIPS_msa_subs_s_b: int  # 1350
MIPS_msa_subs_s_d: int  # 1353
MIPS_msa_subs_s_h: int  # 1351
MIPS_msa_subs_s_w: int  # 1352
MIPS_msa_subs_u_b: int  # 1354
MIPS_msa_subs_u_d: int  # 1357
MIPS_msa_subs_u_h: int  # 1355
MIPS_msa_subs_u_w: int  # 1356
MIPS_msa_subsus_u_b: int  # 1358
MIPS_msa_subsus_u_d: int  # 1361
MIPS_msa_subsus_u_h: int  # 1359
MIPS_msa_subsus_u_w: int  # 1360
MIPS_msa_subsuu_s_b: int  # 1362
MIPS_msa_subsuu_s_d: int  # 1365
MIPS_msa_subsuu_s_h: int  # 1363
MIPS_msa_subsuu_s_w: int  # 1364
MIPS_msa_subv_b: int  # 1214
MIPS_msa_subv_d: int  # 1217
MIPS_msa_subv_h: int  # 1215
MIPS_msa_subv_w: int  # 1216
MIPS_msa_subvi_b: int  # 1218
MIPS_msa_subvi_d: int  # 1221
MIPS_msa_subvi_h: int  # 1219
MIPS_msa_subvi_w: int  # 1220
MIPS_msa_vshf_b: int  # 1460
MIPS_msa_vshf_d: int  # 1463
MIPS_msa_vshf_h: int  # 1461
MIPS_msa_vshf_w: int  # 1462
MIPS_msa_xor_v: int  # 1498
MIPS_msa_xori_b: int  # 1499
MIPS_msub: int  # 502
MIPS_msub3: int  # 751
MIPS_msub_d: int  # 214
MIPS_msub_ps: int  # 523
MIPS_msub_s: int  # 213
MIPS_msubu: int  # 503
MIPS_msubu3: int  # 752
MIPS_mtc0: int  # 56
MIPS_mtc1: int  # 57
MIPS_mtc2: int  # 58
MIPS_mtdr: int  # 611
MIPS_mthc0: int  # 1714
MIPS_mthc1: int  # 524
MIPS_mthc2: int  # 525
MIPS_mthi: int  # 73
MIPS_mthi1: int  # 328
MIPS_mthlip: int  # 1076
MIPS_mtlhx: int  # 818
MIPS_mtlo: int  # 74
MIPS_mtlo1: int  # 329
MIPS_mtm0: int  # 584
MIPS_mtm1: int  # 585
MIPS_mtm2: int  # 586
MIPS_mtp0: int  # 587
MIPS_mtp1: int  # 588
MIPS_mtp2: int  # 589
MIPS_mtsa: int  # 314
MIPS_mtsab: int  # 316
MIPS_mtsah: int  # 317
MIPS_mttacx: int  # 778
MIPS_mttc0: int  # 774
MIPS_mttc1: int  # 781
MIPS_mttc2: int  # 784
MIPS_mttdsp: int  # 779
MIPS_mttgpr: int  # 786
MIPS_mtthc0: int  # 775
MIPS_mtthc1: int  # 780
MIPS_mtthc2: int  # 783
MIPS_mtthi: int  # 777
MIPS_mttlo: int  # 776
MIPS_mttr: int  # 773
MIPS_muh: int  # 1694
MIPS_muhu: int  # 1696
MIPS_mul: int  # 504
MIPS_mul_ph: int  # 1110
MIPS_mul_s_ph: int  # 1111
MIPS_muleq_s_pw_qhl: int  # 875
MIPS_muleq_s_pw_qhr: int  # 877
MIPS_muleq_s_w_phl: int  # 855
MIPS_muleq_s_w_phr: int  # 858
MIPS_muleu_s_ph_qbl: int  # 859
MIPS_muleu_s_ph_qbr: int  # 863
MIPS_muleu_s_qh_obl: int  # 878
MIPS_muleu_s_qh_obr: int  # 881
MIPS_mulq_rs_ph: int  # 866
MIPS_mulq_rs_qh: int  # 884
MIPS_mulq_rs_w: int  # 1113
MIPS_mulq_s_ph: int  # 862
MIPS_mulq_s_w: int  # 1112
MIPS_mulsa_w_ph: int  # 1021
MIPS_mulsaq_s_l_pw: int  # 1053
MIPS_mulsaq_s_w_ph: int  # 1032
MIPS_mulsaq_s_w_qh: int  # 1052
MIPS_mult: int  # 71
MIPS_mult1: int  # 340
MIPS_mult3: int  # 430
MIPS_multp: int  # 819
MIPS_multu: int  # 72
MIPS_multu1: int  # 341
MIPS_multu3: int  # 431
MIPS_mulu: int  # 1695
MIPS_neg: int  # 196
MIPS_negu: int  # 197
MIPS_nmadd_d: int  # 224
MIPS_nmadd_ps: int  # 526
MIPS_nmadd_s: int  # 223
MIPS_nmsub_d: int  # 226
MIPS_nmsub_ps: int  # 527
MIPS_nmsub_s: int  # 225
MIPS_nop: int  # 194
MIPS_nor: int  # 8
MIPS_not: int  # 477
MIPS_null: int  # 0
MIPS_or: int  # 9
MIPS_ori: int  # 37
MIPS_pabsh: int  # 403
MIPS_pabsw: int  # 402
MIPS_packrl_ph: int  # 903
MIPS_packrl_pw: int  # 926
MIPS_paddb: int  # 361
MIPS_paddh: int  # 353
MIPS_paddsb: int  # 393
MIPS_paddsh: int  # 384
MIPS_paddsw: int  # 371
MIPS_paddub: int  # 394
MIPS_padduh: int  # 386
MIPS_padduw: int  # 373
MIPS_paddw: int  # 338
MIPS_padsbh: int  # 355
MIPS_pand: int  # 378
MIPS_pause: int  # 557
MIPS_pceqb: int  # 365
MIPS_pceqh: int  # 358
MIPS_pceqw: int  # 348
MIPS_pcgtb: int  # 363
MIPS_pcgth: int  # 357
MIPS_pcgtw: int  # 346
MIPS_pcpyh: int  # 407
MIPS_pcpyld: int  # 369
MIPS_pcpyud: int  # 370
MIPS_pdivbw: int  # 337
MIPS_pdivuw: int  # 336
MIPS_pdivw: int  # 335
MIPS_pexch: int  # 405
MIPS_pexcw: int  # 410
MIPS_pexoh: int  # 404
MIPS_pexow: int  # 409
MIPS_pext5: int  # 408
MIPS_pextlb: int  # 397
MIPS_pextlh: int  # 390
MIPS_pextlw: int  # 377
MIPS_pextub: int  # 398
MIPS_pextuh: int  # 391
MIPS_pextuw: int  # 379
MIPS_phmadh: int  # 375
MIPS_phmsbh: int  # 388
MIPS_pick_ob: int  # 916
MIPS_pick_ph: int  # 895
MIPS_pick_pw: int  # 918
MIPS_pick_qb: int  # 894
MIPS_pick_qh: int  # 917
MIPS_pinth: int  # 364
MIPS_pintoh: int  # 366
MIPS_pll: int  # 528
MIPS_plu: int  # 529
MIPS_plzcw: int  # 327
MIPS_pmaddh: int  # 372
MIPS_pmadduw: int  # 344
MIPS_pmaddw: int  # 339
MIPS_pmaxh: int  # 359
MIPS_pmaxw: int  # 349
MIPS_pmfhi: int  # 421
MIPS_pmfhl: int  # 423
MIPS_pmflo: int  # 422
MIPS_pminh: int  # 360
MIPS_pminw: int  # 351
MIPS_pmsubh: int  # 385
MIPS_pmsubw: int  # 354
MIPS_pmthi: int  # 331
MIPS_pmthl_lw: int  # 330
MIPS_pmtlo: int  # 332
MIPS_pmulth: int  # 401
MIPS_pmultuw: int  # 368
MIPS_pmultw: int  # 367
MIPS_pnor: int  # 383
MIPS_pop: int  # 590
MIPS_por: int  # 380
MIPS_ppac5: int  # 411
MIPS_ppacb: int  # 399
MIPS_ppach: int  # 392
MIPS_ppacw: int  # 381
MIPS_pperm: int  # 820
MIPS_preceq_pw_qhl: int  # 955
MIPS_preceq_pw_qhla: int  # 963
MIPS_preceq_pw_qhr: int  # 959
MIPS_preceq_pw_qhra: int  # 966
MIPS_preceq_s_l_pwl: int  # 956
MIPS_preceq_s_l_pwr: int  # 960
MIPS_preceq_w_phl: int  # 937
MIPS_preceq_w_phr: int  # 940
MIPS_precequ_ph_qbl: int  # 936
MIPS_precequ_ph_qbla: int  # 942
MIPS_precequ_ph_qbr: int  # 939
MIPS_precequ_ph_qbra: int  # 944
MIPS_precequ_pw_qhl: int  # 954
MIPS_precequ_pw_qhla: int  # 962
MIPS_precequ_pw_qhr: int  # 958
MIPS_precequ_pw_qhra: int  # 965
MIPS_preceu_ph_qbl: int  # 938
MIPS_preceu_ph_qbla: int  # 943
MIPS_preceu_ph_qbr: int  # 941
MIPS_preceu_ph_qbra: int  # 945
MIPS_preceu_qh_obl: int  # 957
MIPS_preceu_qh_obla: int  # 964
MIPS_preceu_qh_obr: int  # 961
MIPS_preceu_qh_obra: int  # 967
MIPS_precr_qb_ph: int  # 900
MIPS_precr_sra_ph_w: int  # 904
MIPS_precr_sra_r_ph_w: int  # 906
MIPS_precrq_ob_qh: int  # 920
MIPS_precrq_ph_w: int  # 898
MIPS_precrq_pw_l: int  # 922
MIPS_precrq_qb_ph: int  # 897
MIPS_precrq_qh_pw: int  # 921
MIPS_precrq_rs_ph_w: int  # 901
MIPS_precrq_rs_qh_pw: int  # 924
MIPS_precrqu_s_ob_qh: int  # 927
MIPS_precrqu_s_qb_ph: int  # 905
MIPS_pref: int  # 206
MIPS_prefe: int  # 1685
MIPS_prefx: int  # 227
MIPS_prepend: int  # 1116
MIPS_prevh: int  # 406
MIPS_prot3w: int  # 412
MIPS_psllh: int  # 413
MIPS_psllvw: int  # 347
MIPS_psllw: int  # 416
MIPS_psrah: int  # 415
MIPS_psravw: int  # 352
MIPS_psraw: int  # 418
MIPS_psrlh: int  # 414
MIPS_psrlvw: int  # 350
MIPS_psrlw: int  # 417
MIPS_psubb: int  # 362
MIPS_psubh: int  # 356
MIPS_psubsb: int  # 395
MIPS_psubsh: int  # 387
MIPS_psubsw: int  # 374
MIPS_psubub: int  # 396
MIPS_psubuh: int  # 389
MIPS_psubuw: int  # 376
MIPS_psubw: int  # 345
MIPS_pul: int  # 530
MIPS_puu: int  # 531
MIPS_pxor: int  # 382
MIPS_qfsrv: int  # 400
MIPS_qmac_00: int  # 1132
MIPS_qmac_01: int  # 1133
MIPS_qmac_02: int  # 1134
MIPS_qmac_03: int  # 1135
MIPS_qmacs_00: int  # 1136
MIPS_qmacs_01: int  # 1137
MIPS_qmacs_02: int  # 1138
MIPS_qmacs_03: int  # 1139
MIPS_qmfc2: int  # 50
MIPS_qmtc2: int  # 52
MIPS_raddu_l_ob: int  # 874
MIPS_raddu_w_qb: int  # 854
MIPS_rddsp: int  # 1064
MIPS_rdhwr: int  # 532
MIPS_rdpgpr: int  # 533
MIPS_repl_ob: int  # 948
MIPS_repl_ph: int  # 932
MIPS_repl_pw: int  # 950
MIPS_repl_qb: int  # 931
MIPS_repl_qh: int  # 949
MIPS_replv_ob: int  # 951
MIPS_replv_ph: int  # 934
MIPS_replv_pw: int  # 953
MIPS_replv_qb: int  # 933
MIPS_replv_qh: int  # 952
MIPS_restore: int  # 545
MIPS_restore_jrc: int  # 1738
MIPS_rotr: int  # 534
MIPS_rotrv: int  # 535
MIPS_rotx: int  # 1723
MIPS_saa: int  # 591
MIPS_saad: int  # 592
MIPS_sadd: int  # 738
MIPS_save: int  # 544
MIPS_sb: int  # 138
MIPS_sbe: int  # 1679
MIPS_sbv: int  # 242
MIPS_sbx: int  # 1706
MIPS_sc: int  # 147
MIPS_scd: int  # 143
MIPS_sce: int  # 1683
MIPS_scwp: int  # 1726
MIPS_scwpe: int  # 1727
MIPS_sd: int  # 144
MIPS_sdbbp: int  # 505
MIPS_sdc1: int  # 145
MIPS_sdc2: int  # 146
MIPS_sdl: int  # 139
MIPS_sdm: int  # 829
MIPS_sdp: int  # 827
MIPS_sdr: int  # 140
MIPS_sdv: int  # 245
MIPS_sdxc1: int  # 209
MIPS_seb: int  # 536
MIPS_seh: int  # 537
MIPS_seq: int  # 593
MIPS_seqi: int  # 594
MIPS_sew: int  # 548
MIPS_sfv: int  # 251
MIPS_sh: int  # 149
MIPS_she: int  # 1680
MIPS_shilo: int  # 1065
MIPS_shilov: int  # 1069
MIPS_shll_ob: int  # 990
MIPS_shll_ph: int  # 969
MIPS_shll_pw: int  # 992
MIPS_shll_qb: int  # 968
MIPS_shll_qh: int  # 991
MIPS_shll_s_ph: int  # 979
MIPS_shll_s_pw: int  # 1003
MIPS_shll_s_qh: int  # 1002
MIPS_shll_s_w: int  # 980
MIPS_shllv_ob: int  # 996
MIPS_shllv_ph: int  # 974
MIPS_shllv_pw: int  # 998
MIPS_shllv_qb: int  # 973
MIPS_shllv_qh: int  # 997
MIPS_shllv_s_ph: int  # 985
MIPS_shllv_s_pw: int  # 1007
MIPS_shllv_s_qh: int  # 1006
MIPS_shllv_s_w: int  # 986
MIPS_shra_ph: int  # 971
MIPS_shra_pw: int  # 995
MIPS_shra_qb: int  # 978
MIPS_shra_qh: int  # 994
MIPS_shra_r_ph: int  # 982
MIPS_shra_r_pw: int  # 1005
MIPS_shra_r_qb: int  # 981
MIPS_shra_r_qh: int  # 1004
MIPS_shra_r_w: int  # 983
MIPS_shrav_ph: int  # 976
MIPS_shrav_pw: int  # 1001
MIPS_shrav_qb: int  # 984
MIPS_shrav_qh: int  # 1000
MIPS_shrav_r_ph: int  # 988
MIPS_shrav_r_pw: int  # 1009
MIPS_shrav_r_qb: int  # 987
MIPS_shrav_r_qh: int  # 1008
MIPS_shrav_r_w: int  # 989
MIPS_shrl_ob: int  # 993
MIPS_shrl_ph: int  # 972
MIPS_shrl_qb: int  # 970
MIPS_shrlv_ob: int  # 999
MIPS_shrlv_ph: int  # 977
MIPS_shrlv_qb: int  # 975
MIPS_shv: int  # 250
MIPS_shx: int  # 1707
MIPS_shxs: int  # 1708
MIPS_sigrie: int  # 1735
MIPS_sll: int  # 21
MIPS_sllv: int  # 27
MIPS_slt: int  # 10
MIPS_slti: int  # 34
MIPS_sltiu: int  # 35
MIPS_sltu: int  # 11
MIPS_slv: int  # 244
MIPS_sne: int  # 595
MIPS_snei: int  # 596
MIPS_sov: int  # 1699
MIPS_spv: int  # 248
MIPS_sq: int  # 425
MIPS_sqc2: int  # 427
MIPS_sqv: int  # 246
MIPS_sra: int  # 22
MIPS_srav: int  # 28
MIPS_srl: int  # 23
MIPS_srlv: int  # 29
MIPS_srv: int  # 247
MIPS_ssnop: int  # 552
MIPS_ssub: int  # 739
MIPS_ssv: int  # 243
MIPS_stv: int  # 253
MIPS_sub: int  # 12
MIPS_subq_ph: int  # 851
MIPS_subq_pw: int  # 872
MIPS_subq_qh: int  # 871
MIPS_subq_s_ph: int  # 864
MIPS_subq_s_pw: int  # 883
MIPS_subq_s_qh: int  # 882
MIPS_subq_s_w: int  # 865
MIPS_subqh_ph: int  # 1102
MIPS_subqh_r_ph: int  # 1108
MIPS_subqh_r_w: int  # 1109
MIPS_subqh_w: int  # 1103
MIPS_subu: int  # 13
MIPS_subu_ob: int  # 868
MIPS_subu_ph: int  # 847
MIPS_subu_qb: int  # 846
MIPS_subu_s_ob: int  # 876
MIPS_subu_s_ph: int  # 857
MIPS_subu_s_qb: int  # 856
MIPS_subuh_qb: int  # 1101
MIPS_subuh_r_qb: int  # 1107
MIPS_suv: int  # 249
MIPS_suxc1: int  # 538
MIPS_sw: int  # 148
MIPS_swc1: int  # 150
MIPS_swc2: int  # 151
MIPS_swe: int  # 1681
MIPS_swl: int  # 141
MIPS_swle: int  # 1688
MIPS_swm: int  # 828
MIPS_swm2: int  # 1765
MIPS_swp: int  # 826
MIPS_swpc: int  # 1722
MIPS_swr: int  # 142
MIPS_swre: int  # 1689
MIPS_swv: int  # 252
MIPS_swx: int  # 1709
MIPS_swxc1: int  # 210
MIPS_swxs: int  # 1710
MIPS_sync: int  # 152
MIPS_synci: int  # 539
MIPS_syncie: int  # 1732
MIPS_synciobdma: int  # 597
MIPS_syncs: int  # 598
MIPS_syncw: int  # 599
MIPS_syncws: int  # 600
MIPS_syscall: int  # 81
MIPS_teq: int  # 39
MIPS_teqi: int  # 59
MIPS_tge: int  # 40
MIPS_tgei: int  # 60
MIPS_tgeiu: int  # 61
MIPS_tgeu: int  # 41
MIPS_tlbinv: int  # 1716
MIPS_tlbinvf: int  # 1717
MIPS_tlbp: int  # 154
MIPS_tlbr: int  # 155
MIPS_tlbwi: int  # 156
MIPS_tlbwr: int  # 157
MIPS_tlt: int  # 42
MIPS_tlti: int  # 62
MIPS_tltiu: int  # 63
MIPS_tltu: int  # 43
MIPS_tne: int  # 44
MIPS_tnei: int  # 64
MIPS_ualh: int  # 1730
MIPS_ualwm: int  # 1728
MIPS_uash: int  # 1731
MIPS_uaswm: int  # 1729
MIPS_ucopyw: int  # 1693
MIPS_uld: int  # 601
MIPS_ulw: int  # 602
MIPS_usd: int  # 603
MIPS_usw: int  # 604
MIPS_v3mulu: int  # 605
MIPS_vabs: int  # 273
MIPS_vaccb: int  # 278
MIPS_vadd: int  # 270
MIPS_vaddb: int  # 276
MIPS_vaddc: int  # 274
MIPS_vand: int  # 292
MIPS_vch: int  # 289
MIPS_vcl: int  # 288
MIPS_vcr: int  # 290
MIPS_veq: int  # 285
MIPS_vextn: int  # 311
MIPS_vextq: int  # 309
MIPS_vextt: int  # 307
MIPS_vge: int  # 287
MIPS_vinsn: int  # 310
MIPS_vinsq: int  # 308
MIPS_vinst: int  # 306
MIPS_vlt: int  # 284
MIPS_vmacf: int  # 255
MIPS_vmacq: int  # 261
MIPS_vmacu: int  # 257
MIPS_vmadh: int  # 263
MIPS_vmadl: int  # 269
MIPS_vmadm: int  # 265
MIPS_vmadn: int  # 267
MIPS_vmm0: int  # 606
MIPS_vmov: int  # 299
MIPS_vmrg: int  # 291
MIPS_vmudh: int  # 262
MIPS_vmudl: int  # 268
MIPS_vmudm: int  # 264
MIPS_vmudn: int  # 266
MIPS_vmulf: int  # 254
MIPS_vmulq: int  # 260
MIPS_vmulu: int  # 256
MIPS_vmulu_cn: int  # 607
MIPS_vnand: int  # 293
MIPS_vne: int  # 286
MIPS_vnoop: int  # 298
MIPS_vnor: int  # 295
MIPS_vnxor: int  # 297
MIPS_vor: int  # 294
MIPS_vrcp: int  # 300
MIPS_vrcph: int  # 302
MIPS_vrcpl: int  # 304
MIPS_vrndn: int  # 259
MIPS_vrndp: int  # 258
MIPS_vrsq: int  # 301
MIPS_vrsqh: int  # 303
MIPS_vrsql: int  # 305
MIPS_vsac: int  # 281
MIPS_vsad: int  # 280
MIPS_vsaw: int  # 283
MIPS_vsub: int  # 271
MIPS_vsubb: int  # 277
MIPS_vsubc: int  # 275
MIPS_vsucb: int  # 279
MIPS_vsum: int  # 282
MIPS_vsut: int  # 272
MIPS_vxor: int  # 296
MIPS_wait: int  # 506
MIPS_wrdsp: int  # 1068
MIPS_wrpgpr: int  # 540
MIPS_wsbh: int  # 541
MIPS_xor: int  # 14
MIPS_xori: int  # 38
MIPS_yield: int  # 758
MIPS_zcb: int  # 1140
MIPS_zcbt: int  # 1141
MIPS_zeb: int  # 549
MIPS_zeh: int  # 550
MIPS_zew: int  # 551
NEC850_ABSF_D: int  # 129
NEC850_ABSF_S: int  # 130
NEC850_ABSF_S4: int  # 395
NEC850_ADD: int  # 71
NEC850_ADDF_D: int  # 131
NEC850_ADDF_S: int  # 132
NEC850_ADDF_S4: int  # 396
NEC850_ADDI: int  # 70
NEC850_ADDRF_S4: int  # 421
NEC850_ADDSUBF_S4: int  # 410
NEC850_ADDSUBNF_S4: int  # 411
NEC850_ADDSUBNXF_S4: int  # 417
NEC850_ADDSUBXF_S4: int  # 418
NEC850_ADDXF_S4: int  # 414
NEC850_ADF: int  # 100
NEC850_AND: int  # 69
NEC850_ANDI: int  # 68
NEC850_BGE: int  # 66
NEC850_BGT: int  # 67
NEC850_BH: int  # 63
NEC850_BINS: int  # 204
NEC850_BL: int  # 53
NEC850_BLE: int  # 59
NEC850_BLT: int  # 58
NEC850_BN: int  # 56
NEC850_BNC: int  # 61
NEC850_BNH: int  # 55
NEC850_BNV: int  # 60
NEC850_BNZ: int  # 62
NEC850_BP: int  # 64
NEC850_BR: int  # 57
NEC850_BREAKPOINT: int  # 1
NEC850_BSA: int  # 65
NEC850_BSH: int  # 93
NEC850_BSW: int  # 92
NEC850_BV: int  # 52
NEC850_BZ: int  # 54
NEC850_CACHE: int  # 212
NEC850_CALLT: int  # 79
NEC850_CAXI: int  # 109
NEC850_CEILF_DL: int  # 155
NEC850_CEILF_DUL: int  # 159
NEC850_CEILF_DUW: int  # 160
NEC850_CEILF_DW: int  # 156
NEC850_CEILF_SL: int  # 157
NEC850_CEILF_SUL: int  # 161
NEC850_CEILF_SUW: int  # 162
NEC850_CEILF_SUW4: int  # 426
NEC850_CEILF_SW: int  # 158
NEC850_CEILF_SW4: int  # 427
NEC850_CLIP_B: int  # 255
NEC850_CLIP_BU: int  # 256
NEC850_CLIP_H: int  # 257
NEC850_CLIP_HU: int  # 258
NEC850_CLL: int  # 211
NEC850_CLR1: int  # 51
NEC850_CMOV: int  # 95
NEC850_CMOVF_D: int  # 200
NEC850_CMOVF_S: int  # 199
NEC850_CMOVF_W4: int  # 393
NEC850_CMP: int  # 50
NEC850_CMPF_D: int  # 198
NEC850_CMPF_S: int  # 197
NEC850_CMPF_S4: int  # 440
NEC850_CNVQ15Q30: int  # 375
NEC850_CNVQ30Q15: int  # 377
NEC850_CNVQ31Q62: int  # 376
NEC850_CNVQ62Q31: int  # 378
NEC850_CTRET: int  # 82
NEC850_CVTF_DL: int  # 163
NEC850_CVTF_DS: int  # 164
NEC850_CVTF_DUL: int  # 165
NEC850_CVTF_DUW: int  # 166
NEC850_CVTF_DW: int  # 167
NEC850_CVTF_HS: int  # 216
NEC850_CVTF_HS4: int  # 428
NEC850_CVTF_LD: int  # 168
NEC850_CVTF_LS: int  # 169
NEC850_CVTF_SD: int  # 170
NEC850_CVTF_SH: int  # 217
NEC850_CVTF_SH4: int  # 429
NEC850_CVTF_SL: int  # 171
NEC850_CVTF_SUL: int  # 172
NEC850_CVTF_SUW: int  # 173
NEC850_CVTF_SUW4: int  # 430
NEC850_CVTF_SW: int  # 174
NEC850_CVTF_SW4: int  # 431
NEC850_CVTF_ULD: int  # 175
NEC850_CVTF_ULS: int  # 176
NEC850_CVTF_UWD: int  # 177
NEC850_CVTF_UWS: int  # 178
NEC850_CVTF_UWS4: int  # 432
NEC850_CVTF_WD: int  # 179
NEC850_CVTF_WS: int  # 180
NEC850_CVTF_WS4: int  # 433
NEC850_CVT_SW: int  # 121
NEC850_CVT_WS: int  # 123
NEC850_DBCP: int  # 223
NEC850_DBHVTRAP: int  # 225
NEC850_DBPUSH: int  # 222
NEC850_DBRET: int  # 81
NEC850_DBTAG: int  # 224
NEC850_DBTRAP: int  # 80
NEC850_DI: int  # 49
NEC850_DISPOSE_r: int  # 78
NEC850_DISPOSE_r0: int  # 77
NEC850_DIV: int  # 90
NEC850_DIVF_D: int  # 133
NEC850_DIVF_S: int  # 134
NEC850_DIVF_S4: int  # 397
NEC850_DIVH: int  # 48
NEC850_DIVHU: int  # 89
NEC850_DIVH_r3: int  # 88
NEC850_DIVQ: int  # 110
NEC850_DIVQU: int  # 111
NEC850_DIVU: int  # 91
NEC850_DST: int  # 227
NEC850_DUP_H: int  # 286
NEC850_DUP_W: int  # 287
NEC850_EI: int  # 47
NEC850_EIRET: int  # 112
NEC850_EST: int  # 226
NEC850_EXPQ31: int  # 379
NEC850_FERET: int  # 113
NEC850_FETRAP: int  # 114
NEC850_FLOORF_DL: int  # 181
NEC850_FLOORF_DUL: int  # 185
NEC850_FLOORF_DUW: int  # 186
NEC850_FLOORF_DW: int  # 182
NEC850_FLOORF_SL: int  # 183
NEC850_FLOORF_SUL: int  # 187
NEC850_FLOORF_SUW: int  # 188
NEC850_FLOORF_SUW4: int  # 434
NEC850_FLOORF_SW: int  # 184
NEC850_FLOORF_SW4: int  # 435
NEC850_FLPV_S4: int  # 383
NEC850_FMAF_S: int  # 218
NEC850_FMAF_S4: int  # 406
NEC850_FMSF_S: int  # 219
NEC850_FMSF_S4: int  # 407
NEC850_FNMAF_S: int  # 220
NEC850_FNMAF_S4: int  # 408
NEC850_FNMSF_S: int  # 221
NEC850_FNMSF_S4: int  # 409
NEC850_HALT: int  # 46
NEC850_HSH: int  # 101
NEC850_HSW: int  # 94
NEC850_HVCALL: int  # 229
NEC850_HVTRAP: int  # 228
NEC850_JARL: int  # 45
NEC850_JMP: int  # 44
NEC850_JR: int  # 43
NEC850_LAST_INSTRUCTION: int  # 441
NEC850_LDFC: int  # 124
NEC850_LDFF: int  # 125
NEC850_LDL_BU: int  # 259
NEC850_LDL_HU: int  # 260
NEC850_LDL_W: int  # 209
NEC850_LDM_MP: int  # 253
NEC850_LDSR: int  # 39
NEC850_LDTC_GR: int  # 232
NEC850_LDTC_PC: int  # 234
NEC850_LDTC_SR: int  # 236
NEC850_LDTC_VR: int  # 238
NEC850_LDVC_SR: int  # 230
NEC850_LDVZ_H4: int  # 388
NEC850_LDV_DW: int  # 385
NEC850_LDV_QW: int  # 386
NEC850_LDV_W: int  # 387
NEC850_LD_B: int  # 40
NEC850_LD_BU: int  # 98
NEC850_LD_DW: int  # 207
NEC850_LD_H: int  # 41
NEC850_LD_HU: int  # 99
NEC850_LD_W: int  # 42
NEC850_LOOP: int  # 206
NEC850_MAC: int  # 102
NEC850_MACU: int  # 103
NEC850_MADDF_S: int  # 151
NEC850_MAXF_D: int  # 135
NEC850_MAXF_S: int  # 136
NEC850_MAXF_S4: int  # 398
NEC850_MAXRF_S4: int  # 422
NEC850_MINF_D: int  # 137
NEC850_MINF_S: int  # 138
NEC850_MINF_S4: int  # 399
NEC850_MINRF_S4: int  # 423
NEC850_MODADD: int  # 312
NEC850_MOV: int  # 38
NEC850_MOVEA: int  # 37
NEC850_MOVHI: int  # 36
NEC850_MOVV_W4: int  # 382
NEC850_MOV_DW: int  # 290
NEC850_MOV_H: int  # 288
NEC850_MOV_W: int  # 289
NEC850_MSUBF_S: int  # 152
NEC850_MUL: int  # 86
NEC850_MULF_D: int  # 139
NEC850_MULF_S: int  # 140
NEC850_MULF_S4: int  # 400
NEC850_MULH: int  # 35
NEC850_MULHI: int  # 34
NEC850_MULRF_S4: int  # 424
NEC850_MULU: int  # 87
NEC850_MULXF_S4: int  # 415
NEC850_NEGF_D: int  # 141
NEC850_NEGF_S: int  # 142
NEC850_NEGF_S4: int  # 401
NEC850_NMADDF_S: int  # 153
NEC850_NMSUBF_S: int  # 154
NEC850_NOP: int  # 33
NEC850_NOT: int  # 32
NEC850_NOT1: int  # 31
NEC850_NULL: int  # 0
NEC850_OR: int  # 30
NEC850_ORI: int  # 29
NEC850_PKI16I32: int  # 368
NEC850_PKI16UI8: int  # 370
NEC850_PKI32I16: int  # 371
NEC850_PKI64I32: int  # 374
NEC850_PKQ15Q31: int  # 369
NEC850_PKQ30Q31: int  # 373
NEC850_PKQ31Q15: int  # 372
NEC850_PKUI8I16: int  # 367
NEC850_POPSP: int  # 215
NEC850_PREF: int  # 213
NEC850_PREPARE_i: int  # 85
NEC850_PREPARE_sp: int  # 84
NEC850_PUSHSP: int  # 214
NEC850_RECIPF_D: int  # 143
NEC850_RECIPF_S: int  # 144
NEC850_RECIPF_S4: int  # 402
NEC850_RESBANK: int  # 261
NEC850_RETI: int  # 28
NEC850_RIE: int  # 116
NEC850_RMTRAP: int  # 115
NEC850_ROTL: int  # 205
NEC850_ROUNDF_DL: int  # 245
NEC850_ROUNDF_DUL: int  # 247
NEC850_ROUNDF_DUW: int  # 248
NEC850_ROUNDF_DW: int  # 246
NEC850_ROUNDF_SL: int  # 249
NEC850_ROUNDF_SUL: int  # 251
NEC850_ROUNDF_SUW: int  # 252
NEC850_ROUNDF_SUW4: int  # 436
NEC850_ROUNDF_SW: int  # 250
NEC850_ROUNDF_SW4: int  # 437
NEC850_RSQRTF_D: int  # 145
NEC850_RSQRTF_S: int  # 146
NEC850_RSQRTF_S4: int  # 403
NEC850_SAR: int  # 27
NEC850_SASF: int  # 83
NEC850_SATADD: int  # 26
NEC850_SATSUB: int  # 25
NEC850_SATSUBI: int  # 24
NEC850_SATSUBR: int  # 23
NEC850_SBF: int  # 104
NEC850_SCH0L: int  # 105
NEC850_SCH0R: int  # 106
NEC850_SCH1L: int  # 107
NEC850_SCH1R: int  # 108
NEC850_SET1: int  # 21
NEC850_SETF: int  # 22
NEC850_SHFLV_W4: int  # 384
NEC850_SHL: int  # 20
NEC850_SHR: int  # 19
NEC850_SLD_B: int  # 16
NEC850_SLD_BU: int  # 96
NEC850_SLD_H: int  # 17
NEC850_SLD_HU: int  # 97
NEC850_SLD_W: int  # 18
NEC850_SNOOZE: int  # 203
NEC850_SQRTF_D: int  # 147
NEC850_SQRTF_S: int  # 148
NEC850_SQRTF_S4: int  # 404
NEC850_SST_B: int  # 13
NEC850_SST_H: int  # 14
NEC850_SST_W: int  # 15
NEC850_STC_B: int  # 262
NEC850_STC_H: int  # 263
NEC850_STC_W: int  # 210
NEC850_STFC: int  # 126
NEC850_STFF: int  # 127
NEC850_STM_MP: int  # 254
NEC850_STSR: int  # 9
NEC850_STTC_GR: int  # 233
NEC850_STTC_PC: int  # 235
NEC850_STTC_SR: int  # 237
NEC850_STTC_VR: int  # 239
NEC850_STVC_SR: int  # 231
NEC850_STVZ_H4: int  # 392
NEC850_STV_DW: int  # 389
NEC850_STV_QW: int  # 390
NEC850_STV_W: int  # 391
NEC850_ST_B: int  # 10
NEC850_ST_DW: int  # 208
NEC850_ST_H: int  # 11
NEC850_ST_W: int  # 12
NEC850_SUB: int  # 8
NEC850_SUBADDF_S4: int  # 412
NEC850_SUBADDNF_S4: int  # 413
NEC850_SUBADDNXF_S4: int  # 419
NEC850_SUBADDXF_S4: int  # 420
NEC850_SUBF_D: int  # 149
NEC850_SUBF_S: int  # 150
NEC850_SUBF_S4: int  # 405
NEC850_SUBR: int  # 7
NEC850_SUBRF_S4: int  # 425
NEC850_SUBXF_S4: int  # 416
NEC850_SWITCH: int  # 72
NEC850_SXB: int  # 74
NEC850_SXH: int  # 76
NEC850_SYNCE: int  # 117
NEC850_SYNCI: int  # 202
NEC850_SYNCM: int  # 118
NEC850_SYNCP: int  # 119
NEC850_SYSCALL: int  # 120
NEC850_TLBAI: int  # 240
NEC850_TLBR: int  # 241
NEC850_TLBS: int  # 242
NEC850_TLBVI: int  # 243
NEC850_TLBW: int  # 244
NEC850_TRAP: int  # 6
NEC850_TRFF: int  # 128
NEC850_TRFSR: int  # 201
NEC850_TRFSRV_W4: int  # 394
NEC850_TRNCF_DL: int  # 189
NEC850_TRNCF_DUL: int  # 190
NEC850_TRNCF_DUW: int  # 191
NEC850_TRNCF_DW: int  # 192
NEC850_TRNCF_SL: int  # 193
NEC850_TRNCF_SUL: int  # 194
NEC850_TRNCF_SUW: int  # 195
NEC850_TRNCF_SUW4: int  # 438
NEC850_TRNCF_SW: int  # 196
NEC850_TRNCF_SW4: int  # 439
NEC850_TRNC_SW: int  # 122
NEC850_TST: int  # 5
NEC850_TST1: int  # 4
NEC850_VABS_H: int  # 341
NEC850_VABS_W: int  # 342
NEC850_VADDSAT_H: int  # 319
NEC850_VADDSAT_W: int  # 320
NEC850_VADDS_H: int  # 323
NEC850_VADDS_W: int  # 324
NEC850_VADD_DW: int  # 315
NEC850_VADD_H: int  # 313
NEC850_VADD_W: int  # 314
NEC850_VAND: int  # 264
NEC850_VBIQ_H: int  # 366
NEC850_VBSWAP_DW: int  # 283
NEC850_VBSWAP_H: int  # 284
NEC850_VBSWAP_W: int  # 285
NEC850_VCALCH: int  # 380
NEC850_VCALCW: int  # 381
NEC850_VCMOV: int  # 311
NEC850_VCMPEQ_H: int  # 333
NEC850_VCMPEQ_W: int  # 334
NEC850_VCMPLE_H: int  # 337
NEC850_VCMPLE_W: int  # 338
NEC850_VCMPLT_H: int  # 335
NEC850_VCMPLT_W: int  # 336
NEC850_VCMPNE_H: int  # 339
NEC850_VCMPNE_W: int  # 340
NEC850_VCONCAT_B: int  # 277
NEC850_VITLVHW_H: int  # 280
NEC850_VITLVWH_H: int  # 281
NEC850_VITLV_H: int  # 278
NEC850_VITLV_W: int  # 279
NEC850_VLD_B: int  # 291
NEC850_VLD_B_FMT3: int  # 292
NEC850_VLD_B_FMT4: int  # 293
NEC850_VLD_DW: int  # 298
NEC850_VLD_DW_FMT3: int  # 299
NEC850_VLD_DW_FMT4: int  # 300
NEC850_VLD_DW_FMT5: int  # 301
NEC850_VLD_H: int  # 294
NEC850_VLD_H_FMT4: int  # 295
NEC850_VLD_W: int  # 296
NEC850_VLD_W_FMT4: int  # 297
NEC850_VMADRN_H: int  # 355
NEC850_VMADRN_W: int  # 356
NEC850_VMADSAT_H: int  # 353
NEC850_VMADSAT_W: int  # 354
NEC850_VMAXGE_H: int  # 346
NEC850_VMAXGE_W: int  # 350
NEC850_VMAXGT_H: int  # 345
NEC850_VMAXGT_W: int  # 349
NEC850_VMINLE_H: int  # 348
NEC850_VMINLE_W: int  # 352
NEC850_VMINLT_H: int  # 347
NEC850_VMINLT_W: int  # 351
NEC850_VMSUMADIM_H: int  # 363
NEC850_VMSUMADIM_W: int  # 364
NEC850_VMSUMADRE_H: int  # 361
NEC850_VMSUMADRE_W: int  # 362
NEC850_VMSUMADRN_H: int  # 365
NEC850_VMSUMAD_H: int  # 359
NEC850_VMSUMAD_W: int  # 360
NEC850_VMSUM_H: int  # 357
NEC850_VMSUM_W: int  # 358
NEC850_VMULCX_H: int  # 331
NEC850_VMULCX_W: int  # 332
NEC850_VMULT_H: int  # 329
NEC850_VMULT_W: int  # 330
NEC850_VMUL_H: int  # 327
NEC850_VMUL_W: int  # 328
NEC850_VNEG_H: int  # 343
NEC850_VNEG_W: int  # 344
NEC850_VNOT: int  # 267
NEC850_VOR: int  # 265
NEC850_VSAR_DW: int  # 270
NEC850_VSAR_H: int  # 268
NEC850_VSAR_W: int  # 269
NEC850_VSHL_DW: int  # 276
NEC850_VSHL_H: int  # 274
NEC850_VSHL_W: int  # 275
NEC850_VSHR_DW: int  # 273
NEC850_VSHR_H: int  # 271
NEC850_VSHR_W: int  # 272
NEC850_VSHUFL_B: int  # 282
NEC850_VST_B: int  # 302
NEC850_VST_B_FMT4: int  # 303
NEC850_VST_DW: int  # 308
NEC850_VST_DW_FMT6: int  # 310
NEC850_VST_DW_FMT_4_5: int  # 309
NEC850_VST_H: int  # 304
NEC850_VST_H_FMT_4_5: int  # 305
NEC850_VST_W: int  # 306
NEC850_VST_W_FMT_4_5: int  # 307
NEC850_VSUBSAT_H: int  # 321
NEC850_VSUBSAT_W: int  # 322
NEC850_VSUBS_H: int  # 325
NEC850_VSUBS_W: int  # 326
NEC850_VSUB_DW: int  # 318
NEC850_VSUB_H: int  # 316
NEC850_VSUB_W: int  # 317
NEC850_VXOR: int  # 266
NEC850_XOR: int  # 3
NEC850_XORI: int  # 2
NEC850_ZXB: int  # 73
NEC850_ZXH: int  # 75
NEC_78K_0S_DI: int  # 43
NEC_78K_0S_EI: int  # 42
NEC_78K_0S_HALT: int  # 44
NEC_78K_0S_STOP: int  # 45
NEC_78K_0S_add: int  # 5
NEC_78K_0S_addc: int  # 7
NEC_78K_0S_addw: int  # 10
NEC_78K_0S_and: int  # 3
NEC_78K_0S_bc: int  # 34
NEC_78K_0S_bf: int  # 39
NEC_78K_0S_bnc: int  # 35
NEC_78K_0S_bnz: int  # 37
NEC_78K_0S_br: int  # 33
NEC_78K_0S_bt: int  # 38
NEC_78K_0S_bz: int  # 36
NEC_78K_0S_call: int  # 20
NEC_78K_0S_callt: int  # 21
NEC_78K_0S_clr1: int  # 28
NEC_78K_0S_cmp: int  # 1
NEC_78K_0S_cmpw: int  # 11
NEC_78K_0S_dbnz: int  # 40
NEC_78K_0S_dec: int  # 13
NEC_78K_0S_decw: int  # 15
NEC_78K_0S_inc: int  # 12
NEC_78K_0S_incw: int  # 14
NEC_78K_0S_last: int  # 46
NEC_78K_0S_mov: int  # 24
NEC_78K_0S_movw: int  # 32
NEC_78K_0S_nop: int  # 41
NEC_78K_0S_not1: int  # 29
NEC_78K_0S_null: int  # 0
NEC_78K_0S_or: int  # 4
NEC_78K_0S_pop: int  # 31
NEC_78K_0S_push: int  # 30
NEC_78K_0S_ret: int  # 22
NEC_78K_0S_reti: int  # 23
NEC_78K_0S_rol: int  # 17
NEC_78K_0S_rolc: int  # 19
NEC_78K_0S_ror: int  # 16
NEC_78K_0S_rorc: int  # 18
NEC_78K_0S_set1: int  # 27
NEC_78K_0S_sub: int  # 6
NEC_78K_0S_subc: int  # 8
NEC_78K_0S_subw: int  # 9
NEC_78K_0S_xch: int  # 25
NEC_78K_0S_xchw: int  # 26
NEC_78K_0S_xor: int  # 2
NEC_78K_0_DI: int  # 58
NEC_78K_0_EI: int  # 57
NEC_78K_0_HALT: int  # 59
NEC_78K_0_STOP: int  # 60
NEC_78K_0_add: int  # 5
NEC_78K_0_addc: int  # 6
NEC_78K_0_addw: int  # 13
NEC_78K_0_adjba: int  # 28
NEC_78K_0_adjbs: int  # 29
NEC_78K_0_and: int  # 9
NEC_78K_0_and1: int  # 31
NEC_78K_0_bc: int  # 47
NEC_78K_0_bf: int  # 52
NEC_78K_0_bnc: int  # 48
NEC_78K_0_bnz: int  # 50
NEC_78K_0_br: int  # 46
NEC_78K_0_brk: int  # 40
NEC_78K_0_bt: int  # 51
NEC_78K_0_btclr: int  # 53
NEC_78K_0_bz: int  # 49
NEC_78K_0_call: int  # 37
NEC_78K_0_callf: int  # 38
NEC_78K_0_callt: int  # 39
NEC_78K_0_clr1: int  # 35
NEC_78K_0_cmp: int  # 12
NEC_78K_0_cmpw: int  # 15
NEC_78K_0_dbnz: int  # 54
NEC_78K_0_dec: int  # 19
NEC_78K_0_decw: int  # 21
NEC_78K_0_divuw: int  # 17
NEC_78K_0_inc: int  # 18
NEC_78K_0_incw: int  # 20
NEC_78K_0_last: int  # 61
NEC_78K_0_mov: int  # 1
NEC_78K_0_mov1: int  # 30
NEC_78K_0_movw: int  # 3
NEC_78K_0_mulu: int  # 16
NEC_78K_0_nop: int  # 56
NEC_78K_0_not1: int  # 36
NEC_78K_0_null: int  # 0
NEC_78K_0_or: int  # 10
NEC_78K_0_or1: int  # 32
NEC_78K_0_pop: int  # 45
NEC_78K_0_push: int  # 44
NEC_78K_0_ret: int  # 41
NEC_78K_0_retb: int  # 42
NEC_78K_0_reti: int  # 43
NEC_78K_0_rol: int  # 23
NEC_78K_0_rol4: int  # 27
NEC_78K_0_rolc: int  # 25
NEC_78K_0_ror: int  # 22
NEC_78K_0_ror4: int  # 26
NEC_78K_0_rorc: int  # 24
NEC_78K_0_sel: int  # 55
NEC_78K_0_set1: int  # 34
NEC_78K_0_sub: int  # 7
NEC_78K_0_subc: int  # 8
NEC_78K_0_subw: int  # 14
NEC_78K_0_xch: int  # 2
NEC_78K_0_xchw: int  # 4
NEC_78K_0_xor: int  # 11
NEC_78K_0_xor1: int  # 33
NET_add: int  # 1
NET_add_ovf: int  # 2
NET_add_ovf_un: int  # 3
NET_and: int  # 4
NET_ann_arg: int  # 5
NET_ann_call: int  # 6
NET_ann_catch: int  # 7
NET_ann_data: int  # 8
NET_ann_data_s: int  # 9
NET_ann_dead: int  # 10
NET_ann_def: int  # 11
NET_ann_hoisted: int  # 12
NET_ann_hoisted_call: int  # 13
NET_ann_lab: int  # 14
NET_ann_live: int  # 15
NET_ann_phi: int  # 16
NET_ann_ref: int  # 17
NET_ann_ref_s: int  # 18
NET_arglist: int  # 19
NET_beq: int  # 20
NET_beq_s: int  # 21
NET_bge: int  # 22
NET_bge_s: int  # 23
NET_bge_un: int  # 24
NET_bge_un_s: int  # 25
NET_bgt: int  # 26
NET_bgt_s: int  # 27
NET_bgt_un: int  # 28
NET_bgt_un_s: int  # 29
NET_ble: int  # 30
NET_ble_s: int  # 31
NET_ble_un: int  # 32
NET_ble_un_s: int  # 33
NET_blt: int  # 34
NET_blt_s: int  # 35
NET_blt_un: int  # 36
NET_blt_un_s: int  # 37
NET_bne_un: int  # 38
NET_bne_un_s: int  # 39
NET_box: int  # 40
NET_br: int  # 41
NET_br_s: int  # 42
NET_break: int  # 43
NET_brfalse: int  # 44
NET_brfalse_s: int  # 45
NET_brtrue: int  # 46
NET_brtrue_s: int  # 47
NET_call: int  # 48
NET_calli: int  # 49
NET_callvirt: int  # 50
NET_castclass: int  # 51
NET_ceq: int  # 52
NET_cgt: int  # 53
NET_cgt_un: int  # 54
NET_ckfinite: int  # 55
NET_clt: int  # 56
NET_clt_un: int  # 57
NET_constrained_: int  # 231
NET_conv_i: int  # 58
NET_conv_i1: int  # 59
NET_conv_i2: int  # 60
NET_conv_i4: int  # 61
NET_conv_i8: int  # 62
NET_conv_ovf_i: int  # 63
NET_conv_ovf_i1: int  # 64
NET_conv_ovf_i1_un: int  # 65
NET_conv_ovf_i2: int  # 66
NET_conv_ovf_i2_un: int  # 67
NET_conv_ovf_i4: int  # 68
NET_conv_ovf_i4_un: int  # 69
NET_conv_ovf_i8: int  # 70
NET_conv_ovf_i8_un: int  # 71
NET_conv_ovf_i_un: int  # 72
NET_conv_ovf_u: int  # 73
NET_conv_ovf_u1: int  # 74
NET_conv_ovf_u1_un: int  # 75
NET_conv_ovf_u2: int  # 76
NET_conv_ovf_u2_un: int  # 77
NET_conv_ovf_u4: int  # 78
NET_conv_ovf_u4_un: int  # 79
NET_conv_ovf_u8: int  # 80
NET_conv_ovf_u8_un: int  # 81
NET_conv_ovf_u_un: int  # 82
NET_conv_r4: int  # 83
NET_conv_r8: int  # 84
NET_conv_r_un: int  # 85
NET_conv_u: int  # 86
NET_conv_u1: int  # 87
NET_conv_u2: int  # 88
NET_conv_u4: int  # 89
NET_conv_u8: int  # 90
NET_cpblk: int  # 91
NET_cpobj: int  # 92
NET_div: int  # 93
NET_div_un: int  # 94
NET_dup: int  # 95
NET_endfilter: int  # 96
NET_endfinally: int  # 97
NET_initblk: int  # 98
NET_initobj: int  # 99
NET_isinst: int  # 100
NET_jmp: int  # 101
NET_last: int  # 234
NET_ldarg: int  # 102
NET_ldarg_0: int  # 103
NET_ldarg_1: int  # 104
NET_ldarg_2: int  # 105
NET_ldarg_3: int  # 106
NET_ldarg_s: int  # 107
NET_ldarga: int  # 108
NET_ldarga_s: int  # 109
NET_ldc_i4: int  # 110
NET_ldc_i4_0: int  # 111
NET_ldc_i4_1: int  # 112
NET_ldc_i4_2: int  # 113
NET_ldc_i4_3: int  # 114
NET_ldc_i4_4: int  # 115
NET_ldc_i4_5: int  # 116
NET_ldc_i4_6: int  # 117
NET_ldc_i4_7: int  # 118
NET_ldc_i4_8: int  # 119
NET_ldc_i4_m1: int  # 120
NET_ldc_i4_s: int  # 121
NET_ldc_i8: int  # 122
NET_ldc_r4: int  # 123
NET_ldc_r8: int  # 124
NET_ldelem: int  # 228
NET_ldelem_i: int  # 125
NET_ldelem_i1: int  # 126
NET_ldelem_i2: int  # 127
NET_ldelem_i4: int  # 128
NET_ldelem_i8: int  # 129
NET_ldelem_r4: int  # 130
NET_ldelem_r8: int  # 131
NET_ldelem_ref: int  # 132
NET_ldelem_u1: int  # 133
NET_ldelem_u2: int  # 134
NET_ldelem_u4: int  # 135
NET_ldelema: int  # 136
NET_ldfld: int  # 137
NET_ldflda: int  # 138
NET_ldftn: int  # 139
NET_ldind_i: int  # 140
NET_ldind_i1: int  # 141
NET_ldind_i2: int  # 142
NET_ldind_i4: int  # 143
NET_ldind_i8: int  # 144
NET_ldind_r4: int  # 145
NET_ldind_r8: int  # 146
NET_ldind_ref: int  # 147
NET_ldind_u1: int  # 148
NET_ldind_u2: int  # 149
NET_ldind_u4: int  # 150
NET_ldlen: int  # 151
NET_ldloc: int  # 152
NET_ldloc_0: int  # 153
NET_ldloc_1: int  # 154
NET_ldloc_2: int  # 155
NET_ldloc_3: int  # 156
NET_ldloc_s: int  # 157
NET_ldloca: int  # 158
NET_ldloca_s: int  # 159
NET_ldnull: int  # 160
NET_ldobj: int  # 161
NET_ldsfld: int  # 162
NET_ldsflda: int  # 163
NET_ldstr: int  # 164
NET_ldtoken: int  # 165
NET_ldvirtftn: int  # 166
NET_leave: int  # 167
NET_leave_s: int  # 168
NET_localloc: int  # 169
NET_mkrefany: int  # 170
NET_mul: int  # 171
NET_mul_ovf: int  # 172
NET_mul_ovf_un: int  # 173
NET_neg: int  # 174
NET_newarr: int  # 175
NET_newobj: int  # 176
NET_no_: int  # 232
NET_nop: int  # 177
NET_not: int  # 178
NET_null: int  # 0
NET_or: int  # 179
NET_pop: int  # 180
NET_readonly_: int  # 233
NET_refanytype: int  # 181
NET_refanyval: int  # 182
NET_rem: int  # 183
NET_rem_un: int  # 184
NET_ret: int  # 185
NET_rethrow: int  # 186
NET_shl: int  # 187
NET_shr: int  # 188
NET_shr_un: int  # 189
NET_sizeof: int  # 190
NET_starg: int  # 191
NET_starg_s: int  # 192
NET_stelem: int  # 229
NET_stelem_i: int  # 193
NET_stelem_i1: int  # 194
NET_stelem_i2: int  # 195
NET_stelem_i4: int  # 196
NET_stelem_i8: int  # 197
NET_stelem_r4: int  # 198
NET_stelem_r8: int  # 199
NET_stelem_ref: int  # 200
NET_stfld: int  # 201
NET_stind_i: int  # 202
NET_stind_i1: int  # 203
NET_stind_i2: int  # 204
NET_stind_i4: int  # 205
NET_stind_i8: int  # 206
NET_stind_r4: int  # 207
NET_stind_r8: int  # 208
NET_stind_ref: int  # 209
NET_stloc: int  # 210
NET_stloc_0: int  # 211
NET_stloc_1: int  # 212
NET_stloc_2: int  # 213
NET_stloc_3: int  # 214
NET_stloc_s: int  # 215
NET_stobj: int  # 216
NET_stsfld: int  # 217
NET_sub: int  # 218
NET_sub_ovf: int  # 219
NET_sub_ovf_un: int  # 220
NET_switch: int  # 221
NET_tail_: int  # 222
NET_throw: int  # 223
NET_unaligned_: int  # 224
NET_unbox: int  # 225
NET_unbox_any: int  # 230
NET_volatile_: int  # 226
NET_xor: int  # 227
NN_aaa: int  # 1
NN_aad: int  # 2
NN_aam: int  # 3
NN_aas: int  # 4
NN_adc: int  # 5
NN_adcx: int  # 743
NN_add: int  # 6
NN_addpd: int  # 519
NN_addps: int  # 424
NN_addsd: int  # 520
NN_addss: int  # 425
NN_addsubpd: int  # 596
NN_addsubps: int  # 597
NN_adox: int  # 744
NN_aesdec: int  # 731
NN_aesdeclast: int  # 732
NN_aesenc: int  # 729
NN_aesenclast: int  # 730
NN_aesimc: int  # 733
NN_aeskeygenassist: int  # 734
NN_and: int  # 7
NN_andn: int  # 745
NN_andnpd: int  # 521
NN_andnps: int  # 426
NN_andpd: int  # 522
NN_andps: int  # 427
NN_arpl: int  # 8
NN_bextr: int  # 746
NN_blendpd: int  # 652
NN_blendps: int  # 653
NN_blendvpd: int  # 654
NN_blendvps: int  # 655
NN_blsi: int  # 747
NN_blsmsk: int  # 748
NN_blsr: int  # 749
NN_bndcl: int  # 1160
NN_bndcn: int  # 1162
NN_bndcu: int  # 1161
NN_bndldx: int  # 1164
NN_bndmk: int  # 1159
NN_bndmov: int  # 1163
NN_bndstx: int  # 1165
NN_bound: int  # 9
NN_bsf: int  # 10
NN_bsr: int  # 11
NN_bswap: int  # 218
NN_bt: int  # 12
NN_btc: int  # 13
NN_btr: int  # 14
NN_bts: int  # 15
NN_bzhi: int  # 750
NN_call: int  # 16
NN_callfi: int  # 17
NN_callni: int  # 18
NN_cbw: int  # 19
NN_cdq: int  # 30
NN_cdqe: int  # 21
NN_clac: int  # 751
NN_clc: int  # 22
NN_cld: int  # 23
NN_cldemote: int  # 1783
NN_clflush: int  # 523
NN_clflushopt: int  # 1170
NN_clgi: int  # 717
NN_cli: int  # 24
NN_clrssbsy: int  # 1774
NN_clts: int  # 25
NN_clui: int  # 1935
NN_clwb: int  # 1171
NN_clzero: int  # 1751
NN_cmc: int  # 26
NN_cmova: int  # 229
NN_cmovb: int  # 230
NN_cmovbe: int  # 231
NN_cmovg: int  # 232
NN_cmovge: int  # 233
NN_cmovl: int  # 234
NN_cmovle: int  # 235
NN_cmovnb: int  # 236
NN_cmovno: int  # 237
NN_cmovnp: int  # 238
NN_cmovns: int  # 239
NN_cmovnz: int  # 240
NN_cmovo: int  # 241
NN_cmovp: int  # 242
NN_cmovs: int  # 243
NN_cmovz: int  # 244
NN_cmp: int  # 27
NN_cmpeqpd: int  # 636
NN_cmpeqps: int  # 489
NN_cmpeqsd: int  # 644
NN_cmpeqss: int  # 497
NN_cmplepd: int  # 638
NN_cmpleps: int  # 491
NN_cmplesd: int  # 646
NN_cmpless: int  # 499
NN_cmpltpd: int  # 637
NN_cmpltps: int  # 490
NN_cmpltsd: int  # 645
NN_cmpltss: int  # 498
NN_cmpneqpd: int  # 640
NN_cmpneqps: int  # 493
NN_cmpneqsd: int  # 648
NN_cmpneqss: int  # 501
NN_cmpnlepd: int  # 642
NN_cmpnleps: int  # 495
NN_cmpnlesd: int  # 650
NN_cmpnless: int  # 503
NN_cmpnltpd: int  # 641
NN_cmpnltps: int  # 494
NN_cmpnltsd: int  # 649
NN_cmpnltss: int  # 502
NN_cmpordpd: int  # 643
NN_cmpordps: int  # 496
NN_cmpordsd: int  # 651
NN_cmpordss: int  # 504
NN_cmppd: int  # 524
NN_cmpps: int  # 428
NN_cmps: int  # 28
NN_cmpsd: int  # 525
NN_cmpss: int  # 429
NN_cmpunordpd: int  # 639
NN_cmpunordps: int  # 492
NN_cmpunordsd: int  # 647
NN_cmpunordss: int  # 500
NN_cmpxchg: int  # 217
NN_cmpxchg16b: int  # 595
NN_cmpxchg8b: int  # 226
NN_comisd: int  # 526
NN_comiss: int  # 430
NN_cpuid: int  # 225
NN_cqo: int  # 31
NN_crc32: int  # 700
NN_cvtdq2pd: int  # 527
NN_cvtdq2ps: int  # 528
NN_cvtpd2dq: int  # 529
NN_cvtpd2pi: int  # 530
NN_cvtpd2ps: int  # 531
NN_cvtpi2pd: int  # 532
NN_cvtpi2ps: int  # 431
NN_cvtps2dq: int  # 533
NN_cvtps2pd: int  # 534
NN_cvtps2pi: int  # 432
NN_cvtsd2si: int  # 535
NN_cvtsd2ss: int  # 536
NN_cvtsi2sd: int  # 537
NN_cvtsi2ss: int  # 433
NN_cvtss2sd: int  # 538
NN_cvtss2si: int  # 434
NN_cvttpd2dq: int  # 539
NN_cvttpd2pi: int  # 540
NN_cvttps2dq: int  # 541
NN_cvttps2pi: int  # 435
NN_cvttsd2si: int  # 542
NN_cvttss2si: int  # 436
NN_cwd: int  # 29
NN_cwde: int  # 20
NN_daa: int  # 32
NN_das: int  # 33
NN_dec: int  # 34
NN_div: int  # 35
NN_divpd: int  # 543
NN_divps: int  # 437
NN_divsd: int  # 544
NN_divss: int  # 438
NN_dppd: int  # 656
NN_dpps: int  # 657
NN_emms: int  # 351
NN_encls: int  # 1628
NN_enclu: int  # 1629
NN_enclv: int  # 1784
NN_endbr32: int  # 1776
NN_endbr64: int  # 1775
NN_enqcmd: int  # 1779
NN_enqcmds: int  # 1780
NN_enter: int  # 37
NN_enterd: int  # 38
NN_enterq: int  # 39
NN_enterw: int  # 36
NN_extractps: int  # 658
NN_extrq: int  # 707
NN_f2xm1: int  # 301
NN_fabs: int  # 290
NN_fadd: int  # 267
NN_faddp: int  # 268
NN_fbld: int  # 265
NN_fbstp: int  # 266
NN_fchs: int  # 291
NN_fclex: int  # 319
NN_fcmovb: int  # 245
NN_fcmovbe: int  # 247
NN_fcmove: int  # 246
NN_fcmovnb: int  # 249
NN_fcmovnbe: int  # 251
NN_fcmovne: int  # 250
NN_fcmovnu: int  # 252
NN_fcmovu: int  # 248
NN_fcom: int  # 292
NN_fcom2: int  # 511
NN_fcomi: int  # 253
NN_fcomip: int  # 255
NN_fcomp: int  # 293
NN_fcomp3: int  # 512
NN_fcomp5: int  # 514
NN_fcompp: int  # 294
NN_fcos: int  # 338
NN_fdecstp: int  # 328
NN_fdisi: int  # 333
NN_fdiv: int  # 279
NN_fdivp: int  # 280
NN_fdivr: int  # 282
NN_fdivrp: int  # 283
NN_femms: int  # 421
NN_feni: int  # 331
NN_ffree: int  # 329
NN_ffreep: int  # 515
NN_fiadd: int  # 269
NN_ficom: int  # 295
NN_ficomp: int  # 296
NN_fidiv: int  # 281
NN_fidivr: int  # 284
NN_fild: int  # 262
NN_fimul: int  # 278
NN_fincstp: int  # 327
NN_finit: int  # 311
NN_fist: int  # 263
NN_fistp: int  # 264
NN_fisttp: int  # 604
NN_fisub: int  # 272
NN_fisubr: int  # 275
NN_fld: int  # 258
NN_fld1: int  # 305
NN_fldcw: int  # 314
NN_fldenv: int  # 323
NN_fldl2e: int  # 308
NN_fldl2t: int  # 307
NN_fldlg2: int  # 309
NN_fldln2: int  # 310
NN_fldpi: int  # 306
NN_fldz: int  # 304
NN_fmul: int  # 276
NN_fmulp: int  # 277
NN_fnclex: int  # 320
NN_fndisi: int  # 334
NN_fneni: int  # 332
NN_fninit: int  # 312
NN_fnop: int  # 330
NN_fnsave: int  # 325
NN_fnstcw: int  # 316
NN_fnstenv: int  # 322
NN_fnstsw: int  # 318
NN_fpatan: int  # 300
NN_fprem: int  # 287
NN_fprem1: int  # 335
NN_fptan: int  # 299
NN_frndint: int  # 288
NN_frstor: int  # 326
NN_fsave: int  # 324
NN_fscale: int  # 286
NN_fsetpm: int  # 313
NN_fsin: int  # 337
NN_fsincos: int  # 336
NN_fsqrt: int  # 285
NN_fst: int  # 259
NN_fstcw: int  # 315
NN_fstenv: int  # 321
NN_fstp: int  # 260
NN_fstp1: int  # 510
NN_fstp8: int  # 517
NN_fstp9: int  # 518
NN_fstsw: int  # 317
NN_fsub: int  # 270
NN_fsubp: int  # 271
NN_fsubr: int  # 273
NN_fsubrp: int  # 274
NN_ftst: int  # 297
NN_fucom: int  # 339
NN_fucomi: int  # 254
NN_fucomip: int  # 256
NN_fucomp: int  # 340
NN_fucompp: int  # 341
NN_fxam: int  # 298
NN_fxch: int  # 261
NN_fxch4: int  # 513
NN_fxch7: int  # 516
NN_fxrstor: int  # 399
NN_fxrstor64: int  # 1800
NN_fxsave: int  # 398
NN_fxsave64: int  # 1799
NN_fxtract: int  # 289
NN_fyl2x: int  # 302
NN_fyl2xp1: int  # 303
NN_getsec: int  # 716
NN_gf2p8affineinvqb: int  # 1795
NN_gf2p8affineqb: int  # 1794
NN_gf2p8mulb: int  # 1793
NN_haddpd: int  # 598
NN_haddps: int  # 599
NN_hlt: int  # 40
NN_hreset: int  # 1940
NN_hsubpd: int  # 600
NN_hsubps: int  # 601
NN_icebp: int  # 349
NN_idiv: int  # 41
NN_imul: int  # 42
NN_in: int  # 43
NN_inc: int  # 44
NN_incsspd: int  # 1763
NN_incsspq: int  # 1764
NN_ins: int  # 45
NN_insertps: int  # 659
NN_insertq: int  # 708
NN_int: int  # 46
NN_int3: int  # 48
NN_into: int  # 47
NN_invd: int  # 220
NN_invept: int  # 726
NN_invlpg: int  # 222
NN_invlpga: int  # 718
NN_invpcid: int  # 762
NN_invvpid: int  # 727
NN_iret: int  # 50
NN_iretd: int  # 51
NN_iretq: int  # 52
NN_iretw: int  # 49
NN_ja: int  # 53
NN_jae: int  # 54
NN_jb: int  # 55
NN_jbe: int  # 56
NN_jc: int  # 57
NN_jcxz: int  # 58
NN_je: int  # 61
NN_jecxz: int  # 59
NN_jg: int  # 62
NN_jge: int  # 63
NN_jl: int  # 64
NN_jle: int  # 65
NN_jmp: int  # 86
NN_jmpfi: int  # 87
NN_jmpni: int  # 88
NN_jmpshort: int  # 89
NN_jna: int  # 66
NN_jnae: int  # 67
NN_jnb: int  # 68
NN_jnbe: int  # 69
NN_jnc: int  # 70
NN_jne: int  # 71
NN_jng: int  # 72
NN_jnge: int  # 73
NN_jnl: int  # 74
NN_jnle: int  # 75
NN_jno: int  # 76
NN_jnp: int  # 77
NN_jns: int  # 78
NN_jnz: int  # 79
NN_jo: int  # 80
NN_jp: int  # 81
NN_jpe: int  # 82
NN_jpo: int  # 83
NN_jrcxz: int  # 60
NN_js: int  # 84
NN_jz: int  # 85
NN_kaddb: int  # 1571
NN_kaddd: int  # 1573
NN_kaddq: int  # 1572
NN_kaddw: int  # 1570
NN_kandb: int  # 1575
NN_kandd: int  # 1577
NN_kandnb: int  # 1579
NN_kandnd: int  # 1581
NN_kandnq: int  # 1580
NN_kandnw: int  # 1578
NN_kandq: int  # 1576
NN_kandw: int  # 1574
NN_kmovb: int  # 1583
NN_kmovd: int  # 1585
NN_kmovq: int  # 1584
NN_kmovw: int  # 1582
NN_knotb: int  # 1590
NN_knotd: int  # 1592
NN_knotq: int  # 1591
NN_knotw: int  # 1589
NN_korb: int  # 1594
NN_kord: int  # 1596
NN_korq: int  # 1595
NN_kortestb: int  # 1598
NN_kortestd: int  # 1600
NN_kortestq: int  # 1599
NN_kortestw: int  # 1597
NN_korw: int  # 1593
NN_kshiftlb: int  # 1602
NN_kshiftld: int  # 1604
NN_kshiftlq: int  # 1603
NN_kshiftlw: int  # 1601
NN_kshiftrb: int  # 1606
NN_kshiftrd: int  # 1608
NN_kshiftrq: int  # 1607
NN_kshiftrw: int  # 1605
NN_ktestb: int  # 1614
NN_ktestd: int  # 1616
NN_ktestq: int  # 1615
NN_ktestw: int  # 1613
NN_kunpckbw: int  # 1586
NN_kunpckdq: int  # 1588
NN_kunpckwd: int  # 1587
NN_kxnorb: int  # 1610
NN_kxnord: int  # 1612
NN_kxnorq: int  # 1611
NN_kxnorw: int  # 1609
NN_kxorb: int  # 1618
NN_kxord: int  # 1620
NN_kxorq: int  # 1619
NN_kxorw: int  # 1617
NN_lahf: int  # 90
NN_lar: int  # 91
NN_last: int  # 1941
NN_lddqu: int  # 605
NN_ldmxcsr: int  # 439
NN_lds: int  # 101
NN_lea: int  # 92
NN_leave: int  # 94
NN_leaved: int  # 95
NN_leaveq: int  # 96
NN_leavew: int  # 93
NN_les: int  # 102
NN_lfence: int  # 545
NN_lfs: int  # 103
NN_lgdt: int  # 97
NN_lgs: int  # 99
NN_lidt: int  # 98
NN_lldt: int  # 104
NN_lmsw: int  # 105
NN_loadall: int  # 350
NN_lock: int  # 106
NN_lods: int  # 107
NN_loop: int  # 109
NN_loopd: int  # 110
NN_loopde: int  # 114
NN_loopdne: int  # 118
NN_loope: int  # 113
NN_loopne: int  # 117
NN_loopq: int  # 111
NN_loopqe: int  # 115
NN_loopqne: int  # 119
NN_loopw: int  # 108
NN_loopwe: int  # 112
NN_loopwne: int  # 116
NN_lsl: int  # 120
NN_lss: int  # 100
NN_ltr: int  # 121
NN_lzcnt: int  # 711
NN_maskmovdqu: int  # 546
NN_maskmovq: int  # 481
NN_maxpd: int  # 547
NN_maxps: int  # 440
NN_maxsd: int  # 548
NN_maxss: int  # 441
NN_mcommit: int  # 1781
NN_mfence: int  # 549
NN_minpd: int  # 550
NN_minps: int  # 442
NN_minsd: int  # 551
NN_minss: int  # 443
NN_monitor: int  # 602
NN_monitorx: int  # 1749
NN_mov: int  # 122
NN_movapd: int  # 552
NN_movaps: int  # 444
NN_movbe: int  # 728
NN_movd: int  # 352
NN_movddup: int  # 591
NN_movdir64b: int  # 1786
NN_movdiri: int  # 1785
NN_movdq2q: int  # 553
NN_movdqa: int  # 554
NN_movdqu: int  # 555
NN_movhlps: int  # 445
NN_movhpd: int  # 556
NN_movhps: int  # 446
NN_movlhps: int  # 447
NN_movlpd: int  # 557
NN_movlps: int  # 448
NN_movmskpd: int  # 558
NN_movmskps: int  # 449
NN_movntdq: int  # 559
NN_movntdqa: int  # 660
NN_movnti: int  # 560
NN_movntpd: int  # 561
NN_movntps: int  # 482
NN_movntq: int  # 483
NN_movntsd: int  # 709
NN_movntss: int  # 710
NN_movq: int  # 353
NN_movq2dq: int  # 562
NN_movs: int  # 124
NN_movsd: int  # 563
NN_movshdup: int  # 592
NN_movsldup: int  # 593
NN_movsp: int  # 123
NN_movss: int  # 450
NN_movsx: int  # 125
NN_movsxd: int  # 594
NN_movupd: int  # 564
NN_movups: int  # 451
NN_movzx: int  # 126
NN_mpsadbw: int  # 661
NN_mul: int  # 127
NN_mulpd: int  # 565
NN_mulps: int  # 452
NN_mulsd: int  # 566
NN_mulss: int  # 453
NN_mulx: int  # 752
NN_mwait: int  # 603
NN_mwaitx: int  # 1750
NN_neg: int  # 128
NN_nop: int  # 129
NN_not: int  # 130
NN_null: int  # 0
NN_or: int  # 131
NN_orpd: int  # 567
NN_orps: int  # 454
NN_out: int  # 132
NN_outs: int  # 133
NN_pabsb: int  # 619
NN_pabsd: int  # 621
NN_pabsw: int  # 620
NN_packssdw: int  # 355
NN_packsswb: int  # 354
NN_packusdw: int  # 662
NN_packuswb: int  # 356
NN_paddb: int  # 357
NN_paddd: int  # 359
NN_paddq: int  # 568
NN_paddsb: int  # 360
NN_paddsw: int  # 361
NN_paddusb: int  # 362
NN_paddusw: int  # 363
NN_paddw: int  # 358
NN_palignr: int  # 618
NN_pand: int  # 364
NN_pandn: int  # 365
NN_pause: int  # 569
NN_pavgb: int  # 469
NN_pavgusb: int  # 402
NN_pavgw: int  # 470
NN_pblendvb: int  # 663
NN_pblendw: int  # 664
NN_pclmulqdq: int  # 735
NN_pcmpeqb: int  # 366
NN_pcmpeqd: int  # 368
NN_pcmpeqq: int  # 665
NN_pcmpeqw: int  # 367
NN_pcmpestri: int  # 701
NN_pcmpestrm: int  # 702
NN_pcmpgtb: int  # 369
NN_pcmpgtd: int  # 371
NN_pcmpgtq: int  # 705
NN_pcmpgtw: int  # 370
NN_pcmpistri: int  # 703
NN_pcmpistrm: int  # 704
NN_pcommit: int  # 1172
NN_pdep: int  # 753
NN_pext: int  # 754
NN_pextrb: int  # 666
NN_pextrd: int  # 667
NN_pextrq: int  # 668
NN_pextrw: int  # 471
NN_pf2id: int  # 413
NN_pf2iw: int  # 505
NN_pfacc: int  # 406
NN_pfadd: int  # 403
NN_pfcmpeq: int  # 409
NN_pfcmpge: int  # 407
NN_pfcmpgt: int  # 408
NN_pfmax: int  # 411
NN_pfmin: int  # 410
NN_pfmul: int  # 416
NN_pfnacc: int  # 506
NN_pfpnacc: int  # 507
NN_pfrcp: int  # 414
NN_pfrcpit1: int  # 417
NN_pfrcpit2: int  # 419
NN_pfrcpv: int  # 634
NN_pfrsqit1: int  # 418
NN_pfrsqrt: int  # 415
NN_pfrsqrtv: int  # 635
NN_pfsub: int  # 404
NN_pfsubr: int  # 405
NN_phaddd: int  # 615
NN_phaddsw: int  # 613
NN_phaddw: int  # 614
NN_phminposuw: int  # 669
NN_phsubd: int  # 617
NN_phsubsw: int  # 612
NN_phsubw: int  # 616
NN_pi2fd: int  # 412
NN_pi2fw: int  # 508
NN_pinsrb: int  # 670
NN_pinsrd: int  # 671
NN_pinsrq: int  # 672
NN_pinsrw: int  # 472
NN_pmaddubsw: int  # 611
NN_pmaddwd: int  # 372
NN_pmaxsb: int  # 673
NN_pmaxsd: int  # 674
NN_pmaxsw: int  # 473
NN_pmaxub: int  # 474
NN_pmaxud: int  # 675
NN_pmaxuw: int  # 676
NN_pminsb: int  # 677
NN_pminsd: int  # 678
NN_pminsw: int  # 475
NN_pminub: int  # 476
NN_pminud: int  # 679
NN_pminuw: int  # 680
NN_pmovmskb: int  # 477
NN_pmovsxbd: int  # 682
NN_pmovsxbq: int  # 683
NN_pmovsxbw: int  # 681
NN_pmovsxdq: int  # 686
NN_pmovsxwd: int  # 684
NN_pmovsxwq: int  # 685
NN_pmovzxbd: int  # 688
NN_pmovzxbq: int  # 689
NN_pmovzxbw: int  # 687
NN_pmovzxdq: int  # 692
NN_pmovzxwd: int  # 690
NN_pmovzxwq: int  # 691
NN_pmuldq: int  # 693
NN_pmulhrsw: int  # 610
NN_pmulhrw: int  # 420
NN_pmulhuw: int  # 478
NN_pmulhw: int  # 373
NN_pmulld: int  # 694
NN_pmullw: int  # 374
NN_pmuludq: int  # 570
NN_pop: int  # 134
NN_popa: int  # 136
NN_popad: int  # 137
NN_popaq: int  # 138
NN_popaw: int  # 135
NN_popcnt: int  # 706
NN_popf: int  # 140
NN_popfd: int  # 141
NN_popfq: int  # 142
NN_popfw: int  # 139
NN_por: int  # 375
NN_prefetch: int  # 422
NN_prefetchnta: int  # 487
NN_prefetcht0: int  # 484
NN_prefetcht1: int  # 485
NN_prefetcht2: int  # 486
NN_prefetchw: int  # 423
NN_prefetchwt1: int  # 1169
NN_psadbw: int  # 479
NN_pshufb: int  # 609
NN_pshufd: int  # 571
NN_pshufhw: int  # 572
NN_pshuflw: int  # 573
NN_pshufw: int  # 480
NN_psignb: int  # 606
NN_psignd: int  # 608
NN_psignw: int  # 607
NN_pslld: int  # 377
NN_pslldq: int  # 574
NN_psllq: int  # 378
NN_psllw: int  # 376
NN_psrad: int  # 380
NN_psraw: int  # 379
NN_psrld: int  # 382
NN_psrldq: int  # 575
NN_psrlq: int  # 383
NN_psrlw: int  # 381
NN_psubb: int  # 384
NN_psubd: int  # 386
NN_psubq: int  # 576
NN_psubsb: int  # 387
NN_psubsw: int  # 388
NN_psubusb: int  # 389
NN_psubusw: int  # 390
NN_psubw: int  # 385
NN_pswapd: int  # 509
NN_ptest: int  # 695
NN_ptwrite: int  # 1752
NN_punpckhbw: int  # 391
NN_punpckhdq: int  # 393
NN_punpckhqdq: int  # 577
NN_punpckhwd: int  # 392
NN_punpcklbw: int  # 394
NN_punpckldq: int  # 396
NN_punpcklqdq: int  # 578
NN_punpcklwd: int  # 395
NN_push: int  # 143
NN_pusha: int  # 145
NN_pushad: int  # 146
NN_pushaq: int  # 147
NN_pushaw: int  # 144
NN_pushf: int  # 149
NN_pushfd: int  # 150
NN_pushfq: int  # 151
NN_pushfw: int  # 148
NN_pxor: int  # 397
NN_rcl: int  # 152
NN_rcpps: int  # 455
NN_rcpss: int  # 456
NN_rcr: int  # 153
NN_rdfsbase: int  # 764
NN_rdgsbase: int  # 765
NN_rdmsr: int  # 223
NN_rdpid: int  # 1761
NN_rdpkru: int  # 1173
NN_rdpmc: int  # 257
NN_rdpru: int  # 1782
NN_rdrand: int  # 742
NN_rdseed: int  # 763
NN_rdsspd: int  # 1765
NN_rdsspq: int  # 1766
NN_rdtsc: int  # 227
NN_rdtscp: int  # 633
NN_rep: int  # 156
NN_repe: int  # 157
NN_repne: int  # 158
NN_retf: int  # 160
NN_retfd: int  # 740
NN_retfq: int  # 741
NN_retfw: int  # 739
NN_retn: int  # 159
NN_retnd: int  # 737
NN_retnq: int  # 738
NN_retnw: int  # 736
NN_rol: int  # 154
NN_ror: int  # 155
NN_rorx: int  # 755
NN_roundpd: int  # 696
NN_roundps: int  # 697
NN_roundsd: int  # 698
NN_roundss: int  # 699
NN_rsdc: int  # 344
NN_rsldt: int  # 346
NN_rsm: int  # 228
NN_rsqrtps: int  # 457
NN_rsqrtss: int  # 458
NN_rstorssp: int  # 1768
NN_rsts: int  # 348
NN_sahf: int  # 161
NN_sal: int  # 162
NN_sar: int  # 163
NN_sarx: int  # 756
NN_saveprevssp: int  # 1767
NN_sbb: int  # 166
NN_scas: int  # 167
NN_senduipi: int  # 1939
NN_serialize: int  # 1790
NN_seta: int  # 168
NN_setae: int  # 169
NN_setalc: int  # 342
NN_setb: int  # 170
NN_setbe: int  # 171
NN_setc: int  # 172
NN_sete: int  # 173
NN_setg: int  # 174
NN_setge: int  # 175
NN_setl: int  # 176
NN_setle: int  # 177
NN_setna: int  # 178
NN_setnae: int  # 179
NN_setnb: int  # 180
NN_setnbe: int  # 181
NN_setnc: int  # 182
NN_setne: int  # 183
NN_setng: int  # 184
NN_setnge: int  # 185
NN_setnl: int  # 186
NN_setnle: int  # 187
NN_setno: int  # 188
NN_setnp: int  # 189
NN_setns: int  # 190
NN_setnz: int  # 191
NN_seto: int  # 192
NN_setp: int  # 193
NN_setpe: int  # 194
NN_setpo: int  # 195
NN_sets: int  # 196
NN_setssbsy: int  # 1773
NN_setz: int  # 197
NN_sfence: int  # 488
NN_sgdt: int  # 198
NN_sha1msg1: int  # 1623
NN_sha1msg2: int  # 1624
NN_sha1nexte: int  # 1622
NN_sha1rnds4: int  # 1621
NN_sha256msg1: int  # 1626
NN_sha256msg2: int  # 1627
NN_sha256rnds2: int  # 1625
NN_shl: int  # 164
NN_shld: int  # 200
NN_shlx: int  # 757
NN_shr: int  # 165
NN_shrd: int  # 201
NN_shrx: int  # 758
NN_shufpd: int  # 579
NN_shufps: int  # 459
NN_sidt: int  # 199
NN_skinit: int  # 719
NN_sldt: int  # 202
NN_smsw: int  # 203
NN_sqrtpd: int  # 580
NN_sqrtps: int  # 460
NN_sqrtsd: int  # 581
NN_sqrtss: int  # 461
NN_stac: int  # 759
NN_stc: int  # 204
NN_std: int  # 205
NN_stgi: int  # 720
NN_sti: int  # 206
NN_stmxcsr: int  # 462
NN_stos: int  # 207
NN_str: int  # 208
NN_stui: int  # 1936
NN_sub: int  # 209
NN_subpd: int  # 582
NN_subps: int  # 463
NN_subsd: int  # 583
NN_subss: int  # 464
NN_svdc: int  # 343
NN_svldt: int  # 345
NN_svts: int  # 347
NN_swapgs: int  # 590
NN_syscall: int  # 588
NN_sysenter: int  # 400
NN_sysexit: int  # 401
NN_sysret: int  # 589
NN_test: int  # 210
NN_testui: int  # 1937
NN_tpause: int  # 1787
NN_tzcnt: int  # 760
NN_ucomisd: int  # 584
NN_ucomiss: int  # 465
NN_ud0: int  # 1777
NN_ud1: int  # 1778
NN_ud2: int  # 632
NN_uiret: int  # 1938
NN_umonitor: int  # 1788
NN_umwait: int  # 1789
NN_unpckhpd: int  # 585
NN_unpckhps: int  # 466
NN_unpcklpd: int  # 586
NN_unpcklps: int  # 467
NN_v4fmaddps: int  # 1753
NN_v4fmaddss: int  # 1755
NN_v4fnmaddps: int  # 1754
NN_v4fnmaddss: int  # 1756
NN_vaddpd: int  # 768
NN_vaddph: int  # 1829
NN_vaddps: int  # 769
NN_vaddsd: int  # 770
NN_vaddsh: int  # 1890
NN_vaddss: int  # 771
NN_vaddsubpd: int  # 772
NN_vaddsubps: int  # 773
NN_vaesdec: int  # 774
NN_vaesdeclast: int  # 775
NN_vaesenc: int  # 776
NN_vaesenclast: int  # 777
NN_vaesimc: int  # 778
NN_vaeskeygenassist: int  # 779
NN_valignd: int  # 1303
NN_valignq: int  # 1304
NN_vandnpd: int  # 780
NN_vandnps: int  # 781
NN_vandpd: int  # 782
NN_vandps: int  # 783
NN_vblendmpd: int  # 1305
NN_vblendmps: int  # 1306
NN_vblendpd: int  # 784
NN_vblendps: int  # 785
NN_vblendvpd: int  # 786
NN_vblendvps: int  # 787
NN_vbroadcastf128: int  # 788
NN_vbroadcastf32x2: int  # 1311
NN_vbroadcastf32x4: int  # 1312
NN_vbroadcastf32x8: int  # 1314
NN_vbroadcastf64x2: int  # 1313
NN_vbroadcastf64x4: int  # 1315
NN_vbroadcasti128: int  # 789
NN_vbroadcasti32x2: int  # 1316
NN_vbroadcasti32x4: int  # 1317
NN_vbroadcasti32x8: int  # 1319
NN_vbroadcasti64x2: int  # 1318
NN_vbroadcasti64x4: int  # 1320
NN_vbroadcastsd: int  # 790
NN_vbroadcastss: int  # 791
NN_vcmpeq_ospd: int  # 1191
NN_vcmpeq_osps: int  # 1223
NN_vcmpeq_ossd: int  # 1255
NN_vcmpeq_osss: int  # 1287
NN_vcmpeq_uqpd: int  # 1183
NN_vcmpeq_uqps: int  # 1215
NN_vcmpeq_uqsd: int  # 1247
NN_vcmpeq_uqss: int  # 1279
NN_vcmpeq_uspd: int  # 1199
NN_vcmpeq_usps: int  # 1231
NN_vcmpeq_ussd: int  # 1263
NN_vcmpeq_usss: int  # 1295
NN_vcmpeqpd: int  # 1175
NN_vcmpeqps: int  # 1207
NN_vcmpeqsd: int  # 1239
NN_vcmpeqss: int  # 1271
NN_vcmpfalse_ospd: int  # 1202
NN_vcmpfalse_osps: int  # 1234
NN_vcmpfalse_ossd: int  # 1266
NN_vcmpfalse_osss: int  # 1298
NN_vcmpfalsepd: int  # 1186
NN_vcmpfalseps: int  # 1218
NN_vcmpfalsesd: int  # 1250
NN_vcmpfalsess: int  # 1282
NN_vcmpge_oqpd: int  # 1204
NN_vcmpge_oqps: int  # 1236
NN_vcmpge_oqsd: int  # 1268
NN_vcmpge_oqss: int  # 1300
NN_vcmpgepd: int  # 1188
NN_vcmpgeps: int  # 1220
NN_vcmpgesd: int  # 1252
NN_vcmpgess: int  # 1284
NN_vcmpgt_oqpd: int  # 1205
NN_vcmpgt_oqps: int  # 1237
NN_vcmpgt_oqsd: int  # 1269
NN_vcmpgt_oqss: int  # 1301
NN_vcmpgtpd: int  # 1189
NN_vcmpgtps: int  # 1221
NN_vcmpgtsd: int  # 1253
NN_vcmpgtss: int  # 1285
NN_vcmple_oqpd: int  # 1193
NN_vcmple_oqps: int  # 1225
NN_vcmple_oqsd: int  # 1257
NN_vcmple_oqss: int  # 1289
NN_vcmplepd: int  # 1177
NN_vcmpleps: int  # 1209
NN_vcmplesd: int  # 1241
NN_vcmpless: int  # 1273
NN_vcmplt_oqpd: int  # 1192
NN_vcmplt_oqps: int  # 1224
NN_vcmplt_oqsd: int  # 1256
NN_vcmplt_oqss: int  # 1288
NN_vcmpltpd: int  # 1176
NN_vcmpltps: int  # 1208
NN_vcmpltsd: int  # 1240
NN_vcmpltss: int  # 1272
NN_vcmpneq_oqpd: int  # 1187
NN_vcmpneq_oqps: int  # 1219
NN_vcmpneq_oqsd: int  # 1251
NN_vcmpneq_oqss: int  # 1283
NN_vcmpneq_ospd: int  # 1203
NN_vcmpneq_osps: int  # 1235
NN_vcmpneq_ossd: int  # 1267
NN_vcmpneq_osss: int  # 1299
NN_vcmpneq_uspd: int  # 1195
NN_vcmpneq_usps: int  # 1227
NN_vcmpneq_ussd: int  # 1259
NN_vcmpneq_usss: int  # 1291
NN_vcmpneqpd: int  # 1179
NN_vcmpneqps: int  # 1211
NN_vcmpneqsd: int  # 1243
NN_vcmpneqss: int  # 1275
NN_vcmpnge_uqpd: int  # 1200
NN_vcmpnge_uqps: int  # 1232
NN_vcmpnge_uqsd: int  # 1264
NN_vcmpnge_uqss: int  # 1296
NN_vcmpngepd: int  # 1184
NN_vcmpngeps: int  # 1216
NN_vcmpngesd: int  # 1248
NN_vcmpngess: int  # 1280
NN_vcmpngt_uqpd: int  # 1201
NN_vcmpngt_uqps: int  # 1233
NN_vcmpngt_uqsd: int  # 1265
NN_vcmpngt_uqss: int  # 1297
NN_vcmpngtpd: int  # 1185
NN_vcmpngtps: int  # 1217
NN_vcmpngtsd: int  # 1249
NN_vcmpngtss: int  # 1281
NN_vcmpnle_uqpd: int  # 1197
NN_vcmpnle_uqps: int  # 1229
NN_vcmpnle_uqsd: int  # 1261
NN_vcmpnle_uqss: int  # 1293
NN_vcmpnlepd: int  # 1181
NN_vcmpnleps: int  # 1213
NN_vcmpnlesd: int  # 1245
NN_vcmpnless: int  # 1277
NN_vcmpnlt_uqpd: int  # 1196
NN_vcmpnlt_uqps: int  # 1228
NN_vcmpnlt_uqsd: int  # 1260
NN_vcmpnlt_uqss: int  # 1292
NN_vcmpnltpd: int  # 1180
NN_vcmpnltps: int  # 1212
NN_vcmpnltsd: int  # 1244
NN_vcmpnltss: int  # 1276
NN_vcmpord_spd: int  # 1198
NN_vcmpord_sps: int  # 1230
NN_vcmpord_ssd: int  # 1262
NN_vcmpord_sss: int  # 1294
NN_vcmpordpd: int  # 1182
NN_vcmpordps: int  # 1214
NN_vcmpordsd: int  # 1246
NN_vcmpordss: int  # 1278
NN_vcmppd: int  # 792
NN_vcmpph: int  # 1830
NN_vcmpps: int  # 793
NN_vcmpsd: int  # 794
NN_vcmpsh: int  # 1891
NN_vcmpss: int  # 795
NN_vcmptrue_uspd: int  # 1206
NN_vcmptrue_usps: int  # 1238
NN_vcmptrue_ussd: int  # 1270
NN_vcmptrue_usss: int  # 1302
NN_vcmptruepd: int  # 1190
NN_vcmptrueps: int  # 1222
NN_vcmptruesd: int  # 1254
NN_vcmptruess: int  # 1286
NN_vcmpunord_spd: int  # 1194
NN_vcmpunord_sps: int  # 1226
NN_vcmpunord_ssd: int  # 1258
NN_vcmpunord_sss: int  # 1290
NN_vcmpunordpd: int  # 1178
NN_vcmpunordps: int  # 1210
NN_vcmpunordsd: int  # 1242
NN_vcmpunordss: int  # 1274
NN_vcomisd: int  # 796
NN_vcomish: int  # 1892
NN_vcomiss: int  # 797
NN_vcompresspd: int  # 1321
NN_vcompressps: int  # 1322
NN_vcvtdq2pd: int  # 798
NN_vcvtdq2ph: int  # 1831
NN_vcvtdq2ps: int  # 799
NN_vcvtne2ps2bf16: int  # 1826
NN_vcvtneps2bf16: int  # 1827
NN_vcvtpd2dq: int  # 800
NN_vcvtpd2ph: int  # 1832
NN_vcvtpd2ps: int  # 801
NN_vcvtpd2qq: int  # 1323
NN_vcvtpd2udq: int  # 1324
NN_vcvtpd2uqq: int  # 1325
NN_vcvtph2dq: int  # 1833
NN_vcvtph2pd: int  # 1834
NN_vcvtph2ps: int  # 802
NN_vcvtph2psx: int  # 1835
NN_vcvtph2qq: int  # 1836
NN_vcvtph2udq: int  # 1837
NN_vcvtph2uqq: int  # 1838
NN_vcvtph2uw: int  # 1839
NN_vcvtph2w: int  # 1840
NN_vcvtps2dq: int  # 803
NN_vcvtps2pd: int  # 804
NN_vcvtps2ph: int  # 805
NN_vcvtps2phx: int  # 1841
NN_vcvtps2qq: int  # 1327
NN_vcvtps2udq: int  # 1326
NN_vcvtps2uqq: int  # 1328
NN_vcvtqq2pd: int  # 1329
NN_vcvtqq2ph: int  # 1842
NN_vcvtqq2ps: int  # 1330
NN_vcvtsd2sh: int  # 1893
NN_vcvtsd2si: int  # 806
NN_vcvtsd2ss: int  # 807
NN_vcvtsd2usi: int  # 1331
NN_vcvtsh2sd: int  # 1894
NN_vcvtsh2si: int  # 1895
NN_vcvtsh2ss: int  # 1896
NN_vcvtsh2usi: int  # 1897
NN_vcvtsi2sd: int  # 808
NN_vcvtsi2sh: int  # 1898
NN_vcvtsi2ss: int  # 809
NN_vcvtss2sd: int  # 810
NN_vcvtss2sh: int  # 1899
NN_vcvtss2si: int  # 811
NN_vcvtss2usi: int  # 1332
NN_vcvttpd2dq: int  # 812
NN_vcvttpd2qq: int  # 1333
NN_vcvttpd2udq: int  # 1334
NN_vcvttpd2uqq: int  # 1335
NN_vcvttph2dq: int  # 1843
NN_vcvttph2qq: int  # 1844
NN_vcvttph2udq: int  # 1845
NN_vcvttph2uqq: int  # 1846
NN_vcvttph2uw: int  # 1847
NN_vcvttph2w: int  # 1848
NN_vcvttps2dq: int  # 813
NN_vcvttps2qq: int  # 1337
NN_vcvttps2udq: int  # 1336
NN_vcvttps2uqq: int  # 1338
NN_vcvttsd2si: int  # 814
NN_vcvttsd2usi: int  # 1339
NN_vcvttsh2si: int  # 1900
NN_vcvttsh2usi: int  # 1901
NN_vcvttss2si: int  # 815
NN_vcvttss2usi: int  # 1340
NN_vcvtudq2pd: int  # 1341
NN_vcvtudq2ph: int  # 1849
NN_vcvtudq2ps: int  # 1342
NN_vcvtuqq2pd: int  # 1343
NN_vcvtuqq2ph: int  # 1850
NN_vcvtuqq2ps: int  # 1344
NN_vcvtusi2sd: int  # 1345
NN_vcvtusi2sh: int  # 1902
NN_vcvtusi2ss: int  # 1346
NN_vcvtuw2ph: int  # 1851
NN_vcvtw2ph: int  # 1852
NN_vdbpsadbw: int  # 1347
NN_vdivpd: int  # 816
NN_vdivph: int  # 1853
NN_vdivps: int  # 817
NN_vdivsd: int  # 818
NN_vdivsh: int  # 1903
NN_vdivss: int  # 819
NN_vdpbf16ps: int  # 1828
NN_vdppd: int  # 820
NN_vdpps: int  # 821
NN_verr: int  # 211
NN_verw: int  # 212
NN_vexp2pd: int  # 1522
NN_vexp2ps: int  # 1523
NN_vexpandpd: int  # 1348
NN_vexpandps: int  # 1349
NN_vextractf128: int  # 822
NN_vextractf32x4: int  # 1350
NN_vextractf32x8: int  # 1352
NN_vextractf64x2: int  # 1351
NN_vextractf64x4: int  # 1353
NN_vextracti128: int  # 823
NN_vextracti32x4: int  # 1354
NN_vextracti32x8: int  # 1356
NN_vextracti64x2: int  # 1355
NN_vextracti64x4: int  # 1357
NN_vextractps: int  # 824
NN_vfcmaddcph: int  # 1854
NN_vfcmaddcsh: int  # 1904
NN_vfcmulcph: int  # 1855
NN_vfcmulcsh: int  # 1905
NN_vfixupimmpd: int  # 1358
NN_vfixupimmps: int  # 1359
NN_vfixupimmsd: int  # 1360
NN_vfixupimmss: int  # 1361
NN_vfmadd132pd: int  # 825
NN_vfmadd132ph: int  # 1856
NN_vfmadd132ps: int  # 826
NN_vfmadd132sd: int  # 827
NN_vfmadd132sh: int  # 1906
NN_vfmadd132ss: int  # 828
NN_vfmadd213pd: int  # 829
NN_vfmadd213ph: int  # 1857
NN_vfmadd213ps: int  # 830
NN_vfmadd213sd: int  # 831
NN_vfmadd213sh: int  # 1907
NN_vfmadd213ss: int  # 832
NN_vfmadd231pd: int  # 833
NN_vfmadd231ph: int  # 1858
NN_vfmadd231ps: int  # 834
NN_vfmadd231sd: int  # 835
NN_vfmadd231sh: int  # 1908
NN_vfmadd231ss: int  # 836
NN_vfmaddcph: int  # 1859
NN_vfmaddcsh: int  # 1909
NN_vfmaddpd: int  # 1144
NN_vfmaddps: int  # 1143
NN_vfmaddsd: int  # 1146
NN_vfmaddss: int  # 1145
NN_vfmaddsub132pd: int  # 837
NN_vfmaddsub132ph: int  # 1860
NN_vfmaddsub132ps: int  # 838
NN_vfmaddsub213pd: int  # 839
NN_vfmaddsub213ph: int  # 1861
NN_vfmaddsub213ps: int  # 840
NN_vfmaddsub231pd: int  # 841
NN_vfmaddsub231ph: int  # 1862
NN_vfmaddsub231ps: int  # 842
NN_vfmaddsubpd: int  # 1140
NN_vfmaddsubps: int  # 1139
NN_vfmsub132pd: int  # 843
NN_vfmsub132ph: int  # 1863
NN_vfmsub132ps: int  # 844
NN_vfmsub132sd: int  # 845
NN_vfmsub132sh: int  # 1910
NN_vfmsub132ss: int  # 846
NN_vfmsub213pd: int  # 847
NN_vfmsub213ph: int  # 1864
NN_vfmsub213ps: int  # 848
NN_vfmsub213sd: int  # 849
NN_vfmsub213sh: int  # 1911
NN_vfmsub213ss: int  # 850
NN_vfmsub231pd: int  # 851
NN_vfmsub231ph: int  # 1865
NN_vfmsub231ps: int  # 852
NN_vfmsub231sd: int  # 853
NN_vfmsub231sh: int  # 1912
NN_vfmsub231ss: int  # 854
NN_vfmsubadd132pd: int  # 855
NN_vfmsubadd132ph: int  # 1866
NN_vfmsubadd132ps: int  # 856
NN_vfmsubadd213pd: int  # 857
NN_vfmsubadd213ph: int  # 1867
NN_vfmsubadd213ps: int  # 858
NN_vfmsubadd231pd: int  # 859
NN_vfmsubadd231ph: int  # 1868
NN_vfmsubadd231ps: int  # 860
NN_vfmsubaddpd: int  # 1142
NN_vfmsubaddps: int  # 1141
NN_vfmsubpd: int  # 1148
NN_vfmsubps: int  # 1147
NN_vfmsubsd: int  # 1150
NN_vfmsubss: int  # 1149
NN_vfmulcph: int  # 1869
NN_vfmulcsh: int  # 1913
NN_vfnmadd132pd: int  # 861
NN_vfnmadd132ph: int  # 1870
NN_vfnmadd132ps: int  # 862
NN_vfnmadd132sd: int  # 863
NN_vfnmadd132sh: int  # 1914
NN_vfnmadd132ss: int  # 864
NN_vfnmadd213pd: int  # 865
NN_vfnmadd213ph: int  # 1871
NN_vfnmadd213ps: int  # 866
NN_vfnmadd213sd: int  # 867
NN_vfnmadd213sh: int  # 1915
NN_vfnmadd213ss: int  # 868
NN_vfnmadd231pd: int  # 869
NN_vfnmadd231ph: int  # 1872
NN_vfnmadd231ps: int  # 870
NN_vfnmadd231sd: int  # 871
NN_vfnmadd231sh: int  # 1916
NN_vfnmadd231ss: int  # 872
NN_vfnmaddpd: int  # 1152
NN_vfnmaddps: int  # 1151
NN_vfnmaddsd: int  # 1154
NN_vfnmaddss: int  # 1153
NN_vfnmsub132pd: int  # 873
NN_vfnmsub132ph: int  # 1873
NN_vfnmsub132ps: int  # 874
NN_vfnmsub132sd: int  # 875
NN_vfnmsub132sh: int  # 1917
NN_vfnmsub132ss: int  # 876
NN_vfnmsub213pd: int  # 877
NN_vfnmsub213ph: int  # 1874
NN_vfnmsub213ps: int  # 878
NN_vfnmsub213sd: int  # 879
NN_vfnmsub213sh: int  # 1918
NN_vfnmsub213ss: int  # 880
NN_vfnmsub231pd: int  # 881
NN_vfnmsub231ph: int  # 1875
NN_vfnmsub231ps: int  # 882
NN_vfnmsub231sd: int  # 883
NN_vfnmsub231sh: int  # 1919
NN_vfnmsub231ss: int  # 884
NN_vfnmsubpd: int  # 1156
NN_vfnmsubps: int  # 1155
NN_vfnmsubsd: int  # 1158
NN_vfnmsubss: int  # 1157
NN_vfpclasspd: int  # 1362
NN_vfpclassph: int  # 1876
NN_vfpclassps: int  # 1363
NN_vfpclasssd: int  # 1364
NN_vfpclasssh: int  # 1920
NN_vfpclassss: int  # 1365
NN_vfrczpd: int  # 1630
NN_vfrczps: int  # 1631
NN_vfrczsd: int  # 1632
NN_vfrczss: int  # 1633
NN_vgatherdpd: int  # 886
NN_vgatherdps: int  # 885
NN_vgatherpf0dpd: int  # 1534
NN_vgatherpf0dps: int  # 1532
NN_vgatherpf0qpd: int  # 1535
NN_vgatherpf0qps: int  # 1533
NN_vgatherpf1dpd: int  # 1538
NN_vgatherpf1dps: int  # 1536
NN_vgatherpf1qpd: int  # 1539
NN_vgatherpf1qps: int  # 1537
NN_vgatherqpd: int  # 888
NN_vgatherqps: int  # 887
NN_vgetexppd: int  # 1366
NN_vgetexpph: int  # 1877
NN_vgetexpps: int  # 1367
NN_vgetexpsd: int  # 1368
NN_vgetexpsh: int  # 1921
NN_vgetexpss: int  # 1369
NN_vgetmantpd: int  # 1370
NN_vgetmantph: int  # 1878
NN_vgetmantps: int  # 1371
NN_vgetmantsd: int  # 1372
NN_vgetmantsh: int  # 1922
NN_vgetmantss: int  # 1373
NN_vgf2p8affineinvqb: int  # 1798
NN_vgf2p8affineqb: int  # 1797
NN_vgf2p8mulb: int  # 1796
NN_vhaddpd: int  # 889
NN_vhaddps: int  # 890
NN_vhsubpd: int  # 891
NN_vhsubps: int  # 892
NN_vinsertf128: int  # 893
NN_vinsertf32x4: int  # 1374
NN_vinsertf32x8: int  # 1376
NN_vinsertf64x2: int  # 1375
NN_vinsertf64x4: int  # 1377
NN_vinserti128: int  # 894
NN_vinserti32x4: int  # 1378
NN_vinserti32x8: int  # 1380
NN_vinserti64x2: int  # 1379
NN_vinserti64x4: int  # 1381
NN_vinsertps: int  # 895
NN_vlddqu: int  # 896
NN_vldmxcsr: int  # 897
NN_vmaskmovdqu: int  # 898
NN_vmaskmovpd: int  # 899
NN_vmaskmovps: int  # 900
NN_vmaxpd: int  # 901
NN_vmaxph: int  # 1879
NN_vmaxps: int  # 902
NN_vmaxsd: int  # 903
NN_vmaxsh: int  # 1923
NN_vmaxss: int  # 904
NN_vmcall: int  # 622
NN_vmclear: int  # 623
NN_vmcli: int  # 1130
NN_vmcpuid: int  # 1125
NN_vmdxdsbl: int  # 1123
NN_vmdxenbl: int  # 1124
NN_vmexit: int  # 721
NN_vmfunc: int  # 1762
NN_vmgetinfo: int  # 1121
NN_vmhlt: int  # 1126
NN_vminpd: int  # 905
NN_vminph: int  # 1880
NN_vminps: int  # 906
NN_vminsd: int  # 907
NN_vminsh: int  # 1924
NN_vminss: int  # 908
NN_vmiretd: int  # 1132
NN_vmlaunch: int  # 624
NN_vmload: int  # 722
NN_vmmcall: int  # 723
NN_vmovapd: int  # 909
NN_vmovaps: int  # 910
NN_vmovd: int  # 911
NN_vmovddup: int  # 912
NN_vmovdqa: int  # 913
NN_vmovdqa32: int  # 1382
NN_vmovdqa64: int  # 1383
NN_vmovdqu: int  # 914
NN_vmovdqu16: int  # 1385
NN_vmovdqu32: int  # 1386
NN_vmovdqu64: int  # 1387
NN_vmovdqu8: int  # 1384
NN_vmovhlps: int  # 915
NN_vmovhpd: int  # 916
NN_vmovhps: int  # 917
NN_vmovlhps: int  # 918
NN_vmovlpd: int  # 919
NN_vmovlps: int  # 920
NN_vmovmskpd: int  # 921
NN_vmovmskps: int  # 922
NN_vmovntdq: int  # 923
NN_vmovntdqa: int  # 924
NN_vmovntpd: int  # 925
NN_vmovntps: int  # 926
NN_vmovq: int  # 927
NN_vmovsd: int  # 928
NN_vmovsh: int  # 1925
NN_vmovshdup: int  # 929
NN_vmovsldup: int  # 930
NN_vmovss: int  # 931
NN_vmovupd: int  # 932
NN_vmovups: int  # 933
NN_vmovw: int  # 1889
NN_vmpopfd: int  # 1129
NN_vmpsadbw: int  # 934
NN_vmptrld: int  # 626
NN_vmptrst: int  # 627
NN_vmpushfd: int  # 1128
NN_vmread: int  # 628
NN_vmresume: int  # 625
NN_vmrun: int  # 724
NN_vmsave: int  # 725
NN_vmsdte: int  # 1137
NN_vmsetinfo: int  # 1122
NN_vmsgdt: int  # 1133
NN_vmsidt: int  # 1134
NN_vmsldt: int  # 1135
NN_vmsplaf: int  # 1127
NN_vmsti: int  # 1131
NN_vmstr: int  # 1136
NN_vmulpd: int  # 935
NN_vmulph: int  # 1881
NN_vmulps: int  # 936
NN_vmulsd: int  # 937
NN_vmulsh: int  # 1926
NN_vmulss: int  # 938
NN_vmwrite: int  # 629
NN_vmxoff: int  # 630
NN_vmxon: int  # 631
NN_vorpd: int  # 939
NN_vorps: int  # 940
NN_vp2intersectd: int  # 1824
NN_vp2intersectq: int  # 1825
NN_vp4dpwssd: int  # 1757
NN_vp4dpwssds: int  # 1758
NN_vpabsb: int  # 941
NN_vpabsd: int  # 942
NN_vpabsq: int  # 1388
NN_vpabsw: int  # 943
NN_vpackssdw: int  # 944
NN_vpacksswb: int  # 945
NN_vpackusdw: int  # 946
NN_vpackuswb: int  # 947
NN_vpaddb: int  # 948
NN_vpaddd: int  # 949
NN_vpaddq: int  # 950
NN_vpaddsb: int  # 951
NN_vpaddsw: int  # 952
NN_vpaddusb: int  # 953
NN_vpaddusw: int  # 954
NN_vpaddw: int  # 955
NN_vpalignr: int  # 956
NN_vpand: int  # 957
NN_vpandd: int  # 1389
NN_vpandn: int  # 958
NN_vpandnd: int  # 1391
NN_vpandnq: int  # 1392
NN_vpandq: int  # 1390
NN_vpavgb: int  # 959
NN_vpavgw: int  # 960
NN_vpblendd: int  # 961
NN_vpblendmb: int  # 1307
NN_vpblendmd: int  # 1309
NN_vpblendmq: int  # 1310
NN_vpblendmw: int  # 1308
NN_vpblendvb: int  # 962
NN_vpblendw: int  # 963
NN_vpbroadcastb: int  # 964
NN_vpbroadcastd: int  # 965
NN_vpbroadcastmb2q: int  # 1393
NN_vpbroadcastmw2d: int  # 1394
NN_vpbroadcastq: int  # 966
NN_vpbroadcastw: int  # 967
NN_vpcext: int  # 1138
NN_vpclmulqdq: int  # 968
NN_vpcmov: int  # 1634
NN_vpcmpb: int  # 1395
NN_vpcmpd: int  # 1397
NN_vpcmpeqb: int  # 969
NN_vpcmpeqd: int  # 970
NN_vpcmpeqq: int  # 971
NN_vpcmpequd: int  # 1553
NN_vpcmpequq: int  # 1564
NN_vpcmpeqw: int  # 972
NN_vpcmpestri: int  # 973
NN_vpcmpestrm: int  # 974
NN_vpcmpgtb: int  # 975
NN_vpcmpgtd: int  # 976
NN_vpcmpgtq: int  # 977
NN_vpcmpgtw: int  # 978
NN_vpcmpistri: int  # 979
NN_vpcmpistrm: int  # 980
NN_vpcmpled: int  # 1549
NN_vpcmpleq: int  # 1560
NN_vpcmpleud: int  # 1555
NN_vpcmpleuq: int  # 1566
NN_vpcmpltd: int  # 1548
NN_vpcmpltq: int  # 1559
NN_vpcmpltud: int  # 1554
NN_vpcmpltuq: int  # 1565
NN_vpcmpneqd: int  # 1550
NN_vpcmpneqq: int  # 1561
NN_vpcmpnequd: int  # 1556
NN_vpcmpnequq: int  # 1567
NN_vpcmpnled: int  # 1552
NN_vpcmpnleq: int  # 1563
NN_vpcmpnleud: int  # 1558
NN_vpcmpnleuq: int  # 1569
NN_vpcmpnltd: int  # 1551
NN_vpcmpnltq: int  # 1562
NN_vpcmpnltud: int  # 1557
NN_vpcmpnltuq: int  # 1568
NN_vpcmpq: int  # 1399
NN_vpcmpub: int  # 1396
NN_vpcmpud: int  # 1398
NN_vpcmpuq: int  # 1400
NN_vpcmpuw: int  # 1402
NN_vpcmpw: int  # 1401
NN_vpcomb: int  # 1635
NN_vpcomd: int  # 1636
NN_vpcomeqb: int  # 1689
NN_vpcomeqd: int  # 1705
NN_vpcomeqq: int  # 1713
NN_vpcomequb: int  # 1721
NN_vpcomequd: int  # 1737
NN_vpcomequq: int  # 1745
NN_vpcomequw: int  # 1729
NN_vpcomeqw: int  # 1697
NN_vpcomfalseb: int  # 1691
NN_vpcomfalsed: int  # 1707
NN_vpcomfalseq: int  # 1715
NN_vpcomfalseub: int  # 1723
NN_vpcomfalseud: int  # 1739
NN_vpcomfalseuq: int  # 1747
NN_vpcomfalseuw: int  # 1731
NN_vpcomfalsew: int  # 1699
NN_vpcomgeb: int  # 1688
NN_vpcomged: int  # 1704
NN_vpcomgeq: int  # 1712
NN_vpcomgeub: int  # 1720
NN_vpcomgeud: int  # 1736
NN_vpcomgeuq: int  # 1744
NN_vpcomgeuw: int  # 1728
NN_vpcomgew: int  # 1696
NN_vpcomgtb: int  # 1687
NN_vpcomgtd: int  # 1703
NN_vpcomgtq: int  # 1711
NN_vpcomgtub: int  # 1719
NN_vpcomgtud: int  # 1735
NN_vpcomgtuq: int  # 1743
NN_vpcomgtuw: int  # 1727
NN_vpcomgtw: int  # 1695
NN_vpcomleb: int  # 1686
NN_vpcomled: int  # 1702
NN_vpcomleq: int  # 1710
NN_vpcomleub: int  # 1718
NN_vpcomleud: int  # 1734
NN_vpcomleuq: int  # 1742
NN_vpcomleuw: int  # 1726
NN_vpcomlew: int  # 1694
NN_vpcomltb: int  # 1685
NN_vpcomltd: int  # 1701
NN_vpcomltq: int  # 1709
NN_vpcomltub: int  # 1717
NN_vpcomltud: int  # 1733
NN_vpcomltuq: int  # 1741
NN_vpcomltuw: int  # 1725
NN_vpcomltw: int  # 1693
NN_vpcomneqb: int  # 1690
NN_vpcomneqd: int  # 1706
NN_vpcomneqq: int  # 1714
NN_vpcomnequb: int  # 1722
NN_vpcomnequd: int  # 1738
NN_vpcomnequq: int  # 1746
NN_vpcomnequw: int  # 1730
NN_vpcomneqw: int  # 1698
NN_vpcompressb: int  # 1805
NN_vpcompressd: int  # 1403
NN_vpcompressq: int  # 1404
NN_vpcompressw: int  # 1806
NN_vpcomq: int  # 1637
NN_vpcomtrueb: int  # 1692
NN_vpcomtrued: int  # 1708
NN_vpcomtrueq: int  # 1716
NN_vpcomtrueub: int  # 1724
NN_vpcomtrueud: int  # 1740
NN_vpcomtrueuq: int  # 1748
NN_vpcomtrueuw: int  # 1732
NN_vpcomtruew: int  # 1700
NN_vpcomub: int  # 1638
NN_vpcomud: int  # 1639
NN_vpcomuq: int  # 1640
NN_vpcomuw: int  # 1641
NN_vpcomw: int  # 1642
NN_vpconflictd: int  # 1405
NN_vpconflictq: int  # 1406
NN_vpdpbusd: int  # 1801
NN_vpdpbusds: int  # 1802
NN_vpdpwssd: int  # 1803
NN_vpdpwssds: int  # 1804
NN_vperm2f128: int  # 981
NN_vperm2i128: int  # 982
NN_vpermb: int  # 1407
NN_vpermd: int  # 983
NN_vpermi2b: int  # 1409
NN_vpermi2d: int  # 1411
NN_vpermi2pd: int  # 1414
NN_vpermi2ps: int  # 1413
NN_vpermi2q: int  # 1412
NN_vpermi2w: int  # 1410
NN_vpermil2pd: int  # 1643
NN_vpermil2ps: int  # 1644
NN_vpermilpd: int  # 984
NN_vpermilps: int  # 985
NN_vpermpd: int  # 986
NN_vpermps: int  # 987
NN_vpermq: int  # 988
NN_vpermt2b: int  # 1415
NN_vpermt2d: int  # 1417
NN_vpermt2pd: int  # 1420
NN_vpermt2ps: int  # 1419
NN_vpermt2q: int  # 1418
NN_vpermt2w: int  # 1416
NN_vpermw: int  # 1408
NN_vpexpandb: int  # 1807
NN_vpexpandd: int  # 1421
NN_vpexpandq: int  # 1422
NN_vpexpandw: int  # 1808
NN_vpextrb: int  # 989
NN_vpextrd: int  # 990
NN_vpextrq: int  # 991
NN_vpextrw: int  # 992
NN_vpgatherdd: int  # 993
NN_vpgatherdq: int  # 994
NN_vpgatherqd: int  # 995
NN_vpgatherqq: int  # 996
NN_vphaddbd: int  # 1645
NN_vphaddbq: int  # 1646
NN_vphaddbw: int  # 1647
NN_vphaddd: int  # 997
NN_vphadddq: int  # 1648
NN_vphaddsw: int  # 998
NN_vphaddubd: int  # 1649
NN_vphaddubq: int  # 1650
NN_vphaddubw: int  # 1651
NN_vphaddudq: int  # 1652
NN_vphadduwd: int  # 1653
NN_vphadduwq: int  # 1654
NN_vphaddw: int  # 999
NN_vphaddwd: int  # 1655
NN_vphaddwq: int  # 1656
NN_vphminposuw: int  # 1000
NN_vphsubbw: int  # 1657
NN_vphsubd: int  # 1001
NN_vphsubdq: int  # 1658
NN_vphsubsw: int  # 1002
NN_vphsubw: int  # 1003
NN_vphsubwd: int  # 1659
NN_vpinsrb: int  # 1004
NN_vpinsrd: int  # 1005
NN_vpinsrq: int  # 1006
NN_vpinsrw: int  # 1007
NN_vplzcntd: int  # 1423
NN_vplzcntq: int  # 1424
NN_vpmacsdd: int  # 1660
NN_vpmacsdqh: int  # 1661
NN_vpmacsdql: int  # 1662
NN_vpmacssdd: int  # 1663
NN_vpmacssdqh: int  # 1664
NN_vpmacssdql: int  # 1665
NN_vpmacsswd: int  # 1666
NN_vpmacssww: int  # 1667
NN_vpmacswd: int  # 1668
NN_vpmacsww: int  # 1669
NN_vpmadcsswd: int  # 1670
NN_vpmadcswd: int  # 1671
NN_vpmadd52huq: int  # 1426
NN_vpmadd52luq: int  # 1425
NN_vpmaddubsw: int  # 1008
NN_vpmaddwd: int  # 1009
NN_vpmaskmovd: int  # 1010
NN_vpmaskmovq: int  # 1011
NN_vpmaxsb: int  # 1012
NN_vpmaxsd: int  # 1013
NN_vpmaxsq: int  # 1427
NN_vpmaxsw: int  # 1014
NN_vpmaxub: int  # 1015
NN_vpmaxud: int  # 1016
NN_vpmaxuq: int  # 1428
NN_vpmaxuw: int  # 1017
NN_vpminsb: int  # 1018
NN_vpminsd: int  # 1019
NN_vpminsq: int  # 1429
NN_vpminsw: int  # 1020
NN_vpminub: int  # 1021
NN_vpminud: int  # 1022
NN_vpminuq: int  # 1430
NN_vpminuw: int  # 1023
NN_vpmovb2m: int  # 1435
NN_vpmovd2m: int  # 1437
NN_vpmovdb: int  # 1448
NN_vpmovdw: int  # 1451
NN_vpmovm2b: int  # 1431
NN_vpmovm2d: int  # 1433
NN_vpmovm2q: int  # 1434
NN_vpmovm2w: int  # 1432
NN_vpmovmskb: int  # 1024
NN_vpmovq2m: int  # 1438
NN_vpmovqb: int  # 1439
NN_vpmovqd: int  # 1445
NN_vpmovqw: int  # 1442
NN_vpmovsdb: int  # 1449
NN_vpmovsdw: int  # 1452
NN_vpmovsqb: int  # 1440
NN_vpmovsqd: int  # 1446
NN_vpmovsqw: int  # 1443
NN_vpmovswb: int  # 1455
NN_vpmovsxbd: int  # 1025
NN_vpmovsxbq: int  # 1026
NN_vpmovsxbw: int  # 1027
NN_vpmovsxdq: int  # 1028
NN_vpmovsxwd: int  # 1029
NN_vpmovsxwq: int  # 1030
NN_vpmovusdb: int  # 1450
NN_vpmovusdw: int  # 1453
NN_vpmovusqb: int  # 1441
NN_vpmovusqd: int  # 1447
NN_vpmovusqw: int  # 1444
NN_vpmovuswb: int  # 1456
NN_vpmovw2m: int  # 1436
NN_vpmovwb: int  # 1454
NN_vpmovzxbd: int  # 1031
NN_vpmovzxbq: int  # 1032
NN_vpmovzxbw: int  # 1033
NN_vpmovzxdq: int  # 1034
NN_vpmovzxwd: int  # 1035
NN_vpmovzxwq: int  # 1036
NN_vpmuldq: int  # 1037
NN_vpmulhrsw: int  # 1038
NN_vpmulhuw: int  # 1039
NN_vpmulhw: int  # 1040
NN_vpmulld: int  # 1041
NN_vpmullq: int  # 1457
NN_vpmullw: int  # 1042
NN_vpmultishiftqb: int  # 1458
NN_vpmuludq: int  # 1043
NN_vpopcntb: int  # 1821
NN_vpopcntd: int  # 1759
NN_vpopcntq: int  # 1760
NN_vpopcntw: int  # 1822
NN_vpor: int  # 1044
NN_vpord: int  # 1459
NN_vporq: int  # 1460
NN_vpperm: int  # 1672
NN_vprold: int  # 1461
NN_vprolq: int  # 1463
NN_vprolvd: int  # 1462
NN_vprolvq: int  # 1464
NN_vprord: int  # 1465
NN_vprorq: int  # 1467
NN_vprorvd: int  # 1466
NN_vprorvq: int  # 1468
NN_vprotb: int  # 1673
NN_vprotd: int  # 1674
NN_vprotq: int  # 1675
NN_vprotw: int  # 1676
NN_vpsadbw: int  # 1045
NN_vpscatterdd: int  # 1469
NN_vpscatterdq: int  # 1470
NN_vpscatterqd: int  # 1471
NN_vpscatterqq: int  # 1472
NN_vpshab: int  # 1677
NN_vpshad: int  # 1678
NN_vpshaq: int  # 1679
NN_vpshaw: int  # 1680
NN_vpshlb: int  # 1681
NN_vpshld: int  # 1682
NN_vpshldd: int  # 1810
NN_vpshldq: int  # 1811
NN_vpshldvd: int  # 1813
NN_vpshldvq: int  # 1814
NN_vpshldvw: int  # 1812
NN_vpshldw: int  # 1809
NN_vpshlq: int  # 1683
NN_vpshlw: int  # 1684
NN_vpshrdd: int  # 1816
NN_vpshrdq: int  # 1817
NN_vpshrdvd: int  # 1819
NN_vpshrdvq: int  # 1820
NN_vpshrdvw: int  # 1818
NN_vpshrdw: int  # 1815
NN_vpshufb: int  # 1046
NN_vpshufbitqmb: int  # 1823
NN_vpshufd: int  # 1047
NN_vpshufhw: int  # 1048
NN_vpshuflw: int  # 1049
NN_vpsignb: int  # 1050
NN_vpsignd: int  # 1051
NN_vpsignw: int  # 1052
NN_vpslld: int  # 1053
NN_vpslldq: int  # 1054
NN_vpsllq: int  # 1055
NN_vpsllvd: int  # 1056
NN_vpsllvq: int  # 1057
NN_vpsllvw: int  # 1474
NN_vpsllw: int  # 1058
NN_vpsrad: int  # 1059
NN_vpsraq: int  # 1473
NN_vpsravd: int  # 1060
NN_vpsravq: int  # 1491
NN_vpsravw: int  # 1490
NN_vpsraw: int  # 1061
NN_vpsrld: int  # 1062
NN_vpsrldq: int  # 1063
NN_vpsrlq: int  # 1064
NN_vpsrlvd: int  # 1065
NN_vpsrlvq: int  # 1066
NN_vpsrlvw: int  # 1475
NN_vpsrlw: int  # 1067
NN_vpsubb: int  # 1068
NN_vpsubd: int  # 1069
NN_vpsubq: int  # 1070
NN_vpsubsb: int  # 1071
NN_vpsubsw: int  # 1072
NN_vpsubusb: int  # 1073
NN_vpsubusw: int  # 1074
NN_vpsubw: int  # 1075
NN_vpternlogd: int  # 1484
NN_vpternlogq: int  # 1485
NN_vptest: int  # 1076
NN_vptestmb: int  # 1486
NN_vptestmd: int  # 1488
NN_vptestmq: int  # 1489
NN_vptestmw: int  # 1487
NN_vptestnmb: int  # 1476
NN_vptestnmd: int  # 1478
NN_vptestnmq: int  # 1479
NN_vptestnmw: int  # 1477
NN_vpunpckhbw: int  # 1077
NN_vpunpckhdq: int  # 1078
NN_vpunpckhqdq: int  # 1079
NN_vpunpckhwd: int  # 1080
NN_vpunpcklbw: int  # 1081
NN_vpunpckldq: int  # 1082
NN_vpunpcklqdq: int  # 1083
NN_vpunpcklwd: int  # 1084
NN_vpxor: int  # 1085
NN_vpxord: int  # 1492
NN_vpxorq: int  # 1493
NN_vrangepd: int  # 1494
NN_vrangeps: int  # 1495
NN_vrangesd: int  # 1496
NN_vrangess: int  # 1497
NN_vrcp14pd: int  # 1498
NN_vrcp14ps: int  # 1500
NN_vrcp14sd: int  # 1499
NN_vrcp14ss: int  # 1501
NN_vrcp28pd: int  # 1524
NN_vrcp28ps: int  # 1526
NN_vrcp28sd: int  # 1525
NN_vrcp28ss: int  # 1527
NN_vrcpph: int  # 1882
NN_vrcpps: int  # 1086
NN_vrcpsh: int  # 1927
NN_vrcpss: int  # 1087
NN_vreducepd: int  # 1502
NN_vreduceph: int  # 1883
NN_vreduceps: int  # 1504
NN_vreducesd: int  # 1503
NN_vreducesh: int  # 1928
NN_vreducess: int  # 1505
NN_vrndscalepd: int  # 1506
NN_vrndscaleph: int  # 1884
NN_vrndscaleps: int  # 1508
NN_vrndscalesd: int  # 1507
NN_vrndscalesh: int  # 1929
NN_vrndscaless: int  # 1509
NN_vroundpd: int  # 1088
NN_vroundps: int  # 1089
NN_vroundsd: int  # 1090
NN_vroundss: int  # 1091
NN_vrsqrt14pd: int  # 1510
NN_vrsqrt14ps: int  # 1512
NN_vrsqrt14sd: int  # 1511
NN_vrsqrt14ss: int  # 1513
NN_vrsqrt28pd: int  # 1528
NN_vrsqrt28ps: int  # 1530
NN_vrsqrt28sd: int  # 1529
NN_vrsqrt28ss: int  # 1531
NN_vrsqrtph: int  # 1885
NN_vrsqrtps: int  # 1092
NN_vrsqrtsh: int  # 1930
NN_vrsqrtss: int  # 1093
NN_vscalefpd: int  # 1514
NN_vscalefph: int  # 1886
NN_vscalefps: int  # 1516
NN_vscalefsd: int  # 1515
NN_vscalefsh: int  # 1931
NN_vscalefss: int  # 1517
NN_vscatterdpd: int  # 1519
NN_vscatterdps: int  # 1518
NN_vscatterpf0dpd: int  # 1542
NN_vscatterpf0dps: int  # 1540
NN_vscatterpf0qpd: int  # 1543
NN_vscatterpf0qps: int  # 1541
NN_vscatterpf1dpd: int  # 1546
NN_vscatterpf1dps: int  # 1544
NN_vscatterpf1qpd: int  # 1547
NN_vscatterpf1qps: int  # 1545
NN_vscatterqpd: int  # 1521
NN_vscatterqps: int  # 1520
NN_vshuff32x4: int  # 1480
NN_vshuff64x2: int  # 1481
NN_vshufi32x4: int  # 1482
NN_vshufi64x2: int  # 1483
NN_vshufpd: int  # 1094
NN_vshufps: int  # 1095
NN_vsqrtpd: int  # 1096
NN_vsqrtph: int  # 1887
NN_vsqrtps: int  # 1097
NN_vsqrtsd: int  # 1098
NN_vsqrtsh: int  # 1932
NN_vsqrtss: int  # 1099
NN_vstmxcsr: int  # 1100
NN_vsubpd: int  # 1101
NN_vsubph: int  # 1888
NN_vsubps: int  # 1102
NN_vsubsd: int  # 1103
NN_vsubsh: int  # 1933
NN_vsubss: int  # 1104
NN_vtestpd: int  # 1105
NN_vtestps: int  # 1106
NN_vucomisd: int  # 1107
NN_vucomish: int  # 1934
NN_vucomiss: int  # 1108
NN_vunpckhpd: int  # 1109
NN_vunpckhps: int  # 1110
NN_vunpcklpd: int  # 1111
NN_vunpcklps: int  # 1112
NN_vxorpd: int  # 1113
NN_vxorps: int  # 1114
NN_vzeroall: int  # 1115
NN_vzeroupper: int  # 1116
NN_wait: int  # 213
NN_wbinvd: int  # 221
NN_wrfsbase: int  # 766
NN_wrgsbase: int  # 767
NN_wrmsr: int  # 224
NN_wrpkru: int  # 1174
NN_wrssd: int  # 1769
NN_wrssq: int  # 1770
NN_wrussd: int  # 1771
NN_wrussq: int  # 1772
NN_xabort: int  # 1117
NN_xadd: int  # 219
NN_xbegin: int  # 1118
NN_xchg: int  # 214
NN_xend: int  # 1119
NN_xgetbv: int  # 712
NN_xlat: int  # 215
NN_xor: int  # 216
NN_xorpd: int  # 587
NN_xorps: int  # 468
NN_xresldtrk: int  # 1791
NN_xrstor: int  # 713
NN_xrstors: int  # 1166
NN_xsave: int  # 714
NN_xsavec: int  # 1167
NN_xsaveopt: int  # 761
NN_xsaves: int  # 1168
NN_xsetbv: int  # 715
NN_xsusldtrk: int  # 1792
NN_xtest: int  # 1120
OAK_Dsp_add: int  # 5
OAK_Dsp_addh: int  # 11
OAK_Dsp_addl: int  # 12
OAK_Dsp_addv: int  # 39
OAK_Dsp_alb_tst0: int  # 40
OAK_Dsp_alb_tst1: int  # 41
OAK_Dsp_alm_msu: int  # 10
OAK_Dsp_alm_tst0: int  # 6
OAK_Dsp_alm_tst1: int  # 7
OAK_Dsp_and: int  # 3
OAK_Dsp_banke: int  # 71
OAK_Dsp_bkrep: int  # 73
OAK_Dsp_br: int  # 75
OAK_Dsp_br_u: int  # 77
OAK_Dsp_break: int  # 74
OAK_Dsp_brr: int  # 76
OAK_Dsp_brr_u: int  # 78
OAK_Dsp_call: int  # 79
OAK_Dsp_calla: int  # 81
OAK_Dsp_callr: int  # 80
OAK_Dsp_chng: int  # 38
OAK_Dsp_clr: int  # 24
OAK_Dsp_clrr: int  # 30
OAK_Dsp_cmp: int  # 8
OAK_Dsp_cmpu: int  # 17
OAK_Dsp_cmpv: int  # 42
OAK_Dsp_cntx: int  # 89
OAK_Dsp_copy: int  # 33
OAK_Dsp_dec: int  # 32
OAK_Dsp_dint: int  # 92
OAK_Dsp_divs: int  # 35
OAK_Dsp_eint: int  # 93
OAK_Dsp_exp: int  # 61
OAK_Dsp_inc: int  # 31
OAK_Dsp_last: int  # 98
OAK_Dsp_lim: int  # 47
OAK_Dsp_load: int  # 96
OAK_Dsp_lpg: int  # 95
OAK_Dsp_maa: int  # 52
OAK_Dsp_maasu: int  # 55
OAK_Dsp_mac: int  # 50
OAK_Dsp_macsu: int  # 54
OAK_Dsp_macus: int  # 51
OAK_Dsp_macuu: int  # 53
OAK_Dsp_max: int  # 45
OAK_Dsp_maxd: int  # 44
OAK_Dsp_min: int  # 46
OAK_Dsp_mod_reserved: int  # 25
OAK_Dsp_modr: int  # 91
OAK_Dsp_mov: int  # 62
OAK_Dsp_mov_eu: int  # 97
OAK_Dsp_movd: int  # 67
OAK_Dsp_movp: int  # 63
OAK_Dsp_movr: int  # 66
OAK_Dsp_movs: int  # 64
OAK_Dsp_movsi: int  # 65
OAK_Dsp_mpy: int  # 48
OAK_Dsp_mpyi: int  # 56
OAK_Dsp_mpysu: int  # 49
OAK_Dsp_msu: int  # 57
OAK_Dsp_neg: int  # 27
OAK_Dsp_nop: int  # 90
OAK_Dsp_norm: int  # 34
OAK_Dsp_not: int  # 26
OAK_Dsp_null: int  # 0
OAK_Dsp_or: int  # 2
OAK_Dsp_pacr: int  # 29
OAK_Dsp_pop: int  # 69
OAK_Dsp_proc: int  # 1
OAK_Dsp_push: int  # 68
OAK_Dsp_rep: int  # 72
OAK_Dsp_ret: int  # 82
OAK_Dsp_ret_u: int  # 83
OAK_Dsp_retd: int  # 84
OAK_Dsp_reti: int  # 85
OAK_Dsp_reti_u: int  # 86
OAK_Dsp_retid: int  # 87
OAK_Dsp_rets: int  # 88
OAK_Dsp_rnd: int  # 28
OAK_Dsp_rol: int  # 23
OAK_Dsp_ror: int  # 22
OAK_Dsp_rst: int  # 37
OAK_Dsp_set: int  # 36
OAK_Dsp_shfc: int  # 59
OAK_Dsp_shfi: int  # 60
OAK_Dsp_shl: int  # 20
OAK_Dsp_shl4: int  # 21
OAK_Dsp_shr: int  # 18
OAK_Dsp_shr4: int  # 19
OAK_Dsp_sqr: int  # 15
OAK_Dsp_sqra: int  # 16
OAK_Dsp_sub: int  # 9
OAK_Dsp_subh: int  # 13
OAK_Dsp_subl: int  # 14
OAK_Dsp_subv: int  # 43
OAK_Dsp_swap: int  # 70
OAK_Dsp_trap: int  # 94
OAK_Dsp_tstb: int  # 58
OAK_Dsp_xor: int  # 4
PIC16_ADD: int  # 9
PIC16_ADDC: int  # 10
PIC16_AND: int  # 26
PIC16_ASR: int  # 33
PIC16_BCLR: int  # 40
PIC16_BRA: int  # 62
PIC16_BREAK: int  # 91
PIC16_BSET: int  # 41
PIC16_BSW: int  # 42
PIC16_BTG: int  # 43
PIC16_BTSC: int  # 49
PIC16_BTSS: int  # 50
PIC16_BTST: int  # 44
PIC16_BTSTS: int  # 45
PIC16_CALL: int  # 63
PIC16_CLR: int  # 27
PIC16_CLR1: int  # 84
PIC16_CLRWDT: int  # 75
PIC16_COM: int  # 28
PIC16_CP: int  # 51
PIC16_CP0: int  # 52
PIC16_CPB: int  # 53
PIC16_CPBEQ: int  # 58
PIC16_CPBGT: int  # 60
PIC16_CPBLT: int  # 61
PIC16_CPBNE: int  # 59
PIC16_CPSEQ: int  # 54
PIC16_CPSGT: int  # 55
PIC16_CPSLT: int  # 56
PIC16_CPSNE: int  # 57
PIC16_DAWB: int  # 11
PIC16_DEC: int  # 12
PIC16_DEC2: int  # 13
PIC16_DISI: int  # 76
PIC16_DIV: int  # 14
PIC16_DIVF: int  # 25
PIC16_DO: int  # 70
PIC16_ED: int  # 85
PIC16_EDAC: int  # 86
PIC16_EXCH: int  # 1
PIC16_FBCL: int  # 46
PIC16_FEX: int  # 94
PIC16_FF1L: int  # 47
PIC16_FF1R: int  # 48
PIC16_GOTO: int  # 64
PIC16_INC: int  # 15
PIC16_INC2: int  # 16
PIC16_IOR: int  # 29
PIC16_LAC: int  # 81
PIC16_LNK: int  # 71
PIC16_LSR: int  # 34
PIC16_MAC: int  # 87
PIC16_MOV: int  # 2
PIC16_MOVPAG: int  # 8
PIC16_MOVSAC: int  # 88
PIC16_MPY: int  # 89
PIC16_MSC: int  # 90
PIC16_MUL: int  # 17
PIC16_MULW: int  # 24
PIC16_NEG: int  # 30
PIC16_NOP: int  # 77
PIC16_NOPR: int  # 78
PIC16_POP: int  # 72
PIC16_PUSH: int  # 73
PIC16_PWRSAV: int  # 79
PIC16_RCALL: int  # 65
PIC16_REPEAT: int  # 66
PIC16_RESET: int  # 80
PIC16_RETFIE: int  # 67
PIC16_RETLW: int  # 68
PIC16_RETURN: int  # 69
PIC16_RLC: int  # 35
PIC16_RLNC: int  # 36
PIC16_RRC: int  # 37
PIC16_RRNC: int  # 38
PIC16_SAC: int  # 82
PIC16_SE: int  # 18
PIC16_SETM: int  # 31
PIC16_SFTAC: int  # 83
PIC16_SL: int  # 39
PIC16_SSTEP: int  # 93
PIC16_SUB: int  # 19
PIC16_SUBB: int  # 20
PIC16_SUBBR: int  # 21
PIC16_SUBR: int  # 22
PIC16_SWAP: int  # 3
PIC16_TBLRDH: int  # 4
PIC16_TBLRDL: int  # 5
PIC16_TBLWTH: int  # 6
PIC16_TBLWTL: int  # 7
PIC16_ULNK: int  # 74
PIC16_URUN: int  # 92
PIC16_XOR: int  # 32
PIC16_ZE: int  # 23
PIC16_last: int  # 95
PIC16_null: int  # 0
PIC_addcf: int  # 60
PIC_adddcf: int  # 61
PIC_addfsr: int  # 130
PIC_addlw: int  # 23
PIC_addwf: int  # 1
PIC_addwf3: int  # 63
PIC_addwfc: int  # 127
PIC_addwfc3: int  # 64
PIC_andlw: int  # 24
PIC_andwf: int  # 2
PIC_andwf3: int  # 65
PIC_asrf: int  # 131
PIC_b: int  # 41
PIC_bc: int  # 54
PIC_bc1: int  # 99
PIC_bcf: int  # 19
PIC_bcf3: int  # 94
PIC_bdc: int  # 55
PIC_bn1: int  # 100
PIC_bnc: int  # 56
PIC_bnc1: int  # 101
PIC_bndc: int  # 57
PIC_bnn1: int  # 102
PIC_bnov1: int  # 103
PIC_bnz: int  # 58
PIC_bnz1: int  # 104
PIC_bov1: int  # 105
PIC_bra: int  # 135
PIC_bra1: int  # 106
PIC_brw: int  # 136
PIC_bsf: int  # 20
PIC_bsf3: int  # 95
PIC_btfsc: int  # 21
PIC_btfsc3: int  # 96
PIC_btfss: int  # 22
PIC_btfss3: int  # 97
PIC_btg3: int  # 98
PIC_bz: int  # 59
PIC_bz1: int  # 107
PIC_call: int  # 25
PIC_call2: int  # 108
PIC_callw: int  # 137
PIC_clrc: int  # 42
PIC_clrdc: int  # 43
PIC_clrf: int  # 3
PIC_clrf2: int  # 66
PIC_clrw: int  # 4
PIC_clrwdt: int  # 26
PIC_clrz: int  # 44
PIC_comf: int  # 5
PIC_comf3: int  # 67
PIC_cpfseq2: int  # 68
PIC_cpfsgt2: int  # 69
PIC_cpfslt2: int  # 70
PIC_daw0: int  # 109
PIC_dcfsnz3: int  # 73
PIC_decf: int  # 6
PIC_decf3: int  # 71
PIC_decfsz: int  # 7
PIC_decfsz3: int  # 72
PIC_goto: int  # 27
PIC_incf: int  # 8
PIC_incf3: int  # 74
PIC_incfsz: int  # 9
PIC_incfsz3: int  # 75
PIC_infsnz3: int  # 76
PIC_iorlw: int  # 28
PIC_iorwf: int  # 10
PIC_iorwf3: int  # 77
PIC_last: int  # 141
PIC_lfsr2: int  # 116
PIC_lslf: int  # 132
PIC_lsrf: int  # 133
PIC_movf: int  # 11
PIC_movf3: int  # 78
PIC_movff2: int  # 79
PIC_movfw: int  # 38
PIC_moviw: int  # 139
PIC_movlb: int  # 129
PIC_movlb1: int  # 117
PIC_movlp: int  # 128
PIC_movlw: int  # 29
PIC_movwf: int  # 12
PIC_movwf2: int  # 80
PIC_movwi: int  # 140
PIC_mullw1: int  # 118
PIC_mulwf2: int  # 81
PIC_negf: int  # 40
PIC_negf2: int  # 82
PIC_nop: int  # 13
PIC_null: int  # 0
PIC_option: int  # 36
PIC_pop0: int  # 110
PIC_push0: int  # 111
PIC_rcall1: int  # 112
PIC_reset: int  # 138
PIC_reset0: int  # 113
PIC_retfie: int  # 30
PIC_retfie1: int  # 114
PIC_retlw: int  # 31
PIC_return: int  # 32
PIC_return1: int  # 115
PIC_rlcf3: int  # 83
PIC_rlf: int  # 14
PIC_rlncf3: int  # 84
PIC_rrcf3: int  # 85
PIC_rrf: int  # 15
PIC_rrncf3: int  # 86
PIC_setc: int  # 45
PIC_setdc: int  # 46
PIC_setf2: int  # 87
PIC_setz: int  # 47
PIC_skpc: int  # 48
PIC_skpdc: int  # 49
PIC_skpnc: int  # 50
PIC_skpndc: int  # 51
PIC_skpnz: int  # 52
PIC_skpz: int  # 53
PIC_sleep: int  # 33
PIC_subcf: int  # 62
PIC_subfwb3: int  # 88
PIC_sublw: int  # 34
PIC_subwf: int  # 16
PIC_subwf3: int  # 89
PIC_subwfb: int  # 134
PIC_subwfb3: int  # 90
PIC_swapf: int  # 17
PIC_swapf3: int  # 91
PIC_tblrd0: int  # 119
PIC_tblrd0m: int  # 121
PIC_tblrd0p: int  # 120
PIC_tblrdp0: int  # 122
PIC_tblwt0: int  # 123
PIC_tblwt0m: int  # 125
PIC_tblwt0p: int  # 124
PIC_tblwtp0: int  # 126
PIC_tris: int  # 37
PIC_tstf: int  # 39
PIC_tstfsz2: int  # 92
PIC_xorlw: int  # 35
PIC_xorwf: int  # 18
PIC_xorwf3: int  # 93
PM96_IFcc: int  # 7
PM96_Long: int  # 5
PM96_NoMove: int  # 0
PM96_R2R: int  # 1
PM96_Update: int  # 2
PM96_XY: int  # 6
PM96_XYMem: int  # 3
PM96_XYmemR: int  # 4
PPC_abs: int  # 362
PPC_abssb: int  # 2238
PPC_abssh: int  # 2244
PPC_abssw: int  # 2250
PPC_absub: int  # 2239
PPC_absuh: int  # 2245
PPC_absuw: int  # 2251
PPC_add: int  # 1
PPC_add16i: int  # 1155
PPC_add2i: int  # 1156
PPC_add2is: int  # 1157
PPC_addb: int  # 2479
PPC_addbss: int  # 2217
PPC_addbu: int  # 2480
PPC_addbus: int  # 2220
PPC_addc: int  # 2
PPC_adde: int  # 3
PPC_addex: int  # 2440
PPC_addg6s: int  # 681
PPC_addh: int  # 2481
PPC_addhss: int  # 2218
PPC_addhu: int  # 2482
PPC_addhus: int  # 2221
PPC_addi: int  # 4
PPC_addic: int  # 5
PPC_addis: int  # 6
PPC_addme: int  # 7
PPC_addpcis: int  # 2256
PPC_addwss: int  # 2219
PPC_addwus: int  # 2222
PPC_addze: int  # 8
PPC_and: int  # 9
PPC_and2i: int  # 1158
PPC_and2is: int  # 1159
PPC_andc: int  # 10
PPC_andi: int  # 11
PPC_andis: int  # 12
PPC_b: int  # 13
PPC_balways: int  # 320
PPC_bc: int  # 14
PPC_bcctr: int  # 15
PPC_bcdadd: int  # 2152
PPC_bcdcfn: int  # 2290
PPC_bcdcfsq: int  # 2295
PPC_bcdcfz: int  # 2291
PPC_bcdcpsgn: int  # 2297
PPC_bcdctn: int  # 2292
PPC_bcdctsq: int  # 2294
PPC_bcdctz: int  # 2293
PPC_bcds: int  # 2298
PPC_bcdsetsgn: int  # 2296
PPC_bcdsr: int  # 2300
PPC_bcdsub: int  # 2153
PPC_bcdtrunc: int  # 2301
PPC_bcdus: int  # 2299
PPC_bcdutrunc: int  # 2302
PPC_bclr: int  # 16
PPC_bclri: int  # 1171
PPC_bctar: int  # 2082
PPC_bdnz: int  # 323
PPC_bdnzf: int  # 325
PPC_bdnzt: int  # 324
PPC_bdz: int  # 326
PPC_bdzf: int  # 328
PPC_bdzt: int  # 327
PPC_beq: int  # 331
PPC_bf: int  # 322
PPC_bge: int  # 332
PPC_bgeni: int  # 1172
PPC_bgt: int  # 333
PPC_ble: int  # 330
PPC_blt: int  # 329
PPC_bmaski: int  # 1173
PPC_bne: int  # 334
PPC_bns: int  # 336
PPC_bpermd: int  # 665
PPC_brd: int  # 3248
PPC_brh: int  # 3249
PPC_brinc: int  # 417
PPC_brw: int  # 3250
PPC_bseti: int  # 1174
PPC_bso: int  # 335
PPC_bt: int  # 321
PPC_btsti: int  # 1175
PPC_byterevh: int  # 2488
PPC_byterevw: int  # 2487
PPC_cbcdtd: int  # 682
PPC_cdtbcd: int  # 683
PPC_cfuged: int  # 3251
PPC_circinc: int  # 1565
PPC_clcs: int  # 363
PPC_clf: int  # 364
PPC_cli: int  # 365
PPC_clrbhrb: int  # 2083
PPC_clrldi: int  # 1193
PPC_clrlsldi: int  # 1195
PPC_clrlslwi: int  # 348
PPC_clrlwi: int  # 346
PPC_clrrdi: int  # 1194
PPC_clrrwi: int  # 347
PPC_cmp: int  # 17
PPC_cmp16i: int  # 1160
PPC_cmpb: int  # 671
PPC_cmpd: int  # 234
PPC_cmpdi: int  # 233
PPC_cmpeqb: int  # 2259
PPC_cmph: int  # 1161
PPC_cmph16i: int  # 1162
PPC_cmphl: int  # 1163
PPC_cmphl16i: int  # 1164
PPC_cmpi: int  # 18
PPC_cmpl: int  # 19
PPC_cmpl16i: int  # 1165
PPC_cmpld: int  # 236
PPC_cmpldi: int  # 235
PPC_cmpli: int  # 20
PPC_cmplw: int  # 232
PPC_cmplwi: int  # 231
PPC_cmprb: int  # 2260
PPC_cmpw: int  # 230
PPC_cmpwi: int  # 229
PPC_cntlzd: int  # 21
PPC_cntlzdm: int  # 3252
PPC_cntlzw: int  # 22
PPC_cnttzd: int  # 2262
PPC_cnttzdm: int  # 3253
PPC_cnttzw: int  # 2261
PPC_copy: int  # 2280
PPC_cpabort: int  # 2286
PPC_crand: int  # 23
PPC_crandc: int  # 24
PPC_crclr: int  # 290
PPC_creqv: int  # 25
PPC_crmove: int  # 289
PPC_crnand: int  # 26
PPC_crnor: int  # 27
PPC_crnot: int  # 288
PPC_cror: int  # 28
PPC_crorc: int  # 29
PPC_crset: int  # 287
PPC_crxor: int  # 30
PPC_dadd: int  # 684
PPC_daddq: int  # 685
PPC_darn: int  # 2263
PPC_dcba: int  # 31
PPC_dcbf: int  # 32
PPC_dcbfep: int  # 759
PPC_dcbfl: int  # 1198
PPC_dcbflp: int  # 1199
PPC_dcbi: int  # 33
PPC_dcblc: int  # 408
PPC_dcblq: int  # 2198
PPC_dcbst: int  # 34
PPC_dcbstep: int  # 760
PPC_dcbt: int  # 35
PPC_dcbtep: int  # 761
PPC_dcbtls: int  # 409
PPC_dcbtst: int  # 36
PPC_dcbtstep: int  # 762
PPC_dcbtstls: int  # 410
PPC_dcbtstt: int  # 1201
PPC_dcbtt: int  # 1200
PPC_dcbz: int  # 37
PPC_dcbz128: int  # 1215
PPC_dcbz_l: int  # 1262
PPC_dcbzep: int  # 763
PPC_dccci: int  # 349
PPC_dcffix: int  # 686
PPC_dcffixq: int  # 687
PPC_dcffixqq: int  # 3254
PPC_dci: int  # 748
PPC_dclst: int  # 366
PPC_dcmpo: int  # 688
PPC_dcmpoq: int  # 689
PPC_dcmpu: int  # 690
PPC_dcmpuq: int  # 691
PPC_dcread: int  # 350
PPC_dctdp: int  # 692
PPC_dctfix: int  # 693
PPC_dctfixq: int  # 694
PPC_dctfixqq: int  # 3255
PPC_dctqpq: int  # 695
PPC_ddedpd: int  # 696
PPC_ddedpdq: int  # 697
PPC_ddiv: int  # 698
PPC_ddivq: int  # 699
PPC_denbcd: int  # 700
PPC_denbcdq: int  # 701
PPC_diex: int  # 702
PPC_diexq: int  # 703
PPC_div: int  # 367
PPC_divd: int  # 38
PPC_divde: int  # 666
PPC_divdeu: int  # 667
PPC_divdu: int  # 39
PPC_divs: int  # 368
PPC_divw: int  # 40
PPC_divwe: int  # 672
PPC_divweu: int  # 673
PPC_divwu: int  # 41
PPC_dlmzb: int  # 831
PPC_dmul: int  # 704
PPC_dmulq: int  # 705
PPC_dnh: int  # 754
PPC_dni: int  # 2252
PPC_doz: int  # 369
PPC_doze: int  # 834
PPC_dozi: int  # 370
PPC_dqua: int  # 706
PPC_dquai: int  # 707
PPC_dquaiq: int  # 708
PPC_dquaq: int  # 709
PPC_drdpq: int  # 710
PPC_drintn: int  # 711
PPC_drintnq: int  # 712
PPC_drintx: int  # 713
PPC_drintxq: int  # 714
PPC_drrnd: int  # 715
PPC_drrndq: int  # 716
PPC_drsp: int  # 717
PPC_dscli: int  # 718
PPC_dscliq: int  # 719
PPC_dscri: int  # 720
PPC_dscriq: int  # 721
PPC_dsn: int  # 734
PPC_dsncb: int  # 2460
PPC_dss: int  # 1141
PPC_dssall: int  # 1142
PPC_dst: int  # 1143
PPC_dstst: int  # 1145
PPC_dststt: int  # 1146
PPC_dstt: int  # 1144
PPC_dsub: int  # 722
PPC_dsubq: int  # 723
PPC_dtstdc: int  # 724
PPC_dtstdcq: int  # 725
PPC_dtstdg: int  # 726
PPC_dtstdgq: int  # 727
PPC_dtstex: int  # 728
PPC_dtstexq: int  # 729
PPC_dtstsf: int  # 730
PPC_dtstsfi: int  # 2288
PPC_dtstsfiq: int  # 2289
PPC_dtstsfq: int  # 731
PPC_dxex: int  # 732
PPC_dxexq: int  # 733
PPC_eciwx: int  # 42
PPC_ecowx: int  # 43
PPC_efdabs: int  # 590
PPC_efdadd: int  # 591
PPC_efdcfh: int  # 2500
PPC_efdcfs: int  # 592
PPC_efdcfsf: int  # 593
PPC_efdcfsi: int  # 594
PPC_efdcfsid: int  # 595
PPC_efdcfuf: int  # 596
PPC_efdcfui: int  # 597
PPC_efdcfuid: int  # 598
PPC_efdcmpeq: int  # 599
PPC_efdcmpgt: int  # 600
PPC_efdcmplt: int  # 601
PPC_efdcth: int  # 2501
PPC_efdctsf: int  # 602
PPC_efdctsi: int  # 603
PPC_efdctsidz: int  # 604
PPC_efdctsiz: int  # 605
PPC_efdctuf: int  # 606
PPC_efdctui: int  # 607
PPC_efdctuidz: int  # 608
PPC_efdctuiz: int  # 609
PPC_efddiv: int  # 610
PPC_efdmax: int  # 2497
PPC_efdmin: int  # 2498
PPC_efdmul: int  # 611
PPC_efdnabs: int  # 612
PPC_efdneg: int  # 613
PPC_efdsqrt: int  # 2499
PPC_efdsub: int  # 614
PPC_efdtsteq: int  # 615
PPC_efdtstgt: int  # 616
PPC_efdtstlt: int  # 617
PPC_efsabs: int  # 619
PPC_efsadd: int  # 620
PPC_efscfd: int  # 618
PPC_efscfh: int  # 1296
PPC_efscfsf: int  # 621
PPC_efscfsi: int  # 622
PPC_efscfuf: int  # 623
PPC_efscfui: int  # 624
PPC_efscmpeq: int  # 625
PPC_efscmpgt: int  # 626
PPC_efscmplt: int  # 627
PPC_efscth: int  # 1297
PPC_efsctsf: int  # 628
PPC_efsctsi: int  # 629
PPC_efsctsiz: int  # 630
PPC_efsctuf: int  # 631
PPC_efsctui: int  # 632
PPC_efsctuiz: int  # 633
PPC_efsdiv: int  # 634
PPC_efsmadd: int  # 1291
PPC_efsmax: int  # 1289
PPC_efsmin: int  # 1290
PPC_efsmsub: int  # 1292
PPC_efsmul: int  # 635
PPC_efsnabs: int  # 636
PPC_efsneg: int  # 637
PPC_efsnmadd: int  # 1294
PPC_efsnmsub: int  # 1295
PPC_efssqrt: int  # 1293
PPC_efssub: int  # 638
PPC_efststeq: int  # 639
PPC_efststgt: int  # 640
PPC_efststlt: int  # 641
PPC_ehpriv: int  # 755
PPC_eieio: int  # 44
PPC_eqv: int  # 45
PPC_evabs: int  # 418
PPC_evabsb: int  # 1522
PPC_evabsbs: int  # 1526
PPC_evabsd: int  # 1524
PPC_evabsdifsb: int  # 2006
PPC_evabsdifsh: int  # 2008
PPC_evabsdifsw: int  # 2004
PPC_evabsdifub: int  # 2005
PPC_evabsdifuh: int  # 2007
PPC_evabsdifuw: int  # 2003
PPC_evabsds: int  # 1528
PPC_evabsh: int  # 1523
PPC_evabshs: int  # 1527
PPC_evabss: int  # 1525
PPC_evadd2subf2h: int  # 1849
PPC_evadd2subf2hss: int  # 1850
PPC_evaddb: int  # 1829
PPC_evaddbss: int  # 1830
PPC_evaddbus: int  # 1842
PPC_evaddd: int  # 1825
PPC_evadddss: int  # 1826
PPC_evadddus: int  # 1841
PPC_evaddh: int  # 1817
PPC_evaddhhisw: int  # 1909
PPC_evaddhhiuw: int  # 1908
PPC_evaddhlosw: int  # 1913
PPC_evaddhlouw: int  # 1912
PPC_evaddhss: int  # 1818
PPC_evaddhus: int  # 1853
PPC_evaddhx: int  # 1821
PPC_evaddhxss: int  # 1822
PPC_evaddhxus: int  # 1854
PPC_evaddib: int  # 1519
PPC_evaddih: int  # 1518
PPC_evaddiw: int  # 419
PPC_evaddsmiaa: int  # 1815
PPC_evaddsmiaaw: int  # 420
PPC_evaddssiaa: int  # 1812
PPC_evaddssiaaw: int  # 421
PPC_evaddsubfh: int  # 1833
PPC_evaddsubfhss: int  # 1834
PPC_evaddsubfhx: int  # 1837
PPC_evaddsubfhxss: int  # 1838
PPC_evaddsubfw: int  # 1863
PPC_evaddsubfwss: int  # 1864
PPC_evaddsubfwx: int  # 1867
PPC_evaddsubfwxss: int  # 1868
PPC_evaddumiaaw: int  # 422
PPC_evaddusiaa: int  # 1811
PPC_evaddusiaaw: int  # 423
PPC_evaddw: int  # 424
PPC_evaddwegsf: int  # 1901
PPC_evaddwegsi: int  # 1900
PPC_evaddwogsf: int  # 1905
PPC_evaddwogsi: int  # 1904
PPC_evaddwss: int  # 1857
PPC_evaddwus: int  # 1845
PPC_evaddwx: int  # 1859
PPC_evaddwxss: int  # 1860
PPC_evaddwxus: int  # 1846
PPC_evand: int  # 425
PPC_evandc: int  # 426
PPC_evavgbs: int  # 2065
PPC_evavgbsr: int  # 2073
PPC_evavgbu: int  # 2064
PPC_evavgbur: int  # 2072
PPC_evavgds: int  # 2069
PPC_evavgdsr: int  # 2077
PPC_evavgdu: int  # 2068
PPC_evavgdur: int  # 2076
PPC_evavghs: int  # 2067
PPC_evavghsr: int  # 2075
PPC_evavghu: int  # 2066
PPC_evavghur: int  # 2074
PPC_evavgws: int  # 2063
PPC_evavgwsr: int  # 2071
PPC_evavgwu: int  # 2062
PPC_evavgwur: int  # 2070
PPC_evclrbe: int  # 1653
PPC_evclrbo: int  # 1654
PPC_evclrh: int  # 1656
PPC_evcmpeq: int  # 427
PPC_evcmpeqd: int  # 1639
PPC_evcmpgtds: int  # 1636
PPC_evcmpgtdu: int  # 1635
PPC_evcmpgts: int  # 428
PPC_evcmpgtu: int  # 429
PPC_evcmpltds: int  # 1638
PPC_evcmpltdu: int  # 1637
PPC_evcmplts: int  # 430
PPC_evcmpltu: int  # 431
PPC_evcntlsh: int  # 1563
PPC_evcntlsw: int  # 432
PPC_evcntlzh: int  # 1562
PPC_evcntlzw: int  # 433
PPC_evdiff2his: int  # 1878
PPC_evdiff2hisa: int  # 1886
PPC_evdiff2hisaaw: int  # 1894
PPC_evdivs: int  # 1898
PPC_evdivu: int  # 1899
PPC_evdivws: int  # 434
PPC_evdivwsf: int  # 1896
PPC_evdivwu: int  # 435
PPC_evdivwuf: int  # 1897
PPC_evdlveb: int  # 2038
PPC_evdlveh: int  # 2039
PPC_evdlveob: int  # 2040
PPC_evdlveoh: int  # 2041
PPC_evdlvob: int  # 2042
PPC_evdlvoeb: int  # 2044
PPC_evdlvoeh: int  # 2045
PPC_evdlvoh: int  # 2043
PPC_evdotp4hgasmf: int  # 1439
PPC_evdotp4hgasmfa: int  # 1465
PPC_evdotp4hgasmfaa: int  # 1478
PPC_evdotp4hgasmfaa3: int  # 1452
PPC_evdotp4hgasmi: int  # 1437
PPC_evdotp4hgasmia: int  # 1463
PPC_evdotp4hgasmiaa: int  # 1476
PPC_evdotp4hgasmiaa3: int  # 1450
PPC_evdotp4hgasumi: int  # 1438
PPC_evdotp4hgasumia: int  # 1464
PPC_evdotp4hgasumiaa: int  # 1477
PPC_evdotp4hgasumiaa3: int  # 1451
PPC_evdotp4hgaumi: int  # 1436
PPC_evdotp4hgaumia: int  # 1462
PPC_evdotp4hgaumiaa: int  # 1475
PPC_evdotp4hgaumiaa3: int  # 1449
PPC_evdotp4hgssmf: int  # 1441
PPC_evdotp4hgssmfa: int  # 1467
PPC_evdotp4hgssmfaa: int  # 1480
PPC_evdotp4hgssmfaa3: int  # 1454
PPC_evdotp4hgssmi: int  # 1440
PPC_evdotp4hgssmia: int  # 1466
PPC_evdotp4hgssmiaa: int  # 1479
PPC_evdotp4hgssmiaa3: int  # 1453
PPC_evdotp4hxgasmf: int  # 1443
PPC_evdotp4hxgasmfa: int  # 1469
PPC_evdotp4hxgasmfaa: int  # 1482
PPC_evdotp4hxgasmfaa3: int  # 1456
PPC_evdotp4hxgasmi: int  # 1442
PPC_evdotp4hxgasmia: int  # 1468
PPC_evdotp4hxgasmiaa: int  # 1481
PPC_evdotp4hxgasmiaa3: int  # 1455
PPC_evdotp4hxgssmf: int  # 1448
PPC_evdotp4hxgssmfa: int  # 1474
PPC_evdotp4hxgssmfaa: int  # 1487
PPC_evdotp4hxgssmfaa3: int  # 1461
PPC_evdotp4hxgssmi: int  # 1447
PPC_evdotp4hxgssmia: int  # 1473
PPC_evdotp4hxgssmiaa: int  # 1486
PPC_evdotp4hxgssmiaa3: int  # 1460
PPC_evdotpbasmi: int  # 1445
PPC_evdotpbasmia: int  # 1471
PPC_evdotpbasmiaaw: int  # 1484
PPC_evdotpbasmiaaw3: int  # 1458
PPC_evdotpbasumi: int  # 1446
PPC_evdotpbasumia: int  # 1472
PPC_evdotpbasumiaaw: int  # 1485
PPC_evdotpbasumiaaw3: int  # 1459
PPC_evdotpbaumi: int  # 1444
PPC_evdotpbaumia: int  # 1470
PPC_evdotpbaumiaaw: int  # 1483
PPC_evdotpbaumiaaw3: int  # 1457
PPC_evdotphasmi: int  # 1396
PPC_evdotphasmia: int  # 1419
PPC_evdotphasmiaaw: int  # 1431
PPC_evdotphasmiaaw3: int  # 1408
PPC_evdotphassf: int  # 1393
PPC_evdotphassfa: int  # 1416
PPC_evdotphassfaaw: int  # 1427
PPC_evdotphassfaaw3: int  # 1404
PPC_evdotphassfr: int  # 1398
PPC_evdotphassfra: int  # 1421
PPC_evdotphassfraaw: int  # 1433
PPC_evdotphassfraaw3: int  # 1410
PPC_evdotphassi: int  # 1391
PPC_evdotphassia: int  # 1414
PPC_evdotphassiaaw: int  # 1425
PPC_evdotphassiaaw3: int  # 1402
PPC_evdotphasumi: int  # 1397
PPC_evdotphasumia: int  # 1420
PPC_evdotphasumiaaw: int  # 1432
PPC_evdotphasumiaaw3: int  # 1409
PPC_evdotphasusi: int  # 1392
PPC_evdotphasusia: int  # 1415
PPC_evdotphasusiaaw: int  # 1426
PPC_evdotphasusiaaw3: int  # 1403
PPC_evdotphaumi: int  # 1395
PPC_evdotphaumia: int  # 1418
PPC_evdotphaumiaaw: int  # 1430
PPC_evdotphaumiaaw3: int  # 1407
PPC_evdotphausi: int  # 1390
PPC_evdotphausia: int  # 1413
PPC_evdotphausiaaw: int  # 1424
PPC_evdotphausiaaw3: int  # 1401
PPC_evdotphihcsmi: int  # 1362
PPC_evdotphihcsmia: int  # 1378
PPC_evdotphihcsmiaaw: int  # 1386
PPC_evdotphihcsmiaaw3: int  # 1370
PPC_evdotphihcssf: int  # 1360
PPC_evdotphihcssfa: int  # 1376
PPC_evdotphihcssfaaw: int  # 1384
PPC_evdotphihcssfaaw3: int  # 1368
PPC_evdotphihcssfr: int  # 1364
PPC_evdotphihcssfra: int  # 1380
PPC_evdotphihcssfraaw: int  # 1388
PPC_evdotphihcssfraaw3: int  # 1372
PPC_evdotphihcssi: int  # 1358
PPC_evdotphihcssia: int  # 1374
PPC_evdotphihcssiaaw: int  # 1382
PPC_evdotphihcssiaaw3: int  # 1366
PPC_evdotphssmi: int  # 1399
PPC_evdotphssmia: int  # 1422
PPC_evdotphssmiaaw: int  # 1434
PPC_evdotphssmiaaw3: int  # 1411
PPC_evdotphsssf: int  # 1394
PPC_evdotphsssfa: int  # 1417
PPC_evdotphsssfaaw: int  # 1429
PPC_evdotphsssfaaw3: int  # 1406
PPC_evdotphsssfr: int  # 1400
PPC_evdotphsssfra: int  # 1423
PPC_evdotphsssfraaw: int  # 1435
PPC_evdotphsssfraaw3: int  # 1412
PPC_evdotphsssiaaw: int  # 1428
PPC_evdotphsssiaaw3: int  # 1405
PPC_evdotplohcsmi: int  # 1363
PPC_evdotplohcsmia: int  # 1379
PPC_evdotplohcsmiaaw: int  # 1387
PPC_evdotplohcsmiaaw3: int  # 1371
PPC_evdotplohcssf: int  # 1361
PPC_evdotplohcssfa: int  # 1377
PPC_evdotplohcssfaaw: int  # 1385
PPC_evdotplohcssfaaw3: int  # 1369
PPC_evdotplohcssfr: int  # 1365
PPC_evdotplohcssfra: int  # 1381
PPC_evdotplohcssfraaw: int  # 1389
PPC_evdotplohcssfraaw3: int  # 1373
PPC_evdotplohcssi: int  # 1359
PPC_evdotplohcssia: int  # 1375
PPC_evdotplohcssiaaw: int  # 1383
PPC_evdotplohcssiaaw3: int  # 1367
PPC_evdotpwasmi: int  # 1492
PPC_evdotpwasmia: int  # 1507
PPC_evdotpwasmiaa: int  # 1515
PPC_evdotpwasmiaa3: int  # 1500
PPC_evdotpwassi: int  # 1489
PPC_evdotpwassia: int  # 1504
PPC_evdotpwassiaa: int  # 1511
PPC_evdotpwassiaa3: int  # 1496
PPC_evdotpwasumi: int  # 1493
PPC_evdotpwasumia: int  # 1508
PPC_evdotpwasumiaa: int  # 1516
PPC_evdotpwasumiaa3: int  # 1501
PPC_evdotpwasusi: int  # 1490
PPC_evdotpwasusia: int  # 1505
PPC_evdotpwasusiaa: int  # 1512
PPC_evdotpwasusiaa3: int  # 1497
PPC_evdotpwaumi: int  # 1491
PPC_evdotpwaumia: int  # 1506
PPC_evdotpwaumiaa: int  # 1514
PPC_evdotpwaumiaa3: int  # 1499
PPC_evdotpwausi: int  # 1488
PPC_evdotpwausia: int  # 1503
PPC_evdotpwausiaa: int  # 1510
PPC_evdotpwausiaa3: int  # 1495
PPC_evdotpwcsmi: int  # 1311
PPC_evdotpwcsmia: int  # 1335
PPC_evdotpwcsmiaaw: int  # 1347
PPC_evdotpwcsmiaaw3: int  # 1323
PPC_evdotpwcssf: int  # 1313
PPC_evdotpwcssfa: int  # 1337
PPC_evdotpwcssfaaw: int  # 1349
PPC_evdotpwcssfaaw3: int  # 1325
PPC_evdotpwcssfr: int  # 1312
PPC_evdotpwcssfra: int  # 1336
PPC_evdotpwcssfraaw: int  # 1348
PPC_evdotpwcssfraaw3: int  # 1324
PPC_evdotpwcssi: int  # 1310
PPC_evdotpwcssia: int  # 1334
PPC_evdotpwcssiaaw: int  # 1346
PPC_evdotpwcssiaaw3: int  # 1322
PPC_evdotpwgasmf: int  # 1314
PPC_evdotpwgasmfa: int  # 1338
PPC_evdotpwgasmfaa: int  # 1350
PPC_evdotpwgasmfaa3: int  # 1326
PPC_evdotpwgasmfr: int  # 1316
PPC_evdotpwgasmfra: int  # 1340
PPC_evdotpwgasmfraa: int  # 1352
PPC_evdotpwgasmfraa3: int  # 1328
PPC_evdotpwgssmf: int  # 1318
PPC_evdotpwgssmfa: int  # 1342
PPC_evdotpwgssmfaa: int  # 1354
PPC_evdotpwgssmfaa3: int  # 1330
PPC_evdotpwgssmfr: int  # 1320
PPC_evdotpwgssmfra: int  # 1344
PPC_evdotpwgssmfraa: int  # 1356
PPC_evdotpwgssmfraa3: int  # 1332
PPC_evdotpwssmi: int  # 1494
PPC_evdotpwssmia: int  # 1509
PPC_evdotpwssmiaa: int  # 1517
PPC_evdotpwssmiaa3: int  # 1502
PPC_evdotpwsssiaa: int  # 1513
PPC_evdotpwsssiaa3: int  # 1498
PPC_evdotpwxgasmf: int  # 1315
PPC_evdotpwxgasmfa: int  # 1339
PPC_evdotpwxgasmfaa: int  # 1351
PPC_evdotpwxgasmfaa3: int  # 1327
PPC_evdotpwxgasmfr: int  # 1317
PPC_evdotpwxgasmfra: int  # 1341
PPC_evdotpwxgasmfraa: int  # 1353
PPC_evdotpwxgasmfraa3: int  # 1329
PPC_evdotpwxgssmf: int  # 1319
PPC_evdotpwxgssmfa: int  # 1343
PPC_evdotpwxgssmfaa: int  # 1355
PPC_evdotpwxgssmfaa3: int  # 1331
PPC_evdotpwxgssmfr: int  # 1321
PPC_evdotpwxgssmfra: int  # 1345
PPC_evdotpwxgssmfraa: int  # 1357
PPC_evdotpwxgssmfraa3: int  # 1333
PPC_eveqv: int  # 436
PPC_evextsb: int  # 437
PPC_evextsbh: int  # 1543
PPC_evextsh: int  # 438
PPC_evextsw: int  # 1544
PPC_evextzb: int  # 1542
PPC_evfsabs: int  # 642
PPC_evfsadd: int  # 643
PPC_evfsaddsub: int  # 1274
PPC_evfsaddsubx: int  # 1282
PPC_evfsaddx: int  # 1280
PPC_evfscfh: int  # 1287
PPC_evfscfsf: int  # 644
PPC_evfscfsi: int  # 645
PPC_evfscfuf: int  # 646
PPC_evfscfui: int  # 647
PPC_evfscmpeq: int  # 648
PPC_evfscmpgt: int  # 649
PPC_evfscmplt: int  # 650
PPC_evfscth: int  # 1288
PPC_evfsctsf: int  # 651
PPC_evfsctsi: int  # 652
PPC_evfsctsiz: int  # 653
PPC_evfsctuf: int  # 654
PPC_evfsctui: int  # 655
PPC_evfsctuiz: int  # 656
PPC_evfsdiff: int  # 1277
PPC_evfsdiffsum: int  # 1279
PPC_evfsdiv: int  # 657
PPC_evfsmadd: int  # 1267
PPC_evfsmax: int  # 1272
PPC_evfsmin: int  # 1273
PPC_evfsmsub: int  # 1268
PPC_evfsmul: int  # 658
PPC_evfsmule: int  # 1285
PPC_evfsmulo: int  # 1286
PPC_evfsmulx: int  # 1284
PPC_evfsnabs: int  # 659
PPC_evfsneg: int  # 660
PPC_evfsnmadd: int  # 1270
PPC_evfsnmsub: int  # 1271
PPC_evfssqrt: int  # 1269
PPC_evfssub: int  # 661
PPC_evfssubadd: int  # 1275
PPC_evfssubaddx: int  # 1283
PPC_evfssubx: int  # 1281
PPC_evfssum: int  # 1276
PPC_evfssumdiff: int  # 1278
PPC_evfststeq: int  # 662
PPC_evfststgt: int  # 663
PPC_evfststlt: int  # 664
PPC_evilveh: int  # 2030
PPC_evilveoh: int  # 2031
PPC_evilvhih: int  # 2032
PPC_evilvhiloh: int  # 2033
PPC_evilvloh: int  # 2034
PPC_evilvlohih: int  # 2035
PPC_evilvoeh: int  # 2036
PPC_evilvoh: int  # 2037
PPC_evinsb: int  # 1648
PPC_evinsh: int  # 1652
PPC_evlbbsplatb: int  # 1698
PPC_evlbbsplatbmx: int  # 1745
PPC_evlbbsplatbu: int  # 1746
PPC_evlbbsplatbx: int  # 1697
PPC_evldb: int  # 1690
PPC_evldbmx: int  # 1721
PPC_evldbu: int  # 1722
PPC_evldbx: int  # 1689
PPC_evldd: int  # 439
PPC_evlddepx: int  # 764
PPC_evlddmx: int  # 1715
PPC_evlddu: int  # 1716
PPC_evlddx: int  # 440
PPC_evldh: int  # 441
PPC_evldhmx: int  # 1719
PPC_evldhu: int  # 1720
PPC_evldhx: int  # 442
PPC_evldw: int  # 443
PPC_evldwmx: int  # 1717
PPC_evldwu: int  # 1718
PPC_evldwx: int  # 444
PPC_evlhhesplat: int  # 445
PPC_evlhhesplatmx: int  # 1723
PPC_evlhhesplatu: int  # 1724
PPC_evlhhesplatx: int  # 446
PPC_evlhhossplat: int  # 447
PPC_evlhhossplatmx: int  # 1729
PPC_evlhhossplatu: int  # 1730
PPC_evlhhossplatx: int  # 448
PPC_evlhhousplat: int  # 449
PPC_evlhhousplatmx: int  # 1727
PPC_evlhhousplatu: int  # 1728
PPC_evlhhousplatx: int  # 450
PPC_evlhhsplath: int  # 1692
PPC_evlhhsplathmx: int  # 1725
PPC_evlhhsplathu: int  # 1726
PPC_evlhhsplathx: int  # 1691
PPC_evlvsl: int  # 1684
PPC_evlvsr: int  # 1685
PPC_evlwbe: int  # 1702
PPC_evlwbemx: int  # 1755
PPC_evlwbeu: int  # 1756
PPC_evlwbex: int  # 1701
PPC_evlwbos: int  # 1706
PPC_evlwbosmx: int  # 1759
PPC_evlwbosu: int  # 1760
PPC_evlwbosx: int  # 1705
PPC_evlwbou: int  # 1704
PPC_evlwboumx: int  # 1757
PPC_evlwbouu: int  # 1758
PPC_evlwboux: int  # 1703
PPC_evlwbsplatw: int  # 1694
PPC_evlwbsplatwmx: int  # 1733
PPC_evlwbsplatwu: int  # 1734
PPC_evlwbsplatwx: int  # 1693
PPC_evlwhe: int  # 451
PPC_evlwhemx: int  # 1731
PPC_evlwheu: int  # 1732
PPC_evlwhex: int  # 452
PPC_evlwhos: int  # 453
PPC_evlwhosmx: int  # 1737
PPC_evlwhosu: int  # 1738
PPC_evlwhosx: int  # 454
PPC_evlwhou: int  # 455
PPC_evlwhoumx: int  # 1735
PPC_evlwhouu: int  # 1736
PPC_evlwhoux: int  # 456
PPC_evlwhsplat: int  # 457
PPC_evlwhsplatmx: int  # 1743
PPC_evlwhsplatu: int  # 1744
PPC_evlwhsplatw: int  # 1696
PPC_evlwhsplatwmx: int  # 1741
PPC_evlwhsplatwu: int  # 1742
PPC_evlwhsplatwx: int  # 1695
PPC_evlwhsplatx: int  # 458
PPC_evlwwsplat: int  # 459
PPC_evlwwsplatmx: int  # 1739
PPC_evlwwsplatu: int  # 1740
PPC_evlwwsplatx: int  # 460
PPC_evmar: int  # 1871
PPC_evmaxbpsh: int  # 1597
PPC_evmaxbpuh: int  # 1596
PPC_evmaxbs: int  # 2047
PPC_evmaxbu: int  # 2046
PPC_evmaxds: int  # 2053
PPC_evmaxdu: int  # 2052
PPC_evmaxhpsw: int  # 1595
PPC_evmaxhpuw: int  # 1594
PPC_evmaxhs: int  # 2049
PPC_evmaxhu: int  # 2048
PPC_evmaxmagws: int  # 1606
PPC_evmaxwpsd: int  # 1599
PPC_evmaxwpud: int  # 1598
PPC_evmaxws: int  # 2051
PPC_evmaxwu: int  # 2050
PPC_evmbesmi: int  # 1786
PPC_evmbesmia: int  # 1794
PPC_evmbesmiaah: int  # 1927
PPC_evmbesmianh: int  # 1957
PPC_evmbessiaah: int  # 1921
PPC_evmbessianh: int  # 1951
PPC_evmbesumi: int  # 1787
PPC_evmbesumia: int  # 1795
PPC_evmbesumiaah: int  # 1928
PPC_evmbesumianh: int  # 1958
PPC_evmbesusiaah: int  # 1922
PPC_evmbesusianh: int  # 1952
PPC_evmbeumi: int  # 1785
PPC_evmbeumia: int  # 1793
PPC_evmbeumiaah: int  # 1926
PPC_evmbeumianh: int  # 1956
PPC_evmbeusiaah: int  # 1920
PPC_evmbeusianh: int  # 1950
PPC_evmbosmi: int  # 1789
PPC_evmbosmia: int  # 1797
PPC_evmbosmiaah: int  # 1930
PPC_evmbosmianh: int  # 1960
PPC_evmbossiaah: int  # 1924
PPC_evmbossianh: int  # 1954
PPC_evmbosumi: int  # 1790
PPC_evmbosumia: int  # 1798
PPC_evmbosumiaah: int  # 1931
PPC_evmbosumianh: int  # 1961
PPC_evmbosusiaah: int  # 1925
PPC_evmbosusianh: int  # 1955
PPC_evmboumi: int  # 1788
PPC_evmboumia: int  # 1796
PPC_evmboumiaah: int  # 1929
PPC_evmboumianh: int  # 1959
PPC_evmbousiaah: int  # 1923
PPC_evmbousianh: int  # 1953
PPC_evmergehi: int  # 461
PPC_evmergehilo: int  # 462
PPC_evmergelo: int  # 463
PPC_evmergelohi: int  # 464
PPC_evmhegsmfaa: int  # 465
PPC_evmhegsmfan: int  # 466
PPC_evmhegsmiaa: int  # 467
PPC_evmhegsmian: int  # 468
PPC_evmhegumiaa: int  # 469
PPC_evmhegumian: int  # 470
PPC_evmhesmf: int  # 471
PPC_evmhesmfa: int  # 472
PPC_evmhesmfaaw: int  # 473
PPC_evmhesmfanw: int  # 474
PPC_evmhesmi: int  # 475
PPC_evmhesmia: int  # 476
PPC_evmhesmiaaw: int  # 477
PPC_evmhesmianw: int  # 478
PPC_evmhessf: int  # 479
PPC_evmhessfa: int  # 480
PPC_evmhessfaaw: int  # 481
PPC_evmhessfanw: int  # 482
PPC_evmhessiaaw: int  # 483
PPC_evmhessianw: int  # 484
PPC_evmhesumi: int  # 1783
PPC_evmhesumia: int  # 1791
PPC_evmhesumiaaw: int  # 1918
PPC_evmhesumianw: int  # 1948
PPC_evmhesusiaaw: int  # 1916
PPC_evmhesusianw: int  # 1946
PPC_evmheumi: int  # 485
PPC_evmheumia: int  # 486
PPC_evmheumiaaw: int  # 487
PPC_evmheumianw: int  # 488
PPC_evmheusiaaw: int  # 489
PPC_evmheusianw: int  # 490
PPC_evmhogsmfaa: int  # 491
PPC_evmhogsmfan: int  # 492
PPC_evmhogsmiaa: int  # 493
PPC_evmhogsmian: int  # 494
PPC_evmhogumiaa: int  # 495
PPC_evmhogumian: int  # 496
PPC_evmhosmf: int  # 497
PPC_evmhosmfa: int  # 498
PPC_evmhosmfaaw: int  # 499
PPC_evmhosmfanw: int  # 500
PPC_evmhosmi: int  # 501
PPC_evmhosmia: int  # 502
PPC_evmhosmiaaw: int  # 503
PPC_evmhosmianw: int  # 504
PPC_evmhossf: int  # 505
PPC_evmhossfa: int  # 506
PPC_evmhossfaaw: int  # 507
PPC_evmhossfanw: int  # 508
PPC_evmhossiaaw: int  # 509
PPC_evmhossianw: int  # 510
PPC_evmhosumi: int  # 1784
PPC_evmhosumia: int  # 1792
PPC_evmhosumiaaw: int  # 1919
PPC_evmhosumianw: int  # 1949
PPC_evmhosusiaaw: int  # 1917
PPC_evmhosusianw: int  # 1947
PPC_evmhoumi: int  # 511
PPC_evmhoumia: int  # 512
PPC_evmhoumiaaw: int  # 513
PPC_evmhoumianw: int  # 514
PPC_evmhousiaaw: int  # 515
PPC_evmhousianw: int  # 516
PPC_evmhssf: int  # 1780
PPC_evmhssfr: int  # 1782
PPC_evmhssi: int  # 1778
PPC_evmhsusi: int  # 1779
PPC_evmhumi: int  # 1781
PPC_evmhusi: int  # 1777
PPC_evminbpsh: int  # 1603
PPC_evminbpuh: int  # 1602
PPC_evminbs: int  # 2055
PPC_evminbu: int  # 2054
PPC_evminds: int  # 2061
PPC_evmindu: int  # 2060
PPC_evminhpsw: int  # 1601
PPC_evminhpuw: int  # 1600
PPC_evminhs: int  # 2057
PPC_evminhu: int  # 2056
PPC_evminwpsd: int  # 1605
PPC_evminwpud: int  # 1604
PPC_evminws: int  # 2059
PPC_evminwu: int  # 2058
PPC_evmr: int  # 1206
PPC_evmra: int  # 517
PPC_evmwehgsmf: int  # 1803
PPC_evmwehgsmfa: int  # 1808
PPC_evmwehgsmfaa: int  # 1943
PPC_evmwehgsmfan: int  # 1973
PPC_evmwehgsmfr: int  # 1802
PPC_evmwehgsmfra: int  # 1807
PPC_evmwehgsmfraa: int  # 1942
PPC_evmwehgsmfran: int  # 1972
PPC_evmwhsmf: int  # 518
PPC_evmwhsmfa: int  # 519
PPC_evmwhsmi: int  # 520
PPC_evmwhsmia: int  # 521
PPC_evmwhssf: int  # 522
PPC_evmwhssfa: int  # 523
PPC_evmwhssfaaw: int  # 1937
PPC_evmwhssfaaw3: int  # 1935
PPC_evmwhssfanw: int  # 1967
PPC_evmwhssfanw3: int  # 1965
PPC_evmwhssfr: int  # 1801
PPC_evmwhssfra: int  # 1806
PPC_evmwhssfraaw: int  # 1936
PPC_evmwhssfraaw3: int  # 1934
PPC_evmwhssfranw: int  # 1966
PPC_evmwhssfranw3: int  # 1964
PPC_evmwhumi: int  # 524
PPC_evmwhumia: int  # 525
PPC_evmwlsmiaaw: int  # 526
PPC_evmwlsmiaaw3: int  # 1939
PPC_evmwlsmianw: int  # 527
PPC_evmwlsmianw3: int  # 1969
PPC_evmwlssiaaw: int  # 528
PPC_evmwlssiaaw3: int  # 1933
PPC_evmwlssianw: int  # 529
PPC_evmwlssianw3: int  # 1963
PPC_evmwlumi: int  # 530
PPC_evmwlumia: int  # 531
PPC_evmwlumiaaw: int  # 532
PPC_evmwlumiaaw3: int  # 1938
PPC_evmwlumianw: int  # 533
PPC_evmwlumianw3: int  # 1968
PPC_evmwlusiaaw: int  # 534
PPC_evmwlusiaaw3: int  # 1932
PPC_evmwlusianw: int  # 535
PPC_evmwlusianw3: int  # 1962
PPC_evmwohgsmf: int  # 1805
PPC_evmwohgsmfa: int  # 1810
PPC_evmwohgsmfaa: int  # 1945
PPC_evmwohgsmfan: int  # 1975
PPC_evmwohgsmfr: int  # 1804
PPC_evmwohgsmfra: int  # 1809
PPC_evmwohgsmfraa: int  # 1944
PPC_evmwohgsmfran: int  # 1974
PPC_evmwsmf: int  # 536
PPC_evmwsmfa: int  # 537
PPC_evmwsmfaa: int  # 538
PPC_evmwsmfan: int  # 539
PPC_evmwsmi: int  # 540
PPC_evmwsmia: int  # 541
PPC_evmwsmiaa: int  # 542
PPC_evmwsmian: int  # 543
PPC_evmwssf: int  # 544
PPC_evmwssfa: int  # 545
PPC_evmwssfaa: int  # 546
PPC_evmwssfan: int  # 547
PPC_evmwssiaa: int  # 1941
PPC_evmwssian: int  # 1971
PPC_evmwssiw: int  # 1800
PPC_evmwumi: int  # 548
PPC_evmwumia: int  # 549
PPC_evmwumiaa: int  # 550
PPC_evmwumian: int  # 551
PPC_evmwusiaa: int  # 1940
PPC_evmwusian: int  # 1970
PPC_evmwusiw: int  # 1799
PPC_evnand: int  # 552
PPC_evneg: int  # 553
PPC_evnegb: int  # 1530
PPC_evnegbo: int  # 1531
PPC_evnegbos: int  # 1538
PPC_evnegbs: int  # 1537
PPC_evnegd: int  # 1534
PPC_evnegds: int  # 1541
PPC_evnegh: int  # 1532
PPC_evnegho: int  # 1533
PPC_evneghos: int  # 1540
PPC_evneghs: int  # 1539
PPC_evnegs: int  # 1535
PPC_evnegwo: int  # 1529
PPC_evnegwos: int  # 1536
PPC_evnor: int  # 554
PPC_evnot: int  # 1207
PPC_evor: int  # 555
PPC_evorc: int  # 556
PPC_evperm: int  # 1660
PPC_evperm2: int  # 1661
PPC_evperm3: int  # 1662
PPC_evpksdshefrs: int  # 2026
PPC_evpksdswfrs: int  # 2025
PPC_evpksdsws: int  # 2028
PPC_evpkshsbs: int  # 2016
PPC_evpkshubs: int  # 2015
PPC_evpkswgshefrs: int  # 2022
PPC_evpkswgswfrs: int  # 2029
PPC_evpkswshfrs: int  # 2023
PPC_evpkswshilvfrs: int  # 2024
PPC_evpkswshilvs: int  # 2021
PPC_evpkswshs: int  # 2018
PPC_evpkswuhs: int  # 2017
PPC_evpkuduws: int  # 2027
PPC_evpkuhubs: int  # 2019
PPC_evpkuwuhs: int  # 2020
PPC_evpopcntb: int  # 1564
PPC_evrlb: int  # 1669
PPC_evrlbi: int  # 1671
PPC_evrlh: int  # 1677
PPC_evrlhi: int  # 1679
PPC_evrlw: int  # 557
PPC_evrlwi: int  # 558
PPC_evrnddnw: int  # 1555
PPC_evrnddnwss: int  # 1561
PPC_evrnddnwus: int  # 1560
PPC_evrnddw: int  # 1546
PPC_evrnddwss: int  # 1552
PPC_evrnddwus: int  # 1551
PPC_evrndhb: int  # 1545
PPC_evrndhbss: int  # 1550
PPC_evrndhbus: int  # 1549
PPC_evrndhnb: int  # 1554
PPC_evrndhnbss: int  # 1559
PPC_evrndhnbus: int  # 1558
PPC_evrndw: int  # 559
PPC_evrndwhss: int  # 1548
PPC_evrndwhus: int  # 1547
PPC_evrndwnh: int  # 1553
PPC_evrndwnhss: int  # 1557
PPC_evrndwnhus: int  # 1556
PPC_evsad2sh: int  # 1996
PPC_evsad2sha: int  # 2002
PPC_evsad2shaaw: int  # 2014
PPC_evsad2uh: int  # 1995
PPC_evsad2uha: int  # 2001
PPC_evsad2uhaaw: int  # 2013
PPC_evsad4sb: int  # 1994
PPC_evsad4sba: int  # 2000
PPC_evsad4sbaaw: int  # 2012
PPC_evsad4ub: int  # 1993
PPC_evsad4uba: int  # 1999
PPC_evsad4ubaaw: int  # 2011
PPC_evsadsw: int  # 1992
PPC_evsadswa: int  # 1998
PPC_evsadswaa: int  # 2010
PPC_evsaduw: int  # 1991
PPC_evsaduwa: int  # 1997
PPC_evsaduwaa: int  # 2009
PPC_evsatsbub: int  # 1592
PPC_evsatsdsw: int  # 1579
PPC_evsatsduw: int  # 1578
PPC_evsatshsb: int  # 1581
PPC_evsatshub: int  # 1580
PPC_evsatshuh: int  # 1588
PPC_evsatswgsdf: int  # 1591
PPC_evsatswsh: int  # 1583
PPC_evsatswuh: int  # 1584
PPC_evsatswuw: int  # 1590
PPC_evsatubsb: int  # 1593
PPC_evsatuduw: int  # 1586
PPC_evsatuhsh: int  # 1589
PPC_evsatuhub: int  # 1585
PPC_evsatuwsw: int  # 1587
PPC_evsatuwuh: int  # 1582
PPC_evsel: int  # 560
PPC_evselbit: int  # 1659
PPC_evselbitm0: int  # 1657
PPC_evselbitm1: int  # 1658
PPC_evseteqb: int  # 1976
PPC_evseteqh: int  # 1977
PPC_evseteqw: int  # 1978
PPC_evsetgtbs: int  # 1984
PPC_evsetgtbu: int  # 1983
PPC_evsetgths: int  # 1980
PPC_evsetgthu: int  # 1979
PPC_evsetgtws: int  # 1982
PPC_evsetgtwu: int  # 1981
PPC_evsetltbs: int  # 1986
PPC_evsetltbu: int  # 1985
PPC_evsetlths: int  # 1988
PPC_evsetlthu: int  # 1987
PPC_evsetltws: int  # 1990
PPC_evsetltwu: int  # 1989
PPC_evsl: int  # 1607
PPC_evslb: int  # 1668
PPC_evslbi: int  # 1670
PPC_evslh: int  # 1676
PPC_evslhi: int  # 1678
PPC_evsli: int  # 1608
PPC_evsloi: int  # 1687
PPC_evslw: int  # 561
PPC_evslwi: int  # 562
PPC_evsplatb: int  # 1651
PPC_evsplatfi: int  # 563
PPC_evsplatfia: int  # 1628
PPC_evsplatfib: int  # 1623
PPC_evsplatfiba: int  # 1630
PPC_evsplatfibo: int  # 1624
PPC_evsplatfiboa: int  # 1631
PPC_evsplatfid: int  # 1627
PPC_evsplatfida: int  # 1634
PPC_evsplatfih: int  # 1625
PPC_evsplatfiha: int  # 1632
PPC_evsplatfiho: int  # 1626
PPC_evsplatfihoa: int  # 1633
PPC_evsplatfio: int  # 1622
PPC_evsplatfioa: int  # 1629
PPC_evsplath: int  # 1650
PPC_evsplati: int  # 564
PPC_evsplatia: int  # 1615
PPC_evsplatib: int  # 1610
PPC_evsplatiba: int  # 1617
PPC_evsplatibe: int  # 1611
PPC_evsplatibea: int  # 1618
PPC_evsplatid: int  # 1614
PPC_evsplatida: int  # 1621
PPC_evsplatie: int  # 1609
PPC_evsplatiea: int  # 1616
PPC_evsplatih: int  # 1612
PPC_evsplatiha: int  # 1619
PPC_evsplatihe: int  # 1613
PPC_evsplatihea: int  # 1620
PPC_evsrbis: int  # 1667
PPC_evsrbiu: int  # 1666
PPC_evsrbs: int  # 1665
PPC_evsrbu: int  # 1664
PPC_evsrhis: int  # 1675
PPC_evsrhiu: int  # 1674
PPC_evsrhs: int  # 1673
PPC_evsrhu: int  # 1672
PPC_evsris: int  # 1683
PPC_evsriu: int  # 1682
PPC_evsrois: int  # 1688
PPC_evsroiu: int  # 1686
PPC_evsrs: int  # 1681
PPC_evsru: int  # 1680
PPC_evsrwis: int  # 565
PPC_evsrwiu: int  # 566
PPC_evsrws: int  # 567
PPC_evsrwu: int  # 568
PPC_evstdb: int  # 1700
PPC_evstdbmx: int  # 1753
PPC_evstdbu: int  # 1754
PPC_evstdbx: int  # 1699
PPC_evstdd: int  # 569
PPC_evstddepx: int  # 765
PPC_evstddmx: int  # 1747
PPC_evstddu: int  # 1748
PPC_evstddx: int  # 570
PPC_evstdh: int  # 571
PPC_evstdhmx: int  # 1751
PPC_evstdhu: int  # 1752
PPC_evstdhx: int  # 572
PPC_evstdw: int  # 573
PPC_evstdwmx: int  # 1749
PPC_evstdwu: int  # 1750
PPC_evstdwx: int  # 574
PPC_evsthb: int  # 1714
PPC_evsthbmx: int  # 1775
PPC_evsthbu: int  # 1776
PPC_evsthbx: int  # 1713
PPC_evstwb: int  # 1712
PPC_evstwbe: int  # 1708
PPC_evstwbemx: int  # 1763
PPC_evstwbeu: int  # 1764
PPC_evstwbex: int  # 1707
PPC_evstwbmx: int  # 1771
PPC_evstwbo: int  # 1710
PPC_evstwbomx: int  # 1767
PPC_evstwbou: int  # 1768
PPC_evstwbox: int  # 1709
PPC_evstwbu: int  # 1772
PPC_evstwbx: int  # 1711
PPC_evstwhe: int  # 575
PPC_evstwhemx: int  # 1761
PPC_evstwheu: int  # 1762
PPC_evstwhex: int  # 576
PPC_evstwho: int  # 577
PPC_evstwhomx: int  # 1765
PPC_evstwhou: int  # 1766
PPC_evstwhox: int  # 578
PPC_evstwwe: int  # 579
PPC_evstwwemx: int  # 1769
PPC_evstwweu: int  # 1770
PPC_evstwwex: int  # 580
PPC_evstwwo: int  # 581
PPC_evstwwomx: int  # 1773
PPC_evstwwou: int  # 1774
PPC_evstwwox: int  # 582
PPC_evsubf2add2h: int  # 1851
PPC_evsubf2add2hss: int  # 1852
PPC_evsubfaddh: int  # 1835
PPC_evsubfaddhss: int  # 1836
PPC_evsubfaddhx: int  # 1839
PPC_evsubfaddhxss: int  # 1840
PPC_evsubfaddw: int  # 1865
PPC_evsubfaddwss: int  # 1866
PPC_evsubfaddwx: int  # 1869
PPC_evsubfaddwxss: int  # 1870
PPC_evsubfb: int  # 1831
PPC_evsubfbss: int  # 1832
PPC_evsubfbus: int  # 1844
PPC_evsubfd: int  # 1827
PPC_evsubfdss: int  # 1828
PPC_evsubfdus: int  # 1843
PPC_evsubfh: int  # 1819
PPC_evsubfhhisw: int  # 1911
PPC_evsubfhhiuw: int  # 1910
PPC_evsubfhlosw: int  # 1915
PPC_evsubfhlouw: int  # 1914
PPC_evsubfhss: int  # 1820
PPC_evsubfhus: int  # 1855
PPC_evsubfhx: int  # 1823
PPC_evsubfhxss: int  # 1824
PPC_evsubfhxus: int  # 1856
PPC_evsubfsmiaa: int  # 1816
PPC_evsubfsmiaaw: int  # 583
PPC_evsubfssiaa: int  # 1814
PPC_evsubfssiaaw: int  # 584
PPC_evsubfumiaaw: int  # 585
PPC_evsubfusiaa: int  # 1813
PPC_evsubfusiaaw: int  # 586
PPC_evsubfw: int  # 587
PPC_evsubfwegsf: int  # 1903
PPC_evsubfwegsi: int  # 1902
PPC_evsubfwogsf: int  # 1907
PPC_evsubfwogsi: int  # 1906
PPC_evsubfwss: int  # 1858
PPC_evsubfwus: int  # 1847
PPC_evsubfwx: int  # 1861
PPC_evsubfwxss: int  # 1862
PPC_evsubfwxus: int  # 1848
PPC_evsubifb: int  # 1521
PPC_evsubifh: int  # 1520
PPC_evsubifw: int  # 588
PPC_evsum2his: int  # 1879
PPC_evsum2hisa: int  # 1887
PPC_evsum2hisaaw: int  # 1895
PPC_evsum2hs: int  # 1877
PPC_evsum2hsa: int  # 1885
PPC_evsum2hsaaw: int  # 1893
PPC_evsum2hu: int  # 1876
PPC_evsum2hua: int  # 1884
PPC_evsum2huaaw: int  # 1892
PPC_evsum4bs: int  # 1875
PPC_evsum4bsa: int  # 1883
PPC_evsum4bsaaw: int  # 1891
PPC_evsum4bu: int  # 1874
PPC_evsum4bua: int  # 1882
PPC_evsum4buaaw: int  # 1890
PPC_evsumws: int  # 1873
PPC_evsumwsa: int  # 1881
PPC_evsumwsaa: int  # 1889
PPC_evsumwu: int  # 1872
PPC_evsumwua: int  # 1880
PPC_evsumwuaa: int  # 1888
PPC_evswapbhilo: int  # 1640
PPC_evswapblohi: int  # 1641
PPC_evswaphe: int  # 1644
PPC_evswaphhi: int  # 1645
PPC_evswaphhilo: int  # 1642
PPC_evswaphlo: int  # 1646
PPC_evswaphlohi: int  # 1643
PPC_evswapho: int  # 1647
PPC_evunpkhibsi: int  # 1567
PPC_evunpkhibui: int  # 1566
PPC_evunpkhihf: int  # 1575
PPC_evunpkhihsi: int  # 1569
PPC_evunpkhihui: int  # 1568
PPC_evunpkhiwgsf: int  # 1577
PPC_evunpklobsi: int  # 1571
PPC_evunpklobui: int  # 1570
PPC_evunpklohf: int  # 1574
PPC_evunpklohsi: int  # 1573
PPC_evunpklohui: int  # 1572
PPC_evunpklowgsf: int  # 1576
PPC_evxor: int  # 589
PPC_evxtrb: int  # 1649
PPC_evxtrd: int  # 1663
PPC_evxtrh: int  # 1655
PPC_extldi: int  # 1185
PPC_extlwi: int  # 337
PPC_extrdi: int  # 1186
PPC_extrwi: int  # 338
PPC_extsb: int  # 46
PPC_extsh: int  # 47
PPC_extsw: int  # 48
PPC_extswsli: int  # 2264
PPC_extzb: int  # 1176
PPC_extzh: int  # 1177
PPC_fabs: int  # 49
PPC_fadd: int  # 50
PPC_fadds: int  # 51
PPC_fcfid: int  # 52
PPC_fcfids: int  # 786
PPC_fcfidu: int  # 787
PPC_fcfidus: int  # 788
PPC_fcmpo: int  # 53
PPC_fcmpu: int  # 54
PPC_fcpsgn: int  # 801
PPC_fctid: int  # 55
PPC_fctidu: int  # 789
PPC_fctiduz: int  # 790
PPC_fctidz: int  # 56
PPC_fctiw: int  # 57
PPC_fctiwu: int  # 791
PPC_fctiwuz: int  # 792
PPC_fctiwz: int  # 58
PPC_fdiv: int  # 59
PPC_fdivs: int  # 60
PPC_fmadd: int  # 61
PPC_fmadds: int  # 62
PPC_fmr: int  # 63
PPC_fmrgew: int  # 2091
PPC_fmrgow: int  # 2092
PPC_fmsub: int  # 64
PPC_fmsubs: int  # 65
PPC_fmul: int  # 66
PPC_fmuls: int  # 67
PPC_fnabs: int  # 68
PPC_fneg: int  # 69
PPC_fnmadd: int  # 70
PPC_fnmadds: int  # 71
PPC_fnmsub: int  # 72
PPC_fnmsubs: int  # 73
PPC_fre: int  # 802
PPC_fres: int  # 74
PPC_frim: int  # 803
PPC_frin: int  # 804
PPC_frip: int  # 805
PPC_friz: int  # 806
PPC_frsp: int  # 75
PPC_frsqrte: int  # 76
PPC_frsqrtes: int  # 371
PPC_fsel: int  # 77
PPC_fsqrt: int  # 78
PPC_fsqrts: int  # 79
PPC_fsub: int  # 80
PPC_fsubs: int  # 81
PPC_ftdiv: int  # 793
PPC_ftsqrt: int  # 794
PPC_hnop: int  # 1197
PPC_hrfid: int  # 372
PPC_hwaccel: int  # 2489
PPC_hwacceli: int  # 2490
PPC_icbi: int  # 82
PPC_icbiep: int  # 766
PPC_icblc: int  # 411
PPC_icblq: int  # 2199
PPC_icbt: int  # 351
PPC_icbtls: int  # 412
PPC_iccci: int  # 352
PPC_ici: int  # 749
PPC_icread: int  # 353
PPC_illegal: int  # 1178
PPC_inslwi: int  # 339
PPC_insrdi: int  # 1187
PPC_insrwi: int  # 340
PPC_isel: int  # 404
PPC_iseleq: int  # 407
PPC_iselgt: int  # 406
PPC_isellt: int  # 405
PPC_isync: int  # 83
PPC_last: int  # 3430
PPC_last_basic: int  # 228
PPC_lbarx: int  # 674
PPC_lbcbx: int  # 2454
PPC_lbdcbx: int  # 2448
PPC_lbdx: int  # 735
PPC_lbepx: int  # 767
PPC_lbz: int  # 84
PPC_lbzcix: int  # 835
PPC_lbzu: int  # 85
PPC_lbzux: int  # 86
PPC_lbzx: int  # 87
PPC_ld: int  # 88
PPC_ldarx: int  # 89
PPC_ldat: int  # 2282
PPC_ldbrw: int  # 2466
PPC_ldbrx: int  # 668
PPC_ldcix: int  # 836
PPC_lddx: int  # 736
PPC_ldepx: int  # 779
PPC_ldu: int  # 90
PPC_ldux: int  # 91
PPC_ldw: int  # 2461
PPC_ldwar: int  # 2477
PPC_ldwbrw: int  # 2467
PPC_ldwcb: int  # 2465
PPC_ldx: int  # 92
PPC_lfd: int  # 93
PPC_lfddx: int  # 737
PPC_lfdepx: int  # 768
PPC_lfdp: int  # 797
PPC_lfdpx: int  # 798
PPC_lfdu: int  # 94
PPC_lfdux: int  # 95
PPC_lfdx: int  # 96
PPC_lfiwax: int  # 795
PPC_lfiwzx: int  # 796
PPC_lfs: int  # 97
PPC_lfsu: int  # 98
PPC_lfsux: int  # 99
PPC_lfsx: int  # 100
PPC_lha: int  # 101
PPC_lharx: int  # 675
PPC_lhau: int  # 102
PPC_lhaux: int  # 103
PPC_lhax: int  # 104
PPC_lhbr: int  # 2474
PPC_lhbrx: int  # 105
PPC_lhcbx: int  # 2455
PPC_lhdcbx: int  # 2449
PPC_lhdx: int  # 738
PPC_lhepx: int  # 769
PPC_lhz: int  # 106
PPC_lhzcix: int  # 837
PPC_lhzu: int  # 107
PPC_lhzux: int  # 108
PPC_lhzx: int  # 109
PPC_li: int  # 285
PPC_lis: int  # 286
PPC_lmvcsrrw: int  # 1304
PPC_lmvdsrrw: int  # 1306
PPC_lmvgprw: int  # 1298
PPC_lmvmcsrrw: int  # 1308
PPC_lmvsprw: int  # 1300
PPC_lmvsrrw: int  # 1302
PPC_lmw: int  # 110
PPC_lnia: int  # 2257
PPC_lq: int  # 832
PPC_lqarx: int  # 2182
PPC_lqdbrw: int  # 2471
PPC_lqw: int  # 2463
PPC_lscbx: int  # 373
PPC_lswi: int  # 111
PPC_lswx: int  # 112
PPC_lvebx: int  # 848
PPC_lvehx: int  # 849
PPC_lvepx: int  # 770
PPC_lvepxl: int  # 771
PPC_lvewx: int  # 850
PPC_lvlx: int  # 1147
PPC_lvlxl: int  # 1148
PPC_lvrx: int  # 1149
PPC_lvrxl: int  # 1150
PPC_lvsl: int  # 851
PPC_lvsr: int  # 852
PPC_lvx: int  # 853
PPC_lvxl: int  # 854
PPC_lwa: int  # 113
PPC_lwarx: int  # 114
PPC_lwat: int  # 2283
PPC_lwaux: int  # 115
PPC_lwax: int  # 116
PPC_lwbr: int  # 2473
PPC_lwbrx: int  # 117
PPC_lwcbx: int  # 2456
PPC_lwdcbx: int  # 2450
PPC_lwdx: int  # 739
PPC_lwepx: int  # 772
PPC_lwsync: int  # 1202
PPC_lwz: int  # 118
PPC_lwzcix: int  # 838
PPC_lwzu: int  # 119
PPC_lwzux: int  # 120
PPC_lwzx: int  # 121
PPC_lxsd: int  # 2354
PPC_lxsdx: int  # 1004
PPC_lxsibzx: int  # 2356
PPC_lxsihzx: int  # 2357
PPC_lxsiwax: int  # 2154
PPC_lxsiwzx: int  # 2156
PPC_lxssp: int  # 2355
PPC_lxsspx: int  # 2155
PPC_lxv: int  # 2358
PPC_lxvb16x: int  # 2359
PPC_lxvd2x: int  # 1005
PPC_lxvdsx: int  # 1006
PPC_lxvh8x: int  # 2360
PPC_lxvkq: int  # 3256
PPC_lxvl: int  # 2361
PPC_lxvll: int  # 2362
PPC_lxvp: int  # 3257
PPC_lxvpx: int  # 3258
PPC_lxvrbx: int  # 3259
PPC_lxvrdx: int  # 3260
PPC_lxvrhx: int  # 3261
PPC_lxvrwx: int  # 3262
PPC_lxvw4x: int  # 1007
PPC_lxvwsx: int  # 2363
PPC_lxvx: int  # 2364
PPC_macchw: int  # 807
PPC_macchws: int  # 808
PPC_macchwsu: int  # 809
PPC_macchwu: int  # 810
PPC_machhw: int  # 811
PPC_machhws: int  # 812
PPC_machhwsu: int  # 813
PPC_machhwu: int  # 814
PPC_maclhw: int  # 815
PPC_maclhws: int  # 816
PPC_maclhwsu: int  # 817
PPC_maclhwu: int  # 818
PPC_maddhd: int  # 2265
PPC_maddhdu: int  # 2266
PPC_maddld: int  # 2267
PPC_maskg: int  # 374
PPC_maskir: int  # 375
PPC_mbar: int  # 745
PPC_mcrf: int  # 122
PPC_mcrfs: int  # 123
PPC_mcrxr: int  # 124
PPC_mcrxrx: int  # 2268
PPC_mdoio: int  # 2214
PPC_mdoom: int  # 2215
PPC_mfar: int  # 1179
PPC_mfbhrbe: int  # 2084
PPC_mfcr: int  # 125
PPC_mfctr: int  # 307
PPC_mfdar: int  # 309
PPC_mfdcr: int  # 354
PPC_mfdcrux: int  # 750
PPC_mfdcrx: int  # 751
PPC_mfdec: int  # 310
PPC_mfdsisr: int  # 308
PPC_mffs: int  # 126
PPC_mffscdrn: int  # 2443
PPC_mffscdrni: int  # 2444
PPC_mffsce: int  # 2442
PPC_mffscrn: int  # 2445
PPC_mffscrni: int  # 2446
PPC_mffsl: int  # 2447
PPC_mfic: int  # 2210
PPC_mflr: int  # 306
PPC_mfmsr: int  # 127
PPC_mfocrf: int  # 403
PPC_mfpmr: int  # 781
PPC_mfppr: int  # 2206
PPC_mfppr32: int  # 2208
PPC_mfpvr: int  # 319
PPC_mfspr: int  # 128
PPC_mfsprg0: int  # 313
PPC_mfsprg1: int  # 314
PPC_mfsprg2: int  # 315
PPC_mfsprg3: int  # 316
PPC_mfsr: int  # 129
PPC_mfsri: int  # 376
PPC_mfsrin: int  # 130
PPC_mfsrr0: int  # 311
PPC_mfsrr1: int  # 312
PPC_mftb: int  # 131
PPC_mftbl: int  # 317
PPC_mftbu: int  # 318
PPC_mftmr: int  # 783
PPC_mfvscr: int  # 855
PPC_mfvsrd: int  # 2086
PPC_mfvsrld: int  # 2274
PPC_mfvsrwz: int  # 2087
PPC_mfvtb: int  # 2212
PPC_mfxer: int  # 305
PPC_miso: int  # 2213
PPC_modsd: int  # 2270
PPC_modsw: int  # 2272
PPC_modud: int  # 2271
PPC_moduw: int  # 2273
PPC_mpure: int  # 2494
PPC_mpusync: int  # 2496
PPC_mpuwe: int  # 2495
PPC_mr: int  # 281
PPC_msgclr: int  # 757
PPC_msgclrp: int  # 2197
PPC_msgclru: int  # 3190
PPC_msgsnd: int  # 758
PPC_msgsndp: int  # 2196
PPC_msgsndu: int  # 3191
PPC_msgsync: int  # 2439
PPC_mtar: int  # 1180
PPC_mtcr: int  # 1208
PPC_mtcrf: int  # 132
PPC_mtctr: int  # 293
PPC_mtdar: int  # 295
PPC_mtdcr: int  # 355
PPC_mtdcrux: int  # 752
PPC_mtdcrx: int  # 753
PPC_mtdec: int  # 296
PPC_mtdsisr: int  # 294
PPC_mtfsb0: int  # 133
PPC_mtfsb1: int  # 134
PPC_mtfsf: int  # 135
PPC_mtfsfi: int  # 136
PPC_mtic: int  # 2209
PPC_mtlr: int  # 292
PPC_mtmsr: int  # 137
PPC_mtmsrd: int  # 138
PPC_mtmsree: int  # 1216
PPC_mtocrf: int  # 402
PPC_mtpmr: int  # 782
PPC_mtppr: int  # 2205
PPC_mtppr32: int  # 2207
PPC_mtsle: int  # 2085
PPC_mtspr: int  # 139
PPC_mtsprg0: int  # 299
PPC_mtsprg1: int  # 300
PPC_mtsprg2: int  # 301
PPC_mtsprg3: int  # 302
PPC_mtsr: int  # 140
PPC_mtsrd: int  # 141
PPC_mtsrdin: int  # 142
PPC_mtsrin: int  # 143
PPC_mtsrr0: int  # 297
PPC_mtsrr1: int  # 298
PPC_mttbl: int  # 303
PPC_mttbu: int  # 304
PPC_mttmr: int  # 784
PPC_mtvscr: int  # 856
PPC_mtvsrbm: int  # 3263
PPC_mtvsrbmi: int  # 3264
PPC_mtvsrd: int  # 2088
PPC_mtvsrdd: int  # 2275
PPC_mtvsrdm: int  # 3265
PPC_mtvsrhm: int  # 3266
PPC_mtvsrqm: int  # 3267
PPC_mtvsrwa: int  # 2089
PPC_mtvsrwm: int  # 3268
PPC_mtvsrws: int  # 2276
PPC_mtvsrwz: int  # 2090
PPC_mtvtb: int  # 2211
PPC_mtxer: int  # 291
PPC_mul: int  # 377
PPC_mulchw: int  # 819
PPC_mulchwu: int  # 820
PPC_mulhd: int  # 144
PPC_mulhdu: int  # 145
PPC_mulhhw: int  # 821
PPC_mulhhwu: int  # 822
PPC_mulhss: int  # 2223
PPC_mulhus: int  # 2225
PPC_mulhw: int  # 146
PPC_mulhwu: int  # 147
PPC_mull2i: int  # 1166
PPC_mulld: int  # 148
PPC_mullhw: int  # 823
PPC_mullhwu: int  # 824
PPC_mulli: int  # 149
PPC_mullw: int  # 150
PPC_mulwss: int  # 2224
PPC_mulwus: int  # 2226
PPC_nabs: int  # 378
PPC_nand: int  # 151
PPC_nap: int  # 839
PPC_neg: int  # 152
PPC_nmacchw: int  # 825
PPC_nmacchws: int  # 826
PPC_nmachhw: int  # 827
PPC_nmachhws: int  # 828
PPC_nmaclhw: int  # 829
PPC_nmaclhws: int  # 830
PPC_nop: int  # 279
PPC_nor: int  # 153
PPC_not: int  # 280
PPC_null: int  # 0
PPC_or: int  # 154
PPC_or2i: int  # 1167
PPC_or2is: int  # 1168
PPC_orc: int  # 155
PPC_ordhwaccel: int  # 2491
PPC_ordhwacceli: int  # 2492
PPC_ori: int  # 156
PPC_oris: int  # 157
PPC_osmcmd: int  # 2493
PPC_paddi: int  # 3193
PPC_paste: int  # 2281
PPC_pdepd: int  # 3269
PPC_pextd: int  # 3270
PPC_plbz: int  # 3194
PPC_pld: int  # 3195
PPC_plfd: int  # 3196
PPC_plfs: int  # 3197
PPC_plha: int  # 3198
PPC_plhz: int  # 3199
PPC_plq: int  # 3200
PPC_plwa: int  # 3201
PPC_plwz: int  # 3202
PPC_plxsd: int  # 3203
PPC_plxssp: int  # 3204
PPC_plxv: int  # 3205
PPC_plxvp: int  # 3206
PPC_pmxvbf16ger2: int  # 3207
PPC_pmxvbf16ger2nn: int  # 3208
PPC_pmxvbf16ger2np: int  # 3209
PPC_pmxvbf16ger2pn: int  # 3210
PPC_pmxvbf16ger2pp: int  # 3211
PPC_pmxvf16ger2: int  # 3212
PPC_pmxvf16ger2nn: int  # 3213
PPC_pmxvf16ger2np: int  # 3214
PPC_pmxvf16ger2pn: int  # 3215
PPC_pmxvf16ger2pp: int  # 3216
PPC_pmxvf32ger: int  # 3217
PPC_pmxvf32gernn: int  # 3218
PPC_pmxvf32gernp: int  # 3219
PPC_pmxvf32gerpn: int  # 3220
PPC_pmxvf32gerpp: int  # 3221
PPC_pmxvf64ger: int  # 3222
PPC_pmxvf64gernn: int  # 3223
PPC_pmxvf64gernp: int  # 3224
PPC_pmxvf64gerpn: int  # 3225
PPC_pmxvf64gerpp: int  # 3226
PPC_pmxvi16ger2: int  # 3227
PPC_pmxvi16ger2pp: int  # 3228
PPC_pmxvi16ger2s: int  # 3229
PPC_pmxvi16ger2spp: int  # 3230
PPC_pmxvi4ger8: int  # 3231
PPC_pmxvi4ger8pp: int  # 3232
PPC_pmxvi8ger4: int  # 3233
PPC_pmxvi8ger4pp: int  # 3234
PPC_pmxvi8ger4spp: int  # 3235
PPC_pnop: int  # 3236
PPC_popcntb: int  # 379
PPC_popcntd: int  # 676
PPC_popcntw: int  # 677
PPC_prtyd: int  # 669
PPC_prtyw: int  # 678
PPC_ps_abs: int  # 1257
PPC_ps_add: int  # 1240
PPC_ps_cmpo0: int  # 1249
PPC_ps_cmpo1: int  # 1255
PPC_ps_cmpu0: int  # 1229
PPC_ps_cmpu1: int  # 1253
PPC_ps_div: int  # 1238
PPC_ps_madd: int  # 1246
PPC_ps_madds0: int  # 1236
PPC_ps_madds1: int  # 1237
PPC_ps_merge00: int  # 1258
PPC_ps_merge01: int  # 1259
PPC_ps_merge10: int  # 1260
PPC_ps_merge11: int  # 1261
PPC_ps_mr: int  # 1254
PPC_ps_msub: int  # 1245
PPC_ps_mul: int  # 1243
PPC_ps_muls0: int  # 1234
PPC_ps_muls1: int  # 1235
PPC_ps_nabs: int  # 1256
PPC_ps_neg: int  # 1252
PPC_ps_nmadd: int  # 1248
PPC_ps_nmsub: int  # 1247
PPC_ps_res: int  # 1242
PPC_ps_rsqrte: int  # 1244
PPC_ps_sel: int  # 1241
PPC_ps_sub: int  # 1239
PPC_ps_sum0: int  # 1232
PPC_ps_sum1: int  # 1233
PPC_psq_l: int  # 1263
PPC_psq_lu: int  # 1264
PPC_psq_lux: int  # 1250
PPC_psq_lx: int  # 1230
PPC_psq_st: int  # 1265
PPC_psq_stu: int  # 1266
PPC_psq_stux: int  # 1251
PPC_psq_stx: int  # 1231
PPC_pstb: int  # 3237
PPC_pstd: int  # 3238
PPC_pstfd: int  # 3239
PPC_pstfs: int  # 3240
PPC_psth: int  # 3241
PPC_pstq: int  # 3242
PPC_pstw: int  # 3243
PPC_pstxsd: int  # 3244
PPC_pstxssp: int  # 3245
PPC_pstxv: int  # 3246
PPC_pstxvp: int  # 3247
PPC_ptesync: int  # 1203
PPC_rac: int  # 380
PPC_rfci: int  # 356
PPC_rfdi: int  # 414
PPC_rfebb: int  # 2193
PPC_rfgi: int  # 756
PPC_rfi: int  # 158
PPC_rfid: int  # 159
PPC_rfmci: int  # 746
PPC_rfscv: int  # 2278
PPC_rfsvc: int  # 381
PPC_rldcl: int  # 160
PPC_rldcr: int  # 161
PPC_rldic: int  # 162
PPC_rldicl: int  # 163
PPC_rldicr: int  # 164
PPC_rldimi: int  # 165
PPC_rlmi: int  # 382
PPC_rlw: int  # 1169
PPC_rlwi: int  # 1170
PPC_rlwimi: int  # 166
PPC_rlwinm: int  # 167
PPC_rlwnm: int  # 168
PPC_rotld: int  # 1190
PPC_rotldi: int  # 1188
PPC_rotlw: int  # 343
PPC_rotlwi: int  # 341
PPC_rotrdi: int  # 1189
PPC_rotrwi: int  # 342
PPC_rrib: int  # 383
PPC_rvwinkle: int  # 840
PPC_sat: int  # 2227
PPC_satsbs: int  # 2234
PPC_satsbu: int  # 2236
PPC_satshs: int  # 2240
PPC_satshu: int  # 2242
PPC_satsws: int  # 2246
PPC_satswu: int  # 2248
PPC_satubs: int  # 2235
PPC_satubu: int  # 2237
PPC_satuhs: int  # 2241
PPC_satuhu: int  # 2243
PPC_satuws: int  # 2247
PPC_satuwu: int  # 2249
PPC_sc: int  # 169
PPC_scv: int  # 2277
PPC_setb: int  # 2269
PPC_setbc: int  # 3271
PPC_setbcr: int  # 3272
PPC_setnbc: int  # 3273
PPC_setnbcr: int  # 3274
PPC_slbfee: int  # 841
PPC_slbia: int  # 170
PPC_slbiag: int  # 2254
PPC_slbie: int  # 171
PPC_slbieg: int  # 2253
PPC_slbmfee: int  # 384
PPC_slbmfev: int  # 385
PPC_slbmte: int  # 386
PPC_slbsync: int  # 2255
PPC_sld: int  # 172
PPC_sldi: int  # 1191
PPC_sle: int  # 387
PPC_sleep: int  # 842
PPC_sleq: int  # 388
PPC_sliq: int  # 389
PPC_slliq: int  # 390
PPC_sllq: int  # 391
PPC_slq: int  # 392
PPC_slw: int  # 173
PPC_slwi: int  # 344
PPC_srad: int  # 174
PPC_sradi: int  # 175
PPC_sraiq: int  # 393
PPC_sraq: int  # 394
PPC_sraw: int  # 176
PPC_srawi: int  # 177
PPC_srd: int  # 178
PPC_srdi: int  # 1192
PPC_sre: int  # 395
PPC_srea: int  # 396
PPC_sreq: int  # 397
PPC_sriq: int  # 398
PPC_srliq: int  # 399
PPC_srlq: int  # 400
PPC_srq: int  # 401
PPC_srw: int  # 179
PPC_srwi: int  # 345
PPC_stb: int  # 180
PPC_stbcix: int  # 843
PPC_stbcx: int  # 679
PPC_stbdcbx: int  # 2451
PPC_stbdx: int  # 740
PPC_stbepx: int  # 773
PPC_stbu: int  # 181
PPC_stbux: int  # 182
PPC_stbwtx: int  # 2457
PPC_stbx: int  # 183
PPC_std: int  # 184
PPC_stdat: int  # 2284
PPC_stdbrw: int  # 2469
PPC_stdbrx: int  # 670
PPC_stdcix: int  # 844
PPC_stdcx: int  # 185
PPC_stddx: int  # 741
PPC_stdepx: int  # 780
PPC_stdu: int  # 186
PPC_stdux: int  # 187
PPC_stdw: int  # 2462
PPC_stdwbrw: int  # 2470
PPC_stdwc: int  # 2478
PPC_stdwwt: int  # 2468
PPC_stdx: int  # 188
PPC_stfd: int  # 189
PPC_stfddx: int  # 742
PPC_stfdepx: int  # 774
PPC_stfdp: int  # 799
PPC_stfdpx: int  # 800
PPC_stfdu: int  # 190
PPC_stfdux: int  # 191
PPC_stfdx: int  # 192
PPC_stfiwx: int  # 193
PPC_stfs: int  # 194
PPC_stfsu: int  # 195
PPC_stfsux: int  # 196
PPC_stfsx: int  # 197
PPC_sth: int  # 198
PPC_sthbr: int  # 2476
PPC_sthbrx: int  # 199
PPC_sthcix: int  # 845
PPC_sthcx: int  # 680
PPC_sthdcbx: int  # 2452
PPC_sthdx: int  # 743
PPC_sthepx: int  # 775
PPC_sthu: int  # 200
PPC_sthux: int  # 201
PPC_sthwtx: int  # 2458
PPC_sthx: int  # 202
PPC_stmvcsrrw: int  # 1305
PPC_stmvdsrrw: int  # 1307
PPC_stmvgprw: int  # 1299
PPC_stmvmcsrrw: int  # 1309
PPC_stmvsprw: int  # 1301
PPC_stmvsrrw: int  # 1303
PPC_stmw: int  # 203
PPC_stop: int  # 2279
PPC_stq: int  # 833
PPC_stqcx: int  # 2183
PPC_stqdbrw: int  # 2472
PPC_stqw: int  # 2464
PPC_stswi: int  # 204
PPC_stswx: int  # 205
PPC_stvebx: int  # 857
PPC_stvehx: int  # 858
PPC_stvepx: int  # 776
PPC_stvepxl: int  # 777
PPC_stvewx: int  # 859
PPC_stvlx: int  # 1151
PPC_stvlxl: int  # 1152
PPC_stvrx: int  # 1153
PPC_stvrxl: int  # 1154
PPC_stvx: int  # 860
PPC_stvxl: int  # 861
PPC_stw: int  # 206
PPC_stwat: int  # 2285
PPC_stwbr: int  # 2475
PPC_stwbrx: int  # 207
PPC_stwcix: int  # 846
PPC_stwcx: int  # 208
PPC_stwdcbx: int  # 2453
PPC_stwdx: int  # 744
PPC_stwepx: int  # 778
PPC_stwu: int  # 209
PPC_stwux: int  # 210
PPC_stwwtx: int  # 2459
PPC_stwx: int  # 211
PPC_stxsd: int  # 2365
PPC_stxsdx: int  # 1008
PPC_stxsibx: int  # 2366
PPC_stxsihx: int  # 2367
PPC_stxsiwx: int  # 2157
PPC_stxssp: int  # 2368
PPC_stxsspx: int  # 2158
PPC_stxv: int  # 2369
PPC_stxvb16x: int  # 2370
PPC_stxvd2x: int  # 1009
PPC_stxvh8x: int  # 2371
PPC_stxvl: int  # 2372
PPC_stxvll: int  # 2373
PPC_stxvp: int  # 3275
PPC_stxvpx: int  # 3276
PPC_stxvrbx: int  # 3277
PPC_stxvrdx: int  # 3278
PPC_stxvrhx: int  # 3279
PPC_stxvrwx: int  # 3280
PPC_stxvw4x: int  # 1010
PPC_stxvx: int  # 2374
PPC_sub: int  # 1181
PPC_sub16i: int  # 1182
PPC_sub2i: int  # 1183
PPC_sub2is: int  # 1184
PPC_subf: int  # 212
PPC_subfb: int  # 2483
PPC_subfbss: int  # 2228
PPC_subfbu: int  # 2484
PPC_subfbus: int  # 2231
PPC_subfc: int  # 213
PPC_subfe: int  # 214
PPC_subfh: int  # 2485
PPC_subfhss: int  # 2229
PPC_subfhu: int  # 2486
PPC_subfhus: int  # 2232
PPC_subfic: int  # 215
PPC_subfme: int  # 216
PPC_subfwss: int  # 2230
PPC_subfwus: int  # 2233
PPC_subfze: int  # 217
PPC_subi: int  # 282
PPC_subic: int  # 283
PPC_subis: int  # 284
PPC_subpcis: int  # 2258
PPC_sync: int  # 218
PPC_tabort: int  # 2186
PPC_tabortdc: int  # 2189
PPC_tabortdci: int  # 2190
PPC_tabortwc: int  # 2187
PPC_tabortwci: int  # 2188
PPC_tbegin: int  # 2184
PPC_tcheck: int  # 2192
PPC_td: int  # 219
PPC_tdeq: int  # 261
PPC_tdeqi: int  # 271
PPC_tdge: int  # 265
PPC_tdgei: int  # 275
PPC_tdgt: int  # 264
PPC_tdgti: int  # 274
PPC_tdi: int  # 220
PPC_tdle: int  # 267
PPC_tdlei: int  # 277
PPC_tdlge: int  # 262
PPC_tdlgei: int  # 272
PPC_tdlgt: int  # 259
PPC_tdlgti: int  # 269
PPC_tdlle: int  # 263
PPC_tdllei: int  # 273
PPC_tdllt: int  # 260
PPC_tdllti: int  # 270
PPC_tdlt: int  # 266
PPC_tdlti: int  # 276
PPC_tdne: int  # 268
PPC_tdnei: int  # 278
PPC_tdu: int  # 2079
PPC_tdui: int  # 2078
PPC_tend: int  # 2185
PPC_tendall: int  # 2202
PPC_tlbia: int  # 221
PPC_tlbie: int  # 222
PPC_tlbiel: int  # 847
PPC_tlbilx: int  # 747
PPC_tlbivax: int  # 413
PPC_tlbld: int  # 415
PPC_tlbli: int  # 416
PPC_tlbre: int  # 357
PPC_tlbsrx: int  # 785
PPC_tlbsx: int  # 358
PPC_tlbsync: int  # 223
PPC_tlbwe: int  # 359
PPC_trap: int  # 237
PPC_trapd: int  # 238
PPC_trechkpt: int  # 2195
PPC_treclaim: int  # 2194
PPC_tresume: int  # 2204
PPC_tsr: int  # 2191
PPC_tsuspend: int  # 2203
PPC_tw: int  # 224
PPC_tweq: int  # 241
PPC_tweqi: int  # 251
PPC_twge: int  # 245
PPC_twgei: int  # 255
PPC_twgt: int  # 244
PPC_twgti: int  # 254
PPC_twi: int  # 225
PPC_twle: int  # 247
PPC_twlei: int  # 257
PPC_twlge: int  # 242
PPC_twlgei: int  # 252
PPC_twlgt: int  # 239
PPC_twlgti: int  # 249
PPC_twlle: int  # 243
PPC_twllei: int  # 253
PPC_twllt: int  # 240
PPC_twllti: int  # 250
PPC_twlt: int  # 246
PPC_twlti: int  # 256
PPC_twne: int  # 248
PPC_twnei: int  # 258
PPC_twu: int  # 2081
PPC_twui: int  # 2080
PPC_urfid: int  # 3192
PPC_vabsdub: int  # 2303
PPC_vabsduh: int  # 2304
PPC_vabsduw: int  # 2305
PPC_vaddcuq: int  # 2104
PPC_vaddcuw: int  # 862
PPC_vaddecuq: int  # 2105
PPC_vaddeuqm: int  # 2103
PPC_vaddfp: int  # 863
PPC_vaddsbs: int  # 864
PPC_vaddshs: int  # 865
PPC_vaddsws: int  # 866
PPC_vaddubm: int  # 867
PPC_vaddubs: int  # 868
PPC_vaddudm: int  # 2101
PPC_vadduhm: int  # 869
PPC_vadduhs: int  # 870
PPC_vadduqm: int  # 2102
PPC_vadduwm: int  # 871
PPC_vadduws: int  # 872
PPC_vand: int  # 873
PPC_vandc: int  # 874
PPC_vavgsb: int  # 875
PPC_vavgsh: int  # 876
PPC_vavgsw: int  # 877
PPC_vavgub: int  # 878
PPC_vavguh: int  # 879
PPC_vavguw: int  # 880
PPC_vbpermd: int  # 2306
PPC_vbpermq: int  # 2151
PPC_vcfpsxws: int  # 1217
PPC_vcfpuxws: int  # 1218
PPC_vcfsx: int  # 881
PPC_vcfuged: int  # 3281
PPC_vcfux: int  # 882
PPC_vcipher: int  # 2130
PPC_vcipherlast: int  # 2131
PPC_vclrlb: int  # 3282
PPC_vclrrb: int  # 3283
PPC_vclzb: int  # 2143
PPC_vclzd: int  # 2146
PPC_vclzdm: int  # 3284
PPC_vclzh: int  # 2144
PPC_vclzlsbb: int  # 2307
PPC_vclzw: int  # 2145
PPC_vcmpbfp: int  # 883
PPC_vcmpeqfp: int  # 884
PPC_vcmpequb: int  # 885
PPC_vcmpequd: int  # 2120
PPC_vcmpequh: int  # 886
PPC_vcmpequq: int  # 3285
PPC_vcmpequw: int  # 887
PPC_vcmpgefp: int  # 888
PPC_vcmpgtfp: int  # 889
PPC_vcmpgtsb: int  # 890
PPC_vcmpgtsd: int  # 2121
PPC_vcmpgtsh: int  # 891
PPC_vcmpgtsq: int  # 3286
PPC_vcmpgtsw: int  # 892
PPC_vcmpgtub: int  # 893
PPC_vcmpgtud: int  # 2122
PPC_vcmpgtuh: int  # 894
PPC_vcmpgtuq: int  # 3287
PPC_vcmpgtuw: int  # 895
PPC_vcmpneb: int  # 2309
PPC_vcmpneh: int  # 2311
PPC_vcmpnew: int  # 2313
PPC_vcmpnezb: int  # 2310
PPC_vcmpnezh: int  # 2312
PPC_vcmpnezw: int  # 2314
PPC_vcmpsq: int  # 3288
PPC_vcmpuq: int  # 3289
PPC_vcntmbb: int  # 3290
PPC_vcntmbd: int  # 3291
PPC_vcntmbh: int  # 3292
PPC_vcntmbw: int  # 3293
PPC_vcsxwfp: int  # 1219
PPC_vctsxs: int  # 896
PPC_vctuxs: int  # 897
PPC_vctzb: int  # 2315
PPC_vctzd: int  # 2318
PPC_vctzdm: int  # 3294
PPC_vctzh: int  # 2316
PPC_vctzlsbb: int  # 2308
PPC_vctzw: int  # 2317
PPC_vcuxwfp: int  # 1220
PPC_vdivesd: int  # 3295
PPC_vdivesq: int  # 3296
PPC_vdivesw: int  # 3297
PPC_vdiveud: int  # 3298
PPC_vdiveuq: int  # 3299
PPC_vdiveuw: int  # 3300
PPC_vdivsd: int  # 3301
PPC_vdivsq: int  # 3302
PPC_vdivsw: int  # 3303
PPC_vdivud: int  # 3304
PPC_vdivuq: int  # 3305
PPC_vdivuw: int  # 3306
PPC_veqv: int  # 2123
PPC_vexpandbm: int  # 3307
PPC_vexpanddm: int  # 3308
PPC_vexpandhm: int  # 3309
PPC_vexpandqm: int  # 3310
PPC_vexpandwm: int  # 3311
PPC_vexptefp: int  # 898
PPC_vextddvlx: int  # 3312
PPC_vextddvrx: int  # 3313
PPC_vextdubvlx: int  # 3314
PPC_vextdubvrx: int  # 3315
PPC_vextduhvlx: int  # 3316
PPC_vextduhvrx: int  # 3317
PPC_vextduwvlx: int  # 3318
PPC_vextduwvrx: int  # 3319
PPC_vextractbm: int  # 3320
PPC_vextractd: int  # 2322
PPC_vextractdm: int  # 3321
PPC_vextracthm: int  # 3322
PPC_vextractqm: int  # 3323
PPC_vextractub: int  # 2319
PPC_vextractuh: int  # 2320
PPC_vextractuw: int  # 2321
PPC_vextractwm: int  # 3324
PPC_vextsb2d: int  # 2324
PPC_vextsb2w: int  # 2323
PPC_vextsd2q: int  # 3325
PPC_vextsh2d: int  # 2326
PPC_vextsh2w: int  # 2325
PPC_vextsw2d: int  # 2327
PPC_vextublx: int  # 2328
PPC_vextubrx: int  # 2329
PPC_vextuhlx: int  # 2330
PPC_vextuhrx: int  # 2331
PPC_vextuwlx: int  # 2332
PPC_vextuwrx: int  # 2333
PPC_vgbbd: int  # 2142
PPC_vgnb: int  # 3326
PPC_vinsblx: int  # 3327
PPC_vinsbrx: int  # 3328
PPC_vinsbvlx: int  # 3329
PPC_vinsbvrx: int  # 3330
PPC_vinsd: int  # 3331
PPC_vinsdlx: int  # 3332
PPC_vinsdrx: int  # 3333
PPC_vinsertb: int  # 2334
PPC_vinsertd: int  # 2337
PPC_vinserth: int  # 2335
PPC_vinsertw: int  # 2336
PPC_vinshlx: int  # 3334
PPC_vinshrx: int  # 3335
PPC_vinshvlx: int  # 3336
PPC_vinshvrx: int  # 3337
PPC_vinsw: int  # 3338
PPC_vinswlx: int  # 3339
PPC_vinswrx: int  # 3340
PPC_vinswvlx: int  # 3341
PPC_vinswvrx: int  # 3342
PPC_vlogefp: int  # 899
PPC_vmaddcfp: int  # 1221
PPC_vmaddfp: int  # 900
PPC_vmaxfp: int  # 901
PPC_vmaxsb: int  # 902
PPC_vmaxsd: int  # 2116
PPC_vmaxsh: int  # 903
PPC_vmaxsw: int  # 904
PPC_vmaxub: int  # 905
PPC_vmaxud: int  # 2117
PPC_vmaxuh: int  # 906
PPC_vmaxuw: int  # 907
PPC_vmhaddshs: int  # 908
PPC_vmhraddshs: int  # 909
PPC_vminfp: int  # 910
PPC_vminsb: int  # 911
PPC_vminsd: int  # 2118
PPC_vminsh: int  # 912
PPC_vminsw: int  # 913
PPC_vminub: int  # 914
PPC_vminud: int  # 2119
PPC_vminuh: int  # 915
PPC_vminuw: int  # 916
PPC_vmladduhm: int  # 917
PPC_vmodsd: int  # 3343
PPC_vmodsq: int  # 3344
PPC_vmodsw: int  # 3345
PPC_vmodud: int  # 3346
PPC_vmoduq: int  # 3347
PPC_vmoduw: int  # 3348
PPC_vmr: int  # 2200
PPC_vmrgew: int  # 2099
PPC_vmrghb: int  # 918
PPC_vmrghh: int  # 919
PPC_vmrghw: int  # 920
PPC_vmrglb: int  # 921
PPC_vmrglh: int  # 922
PPC_vmrglw: int  # 923
PPC_vmrgow: int  # 2100
PPC_vmsum3fp: int  # 1222
PPC_vmsum4fp: int  # 1223
PPC_vmsumcud: int  # 3349
PPC_vmsummbm: int  # 924
PPC_vmsumshm: int  # 925
PPC_vmsumshs: int  # 926
PPC_vmsumubm: int  # 927
PPC_vmsumudm: int  # 2441
PPC_vmsumuhm: int  # 928
PPC_vmsumuhs: int  # 929
PPC_vmul10cuq: int  # 2340
PPC_vmul10ecuq: int  # 2341
PPC_vmul10euq: int  # 2339
PPC_vmul10uq: int  # 2338
PPC_vmulesb: int  # 930
PPC_vmulesd: int  # 3350
PPC_vmulesh: int  # 931
PPC_vmulesw: int  # 2111
PPC_vmuleub: int  # 932
PPC_vmuleud: int  # 3351
PPC_vmuleuh: int  # 933
PPC_vmuleuw: int  # 2112
PPC_vmulfp: int  # 1224
PPC_vmulhsd: int  # 3352
PPC_vmulhsw: int  # 3353
PPC_vmulhud: int  # 3354
PPC_vmulhuw: int  # 3355
PPC_vmulld: int  # 3356
PPC_vmulosb: int  # 934
PPC_vmulosd: int  # 3357
PPC_vmulosh: int  # 935
PPC_vmulosw: int  # 2113
PPC_vmuloub: int  # 936
PPC_vmuloud: int  # 3358
PPC_vmulouh: int  # 937
PPC_vmulouw: int  # 2114
PPC_vmuluwm: int  # 2115
PPC_vnand: int  # 2124
PPC_vncipher: int  # 2132
PPC_vncipherlast: int  # 2133
PPC_vnegd: int  # 2343
PPC_vnegw: int  # 2342
PPC_vnmsubfp: int  # 938
PPC_vnor: int  # 939
PPC_vnot: int  # 2201
PPC_vor: int  # 940
PPC_vorc: int  # 2125
PPC_vpdepd: int  # 3359
PPC_vperm: int  # 941
PPC_vpermr: int  # 2344
PPC_vpermwi: int  # 1225
PPC_vpermxor: int  # 2141
PPC_vpextd: int  # 3360
PPC_vpkd3d: int  # 1226
PPC_vpkpx: int  # 942
PPC_vpksdss: int  # 2093
PPC_vpksdus: int  # 2094
PPC_vpkshss: int  # 943
PPC_vpkshus: int  # 944
PPC_vpkswss: int  # 945
PPC_vpkswus: int  # 946
PPC_vpkudum: int  # 2096
PPC_vpkudus: int  # 2095
PPC_vpkuhum: int  # 947
PPC_vpkuhus: int  # 948
PPC_vpkuwum: int  # 949
PPC_vpkuwus: int  # 950
PPC_vpmsumb: int  # 2137
PPC_vpmsumd: int  # 2138
PPC_vpmsumh: int  # 2139
PPC_vpmsumw: int  # 2140
PPC_vpopcntb: int  # 2147
PPC_vpopcntd: int  # 2148
PPC_vpopcnth: int  # 2149
PPC_vpopcntw: int  # 2150
PPC_vprtybd: int  # 2346
PPC_vprtybq: int  # 2347
PPC_vprtybw: int  # 2345
PPC_vrefp: int  # 951
PPC_vrfim: int  # 952
PPC_vrfin: int  # 953
PPC_vrfip: int  # 954
PPC_vrfiz: int  # 955
PPC_vrlb: int  # 956
PPC_vrld: int  # 2126
PPC_vrldmi: int  # 2351
PPC_vrldnm: int  # 2350
PPC_vrlh: int  # 957
PPC_vrlimi: int  # 1227
PPC_vrlq: int  # 3361
PPC_vrlqmi: int  # 3362
PPC_vrlqnm: int  # 3363
PPC_vrlw: int  # 958
PPC_vrlwmi: int  # 2349
PPC_vrlwnm: int  # 2348
PPC_vrsqrtefp: int  # 959
PPC_vsbox: int  # 2134
PPC_vsel: int  # 960
PPC_vshasigmad: int  # 2135
PPC_vshasigmaw: int  # 2136
PPC_vsl: int  # 961
PPC_vslb: int  # 962
PPC_vsld: int  # 2127
PPC_vsldbi: int  # 3364
PPC_vsldoi: int  # 963
PPC_vslh: int  # 964
PPC_vslo: int  # 965
PPC_vslq: int  # 3365
PPC_vslv: int  # 2352
PPC_vslw: int  # 966
PPC_vspltb: int  # 967
PPC_vsplth: int  # 968
PPC_vspltisb: int  # 969
PPC_vspltish: int  # 970
PPC_vspltisw: int  # 971
PPC_vspltw: int  # 972
PPC_vsr: int  # 973
PPC_vsrab: int  # 974
PPC_vsrad: int  # 2129
PPC_vsrah: int  # 975
PPC_vsraq: int  # 3366
PPC_vsraw: int  # 976
PPC_vsrb: int  # 977
PPC_vsrd: int  # 2128
PPC_vsrdbi: int  # 3367
PPC_vsrh: int  # 978
PPC_vsro: int  # 979
PPC_vsrq: int  # 3368
PPC_vsrv: int  # 2353
PPC_vsrw: int  # 980
PPC_vstribl: int  # 3369
PPC_vstribr: int  # 3370
PPC_vstrihl: int  # 3371
PPC_vstrihr: int  # 3372
PPC_vsubcuq: int  # 2109
PPC_vsubcuw: int  # 981
PPC_vsubecuq: int  # 2110
PPC_vsubeuqm: int  # 2108
PPC_vsubfp: int  # 982
PPC_vsubsbs: int  # 983
PPC_vsubshs: int  # 984
PPC_vsubsws: int  # 985
PPC_vsububm: int  # 986
PPC_vsububs: int  # 987
PPC_vsubudm: int  # 2106
PPC_vsubuhm: int  # 988
PPC_vsubuhs: int  # 989
PPC_vsubuqm: int  # 2107
PPC_vsubuwm: int  # 990
PPC_vsubuws: int  # 991
PPC_vsum2sws: int  # 992
PPC_vsum4sbs: int  # 993
PPC_vsum4shs: int  # 994
PPC_vsum4ubs: int  # 995
PPC_vsumsws: int  # 996
PPC_vupkd3d: int  # 1228
PPC_vupkhpx: int  # 997
PPC_vupkhsb: int  # 998
PPC_vupkhsh: int  # 999
PPC_vupkhsw: int  # 2097
PPC_vupklpx: int  # 1000
PPC_vupklsb: int  # 1001
PPC_vupklsh: int  # 1002
PPC_vupklsw: int  # 2098
PPC_vxor: int  # 1003
PPC_wait: int  # 1140
PPC_wait30: int  # 2287
PPC_waitimpl: int  # 1205
PPC_waitrsv: int  # 1204
PPC_wrtee: int  # 360
PPC_wrteei: int  # 361
PPC_xnop: int  # 1196
PPC_xor: int  # 226
PPC_xori: int  # 227
PPC_xoris: int  # 228
PPC_xsabsdp: int  # 1011
PPC_xsabsqp: int  # 2375
PPC_xsadddp: int  # 1012
PPC_xsaddqp: int  # 2376
PPC_xsaddsp: int  # 2159
PPC_xscmpeqdp: int  # 2405
PPC_xscmpeqqp: int  # 3373
PPC_xscmpexpdp: int  # 2406
PPC_xscmpexpqp: int  # 2377
PPC_xscmpgedp: int  # 2407
PPC_xscmpgeqp: int  # 3374
PPC_xscmpgtdp: int  # 2408
PPC_xscmpgtqp: int  # 3375
PPC_xscmpodp: int  # 1013
PPC_xscmpoqp: int  # 2378
PPC_xscmpudp: int  # 1014
PPC_xscmpuqp: int  # 2379
PPC_xscpsgndp: int  # 1015
PPC_xscpsgnqp: int  # 2380
PPC_xscvdphp: int  # 2427
PPC_xscvdpqp: int  # 2381
PPC_xscvdpsp: int  # 1016
PPC_xscvdpspn: int  # 2160
PPC_xscvdpsxds: int  # 1017
PPC_xscvdpsxws: int  # 1018
PPC_xscvdpuxds: int  # 1019
PPC_xscvdpuxws: int  # 1020
PPC_xscvhpdp: int  # 2428
PPC_xscvqpdp: int  # 2382
PPC_xscvqpsdz: int  # 2383
PPC_xscvqpsqz: int  # 3376
PPC_xscvqpswz: int  # 2384
PPC_xscvqpudz: int  # 2385
PPC_xscvqpuqz: int  # 3377
PPC_xscvqpuwz: int  # 2386
PPC_xscvsdqp: int  # 2387
PPC_xscvspdp: int  # 1021
PPC_xscvspdpn: int  # 2161
PPC_xscvsqqp: int  # 3378
PPC_xscvsxddp: int  # 1022
PPC_xscvsxdsp: int  # 2162
PPC_xscvudqp: int  # 2388
PPC_xscvuqqp: int  # 3379
PPC_xscvuxddp: int  # 1023
PPC_xscvuxdsp: int  # 2163
PPC_xsdivdp: int  # 1024
PPC_xsdivqp: int  # 2389
PPC_xsdivsp: int  # 2164
PPC_xsiexpdp: int  # 2409
PPC_xsiexpqp: int  # 2390
PPC_xsmaddadp: int  # 1025
PPC_xsmaddasp: int  # 2165
PPC_xsmaddmdp: int  # 1026
PPC_xsmaddmsp: int  # 2166
PPC_xsmaddqp: int  # 2391
PPC_xsmaxcdp: int  # 2410
PPC_xsmaxcqp: int  # 3380
PPC_xsmaxdp: int  # 1027
PPC_xsmaxjdp: int  # 2411
PPC_xsmincdp: int  # 2412
PPC_xsmincqp: int  # 3381
PPC_xsmindp: int  # 1028
PPC_xsminjdp: int  # 2413
PPC_xsmsubadp: int  # 1029
PPC_xsmsubasp: int  # 2167
PPC_xsmsubmdp: int  # 1030
PPC_xsmsubmsp: int  # 2168
PPC_xsmsubqp: int  # 2392
PPC_xsmuldp: int  # 1031
PPC_xsmulqp: int  # 2393
PPC_xsmulsp: int  # 2169
PPC_xsnabsdp: int  # 1032
PPC_xsnabsqp: int  # 2394
PPC_xsnegdp: int  # 1033
PPC_xsnegqp: int  # 2395
PPC_xsnmaddadp: int  # 1034
PPC_xsnmaddasp: int  # 2170
PPC_xsnmaddmdp: int  # 1035
PPC_xsnmaddmsp: int  # 2171
PPC_xsnmaddqp: int  # 2396
PPC_xsnmsubadp: int  # 1036
PPC_xsnmsubasp: int  # 2172
PPC_xsnmsubmdp: int  # 1037
PPC_xsnmsubmsp: int  # 2173
PPC_xsnmsubqp: int  # 2397
PPC_xsrdpi: int  # 1038
PPC_xsrdpic: int  # 1039
PPC_xsrdpim: int  # 1040
PPC_xsrdpip: int  # 1041
PPC_xsrdpiz: int  # 1042
PPC_xsredp: int  # 1043
PPC_xsresp: int  # 2174
PPC_xsrqpi: int  # 2404
PPC_xsrqpxp: int  # 2403
PPC_xsrsp: int  # 2175
PPC_xsrsqrtedp: int  # 1044
PPC_xsrsqrtesp: int  # 2176
PPC_xssqrtdp: int  # 1045
PPC_xssqrtqp: int  # 2398
PPC_xssqrtsp: int  # 2177
PPC_xssubdp: int  # 1046
PPC_xssubqp: int  # 2399
PPC_xssubsp: int  # 2178
PPC_xstdivdp: int  # 1047
PPC_xstsqrtdp: int  # 1048
PPC_xststdcdp: int  # 2421
PPC_xststdcqp: int  # 2402
PPC_xststdcsp: int  # 2422
PPC_xsxexpdp: int  # 2425
PPC_xsxexpqp: int  # 2400
PPC_xsxsigdp: int  # 2426
PPC_xsxsigqp: int  # 2401
PPC_xvabsdp: int  # 1049
PPC_xvabssp: int  # 1050
PPC_xvadddp: int  # 1051
PPC_xvaddsp: int  # 1052
PPC_xvbf16ger2: int  # 3382
PPC_xvbf16ger2nn: int  # 3383
PPC_xvbf16ger2np: int  # 3384
PPC_xvbf16ger2pn: int  # 3385
PPC_xvbf16ger2pp: int  # 3386
PPC_xvcmpeqdp: int  # 1053
PPC_xvcmpeqsp: int  # 1054
PPC_xvcmpgedp: int  # 1055
PPC_xvcmpgesp: int  # 1056
PPC_xvcmpgtdp: int  # 1057
PPC_xvcmpgtsp: int  # 1058
PPC_xvcpsgndp: int  # 1059
PPC_xvcpsgnsp: int  # 1060
PPC_xvcvbf16spn: int  # 3387
PPC_xvcvdpsp: int  # 1061
PPC_xvcvdpsxds: int  # 1062
PPC_xvcvdpsxws: int  # 1063
PPC_xvcvdpuxds: int  # 1064
PPC_xvcvdpuxws: int  # 1065
PPC_xvcvhpsp: int  # 2437
PPC_xvcvspbf16: int  # 3388
PPC_xvcvspdp: int  # 1066
PPC_xvcvsphp: int  # 2438
PPC_xvcvspsxds: int  # 1067
PPC_xvcvspsxws: int  # 1068
PPC_xvcvspuxds: int  # 1069
PPC_xvcvspuxws: int  # 1070
PPC_xvcvsxddp: int  # 1071
PPC_xvcvsxdsp: int  # 1072
PPC_xvcvsxwdp: int  # 1073
PPC_xvcvsxwsp: int  # 1074
PPC_xvcvuxddp: int  # 1075
PPC_xvcvuxdsp: int  # 1076
PPC_xvcvuxwdp: int  # 1077
PPC_xvcvuxwsp: int  # 1078
PPC_xvdivdp: int  # 1079
PPC_xvdivsp: int  # 1080
PPC_xvf16ger2: int  # 3389
PPC_xvf16ger2nn: int  # 3390
PPC_xvf16ger2np: int  # 3391
PPC_xvf16ger2pn: int  # 3392
PPC_xvf16ger2pp: int  # 3393
PPC_xvf32ger: int  # 3394
PPC_xvf32gernn: int  # 3395
PPC_xvf32gernp: int  # 3396
PPC_xvf32gerpn: int  # 3397
PPC_xvf32gerpp: int  # 3398
PPC_xvf64ger: int  # 3399
PPC_xvf64gernn: int  # 3400
PPC_xvf64gernp: int  # 3401
PPC_xvf64gerpn: int  # 3402
PPC_xvf64gerpp: int  # 3403
PPC_xvi16ger2: int  # 3404
PPC_xvi16ger2pp: int  # 3405
PPC_xvi16ger2s: int  # 3406
PPC_xvi16ger2spp: int  # 3407
PPC_xvi4ger8: int  # 3408
PPC_xvi4ger8pp: int  # 3409
PPC_xvi8ger4: int  # 3410
PPC_xvi8ger4pp: int  # 3411
PPC_xvi8ger4spp: int  # 3412
PPC_xviexpdp: int  # 2414
PPC_xviexpsp: int  # 2415
PPC_xvmaddadp: int  # 1081
PPC_xvmaddasp: int  # 1082
PPC_xvmaddmdp: int  # 1083
PPC_xvmaddmsp: int  # 1084
PPC_xvmaxdp: int  # 1085
PPC_xvmaxsp: int  # 1086
PPC_xvmindp: int  # 1087
PPC_xvminsp: int  # 1088
PPC_xvmovdp: int  # 1209
PPC_xvmovsp: int  # 1210
PPC_xvmsubadp: int  # 1089
PPC_xvmsubasp: int  # 1090
PPC_xvmsubmdp: int  # 1091
PPC_xvmsubmsp: int  # 1092
PPC_xvmuldp: int  # 1093
PPC_xvmulsp: int  # 1094
PPC_xvnabsdp: int  # 1095
PPC_xvnabssp: int  # 1096
PPC_xvnegdp: int  # 1097
PPC_xvnegsp: int  # 1098
PPC_xvnmaddadp: int  # 1099
PPC_xvnmaddasp: int  # 1100
PPC_xvnmaddmdp: int  # 1101
PPC_xvnmaddmsp: int  # 1102
PPC_xvnmsubadp: int  # 1103
PPC_xvnmsubasp: int  # 1104
PPC_xvnmsubmdp: int  # 1105
PPC_xvnmsubmsp: int  # 1106
PPC_xvrdpi: int  # 1107
PPC_xvrdpic: int  # 1108
PPC_xvrdpim: int  # 1109
PPC_xvrdpip: int  # 1110
PPC_xvrdpiz: int  # 1111
PPC_xvredp: int  # 1112
PPC_xvresp: int  # 1113
PPC_xvrspi: int  # 1114
PPC_xvrspic: int  # 1115
PPC_xvrspim: int  # 1116
PPC_xvrspip: int  # 1117
PPC_xvrspiz: int  # 1118
PPC_xvrsqrtedp: int  # 1119
PPC_xvrsqrtesp: int  # 1120
PPC_xvsqrtdp: int  # 1121
PPC_xvsqrtsp: int  # 1122
PPC_xvsubdp: int  # 1123
PPC_xvsubsp: int  # 1124
PPC_xvtdivdp: int  # 1125
PPC_xvtdivsp: int  # 1126
PPC_xvtlsbb: int  # 3413
PPC_xvtsqrtdp: int  # 1127
PPC_xvtsqrtsp: int  # 1128
PPC_xvtstdcdp: int  # 2423
PPC_xvtstdcsp: int  # 2424
PPC_xvxexpdp: int  # 2429
PPC_xvxexpsp: int  # 2430
PPC_xvxsigdp: int  # 2431
PPC_xvxsigsp: int  # 2432
PPC_xxblendvb: int  # 3414
PPC_xxblendvd: int  # 3415
PPC_xxblendvh: int  # 3416
PPC_xxblendvw: int  # 3417
PPC_xxbrd: int  # 2433
PPC_xxbrh: int  # 2434
PPC_xxbrq: int  # 2435
PPC_xxbrw: int  # 2436
PPC_xxeval: int  # 3418
PPC_xxextractuw: int  # 2416
PPC_xxgenpcvbm: int  # 3419
PPC_xxgenpcvdm: int  # 3420
PPC_xxgenpcvhm: int  # 3421
PPC_xxgenpcvwm: int  # 3422
PPC_xxinsertw: int  # 2417
PPC_xxland: int  # 1129
PPC_xxlandc: int  # 1130
PPC_xxleqv: int  # 2179
PPC_xxlnand: int  # 2180
PPC_xxlnor: int  # 1131
PPC_xxlor: int  # 1132
PPC_xxlorc: int  # 2181
PPC_xxlxor: int  # 1133
PPC_xxmfacc: int  # 3423
PPC_xxmrghd: int  # 1212
PPC_xxmrghw: int  # 1134
PPC_xxmrgld: int  # 1213
PPC_xxmrglw: int  # 1135
PPC_xxmtacc: int  # 3424
PPC_xxperm: int  # 2418
PPC_xxpermdi: int  # 1136
PPC_xxpermr: int  # 2419
PPC_xxpermx: int  # 3425
PPC_xxsel: int  # 1137
PPC_xxsetaccz: int  # 3426
PPC_xxsldwi: int  # 1138
PPC_xxspltd: int  # 1211
PPC_xxsplti32dx: int  # 3427
PPC_xxspltib: int  # 2420
PPC_xxspltidp: int  # 3428
PPC_xxspltiw: int  # 3429
PPC_xxspltw: int  # 1139
PPC_xxswapd: int  # 1214
PPC_yield: int  # 2216
PPC_zabsw: int  # 2506
PPC_zabsws: int  # 2507
PPC_zaddd: int  # 2508
PPC_zadddss: int  # 2509
PPC_zadddus: int  # 2510
PPC_zaddhesw: int  # 2521
PPC_zaddheuw: int  # 2522
PPC_zaddhosw: int  # 2523
PPC_zaddhouw: int  # 2524
PPC_zaddwgsf: int  # 2528
PPC_zaddwgsi: int  # 2529
PPC_zaddwgui: int  # 2530
PPC_zaddwss: int  # 2531
PPC_zaddwus: int  # 2533
PPC_zbrminc: int  # 2502
PPC_zcircinc: int  # 2503
PPC_zcntlsw: int  # 2541
PPC_zdivwsf: int  # 2543
PPC_zldd: int  # 2625
PPC_zlddmx: int  # 2628
PPC_zlddu: int  # 2626
PPC_zlddx: int  # 2627
PPC_zldh: int  # 2629
PPC_zldhmx: int  # 2632
PPC_zldhu: int  # 2630
PPC_zldhx: int  # 2631
PPC_zldw: int  # 2633
PPC_zldwmx: int  # 2636
PPC_zldwu: int  # 2634
PPC_zldwx: int  # 2635
PPC_zlhgwsf: int  # 2637
PPC_zlhgwsfmx: int  # 2640
PPC_zlhgwsfu: int  # 2638
PPC_zlhgwsfx: int  # 2639
PPC_zlhhe: int  # 2641
PPC_zlhhemx: int  # 2644
PPC_zlhheu: int  # 2642
PPC_zlhhex: int  # 2643
PPC_zlhhos: int  # 2645
PPC_zlhhosmx: int  # 2648
PPC_zlhhosu: int  # 2646
PPC_zlhhosx: int  # 2647
PPC_zlhhou: int  # 2649
PPC_zlhhoumx: int  # 2652
PPC_zlhhouu: int  # 2650
PPC_zlhhoux: int  # 2651
PPC_zlhhsplat: int  # 2653
PPC_zlhhsplatmx: int  # 2656
PPC_zlhhsplatu: int  # 2654
PPC_zlhhsplatx: int  # 2655
PPC_zlwgsfd: int  # 2657
PPC_zlwgsfdmx: int  # 2660
PPC_zlwgsfdu: int  # 2658
PPC_zlwgsfdx: int  # 2659
PPC_zlwh: int  # 2661
PPC_zlwhed: int  # 2665
PPC_zlwhedmx: int  # 2668
PPC_zlwhedu: int  # 2666
PPC_zlwhedx: int  # 2667
PPC_zlwhgwsfd: int  # 2669
PPC_zlwhgwsfdmx: int  # 2672
PPC_zlwhgwsfdu: int  # 2670
PPC_zlwhgwsfdx: int  # 2671
PPC_zlwhmx: int  # 2664
PPC_zlwhosd: int  # 2673
PPC_zlwhosdmx: int  # 2676
PPC_zlwhosdu: int  # 2674
PPC_zlwhosdx: int  # 2675
PPC_zlwhoud: int  # 2677
PPC_zlwhoudmx: int  # 2680
PPC_zlwhoudu: int  # 2678
PPC_zlwhoudx: int  # 2679
PPC_zlwhsplatd: int  # 2681
PPC_zlwhsplatdmx: int  # 2684
PPC_zlwhsplatdu: int  # 2682
PPC_zlwhsplatdx: int  # 2683
PPC_zlwhsplatwd: int  # 2685
PPC_zlwhsplatwdmx: int  # 2688
PPC_zlwhsplatwdu: int  # 2686
PPC_zlwhsplatwdx: int  # 2687
PPC_zlwhu: int  # 2662
PPC_zlwhx: int  # 2663
PPC_zlww: int  # 2689
PPC_zlwwmx: int  # 2692
PPC_zlwwosd: int  # 2693
PPC_zlwwosdmx: int  # 2696
PPC_zlwwosdu: int  # 2694
PPC_zlwwosdx: int  # 2695
PPC_zlwwu: int  # 2690
PPC_zlwwx: int  # 2691
PPC_zmhegsi: int  # 2734
PPC_zmhegsiaa: int  # 2747
PPC_zmhegsian: int  # 2748
PPC_zmhegsmf: int  # 2736
PPC_zmhegsmfaa: int  # 2751
PPC_zmhegsmfan: int  # 2752
PPC_zmhegsui: int  # 2735
PPC_zmhegsuiaa: int  # 2749
PPC_zmhegsuian: int  # 2750
PPC_zmhegui: int  # 2733
PPC_zmheguiaa: int  # 2745
PPC_zmheguian: int  # 2746
PPC_zmhegwsmf: int  # 2769
PPC_zmhegwsmfaa: int  # 2775
PPC_zmhegwsmfan: int  # 2778
PPC_zmhegwsmfr: int  # 2772
PPC_zmhegwsmfraa: int  # 2781
PPC_zmhegwsmfran: int  # 2784
PPC_zmheogsi: int  # 2738
PPC_zmheogsiaa: int  # 2755
PPC_zmheogsian: int  # 2756
PPC_zmheogsmf: int  # 2740
PPC_zmheogsmfaa: int  # 2759
PPC_zmheogsmfan: int  # 2760
PPC_zmheogsui: int  # 2739
PPC_zmheogsuiaa: int  # 2757
PPC_zmheogsuian: int  # 2758
PPC_zmheogui: int  # 2737
PPC_zmheoguiaa: int  # 2753
PPC_zmheoguian: int  # 2754
PPC_zmheogwsmf: int  # 2770
PPC_zmheogwsmfaa: int  # 2776
PPC_zmheogwsmfan: int  # 2779
PPC_zmheogwsmfr: int  # 2773
PPC_zmheogwsmfraa: int  # 2782
PPC_zmheogwsmfran: int  # 2785
PPC_zmheosf: int  # 2788
PPC_zmheosfaas: int  # 2794
PPC_zmheosfans: int  # 2797
PPC_zmheosfr: int  # 2791
PPC_zmheosfraas: int  # 2800
PPC_zmheosfrans: int  # 2803
PPC_zmheosi: int  # 2806
PPC_zmheosiaa: int  # 2815
PPC_zmheosiaas: int  # 2833
PPC_zmheosian: int  # 2818
PPC_zmheosians: int  # 2836
PPC_zmheosui: int  # 2809
PPC_zmheosuiaa: int  # 2821
PPC_zmheosuiaas: int  # 2839
PPC_zmheosuian: int  # 2824
PPC_zmheosuians: int  # 2842
PPC_zmheoui: int  # 2812
PPC_zmheouiaa: int  # 2827
PPC_zmheouiaas: int  # 2845
PPC_zmheouian: int  # 2830
PPC_zmheouians: int  # 2848
PPC_zmhesf: int  # 2787
PPC_zmhesfaas: int  # 2793
PPC_zmhesfans: int  # 2796
PPC_zmhesfr: int  # 2790
PPC_zmhesfraas: int  # 2799
PPC_zmhesfrans: int  # 2802
PPC_zmhesi: int  # 2805
PPC_zmhesiaa: int  # 2814
PPC_zmhesiaas: int  # 2832
PPC_zmhesian: int  # 2817
PPC_zmhesians: int  # 2835
PPC_zmhesui: int  # 2808
PPC_zmhesuiaa: int  # 2820
PPC_zmhesuiaas: int  # 2838
PPC_zmhesuian: int  # 2823
PPC_zmhesuians: int  # 2841
PPC_zmheui: int  # 2811
PPC_zmheuiaa: int  # 2826
PPC_zmheuiaas: int  # 2844
PPC_zmheuian: int  # 2829
PPC_zmheuians: int  # 2847
PPC_zmhogsi: int  # 2742
PPC_zmhogsiaa: int  # 2763
PPC_zmhogsian: int  # 2764
PPC_zmhogsmf: int  # 2744
PPC_zmhogsmfaa: int  # 2767
PPC_zmhogsmfan: int  # 2768
PPC_zmhogsui: int  # 2743
PPC_zmhogsuiaa: int  # 2765
PPC_zmhogsuian: int  # 2766
PPC_zmhogui: int  # 2741
PPC_zmhoguiaa: int  # 2761
PPC_zmhoguian: int  # 2762
PPC_zmhogwsmf: int  # 2771
PPC_zmhogwsmfaa: int  # 2777
PPC_zmhogwsmfan: int  # 2780
PPC_zmhogwsmfr: int  # 2774
PPC_zmhogwsmfraa: int  # 2783
PPC_zmhogwsmfran: int  # 2786
PPC_zmhosf: int  # 2789
PPC_zmhosfaas: int  # 2795
PPC_zmhosfans: int  # 2798
PPC_zmhosfr: int  # 2792
PPC_zmhosfraas: int  # 2801
PPC_zmhosfrans: int  # 2804
PPC_zmhosi: int  # 2807
PPC_zmhosiaa: int  # 2816
PPC_zmhosiaas: int  # 2834
PPC_zmhosian: int  # 2819
PPC_zmhosians: int  # 2837
PPC_zmhosui: int  # 2810
PPC_zmhosuiaa: int  # 2822
PPC_zmhosuiaas: int  # 2840
PPC_zmhosuian: int  # 2825
PPC_zmhosuians: int  # 2843
PPC_zmhoui: int  # 2813
PPC_zmhouiaa: int  # 2828
PPC_zmhouiaas: int  # 2846
PPC_zmhouian: int  # 2831
PPC_zmhouians: int  # 2849
PPC_zmwgsi: int  # 2874
PPC_zmwgsiaa: int  # 2877
PPC_zmwgsiaas: int  # 2883
PPC_zmwgsian: int  # 2878
PPC_zmwgsians: int  # 2884
PPC_zmwgsmf: int  # 2889
PPC_zmwgsmfaa: int  # 2891
PPC_zmwgsmfan: int  # 2892
PPC_zmwgsmfr: int  # 2890
PPC_zmwgsmfraa: int  # 2893
PPC_zmwgsmfran: int  # 2894
PPC_zmwgsui: int  # 2875
PPC_zmwgsuiaa: int  # 2879
PPC_zmwgsuiaas: int  # 2885
PPC_zmwgsuian: int  # 2880
PPC_zmwgsuians: int  # 2886
PPC_zmwgui: int  # 2876
PPC_zmwguiaa: int  # 2881
PPC_zmwguiaas: int  # 2887
PPC_zmwguian: int  # 2882
PPC_zmwguians: int  # 2888
PPC_zmwlsiaa: int  # 2898
PPC_zmwlsiaas: int  # 2904
PPC_zmwlsian: int  # 2901
PPC_zmwlsians: int  # 2907
PPC_zmwlsis: int  # 2895
PPC_zmwlsuiaa: int  # 2899
PPC_zmwlsuiaas: int  # 2905
PPC_zmwlsuian: int  # 2902
PPC_zmwlsuians: int  # 2908
PPC_zmwlsuis: int  # 2896
PPC_zmwluiaa: int  # 2900
PPC_zmwluiaas: int  # 2906
PPC_zmwluian: int  # 2903
PPC_zmwluians: int  # 2909
PPC_zmwluis: int  # 2897
PPC_zmwsf: int  # 2910
PPC_zmwsfaas: int  # 2912
PPC_zmwsfans: int  # 2913
PPC_zmwsfr: int  # 2911
PPC_zmwsfraas: int  # 2914
PPC_zmwsfrans: int  # 2915
PPC_znegws: int  # 2552
PPC_zpkswgshfrs: int  # 2554
PPC_zpkswgswfrs: int  # 2555
PPC_zrndwh: int  # 2562
PPC_zrndwhss: int  # 2563
PPC_zsatsdsw: int  # 2564
PPC_zsatsduw: int  # 2565
PPC_zsatswsh: int  # 2567
PPC_zsatswuh: int  # 2568
PPC_zsatswuw: int  # 2569
PPC_zsatuduw: int  # 2570
PPC_zsatuwsh: int  # 2573
PPC_zsatuwsw: int  # 2572
PPC_zsatuwuh: int  # 2574
PPC_zslwiss: int  # 2583
PPC_zslwius: int  # 2585
PPC_zslwss: int  # 2582
PPC_zslwus: int  # 2584
PPC_zstdd: int  # 2697
PPC_zstddmx: int  # 2700
PPC_zstddu: int  # 2698
PPC_zstddx: int  # 2699
PPC_zstdh: int  # 2701
PPC_zstdhmx: int  # 2704
PPC_zstdhu: int  # 2702
PPC_zstdhx: int  # 2703
PPC_zstdw: int  # 2705
PPC_zstdwmx: int  # 2708
PPC_zstdwu: int  # 2706
PPC_zstdwx: int  # 2707
PPC_zsthe: int  # 2709
PPC_zsthemx: int  # 2712
PPC_zstheu: int  # 2710
PPC_zsthex: int  # 2711
PPC_zstho: int  # 2713
PPC_zsthomx: int  # 2716
PPC_zsthou: int  # 2714
PPC_zsthox: int  # 2715
PPC_zstwh: int  # 2717
PPC_zstwhed: int  # 2721
PPC_zstwhedmx: int  # 2724
PPC_zstwhedu: int  # 2722
PPC_zstwhedx: int  # 2723
PPC_zstwhmx: int  # 2720
PPC_zstwhod: int  # 2725
PPC_zstwhodmx: int  # 2728
PPC_zstwhodu: int  # 2726
PPC_zstwhodx: int  # 2727
PPC_zstwhu: int  # 2718
PPC_zstwhx: int  # 2719
PPC_zstww: int  # 2729
PPC_zstwwmx: int  # 2732
PPC_zstwwu: int  # 2730
PPC_zstwwx: int  # 2731
PPC_zsubfd: int  # 2596
PPC_zsubfdss: int  # 2597
PPC_zsubfdus: int  # 2598
PPC_zsubfhesw: int  # 2600
PPC_zsubfheuw: int  # 2601
PPC_zsubfhosw: int  # 2602
PPC_zsubfhouw: int  # 2603
PPC_zsubfwgsf: int  # 2611
PPC_zsubfwgsi: int  # 2612
PPC_zsubfwgui: int  # 2613
PPC_zsubfwss: int  # 2614
PPC_zsubfwus: int  # 2616
PPC_zunpkwgsf: int  # 2623
PPC_zvabsh: int  # 2504
PPC_zvabshs: int  # 2505
PPC_zvaddh: int  # 2511
PPC_zvaddhss: int  # 2512
PPC_zvaddhus: int  # 2513
PPC_zvaddhx: int  # 2514
PPC_zvaddhxss: int  # 2515
PPC_zvaddih: int  # 2516
PPC_zvaddsubfh: int  # 2517
PPC_zvaddsubfhss: int  # 2518
PPC_zvaddsubfhx: int  # 2519
PPC_zvaddsubfhxss: int  # 2520
PPC_zvaddsubfw: int  # 2526
PPC_zvaddsubfwss: int  # 2527
PPC_zvaddw: int  # 2525
PPC_zvaddwss: int  # 2532
PPC_zvaddwus: int  # 2534
PPC_zvcmpeqh: int  # 2535
PPC_zvcmpgths: int  # 2536
PPC_zvcmpgthu: int  # 2537
PPC_zvcmplths: int  # 2538
PPC_zvcmplthu: int  # 2539
PPC_zvcntlsh: int  # 2540
PPC_zvcntlzh: int  # 2542
PPC_zvdotphasfaas: int  # 3104
PPC_zvdotphasfans: int  # 3106
PPC_zvdotphasfraas: int  # 3108
PPC_zvdotphasfrans: int  # 3110
PPC_zvdotphasfrs: int  # 3102
PPC_zvdotphasfs: int  # 3100
PPC_zvdotphasi: int  # 3114
PPC_zvdotphasiaa: int  # 3120
PPC_zvdotphasiaas: int  # 3138
PPC_zvdotphasian: int  # 3126
PPC_zvdotphasians: int  # 3144
PPC_zvdotphasis: int  # 3132
PPC_zvdotphasui: int  # 3116
PPC_zvdotphasuiaa: int  # 3122
PPC_zvdotphasuiaas: int  # 3140
PPC_zvdotphasuian: int  # 3128
PPC_zvdotphasuians: int  # 3146
PPC_zvdotphasuis: int  # 3134
PPC_zvdotphaui: int  # 3112
PPC_zvdotphauiaa: int  # 3118
PPC_zvdotphauiaas: int  # 3136
PPC_zvdotphauian: int  # 3124
PPC_zvdotphauians: int  # 3142
PPC_zvdotphauis: int  # 3130
PPC_zvdotphgasi: int  # 3066
PPC_zvdotphgasiaa: int  # 3074
PPC_zvdotphgasian: int  # 3082
PPC_zvdotphgasmf: int  # 3070
PPC_zvdotphgasmfaa: int  # 3078
PPC_zvdotphgasmfan: int  # 3086
PPC_zvdotphgasui: int  # 3068
PPC_zvdotphgasuiaa: int  # 3076
PPC_zvdotphgasuian: int  # 3084
PPC_zvdotphgaui: int  # 3064
PPC_zvdotphgauiaa: int  # 3072
PPC_zvdotphgauian: int  # 3080
PPC_zvdotphgssi: int  # 3089
PPC_zvdotphgssiaa: int  # 3093
PPC_zvdotphgssian: int  # 3097
PPC_zvdotphgssmf: int  # 3091
PPC_zvdotphgssmfaa: int  # 3095
PPC_zvdotphgssmfan: int  # 3099
PPC_zvdotphgssui: int  # 3090
PPC_zvdotphgssuiaa: int  # 3094
PPC_zvdotphgssuian: int  # 3098
PPC_zvdotphgsui: int  # 3088
PPC_zvdotphgsuiaa: int  # 3092
PPC_zvdotphgsuian: int  # 3096
PPC_zvdotphgwasmf: int  # 3172
PPC_zvdotphgwasmfaa: int  # 3176
PPC_zvdotphgwasmfan: int  # 3178
PPC_zvdotphgwasmfr: int  # 3174
PPC_zvdotphgwasmfraa: int  # 3180
PPC_zvdotphgwasmfran: int  # 3182
PPC_zvdotphgwssmf: int  # 3184
PPC_zvdotphgwssmfaa: int  # 3186
PPC_zvdotphgwssmfan: int  # 3187
PPC_zvdotphgwssmfr: int  # 3185
PPC_zvdotphgwssmfraa: int  # 3188
PPC_zvdotphgwssmfran: int  # 3189
PPC_zvdotphssfaas: int  # 3150
PPC_zvdotphssfans: int  # 3151
PPC_zvdotphssfraas: int  # 3152
PPC_zvdotphssfrans: int  # 3153
PPC_zvdotphssfrs: int  # 3149
PPC_zvdotphssfs: int  # 3148
PPC_zvdotphssi: int  # 3155
PPC_zvdotphssiaa: int  # 3158
PPC_zvdotphssiaas: int  # 3167
PPC_zvdotphssian: int  # 3161
PPC_zvdotphssians: int  # 3170
PPC_zvdotphssis: int  # 3164
PPC_zvdotphssui: int  # 3156
PPC_zvdotphssuiaa: int  # 3159
PPC_zvdotphssuiaas: int  # 3168
PPC_zvdotphssuian: int  # 3162
PPC_zvdotphssuians: int  # 3171
PPC_zvdotphssuis: int  # 3165
PPC_zvdotphsui: int  # 3154
PPC_zvdotphsuiaa: int  # 3157
PPC_zvdotphsuiaas: int  # 3166
PPC_zvdotphsuian: int  # 3160
PPC_zvdotphsuians: int  # 3169
PPC_zvdotphsuis: int  # 3163
PPC_zvdotphxasfaas: int  # 3105
PPC_zvdotphxasfans: int  # 3107
PPC_zvdotphxasfraas: int  # 3109
PPC_zvdotphxasfrans: int  # 3111
PPC_zvdotphxasfrs: int  # 3103
PPC_zvdotphxasfs: int  # 3101
PPC_zvdotphxasi: int  # 3115
PPC_zvdotphxasiaa: int  # 3121
PPC_zvdotphxasiaas: int  # 3139
PPC_zvdotphxasian: int  # 3127
PPC_zvdotphxasians: int  # 3145
PPC_zvdotphxasis: int  # 3133
PPC_zvdotphxasui: int  # 3117
PPC_zvdotphxasuiaa: int  # 3123
PPC_zvdotphxasuiaas: int  # 3141
PPC_zvdotphxasuian: int  # 3129
PPC_zvdotphxasuians: int  # 3147
PPC_zvdotphxasuis: int  # 3135
PPC_zvdotphxaui: int  # 3113
PPC_zvdotphxauiaa: int  # 3119
PPC_zvdotphxauiaas: int  # 3137
PPC_zvdotphxauian: int  # 3125
PPC_zvdotphxauians: int  # 3143
PPC_zvdotphxauis: int  # 3131
PPC_zvdotphxgasi: int  # 3067
PPC_zvdotphxgasiaa: int  # 3075
PPC_zvdotphxgasian: int  # 3083
PPC_zvdotphxgasmf: int  # 3071
PPC_zvdotphxgasmfaa: int  # 3079
PPC_zvdotphxgasmfan: int  # 3087
PPC_zvdotphxgasui: int  # 3069
PPC_zvdotphxgasuiaa: int  # 3077
PPC_zvdotphxgasuian: int  # 3085
PPC_zvdotphxgaui: int  # 3065
PPC_zvdotphxgauiaa: int  # 3073
PPC_zvdotphxgauian: int  # 3081
PPC_zvdotphxgwasmf: int  # 3173
PPC_zvdotphxgwasmfaa: int  # 3177
PPC_zvdotphxgwasmfan: int  # 3179
PPC_zvdotphxgwasmfr: int  # 3175
PPC_zvdotphxgwasmfraa: int  # 3181
PPC_zvdotphxgwasmfran: int  # 3183
PPC_zvmergehih: int  # 2544
PPC_zvmergehiloh: int  # 2545
PPC_zvmergeloh: int  # 2546
PPC_zvmergelohih: int  # 2547
PPC_zvmhllgwsmf: int  # 2917
PPC_zvmhllgwsmfaa: int  # 2925
PPC_zvmhllgwsmfan: int  # 2933
PPC_zvmhllgwsmfanp: int  # 2941
PPC_zvmhllgwsmfr: int  # 2921
PPC_zvmhllgwsmfraa: int  # 2929
PPC_zvmhllgwsmfran: int  # 2937
PPC_zvmhllgwsmfranp: int  # 2945
PPC_zvmhllsf: int  # 2949
PPC_zvmhllsfaas: int  # 2957
PPC_zvmhllsfanps: int  # 2965
PPC_zvmhllsfans: int  # 2961
PPC_zvmhllsfr: int  # 2953
PPC_zvmhllsfraas: int  # 2969
PPC_zvmhllsfranps: int  # 2977
PPC_zvmhllsfrans: int  # 2973
PPC_zvmhllsi: int  # 2981
PPC_zvmhllsiaa: int  # 2993
PPC_zvmhllsiaas: int  # 3029
PPC_zvmhllsian: int  # 2997
PPC_zvmhllsianp: int  # 3001
PPC_zvmhllsianps: int  # 3037
PPC_zvmhllsians: int  # 3033
PPC_zvmhllsui: int  # 2985
PPC_zvmhllsuiaa: int  # 3005
PPC_zvmhllsuiaas: int  # 3041
PPC_zvmhllsuian: int  # 3009
PPC_zvmhllsuianp: int  # 3013
PPC_zvmhllsuianps: int  # 3049
PPC_zvmhllsuians: int  # 3045
PPC_zvmhllui: int  # 2989
PPC_zvmhlluiaa: int  # 3017
PPC_zvmhlluiaas: int  # 3053
PPC_zvmhlluian: int  # 3021
PPC_zvmhlluianp: int  # 3025
PPC_zvmhlluianps: int  # 3061
PPC_zvmhlluians: int  # 3057
PPC_zvmhsfaahs: int  # 2852
PPC_zvmhsfanhs: int  # 2853
PPC_zvmhsfh: int  # 2850
PPC_zvmhsfraahs: int  # 2854
PPC_zvmhsfranhs: int  # 2855
PPC_zvmhsfrh: int  # 2851
PPC_zvmhsiaah: int  # 2862
PPC_zvmhsiaahs: int  # 2868
PPC_zvmhsianh: int  # 2865
PPC_zvmhsianhs: int  # 2871
PPC_zvmhsih: int  # 2856
PPC_zvmhsihs: int  # 2859
PPC_zvmhsuiaah: int  # 2863
PPC_zvmhsuiaahs: int  # 2869
PPC_zvmhsuianh: int  # 2866
PPC_zvmhsuianhs: int  # 2872
PPC_zvmhsuih: int  # 2857
PPC_zvmhsuihs: int  # 2860
PPC_zvmhuiaah: int  # 2864
PPC_zvmhuiaahs: int  # 2870
PPC_zvmhuianh: int  # 2867
PPC_zvmhuianhs: int  # 2873
PPC_zvmhuih: int  # 2858
PPC_zvmhuihs: int  # 2861
PPC_zvmhulgwsmf: int  # 2916
PPC_zvmhulgwsmfaa: int  # 2924
PPC_zvmhulgwsmfan: int  # 2932
PPC_zvmhulgwsmfanp: int  # 2940
PPC_zvmhulgwsmfr: int  # 2920
PPC_zvmhulgwsmfraa: int  # 2928
PPC_zvmhulgwsmfran: int  # 2936
PPC_zvmhulgwsmfranp: int  # 2944
PPC_zvmhulsf: int  # 2948
PPC_zvmhulsfaas: int  # 2956
PPC_zvmhulsfanps: int  # 2964
PPC_zvmhulsfans: int  # 2960
PPC_zvmhulsfr: int  # 2952
PPC_zvmhulsfraas: int  # 2968
PPC_zvmhulsfranps: int  # 2976
PPC_zvmhulsfrans: int  # 2972
PPC_zvmhulsi: int  # 2980
PPC_zvmhulsiaa: int  # 2992
PPC_zvmhulsiaas: int  # 3028
PPC_zvmhulsian: int  # 2996
PPC_zvmhulsianp: int  # 3000
PPC_zvmhulsianps: int  # 3036
PPC_zvmhulsians: int  # 3032
PPC_zvmhulsui: int  # 2984
PPC_zvmhulsuiaa: int  # 3004
PPC_zvmhulsuiaas: int  # 3040
PPC_zvmhulsuian: int  # 3008
PPC_zvmhulsuianp: int  # 3012
PPC_zvmhulsuianps: int  # 3048
PPC_zvmhulsuians: int  # 3044
PPC_zvmhului: int  # 2988
PPC_zvmhuluiaa: int  # 3016
PPC_zvmhuluiaas: int  # 3052
PPC_zvmhuluian: int  # 3020
PPC_zvmhuluianp: int  # 3024
PPC_zvmhuluianps: int  # 3060
PPC_zvmhuluians: int  # 3056
PPC_zvmhuugwsmf: int  # 2918
PPC_zvmhuugwsmfaa: int  # 2926
PPC_zvmhuugwsmfan: int  # 2934
PPC_zvmhuugwsmfanp: int  # 2942
PPC_zvmhuugwsmfr: int  # 2922
PPC_zvmhuugwsmfraa: int  # 2930
PPC_zvmhuugwsmfran: int  # 2938
PPC_zvmhuugwsmfranp: int  # 2946
PPC_zvmhuusf: int  # 2950
PPC_zvmhuusfaas: int  # 2958
PPC_zvmhuusfanps: int  # 2966
PPC_zvmhuusfans: int  # 2962
PPC_zvmhuusfr: int  # 2954
PPC_zvmhuusfraas: int  # 2970
PPC_zvmhuusfranps: int  # 2978
PPC_zvmhuusfrans: int  # 2974
PPC_zvmhuusi: int  # 2982
PPC_zvmhuusiaa: int  # 2994
PPC_zvmhuusiaas: int  # 3030
PPC_zvmhuusian: int  # 2998
PPC_zvmhuusianp: int  # 3002
PPC_zvmhuusianps: int  # 3038
PPC_zvmhuusians: int  # 3034
PPC_zvmhuusui: int  # 2986
PPC_zvmhuusuiaa: int  # 3006
PPC_zvmhuusuiaas: int  # 3042
PPC_zvmhuusuian: int  # 3010
PPC_zvmhuusuianp: int  # 3014
PPC_zvmhuusuianps: int  # 3050
PPC_zvmhuusuians: int  # 3046
PPC_zvmhuuui: int  # 2990
PPC_zvmhuuuiaa: int  # 3018
PPC_zvmhuuuiaas: int  # 3054
PPC_zvmhuuuian: int  # 3022
PPC_zvmhuuuianp: int  # 3026
PPC_zvmhuuuianps: int  # 3062
PPC_zvmhuuuians: int  # 3058
PPC_zvmhxlgwsmf: int  # 2919
PPC_zvmhxlgwsmfaa: int  # 2927
PPC_zvmhxlgwsmfan: int  # 2935
PPC_zvmhxlgwsmfanp: int  # 2943
PPC_zvmhxlgwsmfr: int  # 2923
PPC_zvmhxlgwsmfraa: int  # 2931
PPC_zvmhxlgwsmfran: int  # 2939
PPC_zvmhxlgwsmfranp: int  # 2947
PPC_zvmhxlsf: int  # 2951
PPC_zvmhxlsfaas: int  # 2959
PPC_zvmhxlsfanps: int  # 2967
PPC_zvmhxlsfans: int  # 2963
PPC_zvmhxlsfr: int  # 2955
PPC_zvmhxlsfraas: int  # 2971
PPC_zvmhxlsfranps: int  # 2979
PPC_zvmhxlsfrans: int  # 2975
PPC_zvmhxlsi: int  # 2983
PPC_zvmhxlsiaa: int  # 2995
PPC_zvmhxlsiaas: int  # 3031
PPC_zvmhxlsian: int  # 2999
PPC_zvmhxlsianp: int  # 3003
PPC_zvmhxlsianps: int  # 3039
PPC_zvmhxlsians: int  # 3035
PPC_zvmhxlsui: int  # 2987
PPC_zvmhxlsuiaa: int  # 3007
PPC_zvmhxlsuiaas: int  # 3043
PPC_zvmhxlsuian: int  # 3011
PPC_zvmhxlsuianp: int  # 3015
PPC_zvmhxlsuianps: int  # 3051
PPC_zvmhxlsuians: int  # 3047
PPC_zvmhxlui: int  # 2991
PPC_zvmhxluiaa: int  # 3019
PPC_zvmhxluiaas: int  # 3055
PPC_zvmhxluian: int  # 3023
PPC_zvmhxluianp: int  # 3027
PPC_zvmhxluianps: int  # 3063
PPC_zvmhxluians: int  # 3059
PPC_zvnegh: int  # 2548
PPC_zvnegho: int  # 2549
PPC_zvneghos: int  # 2550
PPC_zvneghs: int  # 2551
PPC_zvpkshgwshfrs: int  # 2553
PPC_zvpkswshfrs: int  # 2556
PPC_zvpkswshs: int  # 2557
PPC_zvpkswuhs: int  # 2558
PPC_zvpkuwuhs: int  # 2559
PPC_zvrlh: int  # 2560
PPC_zvrlhi: int  # 2561
PPC_zvsatshuh: int  # 2566
PPC_zvsatuhsh: int  # 2571
PPC_zvselh: int  # 2575
PPC_zvslh: int  # 2576
PPC_zvslhi: int  # 2577
PPC_zvslhiss: int  # 2579
PPC_zvslhius: int  # 2581
PPC_zvslhss: int  # 2578
PPC_zvslhus: int  # 2580
PPC_zvsplatfih: int  # 2586
PPC_zvsplatih: int  # 2587
PPC_zvsrhis: int  # 2588
PPC_zvsrhiu: int  # 2589
PPC_zvsrhs: int  # 2590
PPC_zvsrhu: int  # 2591
PPC_zvsubfaddh: int  # 2592
PPC_zvsubfaddhss: int  # 2593
PPC_zvsubfaddhx: int  # 2594
PPC_zvsubfaddhxss: int  # 2595
PPC_zvsubfaddw: int  # 2609
PPC_zvsubfaddwss: int  # 2610
PPC_zvsubfh: int  # 2599
PPC_zvsubfhss: int  # 2604
PPC_zvsubfhus: int  # 2605
PPC_zvsubfhx: int  # 2606
PPC_zvsubfhxss: int  # 2607
PPC_zvsubfw: int  # 2608
PPC_zvsubfwss: int  # 2615
PPC_zvsubfwus: int  # 2617
PPC_zvsubifh: int  # 2618
PPC_zvunpkhgwsf: int  # 2619
PPC_zvunpkhsf: int  # 2620
PPC_zvunpkhsi: int  # 2621
PPC_zvunpkhui: int  # 2622
PPC_zxtrw: int  # 2624
PSP_bitrev: int  # 612
PSP_bvf: int  # 629
PSP_bvfl: int  # 631
PSP_bvt: int  # 630
PSP_bvtl: int  # 632
PSP_lv: int  # 619
PSP_lvl: int  # 620
PSP_lvr: int  # 621
PSP_max: int  # 613
PSP_mfic: int  # 615
PSP_mfv: int  # 625
PSP_mfvc: int  # 627
PSP_mfvme: int  # 732
PSP_min: int  # 614
PSP_mtic: int  # 616
PSP_mtv: int  # 626
PSP_mtvc: int  # 628
PSP_mtvme: int  # 733
PSP_sleep: int  # 618
PSP_sv: int  # 622
PSP_svl: int  # 623
PSP_svr: int  # 624
PSP_vabs: int  # 636
PSP_vadd: int  # 637
PSP_vasin: int  # 638
PSP_vavg: int  # 639
PSP_vbfy1: int  # 640
PSP_vbfy2: int  # 641
PSP_vc2i: int  # 642
PSP_vcmovf: int  # 643
PSP_vcmovt: int  # 644
PSP_vcmp: int  # 645
PSP_vcos: int  # 646
PSP_vcrs: int  # 647
PSP_vcrsp: int  # 648
PSP_vcst: int  # 649
PSP_vdet: int  # 650
PSP_vdiv: int  # 651
PSP_vdot: int  # 652
PSP_vexp2: int  # 653
PSP_vf2h: int  # 654
PSP_vf2id: int  # 655
PSP_vf2in: int  # 656
PSP_vf2iu: int  # 657
PSP_vf2iz: int  # 658
PSP_vfad: int  # 659
PSP_vfim: int  # 660
PSP_vflush: int  # 634
PSP_vh2f: int  # 661
PSP_vhdp: int  # 662
PSP_vhtfm2: int  # 663
PSP_vhtfm3: int  # 664
PSP_vhtfm4: int  # 665
PSP_vi2c: int  # 666
PSP_vi2f: int  # 667
PSP_vi2s: int  # 668
PSP_vi2uc: int  # 669
PSP_vi2us: int  # 670
PSP_vidt: int  # 671
PSP_viim: int  # 672
PSP_vlgb: int  # 673
PSP_vlog2: int  # 674
PSP_vmax: int  # 675
PSP_vmfvc: int  # 676
PSP_vmidt: int  # 677
PSP_vmin: int  # 678
PSP_vmmov: int  # 679
PSP_vmmul: int  # 680
PSP_vmone: int  # 681
PSP_vmov: int  # 682
PSP_vmscl: int  # 683
PSP_vmtvc: int  # 684
PSP_vmul: int  # 685
PSP_vmzero: int  # 686
PSP_vneg: int  # 687
PSP_vnop: int  # 633
PSP_vnrcp: int  # 688
PSP_vnsin: int  # 689
PSP_vocp: int  # 690
PSP_vone: int  # 691
PSP_vpfxd: int  # 692
PSP_vpfxs: int  # 693
PSP_vpfxt: int  # 694
PSP_vqmul: int  # 695
PSP_vrcp: int  # 696
PSP_vrexp2: int  # 697
PSP_vrndf1: int  # 698
PSP_vrndf2: int  # 699
PSP_vrndi: int  # 700
PSP_vrnds: int  # 701
PSP_vrot: int  # 702
PSP_vrsq: int  # 703
PSP_vs2i: int  # 704
PSP_vsat0: int  # 705
PSP_vsat1: int  # 706
PSP_vsbn: int  # 707
PSP_vsbz: int  # 708
PSP_vscl: int  # 709
PSP_vscmp: int  # 710
PSP_vsge: int  # 711
PSP_vsgn: int  # 712
PSP_vsin: int  # 713
PSP_vslt: int  # 714
PSP_vsocp: int  # 715
PSP_vsqrt: int  # 716
PSP_vsrt1: int  # 717
PSP_vsrt2: int  # 718
PSP_vsrt3: int  # 719
PSP_vsrt4: int  # 720
PSP_vsub: int  # 721
PSP_vsync: int  # 635
PSP_vt4444: int  # 722
PSP_vt5551: int  # 723
PSP_vt5650: int  # 724
PSP_vtfm2: int  # 725
PSP_vtfm3: int  # 726
PSP_vtfm4: int  # 727
PSP_vuc2i: int  # 728
PSP_vus2i: int  # 729
PSP_vwbn: int  # 730
PSP_vzero: int  # 731
PSP_wsbw: int  # 617
RISCV_add: int  # 28
RISCV_addi: int  # 19
RISCV_addiw: int  # 51
RISCV_addw: int  # 55
RISCV_aes: int  # 386
RISCV_aes64im: int  # 387
RISCV_aes64ks1i: int  # 388
RISCV_aes64ks2: int  # 389
RISCV_amoadd: int  # 84
RISCV_amoand: int  # 86
RISCV_amocas: int  # 92
RISCV_amomax: int  # 89
RISCV_amomaxu: int  # 91
RISCV_amomin: int  # 88
RISCV_amominu: int  # 90
RISCV_amoor: int  # 87
RISCV_amoswap: int  # 83
RISCV_amoxor: int  # 85
RISCV_and: int  # 37
RISCV_andi: int  # 24
RISCV_andn: int  # 339
RISCV_auipc: int  # 2
RISCV_bclr: int  # 340
RISCV_bclri: int  # 341
RISCV_beq: int  # 5
RISCV_beqz: int  # 134
RISCV_bext: int  # 342
RISCV_bexti: int  # 343
RISCV_bge: int  # 8
RISCV_bgeu: int  # 10
RISCV_bgez: int  # 137
RISCV_bgtz: int  # 139
RISCV_binv: int  # 344
RISCV_binvi: int  # 345
RISCV_blez: int  # 136
RISCV_blt: int  # 7
RISCV_bltu: int  # 9
RISCV_bltz: int  # 138
RISCV_bne: int  # 6
RISCV_bnez: int  # 135
RISCV_brev8: int  # 390
RISCV_bset: int  # 346
RISCV_bseti: int  # 347
RISCV_call: int  # 163
RISCV_cbo: int  # 383
RISCV_clmul: int  # 348
RISCV_clmulh: int  # 349
RISCV_clmulr: int  # 350
RISCV_clz: int  # 351
RISCV_clzw: int  # 352
RISCV_cpop: int  # 353
RISCV_cpopw: int  # 354
RISCV_csrc: int  # 152
RISCV_csrci: int  # 155
RISCV_csrr: int  # 149
RISCV_csrrc: int  # 64
RISCV_csrrci: int  # 67
RISCV_csrrs: int  # 63
RISCV_csrrsi: int  # 66
RISCV_csrrw: int  # 62
RISCV_csrrwi: int  # 65
RISCV_csrs: int  # 151
RISCV_csrsi: int  # 154
RISCV_csrw: int  # 150
RISCV_csrwi: int  # 153
RISCV_ctz: int  # 355
RISCV_ctzw: int  # 356
RISCV_div: int  # 72
RISCV_divu: int  # 73
RISCV_divuw: int  # 78
RISCV_divw: int  # 77
RISCV_ebreak: int  # 40
RISCV_ecall: int  # 39
RISCV_fabs: int  # 132
RISCV_fadd: int  # 99
RISCV_fclass: int  # 116
RISCV_fcvtf2f: int  # 109
RISCV_fcvtf2i: int  # 110
RISCV_fcvti2f: int  # 111
RISCV_fdiv: int  # 102
RISCV_fence: int  # 38
RISCV_fencei: int  # 61
RISCV_feq: int  # 113
RISCV_fld: int  # 117
RISCV_fle: int  # 115
RISCV_flh: int  # 375
RISCV_flq: int  # 119
RISCV_flt: int  # 114
RISCV_flw: int  # 93
RISCV_fmadd: int  # 95
RISCV_fmax: int  # 108
RISCV_fmin: int  # 107
RISCV_fmsub: int  # 96
RISCV_fmul: int  # 101
RISCV_fmv: int  # 112
RISCV_fneg: int  # 133
RISCV_fnmadd: int  # 98
RISCV_fnmsub: int  # 97
RISCV_frcsr: int  # 156
RISCV_frflags: int  # 160
RISCV_frrm: int  # 158
RISCV_fscsr: int  # 157
RISCV_fsd: int  # 118
RISCV_fsflags: int  # 161
RISCV_fsgnj: int  # 104
RISCV_fsgnjn: int  # 105
RISCV_fsgnjx: int  # 106
RISCV_fsh: int  # 376
RISCV_fsq: int  # 120
RISCV_fsqrt: int  # 103
RISCV_fsrm: int  # 159
RISCV_fsub: int  # 100
RISCV_fsw: int  # 94
RISCV_hfenceb: int  # 46
RISCV_hfenceg: int  # 47
RISCV_hinval: int  # 381
RISCV_hl: int  # 377
RISCV_hs: int  # 378
RISCV_j: int  # 140
RISCV_jal: int  # 3
RISCV_jalr: int  # 4
RISCV_jr: int  # 141
RISCV_jump: int  # 165
RISCV_la: int  # 162
RISCV_last: int  # 528
RISCV_lb: int  # 11
RISCV_lbu: int  # 14
RISCV_ld: int  # 49
RISCV_lh: int  # 12
RISCV_lhu: int  # 15
RISCV_li: int  # 122
RISCV_lr: int  # 81
RISCV_lui: int  # 1
RISCV_lw: int  # 13
RISCV_lwu: int  # 48
RISCV_max: int  # 357
RISCV_maxu: int  # 358
RISCV_min: int  # 359
RISCV_minu: int  # 360
RISCV_mret: int  # 43
RISCV_mul: int  # 68
RISCV_mulh: int  # 69
RISCV_mulhsu: int  # 70
RISCV_mulhu: int  # 71
RISCV_mulw: int  # 76
RISCV_mv: int  # 123
RISCV_neg: int  # 125
RISCV_negw: int  # 126
RISCV_nop: int  # 121
RISCV_not: int  # 124
RISCV_null: int  # 0
RISCV_or: int  # 36
RISCV_orc: int  # 361
RISCV_ori: int  # 23
RISCV_orn: int  # 362
RISCV_pack: int  # 391
RISCV_packh: int  # 392
RISCV_packw: int  # 393
RISCV_pause: int  # 382
RISCV_prefetch: int  # 384
RISCV_rdcycle: int  # 144
RISCV_rdcycleh: int  # 147
RISCV_rdinstret: int  # 143
RISCV_rdinstreth: int  # 146
RISCV_rdtime: int  # 145
RISCV_rdtimeh: int  # 148
RISCV_rem: int  # 74
RISCV_remu: int  # 75
RISCV_remuw: int  # 80
RISCV_remw: int  # 79
RISCV_ret: int  # 142
RISCV_rev8: int  # 363
RISCV_rol: int  # 364
RISCV_rolw: int  # 365
RISCV_ror: int  # 366
RISCV_rori: int  # 367
RISCV_roriw: int  # 368
RISCV_rorw: int  # 369
RISCV_sb: int  # 16
RISCV_sc: int  # 82
RISCV_sd: int  # 50
RISCV_seqz: int  # 128
RISCV_sext: int  # 127
RISCV_sfence: int  # 45
RISCV_sfencefg: int  # 380
RISCV_sfencevm: int  # 385
RISCV_sgtz: int  # 131
RISCV_sh: int  # 17
RISCV_sh1add: int  # 370
RISCV_sh2add: int  # 371
RISCV_sh3add: int  # 372
RISCV_sha256: int  # 394
RISCV_sha512: int  # 395
RISCV_sinval: int  # 379
RISCV_sll: int  # 30
RISCV_slli: int  # 25
RISCV_slliw: int  # 52
RISCV_sllw: int  # 57
RISCV_slt: int  # 31
RISCV_slti: int  # 20
RISCV_sltiu: int  # 21
RISCV_sltu: int  # 32
RISCV_sltw: int  # 58
RISCV_sltz: int  # 130
RISCV_sm3: int  # 396
RISCV_sm4: int  # 397
RISCV_snez: int  # 129
RISCV_sra: int  # 35
RISCV_srai: int  # 27
RISCV_sraiw: int  # 54
RISCV_sraw: int  # 60
RISCV_sret: int  # 42
RISCV_srl: int  # 34
RISCV_srli: int  # 26
RISCV_srliw: int  # 53
RISCV_srlw: int  # 59
RISCV_sub: int  # 29
RISCV_subw: int  # 56
RISCV_sw: int  # 18
RISCV_tail: int  # 164
RISCV_thaddsl: int  # 430
RISCV_thandn: int  # 509
RISCV_thdcachecall: int  # 404
RISCV_thdcacheciall: int  # 405
RISCV_thdcachecipa: int  # 408
RISCV_thdcachecisw: int  # 414
RISCV_thdcacheciva: int  # 411
RISCV_thdcachecpa: int  # 407
RISCV_thdcachecpal1: int  # 416
RISCV_thdcachecsw: int  # 413
RISCV_thdcachecva: int  # 410
RISCV_thdcachecval1: int  # 417
RISCV_thdcacheiall: int  # 406
RISCV_thdcacheipa: int  # 409
RISCV_thdcacheisw: int  # 415
RISCV_thdcacheiva: int  # 412
RISCV_thext: int  # 433
RISCV_thextu: int  # 434
RISCV_thff0: int  # 435
RISCV_thff1: int  # 436
RISCV_thflrd: int  # 492
RISCV_thflrw: int  # 493
RISCV_thflurd: int  # 494
RISCV_thflurw: int  # 495
RISCV_thfmv: int  # 506
RISCV_thfsrd: int  # 496
RISCV_thfsrw: int  # 497
RISCV_thfsurd: int  # 498
RISCV_thfsurw: int  # 499
RISCV_thicacheiall: int  # 418
RISCV_thicacheialls: int  # 419
RISCV_thicacheipa: int  # 420
RISCV_thicacheiva: int  # 421
RISCV_thipop: int  # 508
RISCV_thipush: int  # 507
RISCV_thl2cachecall: int  # 422
RISCV_thl2cacheciall: int  # 423
RISCV_thl2cacheiall: int  # 424
RISCV_thlbia: int  # 443
RISCV_thlbib: int  # 444
RISCV_thlbuia: int  # 445
RISCV_thlbuib: int  # 446
RISCV_thldd: int  # 487
RISCV_thldia: int  # 455
RISCV_thldib: int  # 456
RISCV_thlhia: int  # 447
RISCV_thlhib: int  # 448
RISCV_thlhuia: int  # 449
RISCV_thlhuib: int  # 450
RISCV_thlrb: int  # 465
RISCV_thlrbu: int  # 466
RISCV_thlrd: int  # 471
RISCV_thlrh: int  # 467
RISCV_thlrhu: int  # 468
RISCV_thlrw: int  # 469
RISCV_thlrwu: int  # 470
RISCV_thlurb: int  # 476
RISCV_thlurbu: int  # 477
RISCV_thlurd: int  # 482
RISCV_thlurh: int  # 478
RISCV_thlurhu: int  # 479
RISCV_thlurw: int  # 480
RISCV_thlurwu: int  # 481
RISCV_thlwd: int  # 488
RISCV_thlwia: int  # 451
RISCV_thlwib: int  # 452
RISCV_thlwud: int  # 489
RISCV_thlwuia: int  # 453
RISCV_thlwuib: int  # 454
RISCV_thmula: int  # 500
RISCV_thmulah: int  # 501
RISCV_thmulaw: int  # 502
RISCV_thmuls: int  # 503
RISCV_thmulsh: int  # 504
RISCV_thmulsw: int  # 505
RISCV_thmveqz: int  # 441
RISCV_thmvnez: int  # 442
RISCV_thorn: int  # 510
RISCV_thpackh: int  # 513
RISCV_thpackhl: int  # 514
RISCV_thpackl: int  # 512
RISCV_threv: int  # 437
RISCV_threvw: int  # 438
RISCV_thsbia: int  # 457
RISCV_thsbib: int  # 458
RISCV_thsdd: int  # 490
RISCV_thsdia: int  # 463
RISCV_thsdib: int  # 464
RISCV_thsfencevmas: int  # 425
RISCV_thshia: int  # 459
RISCV_thshib: int  # 460
RISCV_thsrb: int  # 472
RISCV_thsrd: int  # 475
RISCV_thsrh: int  # 473
RISCV_thsrri: int  # 431
RISCV_thsrriw: int  # 432
RISCV_thsrw: int  # 474
RISCV_thsurb: int  # 483
RISCV_thsurd: int  # 486
RISCV_thsurh: int  # 484
RISCV_thsurw: int  # 485
RISCV_thswd: int  # 491
RISCV_thswia: int  # 461
RISCV_thswib: int  # 462
RISCV_thsync: int  # 426
RISCV_thsynci: int  # 428
RISCV_thsyncis: int  # 429
RISCV_thsyncs: int  # 427
RISCV_thtst: int  # 440
RISCV_thtstnbz: int  # 439
RISCV_thvmaqa: int  # 515
RISCV_thvmaqasu: int  # 517
RISCV_thvmaqau: int  # 516
RISCV_thvmaqaus: int  # 518
RISCV_thvpmaqa: int  # 519
RISCV_thvpmaqasu: int  # 522
RISCV_thvpmaqau: int  # 520
RISCV_thvpmaqaus: int  # 521
RISCV_thvpnclip: int  # 523
RISCV_thvpnclipu: int  # 524
RISCV_thvpwadd: int  # 525
RISCV_thvpwaddu: int  # 526
RISCV_thxorn: int  # 511
RISCV_unk: int  # 527
RISCV_unzip: int  # 398
RISCV_uret: int  # 41
RISCV_vaadd: int  # 225
RISCV_vaaddu: int  # 224
RISCV_vadc: int  # 185
RISCV_vadd: int  # 171
RISCV_vand: int  # 178
RISCV_vasub: int  # 227
RISCV_vasubu: int  # 226
RISCV_vcompress: int  # 240
RISCV_vcpop: int  # 230
RISCV_vdiv: int  # 250
RISCV_vdivu: int  # 249
RISCV_vfabs: int  # 334
RISCV_vfadd: int  # 276
RISCV_vfclass: int  # 296
RISCV_vfcvt: int  # 290
RISCV_vfdiv: int  # 305
RISCV_vfirst: int  # 231
RISCV_vfmacc: int  # 313
RISCV_vfmadd: int  # 309
RISCV_vfmax: int  # 282
RISCV_vfmerge: int  # 297
RISCV_vfmin: int  # 280
RISCV_vfmov: int  # 289
RISCV_vfmsac: int  # 315
RISCV_vfmsub: int  # 311
RISCV_vfmul: int  # 307
RISCV_vfmv: int  # 298
RISCV_vfncvt: int  # 292
RISCV_vfneg: int  # 333
RISCV_vfnmacc: int  # 314
RISCV_vfnmadd: int  # 310
RISCV_vfnmsac: int  # 316
RISCV_vfnmsub: int  # 312
RISCV_vfrdiv: int  # 306
RISCV_vfrec7: int  # 295
RISCV_vfredmax: int  # 283
RISCV_vfredmin: int  # 281
RISCV_vfredosum: int  # 279
RISCV_vfredusum: int  # 277
RISCV_vfrsqrt7: int  # 294
RISCV_vfrsub: int  # 308
RISCV_vfsgnj: int  # 284
RISCV_vfsgnjn: int  # 285
RISCV_vfsgnjx: int  # 286
RISCV_vfslide1down: int  # 288
RISCV_vfslide1up: int  # 287
RISCV_vfsqrt: int  # 293
RISCV_vfsub: int  # 278
RISCV_vfwadd: int  # 317
RISCV_vfwaddw: int  # 321
RISCV_vfwcvt: int  # 291
RISCV_vfwmacc: int  # 324
RISCV_vfwmsac: int  # 326
RISCV_vfwmul: int  # 323
RISCV_vfwnmacc: int  # 325
RISCV_vfwnmsac: int  # 327
RISCV_vfwredosum: int  # 320
RISCV_vfwredusum: int  # 318
RISCV_vfwsub: int  # 319
RISCV_vfwsubw: int  # 322
RISCV_vid: int  # 239
RISCV_viota: int  # 238
RISCV_vl: int  # 169
RISCV_vmacc: int  # 259
RISCV_vmadc: int  # 186
RISCV_vmadd: int  # 257
RISCV_vmand: int  # 242
RISCV_vmandn: int  # 241
RISCV_vmax: int  # 177
RISCV_vmaxu: int  # 176
RISCV_vmclr: int  # 336
RISCV_vmerge: int  # 189
RISCV_vmfeq: int  # 299
RISCV_vmfge: int  # 304
RISCV_vmfgt: int  # 303
RISCV_vmfle: int  # 300
RISCV_vmflt: int  # 301
RISCV_vmfne: int  # 302
RISCV_vmin: int  # 175
RISCV_vminu: int  # 174
RISCV_vmmv: int  # 335
RISCV_vmnand: int  # 246
RISCV_vmnor: int  # 247
RISCV_vmnot: int  # 338
RISCV_vmor: int  # 243
RISCV_vmorn: int  # 245
RISCV_vmsbc: int  # 188
RISCV_vmsbf: int  # 235
RISCV_vmseq: int  # 191
RISCV_vmset: int  # 337
RISCV_vmsgt: int  # 198
RISCV_vmsgtu: int  # 197
RISCV_vmsif: int  # 237
RISCV_vmsle: int  # 196
RISCV_vmsleu: int  # 195
RISCV_vmslt: int  # 194
RISCV_vmsltu: int  # 193
RISCV_vmsne: int  # 192
RISCV_vmsof: int  # 236
RISCV_vmul: int  # 254
RISCV_vmulh: int  # 256
RISCV_vmulhsu: int  # 255
RISCV_vmulhu: int  # 253
RISCV_vmv: int  # 190
RISCV_vmvi: int  # 232
RISCV_vmvr: int  # 205
RISCV_vmxnor: int  # 248
RISCV_vmxor: int  # 244
RISCV_vnclip: int  # 213
RISCV_vnclipu: int  # 212
RISCV_vncvt: int  # 332
RISCV_vneg: int  # 328
RISCV_vnmsac: int  # 260
RISCV_vnmsub: int  # 258
RISCV_vnot: int  # 331
RISCV_vnsra: int  # 211
RISCV_vnsrl: int  # 210
RISCV_vor: int  # 179
RISCV_vredand: int  # 217
RISCV_vredmax: int  # 223
RISCV_vredmaxu: int  # 222
RISCV_vredmin: int  # 221
RISCV_vredminu: int  # 220
RISCV_vredor: int  # 218
RISCV_vredsum: int  # 216
RISCV_vredxor: int  # 219
RISCV_vrem: int  # 252
RISCV_vremu: int  # 251
RISCV_vrgather: int  # 181
RISCV_vrgatherei16: int  # 183
RISCV_vrsub: int  # 173
RISCV_vs: int  # 170
RISCV_vsadd: int  # 200
RISCV_vsaddu: int  # 199
RISCV_vsbc: int  # 187
RISCV_vsetivli: int  # 168
RISCV_vsetvl: int  # 166
RISCV_vsetvli: int  # 167
RISCV_vsext: int  # 234
RISCV_vslide1down: int  # 229
RISCV_vslide1up: int  # 228
RISCV_vslidedown: int  # 184
RISCV_vslideup: int  # 182
RISCV_vsll: int  # 203
RISCV_vsmul: int  # 204
RISCV_vsra: int  # 207
RISCV_vsrl: int  # 206
RISCV_vssra: int  # 209
RISCV_vssrl: int  # 208
RISCV_vssub: int  # 202
RISCV_vssubu: int  # 201
RISCV_vsub: int  # 172
RISCV_vwadd: int  # 262
RISCV_vwaddu: int  # 261
RISCV_vwadduw: int  # 265
RISCV_vwaddw: int  # 266
RISCV_vwcvt: int  # 329
RISCV_vwcvtu: int  # 330
RISCV_vwmacc: int  # 273
RISCV_vwmaccsu: int  # 275
RISCV_vwmaccu: int  # 272
RISCV_vwmaccus: int  # 274
RISCV_vwmul: int  # 271
RISCV_vwmulsu: int  # 270
RISCV_vwmulu: int  # 269
RISCV_vwredsum: int  # 215
RISCV_vwredsumu: int  # 214
RISCV_vwsub: int  # 264
RISCV_vwsubu: int  # 263
RISCV_vwsubuw: int  # 267
RISCV_vwsubw: int  # 268
RISCV_vxor: int  # 180
RISCV_vzext: int  # 233
RISCV_wfi: int  # 44
RISCV_wrsnto: int  # 402
RISCV_wrssto: int  # 403
RISCV_xnor: int  # 373
RISCV_xor: int  # 33
RISCV_xori: int  # 22
RISCV_xperm4: int  # 399
RISCV_xperm8: int  # 400
RISCV_zext: int  # 374
RISCV_zip: int  # 401
RL78_add: int  # 49
RL78_addc: int  # 50
RL78_addw: int  # 5
RL78_and: int  # 14
RL78_and1: int  # 27
RL78_bc: int  # 45
RL78_bf: int  # 38
RL78_bh: int  # 47
RL78_bnc: int  # 46
RL78_bnh: int  # 48
RL78_bnz: int  # 12
RL78_br: int  # 16
RL78_brk: int  # 68
RL78_bt: int  # 37
RL78_btclr: int  # 36
RL78_bz: int  # 21
RL78_call: int  # 3
RL78_callt: int  # 73
RL78_clr1: int  # 29
RL78_clrb: int  # 13
RL78_clrw: int  # 4
RL78_cmp: int  # 18
RL78_cmp0: int  # 61
RL78_cmps: int  # 58
RL78_cmpw: int  # 11
RL78_dec: int  # 55
RL78_decw: int  # 19
RL78_divhu: int  # 76
RL78_divwu: int  # 77
RL78_halt: int  # 60
RL78_inc: int  # 20
RL78_incw: int  # 10
RL78_last: int  # 80
RL78_mach: int  # 79
RL78_machu: int  # 78
RL78_mov: int  # 35
RL78_mov1: int  # 28
RL78_movs: int  # 59
RL78_movw: int  # 2
RL78_mulh: int  # 75
RL78_mulhu: int  # 74
RL78_mulu: int  # 62
RL78_nop: int  # 72
RL78_not1: int  # 31
RL78_null: int  # 0
RL78_oneb: int  # 63
RL78_onew: int  # 9
RL78_or: int  # 15
RL78_or1: int  # 26
RL78_pop: int  # 17
RL78_push: int  # 8
RL78_ret: int  # 6
RL78_retb: int  # 69
RL78_reti: int  # 70
RL78_rol: int  # 65
RL78_rolc: int  # 67
RL78_rolwc: int  # 56
RL78_ror: int  # 64
RL78_rorc: int  # 66
RL78_sar: int  # 41
RL78_sarw: int  # 44
RL78_sel: int  # 7
RL78_set1: int  # 30
RL78_shl: int  # 39
RL78_shlw: int  # 42
RL78_shr: int  # 40
RL78_shrw: int  # 43
RL78_skc: int  # 32
RL78_skh: int  # 24
RL78_sknc: int  # 33
RL78_sknh: int  # 23
RL78_sknz: int  # 22
RL78_skz: int  # 34
RL78_stop: int  # 71
RL78_sub: int  # 51
RL78_subc: int  # 52
RL78_subw: int  # 1
RL78_xch: int  # 54
RL78_xchw: int  # 57
RL78_xor: int  # 53
RL78_xor1: int  # 25
RX_abs: int  # 1
RX_adc: int  # 2
RX_add: int  # 3
RX_and: int  # 4
RX_bclr: int  # 7
RX_beq: int  # 10
RX_bfmov: int  # 8
RX_bfmovz: int  # 9
RX_bge: int  # 18
RX_bgeu: int  # 12
RX_bgt: int  # 20
RX_bgtu: int  # 14
RX_ble: int  # 21
RX_bleu: int  # 15
RX_blt: int  # 19
RX_bltu: int  # 13
RX_bmeq: int  # 24
RX_bmge: int  # 32
RX_bmgeu: int  # 26
RX_bmgt: int  # 34
RX_bmgtu: int  # 28
RX_bmle: int  # 35
RX_bmleu: int  # 29
RX_bmlt: int  # 33
RX_bmltu: int  # 27
RX_bmn: int  # 31
RX_bmne: int  # 25
RX_bmno: int  # 37
RX_bmo: int  # 36
RX_bmpz: int  # 30
RX_bn: int  # 17
RX_bne: int  # 11
RX_bno: int  # 23
RX_bnot: int  # 38
RX_bo: int  # 22
RX_bpz: int  # 16
RX_bra: int  # 5
RX_brk: int  # 6
RX_bset: int  # 39
RX_bsr: int  # 40
RX_btst: int  # 41
RX_clrpsw: int  # 42
RX_cmp: int  # 43
RX_dabs: int  # 153
RX_dadd: int  # 154
RX_dcmpeq: int  # 156
RX_dcmple: int  # 158
RX_dcmplt: int  # 157
RX_dcmpun: int  # 155
RX_ddiv: int  # 159
RX_div: int  # 44
RX_divu: int  # 45
RX_dmov: int  # 160
RX_dmul: int  # 161
RX_dneg: int  # 162
RX_dpopm: int  # 163
RX_dpushm: int  # 164
RX_dround: int  # 165
RX_dsqrt: int  # 166
RX_dsub: int  # 167
RX_dtof: int  # 168
RX_dtoi: int  # 169
RX_dtou: int  # 170
RX_emaca: int  # 46
RX_emsba: int  # 47
RX_emul: int  # 49
RX_emula: int  # 48
RX_emulu: int  # 50
RX_fadd: int  # 51
RX_fcmp: int  # 52
RX_fdiv: int  # 53
RX_fmul: int  # 54
RX_fsqrt: int  # 55
RX_fsub: int  # 56
RX_ftod: int  # 171
RX_ftoi: int  # 57
RX_ftou: int  # 58
RX_int: int  # 59
RX_itod: int  # 172
RX_itof: int  # 60
RX_jmp: int  # 61
RX_jsr: int  # 62
RX_last: int  # 177
RX_machi: int  # 63
RX_maclh: int  # 65
RX_maclo: int  # 64
RX_max: int  # 66
RX_min: int  # 67
RX_mov: int  # 68
RX_movco: int  # 69
RX_movli: int  # 70
RX_movu: int  # 71
RX_msbhi: int  # 72
RX_msblh: int  # 74
RX_msblo: int  # 73
RX_mul: int  # 75
RX_mulhi: int  # 76
RX_mullh: int  # 78
RX_mullo: int  # 77
RX_mvfacgu: int  # 82
RX_mvfachi: int  # 79
RX_mvfaclo: int  # 80
RX_mvfacmi: int  # 81
RX_mvfc: int  # 83
RX_mvfdc: int  # 173
RX_mvfdr: int  # 174
RX_mvtacgu: int  # 84
RX_mvtachi: int  # 85
RX_mvtaclo: int  # 86
RX_mvtc: int  # 87
RX_mvtdc: int  # 175
RX_mvtipl: int  # 88
RX_neg: int  # 89
RX_nop: int  # 90
RX_not: int  # 91
RX_null: int  # 0
RX_or: int  # 92
RX_pop: int  # 93
RX_popc: int  # 94
RX_popm: int  # 95
RX_push: int  # 96
RX_pushc: int  # 97
RX_pushm: int  # 98
RX_racl: int  # 99
RX_racw: int  # 101
RX_rdacl: int  # 100
RX_rdacw: int  # 102
RX_revl: int  # 103
RX_revw: int  # 104
RX_rmpa: int  # 105
RX_rolc: int  # 106
RX_rorc: int  # 107
RX_rotl: int  # 108
RX_rotr: int  # 109
RX_round: int  # 110
RX_rstr: int  # 111
RX_rte: int  # 112
RX_rtfi: int  # 113
RX_rts: int  # 114
RX_rtsd: int  # 115
RX_sat: int  # 116
RX_satr: int  # 117
RX_save: int  # 118
RX_sbb: int  # 119
RX_sceq: int  # 120
RX_scge: int  # 128
RX_scgeu: int  # 122
RX_scgt: int  # 130
RX_scgtu: int  # 124
RX_scle: int  # 131
RX_scleu: int  # 125
RX_sclt: int  # 129
RX_scltu: int  # 123
RX_scmpu: int  # 134
RX_scn: int  # 127
RX_scne: int  # 121
RX_scno: int  # 133
RX_sco: int  # 132
RX_scpz: int  # 126
RX_setpsw: int  # 135
RX_shar: int  # 136
RX_shll: int  # 137
RX_shlr: int  # 138
RX_smovb: int  # 139
RX_smovf: int  # 140
RX_smovu: int  # 141
RX_sstr: int  # 142
RX_stnz: int  # 143
RX_stz: int  # 144
RX_sub: int  # 145
RX_suntil: int  # 146
RX_swhile: int  # 147
RX_tst: int  # 148
RX_utod: int  # 176
RX_utof: int  # 149
RX_wait: int  # 150
RX_xchg: int  # 151
RX_xor: int  # 152
SH2a_band_b: int  # 137
SH2a_bandnot_b: int  # 138
SH2a_bclr: int  # 139
SH2a_bclr_b: int  # 140
SH2a_bld: int  # 141
SH2a_bld_b: int  # 142
SH2a_bldnot_b: int  # 143
SH2a_bor_b: int  # 144
SH2a_bornot_b: int  # 145
SH2a_bset: int  # 146
SH2a_bset_b: int  # 147
SH2a_bst: int  # 148
SH2a_bst_b: int  # 149
SH2a_bxor_b: int  # 150
SH2a_clips_b: int  # 151
SH2a_clips_w: int  # 152
SH2a_clipu_b: int  # 153
SH2a_clipu_w: int  # 154
SH2a_divs: int  # 155
SH2a_divu: int  # 156
SH2a_jsr_n: int  # 157
SH2a_ldbank: int  # 158
SH2a_movi20: int  # 159
SH2a_movi20s: int  # 160
SH2a_movml_l: int  # 161
SH2a_movmu_l: int  # 162
SH2a_movrt: int  # 163
SH2a_movu_b: int  # 164
SH2a_movu_w: int  # 165
SH2a_mulr: int  # 166
SH2a_nott: int  # 167
SH2a_resbank: int  # 168
SH2a_rts_n: int  # 169
SH2a_rtv_n: int  # 170
SH2a_stbank: int  # 171
SH3_add: int  # 1
SH3_addc: int  # 2
SH3_addv: int  # 3
SH3_and: int  # 4
SH3_and_b: int  # 5
SH3_bf: int  # 6
SH3_bf_s: int  # 7
SH3_bra: int  # 8
SH3_braf: int  # 9
SH3_bsr: int  # 10
SH3_bsrf: int  # 11
SH3_bt: int  # 12
SH3_bt_s: int  # 13
SH3_clrmac: int  # 14
SH3_clrs: int  # 15
SH3_clrt: int  # 16
SH3_cmp_eq: int  # 17
SH3_cmp_ge: int  # 18
SH3_cmp_gt: int  # 19
SH3_cmp_hi: int  # 20
SH3_cmp_hs: int  # 21
SH3_cmp_pl: int  # 22
SH3_cmp_pz: int  # 23
SH3_cmp_str: int  # 24
SH3_div0s: int  # 25
SH3_div0u: int  # 26
SH3_div1: int  # 27
SH3_dmuls_l: int  # 28
SH3_dmulu_l: int  # 29
SH3_dt: int  # 30
SH3_exts_b: int  # 31
SH3_exts_w: int  # 32
SH3_extu_b: int  # 33
SH3_extu_w: int  # 34
SH3_jmp: int  # 35
SH3_jsr: int  # 36
SH3_ldc: int  # 37
SH3_ldc_l: int  # 38
SH3_lds: int  # 39
SH3_lds_l: int  # 40
SH3_ldtlb: int  # 41
SH3_mac_l: int  # 43
SH3_mac_w: int  # 42
SH3_mov: int  # 44
SH3_mov_b: int  # 45
SH3_mov_l: int  # 47
SH3_mov_w: int  # 46
SH3_mova: int  # 57
SH3_movi: int  # 48
SH3_movi_l: int  # 50
SH3_movi_w: int  # 49
SH3_movp_b: int  # 51
SH3_movp_l: int  # 53
SH3_movp_w: int  # 52
SH3_movs_b: int  # 54
SH3_movs_l: int  # 56
SH3_movs_w: int  # 55
SH3_movt: int  # 58
SH3_mul: int  # 59
SH3_muls: int  # 60
SH3_mulu: int  # 61
SH3_neg: int  # 62
SH3_negc: int  # 63
SH3_nop: int  # 64
SH3_not: int  # 65
SH3_null: int  # 0
SH3_or: int  # 66
SH3_or_b: int  # 67
SH3_pref: int  # 68
SH3_rotcl: int  # 69
SH3_rotcr: int  # 70
SH3_rotl: int  # 71
SH3_rotr: int  # 72
SH3_rte: int  # 73
SH3_rts: int  # 74
SH3_sets: int  # 75
SH3_sett: int  # 76
SH3_shad: int  # 77
SH3_shal: int  # 78
SH3_shar: int  # 79
SH3_shld: int  # 80
SH3_shll: int  # 81
SH3_shll16: int  # 84
SH3_shll2: int  # 82
SH3_shll8: int  # 83
SH3_shlr: int  # 85
SH3_shlr16: int  # 88
SH3_shlr2: int  # 86
SH3_shlr8: int  # 87
SH3_sleep: int  # 89
SH3_stc: int  # 90
SH3_stc_l: int  # 91
SH3_sts: int  # 92
SH3_sts_l: int  # 93
SH3_sub: int  # 94
SH3_subc: int  # 95
SH3_subv: int  # 96
SH3_swap_b: int  # 97
SH3_swap_w: int  # 98
SH3_tas_b: int  # 99
SH3_trapa: int  # 100
SH3_tst: int  # 101
SH3_tst_b: int  # 102
SH3_xor: int  # 103
SH3_xor_b: int  # 104
SH3_xtrct: int  # 105
SH4_fabs: int  # 106
SH4_fadd: int  # 107
SH4_fcmp_eq: int  # 108
SH4_fcmp_gt: int  # 109
SH4_fcnvds: int  # 110
SH4_fcnvsd: int  # 111
SH4_fdiv: int  # 112
SH4_fipr: int  # 113
SH4_fldi0: int  # 114
SH4_fldi1: int  # 115
SH4_flds: int  # 116
SH4_float: int  # 117
SH4_fmac: int  # 118
SH4_fmov: int  # 119
SH4_fmov_s: int  # 120
SH4_fmovex: int  # 121
SH4_fmul: int  # 122
SH4_fneg: int  # 123
SH4_frchg: int  # 124
SH4_fsca: int  # 136
SH4_fschg: int  # 125
SH4_fsqrt: int  # 126
SH4_fsts: int  # 127
SH4_fsub: int  # 128
SH4_ftrc: int  # 129
SH4_ftrv: int  # 130
SH4_ftstn: int  # 131
SH4_last: int  # 180
SH4_movca_l: int  # 132
SH4_ocbi: int  # 133
SH4_ocbp: int  # 134
SH4_ocbwb: int  # 135
SH4a_fpchg: int  # 179
SH4a_fsrra: int  # 178
SH4a_icbi: int  # 175
SH4a_movco_l: int  # 172
SH4a_movli_l: int  # 173
SH4a_movua_l: int  # 174
SH4a_prefi: int  # 176
SH4a_synco: int  # 177
SPARC_add: int  # 1
SPARC_addc: int  # 3
SPARC_addcc: int  # 2
SPARC_addccc: int  # 4
SPARC_alignaddress: int  # 187
SPARC_and: int  # 5
SPARC_andcc: int  # 6
SPARC_andn: int  # 7
SPARC_andncc: int  # 8
SPARC_array: int  # 188
SPARC_b: int  # 9
SPARC_bclr: int  # 179
SPARC_bmask: int  # 227
SPARC_bp: int  # 10
SPARC_bpr: int  # 11
SPARC_bset: int  # 178
SPARC_bshuffle: int  # 228
SPARC_btog: int  # 180
SPARC_btst: int  # 177
SPARC_call: int  # 12
SPARC_cas: int  # 169
SPARC_casa: int  # 13
SPARC_casl: int  # 170
SPARC_casx: int  # 171
SPARC_casxa: int  # 14
SPARC_casxl: int  # 172
SPARC_clr: int  # 181
SPARC_clrb: int  # 182
SPARC_clrh: int  # 183
SPARC_clruw: int  # 185
SPARC_clrx: int  # 184
SPARC_cmp: int  # 157
SPARC_dec: int  # 175
SPARC_deccc: int  # 176
SPARC_done: int  # 15
SPARC_edge: int  # 189
SPARC_edgen: int  # 229
SPARC_fabs: int  # 16
SPARC_fadd: int  # 17
SPARC_faligndata: int  # 190
SPARC_fand: int  # 193
SPARC_fandnot1: int  # 191
SPARC_fandnot2: int  # 192
SPARC_fb: int  # 19
SPARC_fbp: int  # 18
SPARC_fcmp: int  # 20
SPARC_fcmpe: int  # 21
SPARC_fcmpeq: int  # 194
SPARC_fcmpgt: int  # 195
SPARC_fcmple: int  # 196
SPARC_fcmpne: int  # 197
SPARC_fdiv: int  # 22
SPARC_fdmulq: int  # 23
SPARC_fdtoi: int  # 50
SPARC_fdtoq: int  # 48
SPARC_fdtos: int  # 41
SPARC_fdtox: int  # 35
SPARC_fexpand: int  # 198
SPARC_fitod: int  # 43
SPARC_fitoq: int  # 46
SPARC_fitos: int  # 40
SPARC_flush: int  # 24
SPARC_flushw: int  # 25
SPARC_fmov: int  # 26
SPARC_fmovcc: int  # 27
SPARC_fmovr: int  # 28
SPARC_fmul: int  # 29
SPARC_fmul8sux16: int  # 199
SPARC_fmul8ulx16: int  # 200
SPARC_fmul8x16: int  # 201
SPARC_fmul8x16al: int  # 202
SPARC_fmul8x16au: int  # 203
SPARC_fmuld8sux16: int  # 204
SPARC_fmuld8ulx16: int  # 205
SPARC_fnand: int  # 206
SPARC_fneg: int  # 30
SPARC_fnor: int  # 207
SPARC_fnot1: int  # 208
SPARC_fnot2: int  # 209
SPARC_fone: int  # 210
SPARC_for: int  # 213
SPARC_fornot1: int  # 211
SPARC_fornot2: int  # 212
SPARC_fpack: int  # 215
SPARC_fpackfix: int  # 214
SPARC_fpadd: int  # 216
SPARC_fpmerge: int  # 217
SPARC_fpsub: int  # 218
SPARC_fqtod: int  # 45
SPARC_fqtoi: int  # 51
SPARC_fqtos: int  # 42
SPARC_fqtox: int  # 36
SPARC_fsmuld: int  # 31
SPARC_fsqrt: int  # 32
SPARC_fsrc1: int  # 219
SPARC_fsrc2: int  # 220
SPARC_fstod: int  # 44
SPARC_fstoi: int  # 49
SPARC_fstoq: int  # 47
SPARC_fstox: int  # 34
SPARC_fsub: int  # 33
SPARC_fxnor: int  # 221
SPARC_fxor: int  # 222
SPARC_fxtod: int  # 38
SPARC_fxtoq: int  # 39
SPARC_fxtos: int  # 37
SPARC_fzero: int  # 223
SPARC_illtrap: int  # 52
SPARC_impdep1: int  # 53
SPARC_impdep2: int  # 54
SPARC_inc: int  # 173
SPARC_inccc: int  # 174
SPARC_iprefetch: int  # 159
SPARC_jmp: int  # 158
SPARC_jmpl: int  # 55
SPARC_last: int  # 233
SPARC_ldd: int  # 56
SPARC_ldda: int  # 57
SPARC_lddf: int  # 58
SPARC_lddfa: int  # 59
SPARC_ldf: int  # 60
SPARC_ldfa: int  # 61
SPARC_ldfsr: int  # 62
SPARC_ldqf: int  # 63
SPARC_ldqfa: int  # 64
SPARC_ldsb: int  # 65
SPARC_ldsba: int  # 66
SPARC_ldsh: int  # 67
SPARC_ldsha: int  # 68
SPARC_ldstub: int  # 69
SPARC_ldstuba: int  # 70
SPARC_ldsw: int  # 71
SPARC_ldswa: int  # 72
SPARC_ldub: int  # 73
SPARC_lduba: int  # 74
SPARC_lduh: int  # 75
SPARC_lduha: int  # 76
SPARC_lduw: int  # 77
SPARC_lduwa: int  # 78
SPARC_ldx: int  # 79
SPARC_ldxa: int  # 80
SPARC_ldxfsr: int  # 81
SPARC_membar: int  # 82
SPARC_mov: int  # 83
SPARC_movr: int  # 84
SPARC_mulscc: int  # 85
SPARC_mulx: int  # 86
SPARC_neg: int  # 168
SPARC_nop: int  # 87
SPARC_not: int  # 167
SPARC_null: int  # 0
SPARC_or: int  # 88
SPARC_orcc: int  # 89
SPARC_orn: int  # 90
SPARC_orncc: int  # 91
SPARC_pdist: int  # 224
SPARC_popc: int  # 92
SPARC_prefetch: int  # 93
SPARC_prefetcha: int  # 94
SPARC_pseudo_mov: int  # 186
SPARC_rd: int  # 95
SPARC_rdhpr: int  # 230
SPARC_rdpr: int  # 96
SPARC_restore: int  # 97
SPARC_restored: int  # 98
SPARC_ret: int  # 161
SPARC_retl: int  # 162
SPARC_retry: int  # 99
SPARC_rett: int  # 226
SPARC_return: int  # 100
SPARC_save: int  # 101
SPARC_saved: int  # 102
SPARC_sdiv: int  # 103
SPARC_sdivcc: int  # 104
SPARC_sdivx: int  # 105
SPARC_sethi: int  # 106
SPARC_setsw: int  # 164
SPARC_setuw: int  # 163
SPARC_setx: int  # 165
SPARC_shutdown: int  # 225
SPARC_siam: int  # 232
SPARC_signx: int  # 166
SPARC_sir: int  # 107
SPARC_sll: int  # 108
SPARC_sllx: int  # 109
SPARC_smul: int  # 110
SPARC_smulcc: int  # 111
SPARC_sra: int  # 112
SPARC_srax: int  # 113
SPARC_srl: int  # 114
SPARC_srlx: int  # 115
SPARC_stb: int  # 116
SPARC_stba: int  # 117
SPARC_stbar: int  # 118
SPARC_std: int  # 119
SPARC_stda: int  # 120
SPARC_stdf: int  # 121
SPARC_stdfa: int  # 122
SPARC_stf: int  # 123
SPARC_stfa: int  # 124
SPARC_stfsr: int  # 125
SPARC_sth: int  # 126
SPARC_stha: int  # 127
SPARC_stqf: int  # 128
SPARC_stqfa: int  # 129
SPARC_stw: int  # 130
SPARC_stwa: int  # 131
SPARC_stx: int  # 132
SPARC_stxa: int  # 133
SPARC_stxfsr: int  # 134
SPARC_sub: int  # 135
SPARC_subc: int  # 137
SPARC_subcc: int  # 136
SPARC_subccc: int  # 138
SPARC_swap: int  # 139
SPARC_swapa: int  # 140
SPARC_t: int  # 145
SPARC_taddcc: int  # 141
SPARC_taddcctv: int  # 142
SPARC_tst: int  # 160
SPARC_tsubcc: int  # 143
SPARC_tsubcctv: int  # 144
SPARC_udiv: int  # 146
SPARC_udivcc: int  # 147
SPARC_udivx: int  # 148
SPARC_umul: int  # 149
SPARC_umulcc: int  # 150
SPARC_wr: int  # 151
SPARC_wrhpr: int  # 231
SPARC_wrpr: int  # 152
SPARC_xnor: int  # 153
SPARC_xnorcc: int  # 154
SPARC_xor: int  # 155
SPARC_xorcc: int  # 156
ST10_CoABS: int  # 85
ST10_CoADD: int  # 86
ST10_CoASHR: int  # 87
ST10_CoCMP: int  # 88
ST10_CoLOAD: int  # 89
ST10_CoMAC: int  # 90
ST10_CoMACM: int  # 91
ST10_CoMAX: int  # 92
ST10_CoMIN: int  # 93
ST10_CoMOV: int  # 94
ST10_CoMUL: int  # 95
ST10_CoNEG: int  # 96
ST10_CoNOP: int  # 97
ST10_CoRND: int  # 98
ST10_CoSHL: int  # 99
ST10_CoSHR: int  # 100
ST10_CoSTORE: int  # 101
ST10_CoSUB: int  # 102
ST20_adc: int  # 1
ST20_add: int  # 2
ST20_addc: int  # 3
ST20_ajw: int  # 4
ST20_alt: int  # 81
ST20_altend: int  # 82
ST20_altwt: int  # 83
ST20_and: int  # 5
ST20_arot: int  # 6
ST20_ashr: int  # 7
ST20_bcnt: int  # 84
ST20_biquad: int  # 8
ST20_bitcnt: int  # 85
ST20_bitld: int  # 9
ST20_bitmask: int  # 10
ST20_bitrevnbits: int  # 86
ST20_bitrevword: int  # 87
ST20_bitst: int  # 11
ST20_breakpoint: int  # 12
ST20_bsub: int  # 88
ST20_call: int  # 89
ST20_causeerror: int  # 90
ST20_cb: int  # 91
ST20_cbu: int  # 92
ST20_ccnt1: int  # 93
ST20_cflerr: int  # 94
ST20_cir: int  # 95
ST20_ciru: int  # 96
ST20_cj: int  # 13
ST20_clockdis: int  # 97
ST20_clockenb: int  # 98
ST20_clrhalterr: int  # 99
ST20_crcbyte: int  # 100
ST20_crcword: int  # 101
ST20_cs: int  # 102
ST20_csngl: int  # 103
ST20_csu: int  # 104
ST20_csub0: int  # 105
ST20_cword: int  # 106
ST20_dequeue: int  # 14
ST20_devlb: int  # 107
ST20_devls: int  # 108
ST20_devlw: int  # 109
ST20_devmove: int  # 110
ST20_devsb: int  # 111
ST20_devss: int  # 112
ST20_devsw: int  # 113
ST20_diff: int  # 114
ST20_disc: int  # 115
ST20_diss: int  # 116
ST20_dist: int  # 117
ST20_div: int  # 118
ST20_divstep: int  # 15
ST20_dup: int  # 16
ST20_ecall: int  # 17
ST20_enbc: int  # 119
ST20_enbs: int  # 120
ST20_enbt: int  # 121
ST20_endp: int  # 122
ST20_enqueue: int  # 18
ST20_eqc: int  # 19
ST20_eret: int  # 20
ST20_fcall: int  # 21
ST20_fmul: int  # 123
ST20_fptesterr: int  # 124
ST20_gajw: int  # 22
ST20_gcall: int  # 125
ST20_gintdis: int  # 126
ST20_gintenb: int  # 127
ST20_gt: int  # 23
ST20_gtu: int  # 24
ST20_in: int  # 128
ST20_insertqueue: int  # 129
ST20_intdis: int  # 130
ST20_intenb: int  # 131
ST20_io: int  # 25
ST20_iret: int  # 132
ST20_j: int  # 26
ST20_jab: int  # 27
ST20_ladd: int  # 133
ST20_last: int  # 217
ST20_lb: int  # 134
ST20_lbinc: int  # 28
ST20_lbx: int  # 135
ST20_ldc: int  # 29
ST20_ldclock: int  # 136
ST20_lddevid: int  # 137
ST20_ldiff: int  # 138
ST20_ldinf: int  # 139
ST20_ldiv: int  # 140
ST20_ldl: int  # 30
ST20_ldlp: int  # 31
ST20_ldmemstartval: int  # 141
ST20_ldnl: int  # 32
ST20_ldnlp: int  # 33
ST20_ldpi: int  # 34
ST20_ldpri: int  # 142
ST20_ldprodid: int  # 35
ST20_ldshadow: int  # 143
ST20_ldtdesc: int  # 36
ST20_ldtimer: int  # 144
ST20_ldtraph: int  # 145
ST20_ldtrapped: int  # 146
ST20_lend: int  # 147
ST20_lmul: int  # 148
ST20_ls: int  # 149
ST20_lshl: int  # 150
ST20_lshr: int  # 151
ST20_lsinc: int  # 37
ST20_lsub: int  # 152
ST20_lsum: int  # 153
ST20_lsx: int  # 154
ST20_lsxinc: int  # 38
ST20_lwinc: int  # 39
ST20_mac: int  # 40
ST20_mint: int  # 155
ST20_move: int  # 156
ST20_move2dall: int  # 157
ST20_move2dinit: int  # 158
ST20_move2dnonzero: int  # 159
ST20_move2dzero: int  # 160
ST20_mul: int  # 41
ST20_nfix: int  # 42
ST20_nop: int  # 43
ST20_norm: int  # 161
ST20_not: int  # 44
ST20_null: int  # 0
ST20_opr: int  # 45
ST20_or: int  # 46
ST20_order: int  # 47
ST20_orderu: int  # 48
ST20_out: int  # 162
ST20_outbyte: int  # 163
ST20_outword: int  # 164
ST20_pfix: int  # 49
ST20_pop: int  # 165
ST20_postnormsn: int  # 166
ST20_prod: int  # 167
ST20_reboot: int  # 168
ST20_rem: int  # 169
ST20_resetch: int  # 170
ST20_restart: int  # 171
ST20_ret: int  # 172
ST20_rev: int  # 50
ST20_rmw: int  # 51
ST20_rot: int  # 52
ST20_roundsn: int  # 173
ST20_run: int  # 53
ST20_runp: int  # 174
ST20_satadd: int  # 175
ST20_satmul: int  # 176
ST20_satsub: int  # 177
ST20_saturate: int  # 54
ST20_saveh: int  # 178
ST20_savel: int  # 179
ST20_sb: int  # 180
ST20_sbinc: int  # 55
ST20_seterr: int  # 181
ST20_sethalterr: int  # 182
ST20_settimeslice: int  # 183
ST20_shl: int  # 56
ST20_shr: int  # 57
ST20_signal: int  # 58
ST20_slmul: int  # 184
ST20_smacinit: int  # 59
ST20_smacloop: int  # 60
ST20_smul: int  # 61
ST20_ss: int  # 185
ST20_ssinc: int  # 62
ST20_ssub: int  # 186
ST20_startp: int  # 187
ST20_statusclr: int  # 63
ST20_statusset: int  # 64
ST20_statustst: int  # 65
ST20_stclock: int  # 188
ST20_sthb: int  # 189
ST20_sthf: int  # 190
ST20_stl: int  # 66
ST20_stlb: int  # 191
ST20_stlf: int  # 192
ST20_stnl: int  # 67
ST20_stop: int  # 68
ST20_stoperr: int  # 193
ST20_stopp: int  # 194
ST20_stshadow: int  # 195
ST20_sttimer: int  # 196
ST20_sttraph: int  # 197
ST20_sttrapped: int  # 198
ST20_sub: int  # 69
ST20_subc: int  # 70
ST20_sulmul: int  # 199
ST20_sum: int  # 200
ST20_swap32: int  # 71
ST20_swapqueue: int  # 201
ST20_swaptimer: int  # 202
ST20_swinc: int  # 72
ST20_talt: int  # 203
ST20_taltwt: int  # 204
ST20_testerr: int  # 205
ST20_testhalterr: int  # 206
ST20_testpranal: int  # 207
ST20_timeslice: int  # 73
ST20_tin: int  # 208
ST20_trapdis: int  # 209
ST20_trapenb: int  # 210
ST20_tret: int  # 211
ST20_umac: int  # 74
ST20_unpacksn: int  # 212
ST20_unsign: int  # 75
ST20_wait: int  # 76
ST20_wcnt: int  # 213
ST20_wsub: int  # 77
ST20_wsubdb: int  # 214
ST20_xbword: int  # 78
ST20_xdble: int  # 215
ST20_xor: int  # 79
ST20_xsword: int  # 80
ST20_xword: int  # 216
ST7_adc: int  # 1
ST7_add: int  # 2
ST7_and: int  # 3
ST7_bcp: int  # 4
ST7_bres: int  # 5
ST7_bset: int  # 6
ST7_btjf: int  # 7
ST7_btjt: int  # 8
ST7_call: int  # 9
ST7_callr: int  # 10
ST7_clr: int  # 11
ST7_cp: int  # 12
ST7_cpl: int  # 13
ST7_dec: int  # 14
ST7_halt: int  # 15
ST7_inc: int  # 17
ST7_iret: int  # 16
ST7_jp: int  # 18
ST7_jra: int  # 19
ST7_jrc: int  # 32
ST7_jreq: int  # 30
ST7_jrf: int  # 21
ST7_jrh: int  # 24
ST7_jrih: int  # 22
ST7_jril: int  # 23
ST7_jrm: int  # 26
ST7_jrmi: int  # 28
ST7_jrnc: int  # 33
ST7_jrne: int  # 31
ST7_jrnh: int  # 25
ST7_jrnm: int  # 27
ST7_jrpl: int  # 29
ST7_jrt: int  # 20
ST7_jruge: int  # 35
ST7_jrugt: int  # 36
ST7_jrule: int  # 37
ST7_jrult: int  # 34
ST7_last: int  # 64
ST7_ld: int  # 38
ST7_mul: int  # 39
ST7_neg: int  # 40
ST7_nop: int  # 41
ST7_null: int  # 0
ST7_or: int  # 42
ST7_pop: int  # 43
ST7_push: int  # 44
ST7_rcf: int  # 45
ST7_ret: int  # 46
ST7_rim: int  # 47
ST7_rlc: int  # 48
ST7_rrc: int  # 49
ST7_rsp: int  # 50
ST7_sbc: int  # 51
ST7_scf: int  # 52
ST7_sim: int  # 53
ST7_sla: int  # 54
ST7_sll: int  # 55
ST7_sra: int  # 57
ST7_srl: int  # 56
ST7_sub: int  # 58
ST7_swap: int  # 59
ST7_tnz: int  # 60
ST7_trap: int  # 61
ST7_wfi: int  # 62
ST7_xor: int  # 63
SWIG_PYTHON_LEGACY_BOOL: int  # 1
T900_adc: int  # 25
T900_adcw: int  # 26
T900_add: int  # 23
T900_addw: int  # 24
T900_and: int  # 54
T900_andcf: int  # 62
T900_andw: int  # 55
T900_bit: int  # 69
T900_bs1b: int  # 75
T900_bs1f: int  # 74
T900_call: int  # 121
T900_calr: int  # 122
T900_ccf: int  # 67
T900_chg: int  # 72
T900_cp: int  # 31
T900_cpd: int  # 21
T900_cpdr: int  # 22
T900_cpi: int  # 19
T900_cpir: int  # 20
T900_cpl: int  # 42
T900_cpw: int  # 32
T900_daa: int  # 40
T900_dec: int  # 35
T900_decf: int  # 87
T900_decw: int  # 36
T900_di: int  # 78
T900_div: int  # 45
T900_divs: int  # 46
T900_djnz: int  # 123
T900_ei: int  # 77
T900_ex: int  # 9
T900_exts: int  # 39
T900_extz: int  # 38
T900_halt: int  # 80
T900_inc: int  # 33
T900_incf: int  # 86
T900_incw: int  # 34
T900_jp: int  # 115
T900_jp_cond: int  # 116
T900_jr: int  # 117
T900_jr_cond: int  # 118
T900_jrl: int  # 119
T900_jrl_cond: int  # 120
T900_last: int  # 130
T900_ld: int  # 1
T900_lda: int  # 7
T900_ldar: int  # 8
T900_ldc: int  # 81
T900_ldcf: int  # 60
T900_ldd: int  # 15
T900_lddr: int  # 17
T900_lddrw: int  # 18
T900_lddw: int  # 16
T900_ldf: int  # 85
T900_ldi: int  # 11
T900_ldir: int  # 13
T900_ldirw: int  # 14
T900_ldiw: int  # 12
T900_ldw: int  # 2
T900_ldx: int  # 82
T900_link: int  # 83
T900_max: int  # 128
T900_mdec1: int  # 51
T900_mdec2: int  # 52
T900_mdec4: int  # 53
T900_minc1: int  # 48
T900_minc2: int  # 49
T900_minc4: int  # 50
T900_mirr: int  # 10
T900_mul: int  # 43
T900_mula: int  # 47
T900_muls: int  # 44
T900_neg: int  # 37
T900_nop: int  # 76
T900_normal: int  # 129
T900_null: int  # 0
T900_or: int  # 56
T900_orcf: int  # 63
T900_orw: int  # 57
T900_paa: int  # 41
T900_pop: int  # 5
T900_popw: int  # 6
T900_push: int  # 3
T900_pushw: int  # 4
T900_rcf: int  # 65
T900_res: int  # 70
T900_ret: int  # 124
T900_ret_cond: int  # 125
T900_retd: int  # 126
T900_reti: int  # 127
T900_rl: int  # 95
T900_rl_mem: int  # 96
T900_rlc: int  # 89
T900_rlc_mem: int  # 90
T900_rlcw_mem: int  # 91
T900_rld: int  # 113
T900_rlw_mem: int  # 97
T900_rr: int  # 98
T900_rr_mem: int  # 99
T900_rrc: int  # 92
T900_rrc_mem: int  # 93
T900_rrcw_mem: int  # 94
T900_rrd: int  # 114
T900_rrw_mem: int  # 100
T900_sbc: int  # 29
T900_sbcw: int  # 30
T900_scc: int  # 88
T900_scf: int  # 66
T900_set: int  # 71
T900_sla: int  # 101
T900_sla_mem: int  # 102
T900_slaw_mem: int  # 103
T900_sll: int  # 107
T900_sll_mem: int  # 108
T900_sllw_mem: int  # 109
T900_sra: int  # 104
T900_sra_mem: int  # 105
T900_sraw_mem: int  # 106
T900_srl: int  # 110
T900_srl_mem: int  # 111
T900_srlw_mem: int  # 112
T900_stcf: int  # 61
T900_sub: int  # 27
T900_subw: int  # 28
T900_swi: int  # 79
T900_tset: int  # 73
T900_unlk: int  # 84
T900_xor: int  # 58
T900_xorcf: int  # 64
T900_xorw: int  # 59
T900_zcf: int  # 68
TMS28_aborti: int  # 1
TMS28_abs: int  # 2
TMS28_absf32: int  # 162
TMS28_absf64: int  # 222
TMS28_absi32div32: int  # 324
TMS28_absi32div32u: int  # 325
TMS28_absi64div32: int  # 326
TMS28_absi64div32u: int  # 327
TMS28_absi64div64: int  # 328
TMS28_absi64div64u: int  # 329
TMS28_abstc: int  # 3
TMS28_add: int  # 4
TMS28_addb: int  # 5
TMS28_addcl: int  # 6
TMS28_addcu: int  # 7
TMS28_addf32: int  # 163
TMS28_addf64: int  # 205
TMS28_addl: int  # 8
TMS28_addu: int  # 9
TMS28_addul: int  # 10
TMS28_adrk: int  # 11
TMS28_and: int  # 12
TMS28_andb: int  # 13
TMS28_asp: int  # 14
TMS28_asr: int  # 15
TMS28_asr64: int  # 16
TMS28_asrl: int  # 17
TMS28_atanpuf32: int  # 347
TMS28_b: int  # 18
TMS28_banz: int  # 19
TMS28_bar: int  # 20
TMS28_bf: int  # 21
TMS28_c27map: int  # 22
TMS28_c27obj: int  # 23
TMS28_c28addr: int  # 24
TMS28_c28map: int  # 25
TMS28_c28obj: int  # 26
TMS28_clrc: int  # 27
TMS28_cmp: int  # 28
TMS28_cmp64: int  # 29
TMS28_cmpb: int  # 30
TMS28_cmpf32: int  # 164
TMS28_cmpf64: int  # 207
TMS28_cmpl: int  # 31
TMS28_cmpr: int  # 32
TMS28_cospuf32: int  # 346
TMS28_csb: int  # 33
TMS28_dec: int  # 34
TMS28_dint: int  # 35
TMS28_div2pif32: int  # 342
TMS28_divf32: int  # 343
TMS28_dmac: int  # 36
TMS28_dmov: int  # 37
TMS28_eallow: int  # 38
TMS28_edis: int  # 39
TMS28_eint: int  # 40
TMS28_einvf32: int  # 165
TMS28_einvf64: int  # 226
TMS28_eisqrtf32: int  # 166
TMS28_eisqrtf64: int  # 225
TMS28_enegi32div32: int  # 333
TMS28_enegi64div32: int  # 336
TMS28_enegi64div64: int  # 339
TMS28_estop0: int  # 41
TMS28_estop1: int  # 42
TMS28_f32dtof64: int  # 221
TMS28_f32tof64: int  # 220
TMS28_f32toi16: int  # 167
TMS28_f32toi16r: int  # 168
TMS28_f32toi32: int  # 169
TMS28_f32toui16: int  # 170
TMS28_f32toui16r: int  # 171
TMS28_f32toui32: int  # 172
TMS28_f64tof32: int  # 219
TMS28_f64toi32: int  # 210
TMS28_f64toi64: int  # 214
TMS28_f64toui32: int  # 211
TMS28_f64toui64: int  # 215
TMS28_ffc: int  # 43
TMS28_flip: int  # 44
TMS28_fracf32: int  # 173
TMS28_fracf64: int  # 218
TMS28_i16tof32: int  # 174
TMS28_i32tof32: int  # 175
TMS28_i32tof64: int  # 212
TMS28_i64tof64: int  # 216
TMS28_iack: int  # 45
TMS28_idle: int  # 46
TMS28_iexp2f32: int  # 349
TMS28_imacl: int  # 47
TMS28_impyal: int  # 48
TMS28_impyl: int  # 49
TMS28_impysl: int  # 50
TMS28_impyxul: int  # 51
TMS28_in: int  # 52
TMS28_inc: int  # 53
TMS28_intr: int  # 54
TMS28_iret: int  # 55
TMS28_last: int  # 351
TMS28_lb: int  # 56
TMS28_lc: int  # 57
TMS28_lcr: int  # 58
TMS28_log2f32: int  # 350
TMS28_loopnz: int  # 59
TMS28_loopz: int  # 60
TMS28_lpaddr: int  # 61
TMS28_lret: int  # 62
TMS28_lrete: int  # 63
TMS28_lretr: int  # 64
TMS28_lsl: int  # 65
TMS28_lsl64: int  # 66
TMS28_lsll: int  # 67
TMS28_lsr: int  # 68
TMS28_lsr64: int  # 69
TMS28_lsrl: int  # 70
TMS28_mac: int  # 71
TMS28_macf32: int  # 176
TMS28_macf64: int  # 203
TMS28_max: int  # 72
TMS28_maxcul: int  # 73
TMS28_maxf32: int  # 177
TMS28_maxf64: int  # 208
TMS28_maxl: int  # 74
TMS28_min: int  # 75
TMS28_mincul: int  # 76
TMS28_minf32: int  # 178
TMS28_minf64: int  # 209
TMS28_minl: int  # 77
TMS28_mnegi32div32: int  # 334
TMS28_mnegi64div32: int  # 337
TMS28_mnegi64div64: int  # 340
TMS28_mov: int  # 78
TMS28_mov16: int  # 179
TMS28_mov32: int  # 180
TMS28_mov64: int  # 224
TMS28_mova: int  # 79
TMS28_movad: int  # 80
TMS28_movb: int  # 81
TMS28_movd32: int  # 181
TMS28_movdd32: int  # 201
TMS28_movdl: int  # 82
TMS28_movf32: int  # 182
TMS28_movh: int  # 83
TMS28_movix: int  # 202
TMS28_moviz: int  # 183
TMS28_movl: int  # 84
TMS28_movp: int  # 85
TMS28_movs: int  # 86
TMS28_movst0: int  # 184
TMS28_movu: int  # 87
TMS28_movw: int  # 88
TMS28_movx: int  # 89
TMS28_movxi: int  # 185
TMS28_movz: int  # 90
TMS28_mpy: int  # 91
TMS28_mpy2pif32: int  # 341
TMS28_mpya: int  # 92
TMS28_mpyb: int  # 93
TMS28_mpyf32: int  # 186
TMS28_mpyf64: int  # 204
TMS28_mpys: int  # 94
TMS28_mpyu: int  # 95
TMS28_mpyxu: int  # 96
TMS28_nasp: int  # 97
TMS28_neg: int  # 98
TMS28_neg64: int  # 99
TMS28_negf32: int  # 187
TMS28_negf64: int  # 223
TMS28_negi32div32: int  # 332
TMS28_negi64div32: int  # 335
TMS28_negi64div64: int  # 338
TMS28_negtc: int  # 100
TMS28_nop: int  # 101
TMS28_norm: int  # 102
TMS28_not: int  # 103
TMS28_null: int  # 0
TMS28_or: int  # 104
TMS28_orb: int  # 105
TMS28_out: int  # 106
TMS28_pop: int  # 107
TMS28_poprb: int  # 188
TMS28_pread: int  # 108
TMS28_push: int  # 109
TMS28_pushrb: int  # 189
TMS28_pwrite: int  # 110
TMS28_qmacl: int  # 111
TMS28_qmpyal: int  # 112
TMS28_qmpyl: int  # 113
TMS28_qmpysl: int  # 114
TMS28_qmpyul: int  # 115
TMS28_qmpyxul: int  # 116
TMS28_quadf32: int  # 348
TMS28_restore: int  # 190
TMS28_rol: int  # 117
TMS28_ror: int  # 118
TMS28_rpt: int  # 119
TMS28_rptb: int  # 191
TMS28_sat: int  # 120
TMS28_sat64: int  # 121
TMS28_save: int  # 192
TMS28_sb: int  # 122
TMS28_sbbu: int  # 123
TMS28_sbf: int  # 124
TMS28_sbrk: int  # 125
TMS28_setc: int  # 126
TMS28_setflg: int  # 193
TMS28_sfr: int  # 127
TMS28_sinpuf32: int  # 345
TMS28_spm: int  # 128
TMS28_sqra: int  # 129
TMS28_sqrs: int  # 130
TMS28_sqrtf32: int  # 344
TMS28_sub: int  # 131
TMS28_subb: int  # 132
TMS28_subbl: int  # 133
TMS28_subc2ui64: int  # 331
TMS28_subc4ui32: int  # 330
TMS28_subcu: int  # 134
TMS28_subcul: int  # 135
TMS28_subf32: int  # 194
TMS28_subf64: int  # 206
TMS28_subl: int  # 136
TMS28_subr: int  # 137
TMS28_subrl: int  # 138
TMS28_subu: int  # 139
TMS28_subul: int  # 140
TMS28_swapf: int  # 195
TMS28_sxtb: int  # 141
TMS28_tbit: int  # 142
TMS28_tclr: int  # 143
TMS28_test: int  # 144
TMS28_testtf: int  # 196
TMS28_trap: int  # 145
TMS28_tset: int  # 146
TMS28_ui16tof32: int  # 197
TMS28_ui32tof32: int  # 198
TMS28_ui32tof64: int  # 213
TMS28_ui64tof64: int  # 217
TMS28_uout: int  # 147
TMS28_vashl32: int  # 286
TMS28_vashr32: int  # 287
TMS28_vbitflip: int  # 288
TMS28_vcadd: int  # 243
TMS28_vccmac: int  # 291
TMS28_vccmpy: int  # 292
TMS28_vccon: int  # 293
TMS28_vcdadd16: int  # 244
TMS28_vcdsub16: int  # 245
TMS28_vcfft1: int  # 303
TMS28_vcfft10: int  # 312
TMS28_vcfft2: int  # 304
TMS28_vcfft3: int  # 305
TMS28_vcfft4: int  # 306
TMS28_vcfft5: int  # 307
TMS28_vcfft6: int  # 308
TMS28_vcfft7: int  # 309
TMS28_vcfft8: int  # 310
TMS28_vcfft9: int  # 311
TMS28_vcflip: int  # 294
TMS28_vclear: int  # 227
TMS28_vclearall: int  # 228
TMS28_vclrcpack: int  # 280
TMS28_vclrcrcmsgflip: int  # 271
TMS28_vclrdive: int  # 298
TMS28_vclropack: int  # 281
TMS28_vclrovfi: int  # 229
TMS28_vclrovfr: int  # 230
TMS28_vcmac: int  # 246
TMS28_vcmag: int  # 295
TMS28_vcmpy: int  # 247
TMS28_vcrc16p1h_1: int  # 252
TMS28_vcrc16p1l_1: int  # 253
TMS28_vcrc16p2h_1: int  # 254
TMS28_vcrc16p2l_1: int  # 255
TMS28_vcrc24h_1: int  # 275
TMS28_vcrc24l_1: int  # 274
TMS28_vcrc32h_1: int  # 256
TMS28_vcrc32l_1: int  # 257
TMS28_vcrc32p2h_1: int  # 273
TMS28_vcrc32p2l_1: int  # 272
TMS28_vcrc8h_1: int  # 250
TMS28_vcrc8l_1: int  # 251
TMS28_vcrcclr: int  # 258
TMS28_vcrch: int  # 278
TMS28_vcrcl: int  # 277
TMS28_vcshl16: int  # 296
TMS28_vcshr16: int  # 297
TMS28_vcsub: int  # 249
TMS28_vdec: int  # 299
TMS28_vgfacc: int  # 313
TMS28_vgfadd4: int  # 314
TMS28_vgfinit: int  # 315
TMS28_vgfmac4: int  # 316
TMS28_vgfmpy4: int  # 317
TMS28_vinc: int  # 300
TMS28_vitbm2: int  # 259
TMS28_vitbm3: int  # 260
TMS28_vitdhaddsub: int  # 261
TMS28_vitdhsubadd: int  # 262
TMS28_vitdladdsub: int  # 263
TMS28_vitdlsubadd: int  # 264
TMS28_vithsel: int  # 265
TMS28_vitlsel: int  # 266
TMS28_vitstage: int  # 321
TMS28_vlshl32: int  # 289
TMS28_vlshr32: int  # 290
TMS28_vmod32: int  # 301
TMS28_vmov16: int  # 231
TMS28_vmov32: int  # 232
TMS28_vmovd32: int  # 233
TMS28_vmovix: int  # 234
TMS28_vmovxi: int  # 236
TMS28_vmovzi: int  # 235
TMS28_vmpyadd: int  # 302
TMS28_vneg: int  # 248
TMS28_vnop: int  # 269
TMS28_vpack4: int  # 318
TMS28_vrevb: int  # 319
TMS28_vrndoff: int  # 237
TMS28_vrndon: int  # 238
TMS28_vsatoff: int  # 239
TMS28_vsaton: int  # 240
TMS28_vsetcpack: int  # 282
TMS28_vsetcrcmsgflip: int  # 270
TMS28_vsetcrcsize: int  # 276
TMS28_vsetk: int  # 322
TMS28_vsetopack: int  # 283
TMS28_vsetshl: int  # 241
TMS28_vsetshr: int  # 242
TMS28_vshlmb: int  # 320
TMS28_vsminit: int  # 323
TMS28_vswap32: int  # 284
TMS28_vswapcrc: int  # 279
TMS28_vtclear: int  # 267
TMS28_vtrace: int  # 268
TMS28_vxormov32: int  # 285
TMS28_xb: int  # 148
TMS28_xbanz: int  # 149
TMS28_xcall: int  # 150
TMS28_xmac: int  # 151
TMS28_xmacd: int  # 152
TMS28_xor: int  # 153
TMS28_xorb: int  # 154
TMS28_xpread: int  # 155
TMS28_xpwrite: int  # 156
TMS28_xret: int  # 157
TMS28_xretc: int  # 158
TMS28_zalr: int  # 159
TMS28_zap: int  # 160
TMS28_zapa: int  # 161
TMS28_zero: int  # 199
TMS28_zeroa: int  # 200
TMS2_abs: int  # 139
TMS2_add: int  # 140
TMS2_addc: int  # 141
TMS2_addh: int  # 142
TMS2_addk: int  # 143
TMS2_adds: int  # 144
TMS2_addt: int  # 145
TMS2_adlk: int  # 146
TMS2_adrk: int  # 147
TMS2_and: int  # 148
TMS2_andk: int  # 149
TMS2_apac: int  # 150
TMS2_b: int  # 151
TMS2_bacc: int  # 152
TMS2_banz: int  # 153
TMS2_bbnz: int  # 154
TMS2_bbz: int  # 155
TMS2_bc: int  # 156
TMS2_bgez: int  # 157
TMS2_bgz: int  # 158
TMS2_bioz: int  # 159
TMS2_bit: int  # 160
TMS2_bitt: int  # 161
TMS2_blez: int  # 162
TMS2_blkd: int  # 163
TMS2_blkp: int  # 164
TMS2_blz: int  # 165
TMS2_bnc: int  # 166
TMS2_bnv: int  # 167
TMS2_bnz: int  # 168
TMS2_bv: int  # 169
TMS2_bz: int  # 170
TMS2_cala: int  # 171
TMS2_call: int  # 172
TMS2_cmpl: int  # 173
TMS2_cmpr: int  # 174
TMS2_cnfd: int  # 175
TMS2_cnfp: int  # 176
TMS2_conf: int  # 177
TMS2_dint: int  # 178
TMS2_dmov: int  # 179
TMS2_eint: int  # 180
TMS2_fort: int  # 181
TMS2_idle: int  # 182
TMS2_in: int  # 183
TMS2_lac: int  # 184
TMS2_lack: int  # 185
TMS2_lact: int  # 186
TMS2_lalk: int  # 187
TMS2_lar: int  # 188
TMS2_lark: int  # 189
TMS2_larp: int  # 190
TMS2_ldp: int  # 191
TMS2_ldpk: int  # 192
TMS2_lph: int  # 193
TMS2_lrlk: int  # 194
TMS2_lst: int  # 195
TMS2_lst1: int  # 196
TMS2_lt: int  # 197
TMS2_lta: int  # 198
TMS2_ltd: int  # 199
TMS2_ltp: int  # 200
TMS2_lts: int  # 201
TMS2_mac: int  # 202
TMS2_macd: int  # 203
TMS2_mar: int  # 204
TMS2_mpy: int  # 205
TMS2_mpya: int  # 206
TMS2_mpyk: int  # 207
TMS2_mpys: int  # 208
TMS2_mpyu: int  # 209
TMS2_neg: int  # 210
TMS2_nop: int  # 211
TMS2_norm: int  # 212
TMS2_or: int  # 213
TMS2_ork: int  # 214
TMS2_out: int  # 215
TMS2_pac: int  # 216
TMS2_pop: int  # 217
TMS2_popd: int  # 218
TMS2_pshd: int  # 219
TMS2_push: int  # 220
TMS2_rc: int  # 221
TMS2_ret: int  # 222
TMS2_rfsm: int  # 223
TMS2_rhm: int  # 224
TMS2_rol: int  # 225
TMS2_ror: int  # 226
TMS2_rovm: int  # 227
TMS2_rpt: int  # 228
TMS2_rptk: int  # 229
TMS2_rsxm: int  # 230
TMS2_rtc: int  # 231
TMS2_rtxm: int  # 232
TMS2_rxf: int  # 233
TMS2_sach: int  # 234
TMS2_sacl: int  # 235
TMS2_sar: int  # 236
TMS2_sblk: int  # 237
TMS2_sbrk: int  # 238
TMS2_sc: int  # 239
TMS2_sfl: int  # 240
TMS2_sfr: int  # 241
TMS2_sfsm: int  # 242
TMS2_shm: int  # 243
TMS2_sovm: int  # 244
TMS2_spac: int  # 245
TMS2_sph: int  # 246
TMS2_spl: int  # 247
TMS2_spm: int  # 248
TMS2_sqra: int  # 249
TMS2_sqrs: int  # 250
TMS2_sst: int  # 251
TMS2_sst1: int  # 252
TMS2_ssxm: int  # 253
TMS2_stc: int  # 254
TMS2_stxm: int  # 255
TMS2_sub: int  # 256
TMS2_subb: int  # 257
TMS2_subc: int  # 258
TMS2_subh: int  # 259
TMS2_subk: int  # 260
TMS2_subs: int  # 261
TMS2_subt: int  # 262
TMS2_sxf: int  # 263
TMS2_tblr: int  # 264
TMS2_tblw: int  # 265
TMS2_trap: int  # 266
TMS2_xor: int  # 267
TMS2_xork: int  # 268
TMS2_zac: int  # 269
TMS2_zalh: int  # 270
TMS2_zalr: int  # 271
TMS2_zals: int  # 272
TMS320C3X_ABSF: int  # 1
TMS320C3X_ABSI: int  # 2
TMS320C3X_ADDC: int  # 3
TMS320C3X_ADDC3: int  # 58
TMS320C3X_ADDF: int  # 4
TMS320C3X_ADDF3: int  # 59
TMS320C3X_ADDI: int  # 5
TMS320C3X_ADDI3: int  # 60
TMS320C3X_AND: int  # 6
TMS320C3X_AND3: int  # 61
TMS320C3X_ANDN: int  # 7
TMS320C3X_ANDN3: int  # 62
TMS320C3X_ASH: int  # 8
TMS320C3X_ASH3: int  # 63
TMS320C3X_BR: int  # 77
TMS320C3X_BRD: int  # 78
TMS320C3X_Bcond: int  # 82
TMS320C3X_CALL: int  # 79
TMS320C3X_CALLcond: int  # 84
TMS320C3X_CMPF: int  # 9
TMS320C3X_CMPF3: int  # 64
TMS320C3X_CMPI: int  # 10
TMS320C3X_CMPI3: int  # 65
TMS320C3X_DBcond: int  # 83
TMS320C3X_FIX: int  # 11
TMS320C3X_FLOAT: int  # 12
TMS320C3X_IACK: int  # 57
TMS320C3X_IDLE: int  # 13
TMS320C3X_IDLE2: int  # 14
TMS320C3X_LDE: int  # 15
TMS320C3X_LDF: int  # 16
TMS320C3X_LDFI: int  # 17
TMS320C3X_LDFcond: int  # 75
TMS320C3X_LDI: int  # 18
TMS320C3X_LDII: int  # 19
TMS320C3X_LDIcond: int  # 76
TMS320C3X_LDM: int  # 20
TMS320C3X_LOPOWER: int  # 35
TMS320C3X_LSH: int  # 21
TMS320C3X_LSH3: int  # 66
TMS320C3X_MAXSPEED: int  # 36
TMS320C3X_MPYF: int  # 22
TMS320C3X_MPYF3: int  # 67
TMS320C3X_MPYI: int  # 23
TMS320C3X_MPYI3: int  # 68
TMS320C3X_MV_IDX: int  # 91
TMS320C3X_NEGB: int  # 24
TMS320C3X_NEGF: int  # 25
TMS320C3X_NEGI: int  # 26
TMS320C3X_NONE: int  # 90
TMS320C3X_NOP: int  # 27
TMS320C3X_NORM: int  # 28
TMS320C3X_NOT: int  # 29
TMS320C3X_OR: int  # 34
TMS320C3X_OR3: int  # 69
TMS320C3X_POP: int  # 30
TMS320C3X_POPF: int  # 31
TMS320C3X_PUSH: int  # 32
TMS320C3X_PUSHF: int  # 33
TMS320C3X_RETIU: int  # 88
TMS320C3X_RETIcond: int  # 86
TMS320C3X_RETSU: int  # 89
TMS320C3X_RETScond: int  # 87
TMS320C3X_RND: int  # 37
TMS320C3X_ROL: int  # 38
TMS320C3X_ROLC: int  # 39
TMS320C3X_ROR: int  # 40
TMS320C3X_RORC: int  # 41
TMS320C3X_RPTB: int  # 80
TMS320C3X_RPTS: int  # 42
TMS320C3X_SIGI: int  # 47
TMS320C3X_STF: int  # 43
TMS320C3X_STFI: int  # 44
TMS320C3X_STI: int  # 45
TMS320C3X_STII: int  # 46
TMS320C3X_SUBB: int  # 48
TMS320C3X_SUBB3: int  # 70
TMS320C3X_SUBC: int  # 49
TMS320C3X_SUBF: int  # 50
TMS320C3X_SUBF3: int  # 71
TMS320C3X_SUBI: int  # 51
TMS320C3X_SUBI3: int  # 72
TMS320C3X_SUBRB: int  # 52
TMS320C3X_SUBRF: int  # 53
TMS320C3X_SUBRI: int  # 54
TMS320C3X_SWI: int  # 81
TMS320C3X_TRAPcond: int  # 85
TMS320C3X_TSTB: int  # 55
TMS320C3X_TSTB3: int  # 73
TMS320C3X_XOR: int  # 56
TMS320C3X_XOR3: int  # 74
TMS320C3X_last: int  # 92
TMS320C3X_null: int  # 0
TMS320C54_abdst: int  # 51
TMS320C54_abs1: int  # 52
TMS320C54_abs2: int  # 53
TMS320C54_add1: int  # 1
TMS320C54_add2: int  # 2
TMS320C54_add3: int  # 3
TMS320C54_addc: int  # 4
TMS320C54_addm: int  # 5
TMS320C54_adds: int  # 6
TMS320C54_and1: int  # 71
TMS320C54_and2: int  # 72
TMS320C54_and3: int  # 73
TMS320C54_andm: int  # 74
TMS320C54_b: int  # 96
TMS320C54_bacc: int  # 98
TMS320C54_baccd: int  # 99
TMS320C54_banz: int  # 100
TMS320C54_banzd: int  # 101
TMS320C54_bc2: int  # 102
TMS320C54_bc3: int  # 103
TMS320C54_bcd2: int  # 104
TMS320C54_bcd3: int  # 105
TMS320C54_bd: int  # 97
TMS320C54_bit: int  # 91
TMS320C54_bitf: int  # 92
TMS320C54_bitt: int  # 93
TMS320C54_cala: int  # 110
TMS320C54_calad: int  # 111
TMS320C54_call: int  # 112
TMS320C54_calld: int  # 113
TMS320C54_cc2: int  # 114
TMS320C54_cc3: int  # 115
TMS320C54_ccd2: int  # 116
TMS320C54_ccd3: int  # 117
TMS320C54_cmpl1: int  # 54
TMS320C54_cmpl2: int  # 55
TMS320C54_cmpm: int  # 94
TMS320C54_cmpr: int  # 95
TMS320C54_cmps: int  # 175
TMS320C54_dadd2: int  # 44
TMS320C54_dadd3: int  # 45
TMS320C54_dadst: int  # 46
TMS320C54_delay: int  # 56
TMS320C54_dld: int  # 159
TMS320C54_drsub: int  # 47
TMS320C54_dsadt: int  # 48
TMS320C54_dst: int  # 167
TMS320C54_dsub: int  # 49
TMS320C54_dsubt: int  # 50
TMS320C54_exp: int  # 57
TMS320C54_fb: int  # 106
TMS320C54_fbacc: int  # 108
TMS320C54_fbaccd: int  # 109
TMS320C54_fbd: int  # 107
TMS320C54_fcala: int  # 118
TMS320C54_fcalad: int  # 119
TMS320C54_fcall: int  # 120
TMS320C54_fcalld: int  # 121
TMS320C54_firs: int  # 58
TMS320C54_frame: int  # 144
TMS320C54_fret: int  # 124
TMS320C54_fretd: int  # 125
TMS320C54_frete: int  # 126
TMS320C54_freted: int  # 127
TMS320C54_idle: int  # 149
TMS320C54_intr: int  # 122
TMS320C54_last: int  # 203
TMS320C54_ld1: int  # 160
TMS320C54_ld2: int  # 161
TMS320C54_ld3: int  # 162
TMS320C54_ld_mac: int  # 180
TMS320C54_ld_macr: int  # 181
TMS320C54_ld_mas: int  # 182
TMS320C54_ld_masr: int  # 183
TMS320C54_ldm: int  # 163
TMS320C54_ldr: int  # 164
TMS320C54_ldu: int  # 165
TMS320C54_lms: int  # 59
TMS320C54_ltd: int  # 166
TMS320C54_mac2: int  # 19
TMS320C54_mac3: int  # 20
TMS320C54_maca1: int  # 23
TMS320C54_maca2: int  # 24
TMS320C54_maca3: int  # 25
TMS320C54_macar1: int  # 26
TMS320C54_macar2: int  # 27
TMS320C54_macar3: int  # 28
TMS320C54_macd: int  # 29
TMS320C54_macp: int  # 30
TMS320C54_macr2: int  # 21
TMS320C54_macr3: int  # 22
TMS320C54_macsu: int  # 31
TMS320C54_mar: int  # 150
TMS320C54_mas2: int  # 32
TMS320C54_mas3: int  # 33
TMS320C54_masa1: int  # 36
TMS320C54_masa2: int  # 37
TMS320C54_masa3: int  # 38
TMS320C54_masar1: int  # 39
TMS320C54_masar2: int  # 40
TMS320C54_masar3: int  # 41
TMS320C54_masr2: int  # 34
TMS320C54_masr3: int  # 35
TMS320C54_max: int  # 60
TMS320C54_min: int  # 61
TMS320C54_mpy2: int  # 13
TMS320C54_mpy3: int  # 14
TMS320C54_mpya: int  # 16
TMS320C54_mpyr2: int  # 15
TMS320C54_mpyu: int  # 17
TMS320C54_mvdd: int  # 191
TMS320C54_mvdk: int  # 192
TMS320C54_mvdm: int  # 193
TMS320C54_mvdp: int  # 194
TMS320C54_mvkd: int  # 195
TMS320C54_mvmd: int  # 196
TMS320C54_mvmm: int  # 197
TMS320C54_mvpd: int  # 198
TMS320C54_neg1: int  # 62
TMS320C54_neg2: int  # 63
TMS320C54_nop: int  # 151
TMS320C54_norm1: int  # 64
TMS320C54_norm2: int  # 65
TMS320C54_null: int  # 0
TMS320C54_or1: int  # 75
TMS320C54_or2: int  # 76
TMS320C54_or3: int  # 77
TMS320C54_orm: int  # 78
TMS320C54_poly: int  # 66
TMS320C54_popd: int  # 145
TMS320C54_popm: int  # 146
TMS320C54_portr: int  # 199
TMS320C54_portw: int  # 200
TMS320C54_pshd: int  # 147
TMS320C54_pshm: int  # 148
TMS320C54_rc1: int  # 128
TMS320C54_rc2: int  # 129
TMS320C54_rc3: int  # 130
TMS320C54_rcd1: int  # 131
TMS320C54_rcd2: int  # 132
TMS320C54_rcd3: int  # 133
TMS320C54_reada: int  # 201
TMS320C54_reset: int  # 152
TMS320C54_ret: int  # 134
TMS320C54_retd: int  # 135
TMS320C54_rete: int  # 136
TMS320C54_reted: int  # 137
TMS320C54_retf: int  # 138
TMS320C54_retfd: int  # 139
TMS320C54_rnd1: int  # 67
TMS320C54_rnd2: int  # 68
TMS320C54_rol: int  # 83
TMS320C54_roltc: int  # 84
TMS320C54_ror: int  # 85
TMS320C54_rpt: int  # 140
TMS320C54_rptb: int  # 141
TMS320C54_rptbd: int  # 142
TMS320C54_rptz: int  # 143
TMS320C54_rsbx1: int  # 153
TMS320C54_rsbx2: int  # 154
TMS320C54_saccd: int  # 176
TMS320C54_sat: int  # 69
TMS320C54_sfta2: int  # 86
TMS320C54_sfta3: int  # 87
TMS320C54_sftc: int  # 88
TMS320C54_sftl2: int  # 89
TMS320C54_sftl3: int  # 90
TMS320C54_sqdst: int  # 70
TMS320C54_squr: int  # 18
TMS320C54_squra: int  # 42
TMS320C54_squrs: int  # 43
TMS320C54_srccd: int  # 177
TMS320C54_ssbx1: int  # 155
TMS320C54_ssbx2: int  # 156
TMS320C54_st: int  # 168
TMS320C54_st_add: int  # 184
TMS320C54_st_ld: int  # 179
TMS320C54_st_mac: int  # 186
TMS320C54_st_macr: int  # 187
TMS320C54_st_mas: int  # 188
TMS320C54_st_masr: int  # 189
TMS320C54_st_mpy: int  # 190
TMS320C54_st_sub: int  # 185
TMS320C54_sth2: int  # 169
TMS320C54_sth3: int  # 170
TMS320C54_stl2: int  # 171
TMS320C54_stl3: int  # 172
TMS320C54_stlm: int  # 173
TMS320C54_stm: int  # 174
TMS320C54_strcd: int  # 178
TMS320C54_sub1: int  # 7
TMS320C54_sub2: int  # 8
TMS320C54_sub3: int  # 9
TMS320C54_subb: int  # 10
TMS320C54_subc: int  # 11
TMS320C54_subs: int  # 12
TMS320C54_trap: int  # 123
TMS320C54_writa: int  # 202
TMS320C54_xc2: int  # 157
TMS320C54_xc3: int  # 158
TMS320C54_xor1: int  # 79
TMS320C54_xor2: int  # 80
TMS320C54_xor3: int  # 81
TMS320C54_xorm: int  # 82
TMS320C55_aadd: int  # 89
TMS320C55_abdst: int  # 1
TMS320C55_abs1: int  # 2
TMS320C55_abs2: int  # 3
TMS320C55_add1: int  # 4
TMS320C55_add2: int  # 5
TMS320C55_add3: int  # 6
TMS320C55_add4: int  # 7
TMS320C55_add_asub: int  # 79
TMS320C55_add_mov: int  # 73
TMS320C55_addrv1: int  # 10
TMS320C55_addrv2: int  # 11
TMS320C55_addsub: int  # 22
TMS320C55_addsub2cc: int  # 18
TMS320C55_addsubcc4: int  # 16
TMS320C55_addsubcc5: int  # 17
TMS320C55_addv1: int  # 8
TMS320C55_addv2: int  # 9
TMS320C55_amar1: int  # 92
TMS320C55_amar2: int  # 209
TMS320C55_amar3: int  # 64
TMS320C55_amar_amar: int  # 78
TMS320C55_amar_mac: int  # 48
TMS320C55_amar_mac40: int  # 50
TMS320C55_amar_macr: int  # 49
TMS320C55_amar_macr40: int  # 51
TMS320C55_amar_mas: int  # 56
TMS320C55_amar_mas40: int  # 58
TMS320C55_amar_masr: int  # 57
TMS320C55_amar_masr40: int  # 59
TMS320C55_amar_mpy: int  # 36
TMS320C55_amar_mpy40: int  # 38
TMS320C55_amar_mpyr: int  # 37
TMS320C55_amar_mpyr40: int  # 39
TMS320C55_amov: int  # 91
TMS320C55_and1: int  # 215
TMS320C55_and2: int  # 216
TMS320C55_and3: int  # 217
TMS320C55_asub: int  # 90
TMS320C55_b: int  # 241
TMS320C55_band: int  # 196
TMS320C55_bcc: int  # 239
TMS320C55_bccu: int  # 240
TMS320C55_bclr1: int  # 207
TMS320C55_bclr2: int  # 201
TMS320C55_bcnt: int  # 212
TMS320C55_bfxpa: int  # 197
TMS320C55_bfxtr: int  # 198
TMS320C55_bnot: int  # 200
TMS320C55_bset1: int  # 208
TMS320C55_bset2: int  # 202
TMS320C55_btst: int  # 199
TMS320C55_btst_mov: int  # 80
TMS320C55_btstclr: int  # 204
TMS320C55_btstnot: int  # 205
TMS320C55_btstp: int  # 206
TMS320C55_btstset: int  # 203
TMS320C55_call: int  # 243
TMS320C55_callcc: int  # 242
TMS320C55_cmp: int  # 87
TMS320C55_cmpand: int  # 177
TMS320C55_cmpandu: int  # 178
TMS320C55_cmpor: int  # 179
TMS320C55_cmporu: int  # 180
TMS320C55_cmpu: int  # 88
TMS320C55_delay: int  # 234
TMS320C55_dmaxdiff: int  # 13
TMS320C55_dmindiff: int  # 15
TMS320C55_exp: int  # 176
TMS320C55_firsadd: int  # 65
TMS320C55_firssub: int  # 66
TMS320C55_idle: int  # 246
TMS320C55_intr: int  # 258
TMS320C55_last: int  # 261
TMS320C55_lms: int  # 82
TMS320C55_mac3: int  # 123
TMS320C55_mac4: int  # 124
TMS320C55_mac40_mac40: int  # 42
TMS320C55_mac40_mpy40: int  # 30
TMS320C55_mac_mac: int  # 40
TMS320C55_mac_mpy: int  # 28
TMS320C55_mack3: int  # 127
TMS320C55_mack4: int  # 128
TMS320C55_mackr3: int  # 129
TMS320C55_mackr4: int  # 130
TMS320C55_macm2: int  # 131
TMS320C55_macm3: int  # 132
TMS320C55_macm4: int  # 133
TMS320C55_macm403: int  # 137
TMS320C55_macm404: int  # 138
TMS320C55_macm_mov: int  # 69
TMS320C55_macmk3: int  # 147
TMS320C55_macmk4: int  # 148
TMS320C55_macmkr3: int  # 149
TMS320C55_macmkr4: int  # 150
TMS320C55_macmr2: int  # 134
TMS320C55_macmr3: int  # 135
TMS320C55_macmr4: int  # 136
TMS320C55_macmr403: int  # 139
TMS320C55_macmr404: int  # 140
TMS320C55_macmr_mov: int  # 70
TMS320C55_macmrz: int  # 142
TMS320C55_macmz: int  # 141
TMS320C55_macr3: int  # 125
TMS320C55_macr4: int  # 126
TMS320C55_macr40_macr40: int  # 43
TMS320C55_macr40_mpyr40: int  # 31
TMS320C55_macr_macr: int  # 41
TMS320C55_macr_mpyr: int  # 29
TMS320C55_mant_nexp: int  # 175
TMS320C55_mas2: int  # 155
TMS320C55_mas3: int  # 156
TMS320C55_mas40_mac40: int  # 46
TMS320C55_mas40_mas40: int  # 54
TMS320C55_mas40_mpy40: int  # 34
TMS320C55_mas_mac: int  # 44
TMS320C55_mas_mas: int  # 52
TMS320C55_mas_mpy: int  # 32
TMS320C55_masm2: int  # 159
TMS320C55_masm3: int  # 160
TMS320C55_masm4: int  # 161
TMS320C55_masm403: int  # 165
TMS320C55_masm404: int  # 166
TMS320C55_masm_mov: int  # 71
TMS320C55_masmr2: int  # 162
TMS320C55_masmr3: int  # 163
TMS320C55_masmr4: int  # 164
TMS320C55_masmr403: int  # 167
TMS320C55_masmr404: int  # 168
TMS320C55_masmr_mov: int  # 72
TMS320C55_masr2: int  # 157
TMS320C55_masr3: int  # 158
TMS320C55_masr40_macr40: int  # 47
TMS320C55_masr40_masr40: int  # 55
TMS320C55_masr40_mpyr40: int  # 35
TMS320C55_masr_macr: int  # 45
TMS320C55_masr_masr: int  # 53
TMS320C55_masr_mpyr: int  # 33
TMS320C55_max1: int  # 83
TMS320C55_max2: int  # 84
TMS320C55_maxdiff: int  # 12
TMS320C55_min1: int  # 85
TMS320C55_min2: int  # 86
TMS320C55_mindiff: int  # 14
TMS320C55_mov2: int  # 231
TMS320C55_mov3: int  # 232
TMS320C55_mov402: int  # 233
TMS320C55_mov_aadd: int  # 76
TMS320C55_mov_add: int  # 77
TMS320C55_mov_asub: int  # 81
TMS320C55_mov_mov: int  # 75
TMS320C55_mpy1: int  # 97
TMS320C55_mpy2: int  # 98
TMS320C55_mpy3: int  # 99
TMS320C55_mpy40_mac40: int  # 62
TMS320C55_mpy_mac: int  # 60
TMS320C55_mpy_mpy: int  # 24
TMS320C55_mpy_mpy40: int  # 26
TMS320C55_mpy_mpyr: int  # 25
TMS320C55_mpy_mpyr40: int  # 27
TMS320C55_mpyk2: int  # 103
TMS320C55_mpyk3: int  # 104
TMS320C55_mpykr2: int  # 105
TMS320C55_mpykr3: int  # 106
TMS320C55_mpym2: int  # 107
TMS320C55_mpym3: int  # 108
TMS320C55_mpym403: int  # 111
TMS320C55_mpym_mov: int  # 67
TMS320C55_mpymk: int  # 117
TMS320C55_mpymkr: int  # 118
TMS320C55_mpymr2: int  # 109
TMS320C55_mpymr3: int  # 110
TMS320C55_mpymr403: int  # 112
TMS320C55_mpymr_mov: int  # 68
TMS320C55_mpymru3: int  # 114
TMS320C55_mpymu3: int  # 113
TMS320C55_mpyr1: int  # 100
TMS320C55_mpyr2: int  # 101
TMS320C55_mpyr3: int  # 102
TMS320C55_mpyr40_macr40: int  # 63
TMS320C55_mpyr_macr: int  # 61
TMS320C55_neg1: int  # 173
TMS320C55_neg2: int  # 174
TMS320C55_nop: int  # 247
TMS320C55_nop_16: int  # 248
TMS320C55_not1: int  # 213
TMS320C55_not2: int  # 214
TMS320C55_null: int  # 0
TMS320C55_or1: int  # 218
TMS320C55_or2: int  # 219
TMS320C55_or3: int  # 220
TMS320C55_pop1: int  # 235
TMS320C55_pop2: int  # 236
TMS320C55_popboth: int  # 210
TMS320C55_psh1: int  # 237
TMS320C55_psh2: int  # 238
TMS320C55_pshboth: int  # 211
TMS320C55_reset: int  # 259
TMS320C55_ret: int  # 256
TMS320C55_retcc: int  # 255
TMS320C55_reti: int  # 257
TMS320C55_rol: int  # 226
TMS320C55_ror: int  # 227
TMS320C55_round1: int  # 181
TMS320C55_round2: int  # 182
TMS320C55_rpt: int  # 252
TMS320C55_rptadd: int  # 253
TMS320C55_rptb: int  # 250
TMS320C55_rptblocal: int  # 249
TMS320C55_rptcc: int  # 251
TMS320C55_rptsub: int  # 254
TMS320C55_sat1: int  # 183
TMS320C55_sat2: int  # 184
TMS320C55_satr1: int  # 185
TMS320C55_satr2: int  # 186
TMS320C55_sftcc: int  # 19
TMS320C55_sftl2: int  # 224
TMS320C55_sftl3: int  # 225
TMS320C55_sfts2: int  # 187
TMS320C55_sfts3: int  # 188
TMS320C55_sftsc2: int  # 189
TMS320C55_sftsc3: int  # 190
TMS320C55_sqa1: int  # 119
TMS320C55_sqa2: int  # 120
TMS320C55_sqam2: int  # 143
TMS320C55_sqam3: int  # 144
TMS320C55_sqamr2: int  # 145
TMS320C55_sqamr3: int  # 146
TMS320C55_sqar1: int  # 121
TMS320C55_sqar2: int  # 122
TMS320C55_sqdst: int  # 191
TMS320C55_sqr1: int  # 93
TMS320C55_sqr2: int  # 94
TMS320C55_sqrm: int  # 115
TMS320C55_sqrmr: int  # 116
TMS320C55_sqrr1: int  # 95
TMS320C55_sqrr2: int  # 96
TMS320C55_sqs1: int  # 151
TMS320C55_sqs2: int  # 152
TMS320C55_sqsm2: int  # 169
TMS320C55_sqsm3: int  # 170
TMS320C55_sqsmr2: int  # 171
TMS320C55_sqsmr3: int  # 172
TMS320C55_sqsr1: int  # 153
TMS320C55_sqsr2: int  # 154
TMS320C55_sub1: int  # 192
TMS320C55_sub2: int  # 193
TMS320C55_sub3: int  # 194
TMS320C55_sub4: int  # 195
TMS320C55_sub_mov: int  # 74
TMS320C55_subadd: int  # 23
TMS320C55_subc2: int  # 20
TMS320C55_subc3: int  # 21
TMS320C55_swap: int  # 228
TMS320C55_swap4: int  # 230
TMS320C55_swapp: int  # 229
TMS320C55_trap: int  # 260
TMS320C55_xcc: int  # 244
TMS320C55_xccpart: int  # 245
TMS320C55_xor1: int  # 221
TMS320C55_xor2: int  # 222
TMS320C55_xor3: int  # 223
TMS6_abs: int  # 1
TMS6_abs2: int  # 78
TMS6_absdp: int  # 79
TMS6_abssp: int  # 80
TMS6_add: int  # 2
TMS6_add2: int  # 8
TMS6_add4: int  # 81
TMS6_addab: int  # 4
TMS6_addad: int  # 82
TMS6_addah: int  # 5
TMS6_addaw: int  # 6
TMS6_adddp: int  # 83
TMS6_addk: int  # 7
TMS6_addkpc: int  # 84
TMS6_addsp: int  # 85
TMS6_addsub: int  # 86
TMS6_addsub2: int  # 87
TMS6_addu: int  # 3
TMS6_and: int  # 9
TMS6_andn: int  # 88
TMS6_avg2: int  # 89
TMS6_avgu4: int  # 90
TMS6_b: int  # 10
TMS6_bdec: int  # 91
TMS6_bitc4: int  # 92
TMS6_bitr: int  # 93
TMS6_bnop: int  # 94
TMS6_bpos: int  # 95
TMS6_callp: int  # 96
TMS6_ccmatmpy: int  # 233
TMS6_ccmatmpyr1: int  # 231
TMS6_ccmpy32r1: int  # 232
TMS6_clr: int  # 11
TMS6_cmatmpy: int  # 230
TMS6_cmatmpyr1: int  # 234
TMS6_cmpeq: int  # 12
TMS6_cmpeq2: int  # 97
TMS6_cmpeq4: int  # 98
TMS6_cmpeqdp: int  # 99
TMS6_cmpeqsp: int  # 100
TMS6_cmpgt: int  # 13
TMS6_cmpgt2: int  # 101
TMS6_cmpgtdp: int  # 102
TMS6_cmpgtsp: int  # 103
TMS6_cmpgtu: int  # 14
TMS6_cmpgtu4: int  # 104
TMS6_cmplt: int  # 15
TMS6_cmplt2: int  # 105
TMS6_cmpltdp: int  # 106
TMS6_cmpltsp: int  # 107
TMS6_cmpltu: int  # 16
TMS6_cmpltu4: int  # 108
TMS6_cmpy: int  # 109
TMS6_cmpyr: int  # 110
TMS6_cmpyr1: int  # 111
TMS6_cmpysp: int  # 235
TMS6_crot270: int  # 237
TMS6_crot90: int  # 236
TMS6_dadd: int  # 238
TMS6_dadd2: int  # 239
TMS6_daddsp: int  # 240
TMS6_dapys2: int  # 241
TMS6_davg2: int  # 242
TMS6_davgnr2: int  # 243
TMS6_davgnru4: int  # 244
TMS6_davgu4: int  # 245
TMS6_dccmpy: int  # 246
TMS6_dccmpyr1: int  # 247
TMS6_dcmpeq2: int  # 248
TMS6_dcmpeq4: int  # 249
TMS6_dcmpgt2: int  # 250
TMS6_dcmpgtu4: int  # 251
TMS6_dcmpy: int  # 252
TMS6_dcmpyr1: int  # 253
TMS6_dcrot270: int  # 254
TMS6_dcrot90: int  # 255
TMS6_ddotp4: int  # 112
TMS6_ddotph2: int  # 113
TMS6_ddotph2r: int  # 114
TMS6_ddotpl2: int  # 115
TMS6_ddotpl2r: int  # 116
TMS6_deal: int  # 117
TMS6_dint: int  # 118
TMS6_dinthspu: int  # 256
TMS6_dintspu: int  # 257
TMS6_dmax2: int  # 258
TMS6_dmaxu4: int  # 259
TMS6_dmin2: int  # 260
TMS6_dminu4: int  # 261
TMS6_dmpy2: int  # 262
TMS6_dmpysp: int  # 263
TMS6_dmpysu4: int  # 264
TMS6_dmpyu2: int  # 265
TMS6_dmpyu4: int  # 266
TMS6_dmv: int  # 119
TMS6_dmvd: int  # 267
TMS6_dotp2: int  # 120
TMS6_dotpn2: int  # 121
TMS6_dotpnrsu2: int  # 122
TMS6_dotpnrus2: int  # 123
TMS6_dotprsu2: int  # 124
TMS6_dotprus2: int  # 125
TMS6_dotpsu4: int  # 126
TMS6_dotpu4: int  # 127
TMS6_dotpus4: int  # 128
TMS6_dpack2: int  # 129
TMS6_dpackh2: int  # 268
TMS6_dpackh4: int  # 269
TMS6_dpackhl2: int  # 270
TMS6_dpackl2: int  # 271
TMS6_dpackl4: int  # 272
TMS6_dpacklh2: int  # 273
TMS6_dpackx2: int  # 130
TMS6_dpint: int  # 131
TMS6_dpsp: int  # 132
TMS6_dptrunc: int  # 133
TMS6_dsadd: int  # 274
TMS6_dsadd2: int  # 275
TMS6_dshl: int  # 276
TMS6_dshl2: int  # 277
TMS6_dshr: int  # 278
TMS6_dshr2: int  # 279
TMS6_dshru: int  # 280
TMS6_dshru2: int  # 281
TMS6_dsmpy2: int  # 282
TMS6_dspacku4: int  # 283
TMS6_dspint: int  # 284
TMS6_dspinth: int  # 285
TMS6_dssub: int  # 286
TMS6_dssub2: int  # 287
TMS6_dsub: int  # 288
TMS6_dsub2: int  # 289
TMS6_dsubsp: int  # 290
TMS6_dxpnd2: int  # 291
TMS6_dxpnd4: int  # 292
TMS6_ext: int  # 17
TMS6_extu: int  # 18
TMS6_fadddp: int  # 293
TMS6_faddsp: int  # 294
TMS6_fmpydp: int  # 295
TMS6_fphead: int  # 310
TMS6_fsubdp: int  # 296
TMS6_fsubsp: int  # 297
TMS6_gmpy: int  # 134
TMS6_gmpy4: int  # 135
TMS6_idle: int  # 19
TMS6_intdp: int  # 136
TMS6_intdpu: int  # 137
TMS6_intsp: int  # 138
TMS6_intspu: int  # 139
TMS6_land: int  # 298
TMS6_landn: int  # 299
TMS6_last: int  # 311
TMS6_ldb: int  # 20
TMS6_ldbu: int  # 21
TMS6_lddw: int  # 140
TMS6_ldh: int  # 22
TMS6_ldhu: int  # 23
TMS6_ldndw: int  # 141
TMS6_ldnw: int  # 142
TMS6_ldw: int  # 24
TMS6_lmbd: int  # 25
TMS6_lor: int  # 300
TMS6_max2: int  # 143
TMS6_maxu4: int  # 144
TMS6_mfence: int  # 301
TMS6_min2: int  # 145
TMS6_minu4: int  # 146
TMS6_mpy: int  # 26
TMS6_mpy2: int  # 147
TMS6_mpy2ir: int  # 148
TMS6_mpy32: int  # 149
TMS6_mpy32su: int  # 150
TMS6_mpy32u: int  # 151
TMS6_mpy32us: int  # 152
TMS6_mpydp: int  # 153
TMS6_mpyh: int  # 30
TMS6_mpyhi: int  # 154
TMS6_mpyhir: int  # 155
TMS6_mpyhl: int  # 34
TMS6_mpyhlu: int  # 35
TMS6_mpyhslu: int  # 37
TMS6_mpyhsu: int  # 33
TMS6_mpyhu: int  # 31
TMS6_mpyhuls: int  # 36
TMS6_mpyhus: int  # 32
TMS6_mpyi: int  # 156
TMS6_mpyid: int  # 157
TMS6_mpyih: int  # 158
TMS6_mpyihr: int  # 159
TMS6_mpyil: int  # 160
TMS6_mpyilr: int  # 161
TMS6_mpylh: int  # 38
TMS6_mpylhu: int  # 39
TMS6_mpyli: int  # 162
TMS6_mpylir: int  # 163
TMS6_mpylshu: int  # 41
TMS6_mpyluhs: int  # 40
TMS6_mpysp: int  # 164
TMS6_mpysp2dp: int  # 165
TMS6_mpyspdp: int  # 166
TMS6_mpysu: int  # 29
TMS6_mpysu4: int  # 167
TMS6_mpyu: int  # 27
TMS6_mpyu2: int  # 302
TMS6_mpyu4: int  # 168
TMS6_mpyus: int  # 28
TMS6_mpyus4: int  # 169
TMS6_mv: int  # 42
TMS6_mvc: int  # 43
TMS6_mvd: int  # 170
TMS6_mvk: int  # 44
TMS6_mvkh: int  # 45
TMS6_mvkl: int  # 171
TMS6_mvklh: int  # 46
TMS6_neg: int  # 47
TMS6_nop: int  # 48
TMS6_norm: int  # 49
TMS6_not: int  # 50
TMS6_null: int  # 0
TMS6_or: int  # 51
TMS6_pack2: int  # 172
TMS6_packh2: int  # 173
TMS6_packh4: int  # 174
TMS6_packhl2: int  # 175
TMS6_packl4: int  # 176
TMS6_packlh2: int  # 177
TMS6_qmpy32: int  # 303
TMS6_qmpysp: int  # 304
TMS6_qsmpy32r1: int  # 305
TMS6_rcpdp: int  # 178
TMS6_rcpsp: int  # 179
TMS6_rint: int  # 180
TMS6_rotl: int  # 181
TMS6_rpack2: int  # 182
TMS6_rsqrdp: int  # 183
TMS6_rsqrsp: int  # 184
TMS6_sadd: int  # 52
TMS6_sadd2: int  # 185
TMS6_saddsu2: int  # 186
TMS6_saddsub: int  # 187
TMS6_saddsub2: int  # 188
TMS6_saddu4: int  # 189
TMS6_saddus2: int  # 190
TMS6_sat: int  # 53
TMS6_set: int  # 54
TMS6_shfl: int  # 191
TMS6_shfl3: int  # 192
TMS6_shl: int  # 55
TMS6_shl2: int  # 306
TMS6_shlmb: int  # 193
TMS6_shr: int  # 56
TMS6_shr2: int  # 194
TMS6_shrmb: int  # 195
TMS6_shru: int  # 57
TMS6_shru2: int  # 196
TMS6_smpy: int  # 58
TMS6_smpy2: int  # 197
TMS6_smpy32: int  # 198
TMS6_smpyh: int  # 61
TMS6_smpyhl: int  # 59
TMS6_smpylh: int  # 60
TMS6_spack2: int  # 199
TMS6_spacku4: int  # 200
TMS6_spdp: int  # 201
TMS6_spint: int  # 202
TMS6_spkernel: int  # 203
TMS6_spkernelr: int  # 204
TMS6_sploop: int  # 205
TMS6_sploopd: int  # 206
TMS6_sploopw: int  # 207
TMS6_spmask: int  # 208
TMS6_spmaskr: int  # 209
TMS6_sptrunc: int  # 210
TMS6_sshl: int  # 62
TMS6_sshvl: int  # 211
TMS6_sshvr: int  # 212
TMS6_ssub: int  # 63
TMS6_ssub2: int  # 213
TMS6_stb: int  # 64
TMS6_stbu: int  # 65
TMS6_stdw: int  # 214
TMS6_sth: int  # 66
TMS6_sthu: int  # 67
TMS6_stndw: int  # 215
TMS6_stnw: int  # 216
TMS6_stw: int  # 68
TMS6_sub: int  # 69
TMS6_sub2: int  # 75
TMS6_sub4: int  # 217
TMS6_subab: int  # 71
TMS6_subabs4: int  # 218
TMS6_subah: int  # 72
TMS6_subaw: int  # 73
TMS6_subc: int  # 74
TMS6_subdp: int  # 219
TMS6_subsp: int  # 220
TMS6_subu: int  # 70
TMS6_swap2: int  # 221
TMS6_swap4: int  # 222
TMS6_swe: int  # 223
TMS6_swenr: int  # 224
TMS6_unpkbu4: int  # 307
TMS6_unpkh2: int  # 308
TMS6_unpkhu2: int  # 309
TMS6_unpkhu4: int  # 225
TMS6_unpklu4: int  # 226
TMS6_xor: int  # 76
TMS6_xormpy: int  # 227
TMS6_xpnd2: int  # 228
TMS6_xpnd4: int  # 229
TMS6_zero: int  # 77
TMS_abs: int  # 1
TMS_adcb: int  # 2
TMS_add: int  # 3
TMS_addb: int  # 4
TMS_addc: int  # 5
TMS_adds: int  # 6
TMS_addt: int  # 7
TMS_adrk: int  # 8
TMS_and: int  # 9
TMS_andb: int  # 10
TMS_apac: int  # 11
TMS_apl: int  # 12
TMS_apl2: int  # 13
TMS_b: int  # 14
TMS_bacc: int  # 15
TMS_baccd: int  # 16
TMS_banz: int  # 17
TMS_banzd: int  # 18
TMS_bcnd: int  # 19
TMS_bcndd: int  # 20
TMS_bd: int  # 21
TMS_bit: int  # 22
TMS_bitt: int  # 23
TMS_bldd: int  # 24
TMS_bldp: int  # 25
TMS_blpd: int  # 26
TMS_bsar: int  # 27
TMS_cala: int  # 28
TMS_calad: int  # 29
TMS_call: int  # 30
TMS_calld: int  # 31
TMS_cc: int  # 32
TMS_ccd: int  # 33
TMS_clrc: int  # 34
TMS_cmpl: int  # 35
TMS_cmpr: int  # 36
TMS_cpl: int  # 37
TMS_cpl2: int  # 38
TMS_crgt: int  # 39
TMS_crlt: int  # 40
TMS_dmov: int  # 41
TMS_estop: int  # 42
TMS_exar: int  # 43
TMS_idle: int  # 44
TMS_idle2: int  # 45
TMS_in: int  # 46
TMS_intr: int  # 47
TMS_lacb: int  # 48
TMS_lacc: int  # 49
TMS_lacl: int  # 50
TMS_lact: int  # 51
TMS_lamm: int  # 52
TMS_lar: int  # 53
TMS_last: int  # 273
TMS_ldp: int  # 54
TMS_lmmr: int  # 55
TMS_lph: int  # 56
TMS_lst: int  # 57
TMS_lt: int  # 58
TMS_lta: int  # 59
TMS_ltd: int  # 60
TMS_ltp: int  # 61
TMS_lts: int  # 62
TMS_mac: int  # 63
TMS_macd: int  # 64
TMS_madd: int  # 65
TMS_mads: int  # 66
TMS_mar: int  # 67
TMS_mpy: int  # 68
TMS_mpya: int  # 69
TMS_mpys: int  # 70
TMS_mpyu: int  # 71
TMS_neg: int  # 72
TMS_nmi: int  # 73
TMS_nop: int  # 74
TMS_norm: int  # 75
TMS_null: int  # 0
TMS_opl: int  # 76
TMS_opl2: int  # 77
TMS_or: int  # 78
TMS_orb: int  # 79
TMS_out: int  # 80
TMS_pac: int  # 81
TMS_pop: int  # 82
TMS_popd: int  # 83
TMS_pshd: int  # 84
TMS_push: int  # 85
TMS_ret: int  # 86
TMS_retc: int  # 87
TMS_retcd: int  # 88
TMS_retd: int  # 89
TMS_rete: int  # 90
TMS_reti: int  # 91
TMS_rol: int  # 92
TMS_rolb: int  # 93
TMS_ror: int  # 94
TMS_rorb: int  # 95
TMS_rpt: int  # 96
TMS_rptb: int  # 97
TMS_rptz: int  # 98
TMS_sacb: int  # 99
TMS_sach: int  # 100
TMS_sacl: int  # 101
TMS_samm: int  # 102
TMS_sar: int  # 103
TMS_sath: int  # 104
TMS_satl: int  # 105
TMS_sbb: int  # 106
TMS_sbbb: int  # 107
TMS_sbrk: int  # 108
TMS_setc: int  # 109
TMS_sfl: int  # 110
TMS_sflb: int  # 111
TMS_sfr: int  # 112
TMS_sfrb: int  # 113
TMS_smmr: int  # 114
TMS_spac: int  # 115
TMS_sph: int  # 116
TMS_spl: int  # 117
TMS_splk: int  # 118
TMS_spm: int  # 119
TMS_sqra: int  # 120
TMS_sqrs: int  # 121
TMS_sst: int  # 122
TMS_sub: int  # 123
TMS_subb: int  # 124
TMS_subc: int  # 125
TMS_subs: int  # 126
TMS_subt: int  # 127
TMS_tblr: int  # 128
TMS_tblw: int  # 129
TMS_trap: int  # 130
TMS_xc: int  # 131
TMS_xor: int  # 132
TMS_xorb: int  # 133
TMS_xpl: int  # 134
TMS_xpl2: int  # 135
TMS_zalr: int  # 136
TMS_zap: int  # 137
TMS_zpr: int  # 138
TRICORE_abs: int  # 1
TRICORE_abs_b: int  # 2
TRICORE_abs_df: int  # 439
TRICORE_abs_f: int  # 449
TRICORE_abs_h: int  # 3
TRICORE_absdif: int  # 4
TRICORE_absdif_b: int  # 5
TRICORE_absdif_h: int  # 6
TRICORE_absdifs: int  # 7
TRICORE_absdifs_h: int  # 8
TRICORE_abss: int  # 9
TRICORE_abss_h: int  # 10
TRICORE_add16: int  # 14
TRICORE_add16_a: int  # 15
TRICORE_add32: int  # 16
TRICORE_add32_a: int  # 17
TRICORE_add_b: int  # 11
TRICORE_add_df: int  # 441
TRICORE_add_f: int  # 12
TRICORE_add_h: int  # 13
TRICORE_addc: int  # 18
TRICORE_addi: int  # 19
TRICORE_addih: int  # 20
TRICORE_addih_a: int  # 21
TRICORE_adds: int  # 22
TRICORE_adds16: int  # 26
TRICORE_adds_h: int  # 23
TRICORE_adds_hu: int  # 24
TRICORE_adds_u: int  # 25
TRICORE_addsc16_a: int  # 28
TRICORE_addsc32_a: int  # 29
TRICORE_addsc_at: int  # 27
TRICORE_addx: int  # 30
TRICORE_and16: int  # 42
TRICORE_and32: int  # 43
TRICORE_and_and_t: int  # 31
TRICORE_and_andn_t: int  # 32
TRICORE_and_eq: int  # 33
TRICORE_and_ge: int  # 34
TRICORE_and_ge_u: int  # 35
TRICORE_and_lt: int  # 36
TRICORE_and_lt_u: int  # 37
TRICORE_and_ne: int  # 38
TRICORE_and_nor_t: int  # 39
TRICORE_and_or_t: int  # 40
TRICORE_and_t: int  # 41
TRICORE_andn: int  # 44
TRICORE_andn_t: int  # 45
TRICORE_bisr16: int  # 46
TRICORE_bisr32: int  # 47
TRICORE_bmerge: int  # 48
TRICORE_bsplit: int  # 49
TRICORE_cachea_i: int  # 50
TRICORE_cachea_i_vm: int  # 428
TRICORE_cachea_w: int  # 51
TRICORE_cachea_w_vm: int  # 429
TRICORE_cachea_wi: int  # 52
TRICORE_cachea_wi_vm: int  # 430
TRICORE_cachei_i: int  # 382
TRICORE_cachei_i_vm: int  # 431
TRICORE_cachei_w: int  # 383
TRICORE_cachei_w_vm: int  # 432
TRICORE_cachei_wi: int  # 384
TRICORE_cachei_wi_vm: int  # 433
TRICORE_cadd16: int  # 53
TRICORE_cadd32: int  # 54
TRICORE_caddn16: int  # 55
TRICORE_caddn32: int  # 56
TRICORE_call16: int  # 57
TRICORE_call32: int  # 58
TRICORE_calla: int  # 59
TRICORE_calli: int  # 60
TRICORE_calli16: int  # 460
TRICORE_clo: int  # 61
TRICORE_clo_h: int  # 62
TRICORE_cls: int  # 63
TRICORE_cls_h: int  # 64
TRICORE_clz: int  # 65
TRICORE_clz_h: int  # 66
TRICORE_cmov16: int  # 67
TRICORE_cmovn16: int  # 68
TRICORE_cmp_df: int  # 436
TRICORE_cmp_f: int  # 69
TRICORE_cmpswap_w: int  # 398
TRICORE_crc32: int  # 396
TRICORE_crc32_b: int  # 400
TRICORE_crc32l_w: int  # 401
TRICORE_crcn: int  # 402
TRICORE_csub: int  # 70
TRICORE_csubn: int  # 71
TRICORE_debug16: int  # 72
TRICORE_debug32: int  # 73
TRICORE_dextr: int  # 74
TRICORE_dftof: int  # 421
TRICORE_dftoi: int  # 418
TRICORE_dftoin: int  # 417
TRICORE_dftoiz: int  # 426
TRICORE_dftol: int  # 420
TRICORE_dftolz: int  # 423
TRICORE_dftou: int  # 422
TRICORE_dftoul: int  # 419
TRICORE_dftoulz: int  # 425
TRICORE_dftouz: int  # 424
TRICORE_disable: int  # 75
TRICORE_div: int  # 385
TRICORE_div64: int  # 454
TRICORE_div64_u: int  # 453
TRICORE_div_df: int  # 437
TRICORE_div_f: int  # 76
TRICORE_div_u: int  # 386
TRICORE_dsync: int  # 77
TRICORE_dvadj: int  # 78
TRICORE_dvinit: int  # 79
TRICORE_dvinit_b: int  # 80
TRICORE_dvinit_bu: int  # 81
TRICORE_dvinit_h: int  # 82
TRICORE_dvinit_hu: int  # 83
TRICORE_dvinit_u: int  # 84
TRICORE_dvstep: int  # 85
TRICORE_dvstep_u: int  # 86
TRICORE_enable: int  # 87
TRICORE_eq16: int  # 92
TRICORE_eq32: int  # 93
TRICORE_eq_a: int  # 88
TRICORE_eq_b: int  # 89
TRICORE_eq_h: int  # 90
TRICORE_eq_w: int  # 91
TRICORE_eqany_b: int  # 94
TRICORE_eqany_h: int  # 95
TRICORE_eqz_a: int  # 96
TRICORE_extr: int  # 97
TRICORE_extr_u: int  # 98
TRICORE_fcall: int  # 387
TRICORE_fcalla: int  # 388
TRICORE_fcalli: int  # 389
TRICORE_fret16: int  # 390
TRICORE_fret32: int  # 391
TRICORE_ftodf: int  # 413
TRICORE_ftohp: int  # 406
TRICORE_ftoi: int  # 99
TRICORE_ftoin: int  # 427
TRICORE_ftoiz: int  # 392
TRICORE_ftoq31: int  # 100
TRICORE_ftoq31z: int  # 393
TRICORE_ftou: int  # 101
TRICORE_ftouz: int  # 394
TRICORE_ge: int  # 102
TRICORE_ge_a: int  # 103
TRICORE_ge_u: int  # 104
TRICORE_hptof: int  # 407
TRICORE_hvcall: int  # 411
TRICORE_imask: int  # 105
TRICORE_ins_t: int  # 106
TRICORE_insert: int  # 107
TRICORE_insn_t: int  # 108
TRICORE_isync: int  # 109
TRICORE_itodf: int  # 416
TRICORE_itof: int  # 110
TRICORE_ixmax: int  # 111
TRICORE_ixmax_u: int  # 112
TRICORE_ixmin: int  # 113
TRICORE_ixmin_u: int  # 114
TRICORE_j16: int  # 115
TRICORE_j32: int  # 116
TRICORE_ja: int  # 117
TRICORE_jeq16: int  # 119
TRICORE_jeq32: int  # 120
TRICORE_jeq_a: int  # 118
TRICORE_jge: int  # 121
TRICORE_jge_u: int  # 122
TRICORE_jgez16: int  # 123
TRICORE_jgtz16: int  # 124
TRICORE_ji16: int  # 125
TRICORE_ji32: int  # 126
TRICORE_jl: int  # 127
TRICORE_jla: int  # 128
TRICORE_jlez16: int  # 129
TRICORE_jli: int  # 130
TRICORE_jlt: int  # 131
TRICORE_jlt_u: int  # 132
TRICORE_jltz16: int  # 133
TRICORE_jne16: int  # 135
TRICORE_jne32: int  # 136
TRICORE_jne_a: int  # 134
TRICORE_jned: int  # 137
TRICORE_jnei: int  # 138
TRICORE_jnz16: int  # 139
TRICORE_jnz16_a: int  # 140
TRICORE_jnz16_t: int  # 141
TRICORE_jnz32_a: int  # 142
TRICORE_jnz32_t: int  # 143
TRICORE_jri: int  # 459
TRICORE_jz16: int  # 144
TRICORE_jz16_a: int  # 145
TRICORE_jz16_t: int  # 146
TRICORE_jz32_a: int  # 147
TRICORE_jz32_t: int  # 148
TRICORE_last: int  # 461
TRICORE_ld16_a: int  # 154
TRICORE_ld16_bu: int  # 155
TRICORE_ld16_h: int  # 156
TRICORE_ld16_w: int  # 157
TRICORE_ld32_a: int  # 158
TRICORE_ld32_bu: int  # 159
TRICORE_ld32_h: int  # 160
TRICORE_ld32_w: int  # 161
TRICORE_ld_b: int  # 149
TRICORE_ld_d: int  # 150
TRICORE_ld_da: int  # 151
TRICORE_ld_dd: int  # 451
TRICORE_ld_hu: int  # 152
TRICORE_ld_q: int  # 153
TRICORE_ldlcx: int  # 162
TRICORE_ldmst: int  # 163
TRICORE_lducx: int  # 164
TRICORE_lea: int  # 165
TRICORE_lha: int  # 405
TRICORE_loop16: int  # 166
TRICORE_loop32: int  # 167
TRICORE_loopu: int  # 168
TRICORE_lsync: int  # 409
TRICORE_lt16: int  # 177
TRICORE_lt32: int  # 178
TRICORE_lt_a: int  # 169
TRICORE_lt_b: int  # 170
TRICORE_lt_bu: int  # 171
TRICORE_lt_h: int  # 172
TRICORE_lt_hu: int  # 173
TRICORE_lt_u: int  # 174
TRICORE_lt_w: int  # 175
TRICORE_lt_wu: int  # 176
TRICORE_ltodf: int  # 412
TRICORE_madd: int  # 179
TRICORE_madd_df: int  # 443
TRICORE_madd_f: int  # 180
TRICORE_madd_h: int  # 181
TRICORE_madd_q: int  # 182
TRICORE_madd_u: int  # 183
TRICORE_maddm_h: int  # 184
TRICORE_maddms_h: int  # 185
TRICORE_maddr_h: int  # 186
TRICORE_maddr_q: int  # 187
TRICORE_maddrs_h: int  # 188
TRICORE_maddrs_q: int  # 189
TRICORE_madds: int  # 190
TRICORE_madds_h: int  # 191
TRICORE_madds_q: int  # 192
TRICORE_madds_u: int  # 193
TRICORE_maddsu_h: int  # 194
TRICORE_maddsum_h: int  # 195
TRICORE_maddsums_h: int  # 196
TRICORE_maddsur_h: int  # 197
TRICORE_maddsurs_h: int  # 198
TRICORE_maddsus_h: int  # 199
TRICORE_max: int  # 200
TRICORE_max_b: int  # 201
TRICORE_max_bu: int  # 202
TRICORE_max_df: int  # 442
TRICORE_max_f: int  # 447
TRICORE_max_h: int  # 203
TRICORE_max_hu: int  # 204
TRICORE_max_u: int  # 205
TRICORE_mfcr: int  # 206
TRICORE_mfdcr: int  # 434
TRICORE_min: int  # 207
TRICORE_min_b: int  # 208
TRICORE_min_bu: int  # 209
TRICORE_min_df: int  # 445
TRICORE_min_f: int  # 450
TRICORE_min_h: int  # 210
TRICORE_min_hu: int  # 211
TRICORE_min_u: int  # 212
TRICORE_mov16: int  # 214
TRICORE_mov16_a: int  # 215
TRICORE_mov16_aa: int  # 216
TRICORE_mov16_d: int  # 217
TRICORE_mov32: int  # 218
TRICORE_mov32_a: int  # 219
TRICORE_mov32_aa: int  # 220
TRICORE_mov32_d: int  # 221
TRICORE_mov_u: int  # 213
TRICORE_movh: int  # 222
TRICORE_movh_a: int  # 223
TRICORE_msub: int  # 224
TRICORE_msub_df: int  # 444
TRICORE_msub_f: int  # 225
TRICORE_msub_h: int  # 226
TRICORE_msub_q: int  # 227
TRICORE_msub_u: int  # 228
TRICORE_msubad_h: int  # 229
TRICORE_msubadm_h: int  # 230
TRICORE_msubadms_h: int  # 231
TRICORE_msubadr_h: int  # 232
TRICORE_msubadrs_h: int  # 233
TRICORE_msubads_h: int  # 234
TRICORE_msubm_h: int  # 235
TRICORE_msubms_h: int  # 236
TRICORE_msubr_h: int  # 237
TRICORE_msubr_q: int  # 238
TRICORE_msubrs_h: int  # 239
TRICORE_msubrs_q: int  # 240
TRICORE_msubs: int  # 241
TRICORE_msubs_h: int  # 242
TRICORE_msubs_q: int  # 243
TRICORE_msubs_u: int  # 244
TRICORE_mtcr: int  # 245
TRICORE_mtdcr: int  # 435
TRICORE_mul16: int  # 250
TRICORE_mul32: int  # 251
TRICORE_mul_df: int  # 438
TRICORE_mul_f: int  # 246
TRICORE_mul_h: int  # 247
TRICORE_mul_q: int  # 248
TRICORE_mul_u: int  # 249
TRICORE_mulm_h: int  # 252
TRICORE_mulms_h: int  # 253
TRICORE_mulp_b: int  # 457
TRICORE_mulr_h: int  # 254
TRICORE_mulr_q: int  # 255
TRICORE_muls: int  # 256
TRICORE_muls_u: int  # 257
TRICORE_nand: int  # 258
TRICORE_nand_t: int  # 259
TRICORE_ne: int  # 260
TRICORE_ne_a: int  # 261
TRICORE_neg_df: int  # 446
TRICORE_neg_f: int  # 448
TRICORE_nez_a: int  # 262
TRICORE_nop16: int  # 263
TRICORE_nop32: int  # 264
TRICORE_nor32: int  # 267
TRICORE_nor_t: int  # 265
TRICORE_not16: int  # 266
TRICORE_null: int  # 0
TRICORE_or16: int  # 279
TRICORE_or32: int  # 280
TRICORE_or_and_t: int  # 268
TRICORE_or_andn_t: int  # 269
TRICORE_or_eq: int  # 270
TRICORE_or_ge: int  # 271
TRICORE_or_ge_u: int  # 272
TRICORE_or_lt: int  # 273
TRICORE_or_lt_u: int  # 274
TRICORE_or_ne: int  # 275
TRICORE_or_nor_t: int  # 276
TRICORE_or_or_t: int  # 277
TRICORE_or_t: int  # 278
TRICORE_orn: int  # 281
TRICORE_orn_t: int  # 282
TRICORE_pack: int  # 283
TRICORE_parity: int  # 284
TRICORE_popcnt_w: int  # 404
TRICORE_q31tof: int  # 285
TRICORE_qseed_df: int  # 458
TRICORE_qseed_f: int  # 286
TRICORE_rem64: int  # 455
TRICORE_rem64_u: int  # 456
TRICORE_restore: int  # 395
TRICORE_ret16: int  # 287
TRICORE_ret32: int  # 288
TRICORE_rfe16: int  # 289
TRICORE_rfe32: int  # 290
TRICORE_rfh: int  # 408
TRICORE_rfm: int  # 291
TRICORE_rslcx: int  # 292
TRICORE_rstv: int  # 293
TRICORE_rsub16: int  # 294
TRICORE_rsub32: int  # 295
TRICORE_rsubs: int  # 296
TRICORE_rsubs_u: int  # 297
TRICORE_sat16_b: int  # 298
TRICORE_sat16_bu: int  # 299
TRICORE_sat16_h: int  # 300
TRICORE_sat16_hu: int  # 301
TRICORE_sat32_b: int  # 302
TRICORE_sat32_bu: int  # 303
TRICORE_sat32_h: int  # 304
TRICORE_sat32_hu: int  # 305
TRICORE_sel: int  # 306
TRICORE_seln: int  # 307
TRICORE_sh16: int  # 323
TRICORE_sh32: int  # 324
TRICORE_sh_and_t: int  # 308
TRICORE_sh_andn_t: int  # 309
TRICORE_sh_eq: int  # 310
TRICORE_sh_ge: int  # 311
TRICORE_sh_ge_u: int  # 312
TRICORE_sh_h: int  # 313
TRICORE_sh_lt: int  # 314
TRICORE_sh_lt_u: int  # 315
TRICORE_sh_nand_t: int  # 316
TRICORE_sh_ne: int  # 317
TRICORE_sh_nor_t: int  # 318
TRICORE_sh_or_t: int  # 319
TRICORE_sh_orn_t: int  # 320
TRICORE_sh_xnor_t: int  # 321
TRICORE_sh_xor_t: int  # 322
TRICORE_sha16: int  # 326
TRICORE_sha32: int  # 327
TRICORE_sha_h: int  # 325
TRICORE_shas: int  # 328
TRICORE_shuffle: int  # 403
TRICORE_st16_a: int  # 333
TRICORE_st16_b: int  # 334
TRICORE_st16_h: int  # 335
TRICORE_st16_w: int  # 336
TRICORE_st32_a: int  # 337
TRICORE_st32_b: int  # 338
TRICORE_st32_h: int  # 339
TRICORE_st32_w: int  # 340
TRICORE_st_d: int  # 329
TRICORE_st_da: int  # 330
TRICORE_st_dd: int  # 452
TRICORE_st_q: int  # 331
TRICORE_st_t: int  # 332
TRICORE_stlcx: int  # 341
TRICORE_stucx: int  # 342
TRICORE_sub16: int  # 346
TRICORE_sub16_a: int  # 347
TRICORE_sub32: int  # 348
TRICORE_sub32_a: int  # 349
TRICORE_sub_b: int  # 343
TRICORE_sub_df: int  # 440
TRICORE_sub_f: int  # 344
TRICORE_sub_h: int  # 345
TRICORE_subc: int  # 350
TRICORE_subs16: int  # 354
TRICORE_subs32: int  # 355
TRICORE_subs_h: int  # 351
TRICORE_subs_hu: int  # 352
TRICORE_subs_u: int  # 353
TRICORE_subx: int  # 356
TRICORE_svlcx: int  # 357
TRICORE_swap_w: int  # 358
TRICORE_swapmsk_w: int  # 399
TRICORE_syscall: int  # 359
TRICORE_tlbdemap: int  # 360
TRICORE_tlbflush_a: int  # 361
TRICORE_tlbflush_b: int  # 362
TRICORE_tlbmap: int  # 363
TRICORE_tlbprobe_a: int  # 364
TRICORE_tlbprobe_i: int  # 365
TRICORE_trapinv: int  # 410
TRICORE_trapsv: int  # 366
TRICORE_trapv: int  # 367
TRICORE_ultodf: int  # 415
TRICORE_unpack: int  # 368
TRICORE_updfl: int  # 369
TRICORE_utodf: int  # 414
TRICORE_utof: int  # 370
TRICORE_wait: int  # 397
TRICORE_xnor: int  # 371
TRICORE_xnor_t: int  # 372
TRICORE_xor16: int  # 380
TRICORE_xor32: int  # 381
TRICORE_xor_eq: int  # 373
TRICORE_xor_ge: int  # 374
TRICORE_xor_ge_u: int  # 375
TRICORE_xor_lt: int  # 376
TRICORE_xor_lt_u: int  # 377
TRICORE_xor_ne: int  # 378
TRICORE_xor_t: int  # 379
TRIMEDIA_alloc: int  # 172
TRIMEDIA_allocd: int  # 168
TRIMEDIA_allocr: int  # 169
TRIMEDIA_allocx: int  # 170
TRIMEDIA_asl: int  # 20
TRIMEDIA_asli: int  # 12
TRIMEDIA_asr: int  # 19
TRIMEDIA_asri: int  # 11
TRIMEDIA_bitand: int  # 17
TRIMEDIA_bitandinv: int  # 50
TRIMEDIA_bitinv: int  # 51
TRIMEDIA_bitor: int  # 18
TRIMEDIA_bitxor: int  # 49
TRIMEDIA_borrow: int  # 203
TRIMEDIA_carry: int  # 46
TRIMEDIA_curcycles: int  # 141
TRIMEDIA_cycles: int  # 133
TRIMEDIA_dcb: int  # 162
TRIMEDIA_dinvalid: int  # 163
TRIMEDIA_dspiabs: int  # 173
TRIMEDIA_dspiadd: int  # 62
TRIMEDIA_dspidualabs: int  # 174
TRIMEDIA_dspidualadd: int  # 66
TRIMEDIA_dspidualmul: int  # 85
TRIMEDIA_dspidualsub: int  # 67
TRIMEDIA_dspimul: int  # 120
TRIMEDIA_dspisub: int  # 64
TRIMEDIA_dspuadd: int  # 63
TRIMEDIA_dspumul: int  # 121
TRIMEDIA_dspuquadaddui: int  # 74
TRIMEDIA_dspusub: int  # 65
TRIMEDIA_dualasr: int  # 92
TRIMEDIA_dualiclipi: int  # 77
TRIMEDIA_dualuclipi: int  # 78
TRIMEDIA_fabsval: int  # 101
TRIMEDIA_fabsvalflags: int  # 102
TRIMEDIA_fadd: int  # 23
TRIMEDIA_faddflags: int  # 98
TRIMEDIA_fdiv: int  # 94
TRIMEDIA_fdivflags: int  # 95
TRIMEDIA_feql: int  # 127
TRIMEDIA_feqlflags: int  # 128
TRIMEDIA_fgeq: int  # 125
TRIMEDIA_fgeqflags: int  # 126
TRIMEDIA_fgtr: int  # 123
TRIMEDIA_fgtrflags: int  # 124
TRIMEDIA_fleq: int  # 198
TRIMEDIA_fleqflags: int  # 202
TRIMEDIA_fles: int  # 197
TRIMEDIA_flesflags: int  # 201
TRIMEDIA_fmul: int  # 29
TRIMEDIA_fmulflags: int  # 122
TRIMEDIA_fneq: int  # 129
TRIMEDIA_fneqflags: int  # 130
TRIMEDIA_fsign: int  # 131
TRIMEDIA_fsignflags: int  # 132
TRIMEDIA_fsqrt: int  # 96
TRIMEDIA_fsqrtflags: int  # 97
TRIMEDIA_fsub: int  # 99
TRIMEDIA_fsubflags: int  # 100
TRIMEDIA_funshift1: int  # 89
TRIMEDIA_funshift2: int  # 90
TRIMEDIA_funshift3: int  # 91
TRIMEDIA_h_dspiabs: int  # 61
TRIMEDIA_h_dspidualabs: int  # 68
TRIMEDIA_h_iabs: int  # 45
TRIMEDIA_h_st16d: int  # 31
TRIMEDIA_h_st32d: int  # 32
TRIMEDIA_h_st8d: int  # 30
TRIMEDIA_hicycles: int  # 134
TRIMEDIA_iabs: int  # 175
TRIMEDIA_iadd: int  # 13
TRIMEDIA_iaddi: int  # 6
TRIMEDIA_iavgonep: int  # 26
TRIMEDIA_ibytesel: int  # 57
TRIMEDIA_iclipi: int  # 70
TRIMEDIA_iclr: int  # 148
TRIMEDIA_ident: int  # 192
TRIMEDIA_ieql: int  # 38
TRIMEDIA_ieqli: int  # 5
TRIMEDIA_ifir16: int  # 83
TRIMEDIA_ifir8ii: int  # 82
TRIMEDIA_ifir8ui: int  # 81
TRIMEDIA_ifixieee: int  # 107
TRIMEDIA_ifixieeeflags: int  # 108
TRIMEDIA_ifixrz: int  # 22
TRIMEDIA_ifixrzflags: int  # 115
TRIMEDIA_iflip: int  # 73
TRIMEDIA_ifloat: int  # 21
TRIMEDIA_ifloatflags: int  # 116
TRIMEDIA_ifloatrz: int  # 103
TRIMEDIA_ifloatrzflags: int  # 104
TRIMEDIA_igeq: int  # 15
TRIMEDIA_igeqi: int  # 2
TRIMEDIA_igtr: int  # 16
TRIMEDIA_igtri: int  # 1
TRIMEDIA_ijmpf: int  # 147
TRIMEDIA_ijmpi: int  # 145
TRIMEDIA_ijmpt: int  # 143
TRIMEDIA_ild16: int  # 176
TRIMEDIA_ild16d: int  # 7
TRIMEDIA_ild16r: int  # 153
TRIMEDIA_ild16x: int  # 154
TRIMEDIA_ild8: int  # 177
TRIMEDIA_ild8d: int  # 150
TRIMEDIA_ild8r: int  # 151
TRIMEDIA_ileq: int  # 194
TRIMEDIA_ileqi: int  # 43
TRIMEDIA_iles: int  # 193
TRIMEDIA_ilesi: int  # 3
TRIMEDIA_imax: int  # 25
TRIMEDIA_imin: int  # 24
TRIMEDIA_imul: int  # 28
TRIMEDIA_imulm: int  # 118
TRIMEDIA_ineg: int  # 178
TRIMEDIA_ineq: int  # 40
TRIMEDIA_ineqi: int  # 4
TRIMEDIA_inonzero: int  # 48
TRIMEDIA_isub: int  # 14
TRIMEDIA_isubi: int  # 33
TRIMEDIA_izero: int  # 47
TRIMEDIA_jmpf: int  # 146
TRIMEDIA_jmpi: int  # 144
TRIMEDIA_jmpt: int  # 142
TRIMEDIA_last: int  # 207
TRIMEDIA_ld32: int  # 179
TRIMEDIA_ld32d: int  # 8
TRIMEDIA_ld32r: int  # 158
TRIMEDIA_ld32x: int  # 159
TRIMEDIA_lsl: int  # 205
TRIMEDIA_lsli: int  # 206
TRIMEDIA_lsr: int  # 86
TRIMEDIA_lsri: int  # 10
TRIMEDIA_mergedual16lsb: int  # 93
TRIMEDIA_mergelsb: int  # 58
TRIMEDIA_mergemsb: int  # 59
TRIMEDIA_nop: int  # 171
TRIMEDIA_null: int  # 0
TRIMEDIA_pack16lsb: int  # 54
TRIMEDIA_pack16msb: int  # 55
TRIMEDIA_packbytes: int  # 53
TRIMEDIA_pref: int  # 180
TRIMEDIA_pref16x: int  # 166
TRIMEDIA_pref32x: int  # 167
TRIMEDIA_prefd: int  # 164
TRIMEDIA_prefr: int  # 165
TRIMEDIA_quadavg: int  # 69
TRIMEDIA_quadumax: int  # 76
TRIMEDIA_quadumin: int  # 75
TRIMEDIA_quadumulmsb: int  # 79
TRIMEDIA_rdstatus: int  # 161
TRIMEDIA_rdtag: int  # 160
TRIMEDIA_readdpc: int  # 135
TRIMEDIA_readpcsw: int  # 137
TRIMEDIA_readspc: int  # 136
TRIMEDIA_rol: int  # 87
TRIMEDIA_roli: int  # 88
TRIMEDIA_sex16: int  # 52
TRIMEDIA_sex8: int  # 181
TRIMEDIA_st16: int  # 182
TRIMEDIA_st16d: int  # 183
TRIMEDIA_st32: int  # 184
TRIMEDIA_st32d: int  # 185
TRIMEDIA_st8: int  # 186
TRIMEDIA_st8d: int  # 187
TRIMEDIA_ubytesel: int  # 56
TRIMEDIA_uclipi: int  # 71
TRIMEDIA_uclipu: int  # 72
TRIMEDIA_ueql: int  # 199
TRIMEDIA_ueqli: int  # 39
TRIMEDIA_ufir16: int  # 84
TRIMEDIA_ufir8uu: int  # 80
TRIMEDIA_ufixieee: int  # 109
TRIMEDIA_ufixieeeflags: int  # 110
TRIMEDIA_ufixrz: int  # 111
TRIMEDIA_ufixrzflags: int  # 112
TRIMEDIA_ufloat: int  # 113
TRIMEDIA_ufloatflags: int  # 114
TRIMEDIA_ufloatrz: int  # 105
TRIMEDIA_ufloatrzflags: int  # 106
TRIMEDIA_ugeq: int  # 36
TRIMEDIA_ugeqi: int  # 37
TRIMEDIA_ugtr: int  # 34
TRIMEDIA_ugtri: int  # 35
TRIMEDIA_uimm: int  # 149
TRIMEDIA_uld16: int  # 188
TRIMEDIA_uld16d: int  # 155
TRIMEDIA_uld16r: int  # 156
TRIMEDIA_uld16x: int  # 157
TRIMEDIA_uld8: int  # 189
TRIMEDIA_uld8d: int  # 9
TRIMEDIA_uld8r: int  # 152
TRIMEDIA_uleq: int  # 196
TRIMEDIA_uleqi: int  # 44
TRIMEDIA_ules: int  # 195
TRIMEDIA_ulesi: int  # 42
TRIMEDIA_ume8ii: int  # 60
TRIMEDIA_ume8uu: int  # 27
TRIMEDIA_umin: int  # 204
TRIMEDIA_umul: int  # 117
TRIMEDIA_umulm: int  # 119
TRIMEDIA_uneq: int  # 200
TRIMEDIA_uneqi: int  # 41
TRIMEDIA_writedpc: int  # 139
TRIMEDIA_writepcsw: int  # 140
TRIMEDIA_writespc: int  # 138
TRIMEDIA_zex16: int  # 190
TRIMEDIA_zex8: int  # 191
UNSP_adc: int  # 2
UNSP_adc_s: int  # 16
UNSP_add: int  # 1
UNSP_add_s: int  # 15
UNSP_and: int  # 12
UNSP_and_s: int  # 26
UNSP_asr: int  # 66
UNSP_asror: int  # 67
UNSP_break: int  # 65
UNSP_call: int  # 33
UNSP_clrb: int  # 76
UNSP_cmp: int  # 5
UNSP_cmp_s: int  # 19
UNSP_cmpc: int  # 6
UNSP_cmpc_s: int  # 20
UNSP_divq: int  # 56
UNSP_divs: int  # 55
UNSP_exp: int  # 36
UNSP_fiq: int  # 63
UNSP_fir_mov: int  # 59
UNSP_fraction: int  # 60
UNSP_goto: int  # 34
UNSP_int1: int  # 57
UNSP_int2: int  # 58
UNSP_invb: int  # 77
UNSP_irq: int  # 61
UNSP_irqnest: int  # 64
UNSP_ja: int  # 46
UNSP_jae: int  # 38
UNSP_jb: int  # 37
UNSP_jbe: int  # 45
UNSP_je: int  # 42
UNSP_jg: int  # 48
UNSP_jge: int  # 39
UNSP_jl: int  # 40
UNSP_jle: int  # 47
UNSP_jmi: int  # 44
UNSP_jmp: int  # 51
UNSP_jne: int  # 41
UNSP_jpl: int  # 43
UNSP_jvc: int  # 49
UNSP_jvs: int  # 50
UNSP_last: int  # 78
UNSP_load: int  # 10
UNSP_load_s: int  # 24
UNSP_lsl: int  # 68
UNSP_lslor: int  # 69
UNSP_lsr: int  # 70
UNSP_lsror: int  # 71
UNSP_mulss: int  # 52
UNSP_mulus: int  # 53
UNSP_muluu: int  # 54
UNSP_neg: int  # 7
UNSP_neg_s: int  # 21
UNSP_negc: int  # 8
UNSP_negc_s: int  # 22
UNSP_nop: int  # 35
UNSP_null: int  # 0
UNSP_or: int  # 11
UNSP_or_s: int  # 25
UNSP_pop: int  # 31
UNSP_push: int  # 32
UNSP_retf: int  # 29
UNSP_reti: int  # 30
UNSP_rol: int  # 72
UNSP_ror: int  # 73
UNSP_sbc: int  # 4
UNSP_sbc_s: int  # 18
UNSP_secbank: int  # 62
UNSP_setb: int  # 75
UNSP_store: int  # 14
UNSP_store_s: int  # 28
UNSP_sub: int  # 3
UNSP_sub_s: int  # 17
UNSP_test: int  # 13
UNSP_test_s: int  # 27
UNSP_tstb: int  # 74
UNSP_xor: int  # 9
UNSP_xor_s: int  # 23
XTENSA_abs: int  # 1
XTENSA_abs_d: int  # 181
XTENSA_abs_s: int  # 182
XTENSA_add: int  # 2
XTENSA_add_d: int  # 183
XTENSA_add_s: int  # 184
XTENSA_addexp_d: int  # 185
XTENSA_addexp_s: int  # 186
XTENSA_addexpm_d: int  # 187
XTENSA_addexpm_s: int  # 188
XTENSA_addi: int  # 3
XTENSA_addmi: int  # 4
XTENSA_addx2: int  # 5
XTENSA_addx4: int  # 6
XTENSA_addx8: int  # 7
XTENSA_ae2_rur: int  # 343
XTENSA_ae2_wur: int  # 344
XTENSA_ae_rur: int  # 345
XTENSA_ae_wur: int  # 346
XTENSA_all4: int  # 134
XTENSA_all8: int  # 135
XTENSA_and: int  # 8
XTENSA_andb: int  # 136
XTENSA_andbc: int  # 137
XTENSA_andi: int  # 115
XTENSA_any4: int  # 138
XTENSA_any8: int  # 139
XTENSA_ball: int  # 9
XTENSA_bany: int  # 10
XTENSA_bbc: int  # 11
XTENSA_bbci: int  # 13
XTENSA_bbs: int  # 12
XTENSA_bbsi: int  # 14
XTENSA_beq: int  # 15
XTENSA_beqi: int  # 16
XTENSA_beqz: int  # 17
XTENSA_bf: int  # 140
XTENSA_bge: int  # 18
XTENSA_bgei: int  # 19
XTENSA_bgeu: int  # 20
XTENSA_bgeui: int  # 21
XTENSA_bgez: int  # 22
XTENSA_blt: int  # 23
XTENSA_blti: int  # 24
XTENSA_bltu: int  # 25
XTENSA_bltui: int  # 26
XTENSA_bltz: int  # 27
XTENSA_bnall: int  # 28
XTENSA_bne: int  # 30
XTENSA_bnei: int  # 31
XTENSA_bnez: int  # 32
XTENSA_bnone: int  # 29
XTENSA_break: int  # 33
XTENSA_bt: int  # 141
XTENSA_call0: int  # 34
XTENSA_call12: int  # 37
XTENSA_call4: int  # 35
XTENSA_call8: int  # 36
XTENSA_callx0: int  # 38
XTENSA_callx12: int  # 41
XTENSA_callx4: int  # 39
XTENSA_callx8: int  # 40
XTENSA_ceil_d: int  # 189
XTENSA_ceil_s: int  # 190
XTENSA_clamps: int  # 315
XTENSA_clrb_expstate: int  # 336
XTENSA_clrex: int  # 177
XTENSA_const_d: int  # 191
XTENSA_const_s: int  # 192
XTENSA_cvtd_s: int  # 193
XTENSA_cvts_d: int  # 194
XTENSA_dci: int  # 148
XTENSA_dcwb: int  # 149
XTENSA_dcwbi: int  # 150
XTENSA_depbits: int  # 173
XTENSA_dhi: int  # 151
XTENSA_dhi_b: int  # 125
XTENSA_dhu: int  # 152
XTENSA_dhwb: int  # 153
XTENSA_dhwb_b: int  # 126
XTENSA_dhwbi: int  # 154
XTENSA_dhwbi_b: int  # 127
XTENSA_dii: int  # 155
XTENSA_diu: int  # 156
XTENSA_div0_d: int  # 195
XTENSA_div0_s: int  # 196
XTENSA_divn_d: int  # 197
XTENSA_divn_s: int  # 198
XTENSA_diwb: int  # 157
XTENSA_diwbi: int  # 158
XTENSA_diwbui_p: int  # 159
XTENSA_dpfl: int  # 160
XTENSA_dpfm_b: int  # 128
XTENSA_dpfm_bf: int  # 129
XTENSA_dpfr: int  # 161
XTENSA_dpfr_b: int  # 130
XTENSA_dpfr_bf: int  # 131
XTENSA_dpfro: int  # 162
XTENSA_dpfw: int  # 163
XTENSA_dpfw_b: int  # 132
XTENSA_dpfw_bf: int  # 133
XTENSA_dpfwo: int  # 164
XTENSA_dsync: int  # 42
XTENSA_entry: int  # 43
XTENSA_esync: int  # 44
XTENSA_excw: int  # 45
XTENSA_extui: int  # 46
XTENSA_extw: int  # 47
XTENSA_float_d: int  # 199
XTENSA_float_s: int  # 200
XTENSA_floor_d: int  # 201
XTENSA_floor_s: int  # 202
XTENSA_fsync: int  # 119
XTENSA_getex: int  # 178
XTENSA_hwwdtlba: int  # 337
XTENSA_hwwitlba: int  # 338
XTENSA_idtlb: int  # 317
XTENSA_ihi: int  # 279
XTENSA_ihu: int  # 280
XTENSA_iii: int  # 281
XTENSA_iitlb: int  # 318
XTENSA_iiu: int  # 282
XTENSA_ill: int  # 114
XTENSA_ipf: int  # 283
XTENSA_ipfl: int  # 284
XTENSA_isync: int  # 48
XTENSA_j: int  # 49
XTENSA_jx: int  # 50
XTENSA_l16si: int  # 57
XTENSA_l16ui: int  # 58
XTENSA_l32ai: int  # 316
XTENSA_l32e: int  # 330
XTENSA_l32ex: int  # 179
XTENSA_l32i: int  # 59
XTENSA_l32r: int  # 60
XTENSA_l8ui: int  # 56
XTENSA_last: int  # 347
XTENSA_ldct: int  # 165
XTENSA_ldcw: int  # 166
XTENSA_lddec: int  # 295
XTENSA_lddr32_p: int  # 169
XTENSA_ldi: int  # 203
XTENSA_ldinc: int  # 296
XTENSA_ldip: int  # 204
XTENSA_ldpte: int  # 339
XTENSA_ldx: int  # 205
XTENSA_ldxp: int  # 206
XTENSA_lict: int  # 285
XTENSA_licw: int  # 286
XTENSA_loop: int  # 51
XTENSA_loopgtz: int  # 52
XTENSA_loopnez: int  # 53
XTENSA_lsi: int  # 54
XTENSA_lsip: int  # 207
XTENSA_lsiu: int  # 208
XTENSA_lsx: int  # 55
XTENSA_lsxp: int  # 209
XTENSA_lsxu: int  # 210
XTENSA_madd_d: int  # 211
XTENSA_madd_s: int  # 212
XTENSA_maddn_d: int  # 213
XTENSA_maddn_s: int  # 214
XTENSA_max: int  # 61
XTENSA_maxu: int  # 62
XTENSA_memw: int  # 63
XTENSA_min: int  # 64
XTENSA_minu: int  # 65
XTENSA_mkdadj_d: int  # 215
XTENSA_mkdadj_s: int  # 216
XTENSA_mksadj_d: int  # 217
XTENSA_mksadj_s: int  # 218
XTENSA_mov: int  # 66
XTENSA_mov_d: int  # 219
XTENSA_mov_s: int  # 220
XTENSA_moveqz: int  # 67
XTENSA_moveqz_s: int  # 221
XTENSA_movf: int  # 142
XTENSA_movf_s: int  # 222
XTENSA_movgez: int  # 68
XTENSA_movgez_s: int  # 223
XTENSA_movi: int  # 69
XTENSA_movltz: int  # 70
XTENSA_movltz_s: int  # 224
XTENSA_movnez: int  # 71
XTENSA_movnez_s: int  # 225
XTENSA_movsp: int  # 331
XTENSA_movt: int  # 143
XTENSA_movt_s: int  # 226
XTENSA_msub_d: int  # 227
XTENSA_msub_s: int  # 228
XTENSA_mul16s: int  # 72
XTENSA_mul16u: int  # 73
XTENSA_mul_aa: int  # 297
XTENSA_mul_ad: int  # 298
XTENSA_mul_d: int  # 229
XTENSA_mul_da: int  # 299
XTENSA_mul_dd: int  # 300
XTENSA_mul_s: int  # 230
XTENSA_mula_aa: int  # 301
XTENSA_mula_ad: int  # 302
XTENSA_mula_da: int  # 303
XTENSA_mula_da_lddec: int  # 304
XTENSA_mula_da_ldinc: int  # 305
XTENSA_mula_dd: int  # 306
XTENSA_mula_dd_lddec: int  # 307
XTENSA_mula_dd_ldinc: int  # 308
XTENSA_mull: int  # 74
XTENSA_muls_aa: int  # 309
XTENSA_muls_ad: int  # 310
XTENSA_muls_da: int  # 311
XTENSA_muls_dd: int  # 312
XTENSA_mulsh: int  # 289
XTENSA_muluh: int  # 290
XTENSA_neg: int  # 75
XTENSA_neg_d: int  # 231
XTENSA_neg_s: int  # 232
XTENSA_nexp01_d: int  # 233
XTENSA_nexp01_s: int  # 234
XTENSA_nop: int  # 78
XTENSA_nsa: int  # 76
XTENSA_nsau: int  # 77
XTENSA_null: int  # 0
XTENSA_oeq_d: int  # 235
XTENSA_oeq_s: int  # 236
XTENSA_ole_d: int  # 237
XTENSA_ole_s: int  # 238
XTENSA_olt_d: int  # 239
XTENSA_olt_s: int  # 240
XTENSA_or: int  # 79
XTENSA_orb: int  # 144
XTENSA_orbc: int  # 145
XTENSA_ori: int  # 116
XTENSA_pdtlb: int  # 319
XTENSA_pitlb: int  # 320
XTENSA_pptlb: int  # 321
XTENSA_quos: int  # 291
XTENSA_quou: int  # 292
XTENSA_rdtlb0: int  # 322
XTENSA_rdtlb1: int  # 323
XTENSA_read_impwire: int  # 340
XTENSA_recip0_d: int  # 241
XTENSA_recip0_s: int  # 242
XTENSA_rems: int  # 293
XTENSA_remu: int  # 294
XTENSA_rer: int  # 120
XTENSA_ret: int  # 80
XTENSA_retw: int  # 81
XTENSA_rfdd: int  # 170
XTENSA_rfde: int  # 174
XTENSA_rfdo: int  # 171
XTENSA_rfe: int  # 82
XTENSA_rfi: int  # 83
XTENSA_rfme: int  # 314
XTENSA_rfr: int  # 243
XTENSA_rfrd: int  # 244
XTENSA_rfue: int  # 175
XTENSA_rfwo: int  # 332
XTENSA_rfwu: int  # 333
XTENSA_ritlb0: int  # 324
XTENSA_ritlb1: int  # 325
XTENSA_rotw: int  # 334
XTENSA_round_d: int  # 245
XTENSA_round_s: int  # 246
XTENSA_rptlb0: int  # 326
XTENSA_rptlb1: int  # 327
XTENSA_rsil: int  # 84
XTENSA_rsqrt0_d: int  # 247
XTENSA_rsqrt0_s: int  # 248
XTENSA_rsr: int  # 85
XTENSA_rsync: int  # 86
XTENSA_rur: int  # 117
XTENSA_s16i: int  # 88
XTENSA_s32c1i: int  # 147
XTENSA_s32e: int  # 335
XTENSA_s32ex: int  # 180
XTENSA_s32i: int  # 89
XTENSA_s32nb: int  # 121
XTENSA_s32ri: int  # 90
XTENSA_s8i: int  # 87
XTENSA_salt: int  # 122
XTENSA_saltu: int  # 123
XTENSA_sdct: int  # 167
XTENSA_sdcw: int  # 168
XTENSA_sddr32_p: int  # 172
XTENSA_sdi: int  # 249
XTENSA_sdip: int  # 250
XTENSA_sdx: int  # 251
XTENSA_sdxp: int  # 252
XTENSA_setb_expstate: int  # 341
XTENSA_sext: int  # 91
XTENSA_sict: int  # 287
XTENSA_sicw: int  # 288
XTENSA_simcall: int  # 329
XTENSA_sll: int  # 92
XTENSA_slli: int  # 93
XTENSA_sqrt0_d: int  # 253
XTENSA_sqrt0_s: int  # 254
XTENSA_sra: int  # 94
XTENSA_srai: int  # 95
XTENSA_src: int  # 96
XTENSA_srl: int  # 97
XTENSA_srli: int  # 98
XTENSA_ssa8b: int  # 99
XTENSA_ssa8l: int  # 100
XTENSA_ssai: int  # 101
XTENSA_ssi: int  # 255
XTENSA_ssip: int  # 256
XTENSA_ssiu: int  # 257
XTENSA_ssl: int  # 102
XTENSA_ssr: int  # 103
XTENSA_ssx: int  # 258
XTENSA_ssxp: int  # 259
XTENSA_ssxu: int  # 260
XTENSA_sub: int  # 104
XTENSA_sub_d: int  # 261
XTENSA_sub_s: int  # 262
XTENSA_subx2: int  # 105
XTENSA_subx4: int  # 106
XTENSA_subx8: int  # 107
XTENSA_syscall: int  # 176
XTENSA_trunc_d: int  # 263
XTENSA_trunc_s: int  # 264
XTENSA_ueq_d: int  # 265
XTENSA_ueq_s: int  # 266
XTENSA_ufloat_d: int  # 267
XTENSA_ufloat_s: int  # 268
XTENSA_ule_d: int  # 269
XTENSA_ule_s: int  # 270
XTENSA_ult_d: int  # 271
XTENSA_ult_s: int  # 272
XTENSA_umul_aa: int  # 313
XTENSA_un_d: int  # 273
XTENSA_un_s: int  # 274
XTENSA_utrunc_d: int  # 275
XTENSA_utrunc_s: int  # 276
XTENSA_waiti: int  # 108
XTENSA_wdtlb: int  # 109
XTENSA_wer: int  # 124
XTENSA_wfr: int  # 277
XTENSA_wfrd: int  # 278
XTENSA_witlb: int  # 110
XTENSA_wptlb: int  # 328
XTENSA_wrmsk_expstate: int  # 342
XTENSA_wsr: int  # 111
XTENSA_wur: int  # 118
XTENSA_xor: int  # 112
XTENSA_xorb: int  # 146
XTENSA_xsr: int  # 113
Z80_adc: int  # 2
Z80_adcw: int  # 205
Z80_add: int  # 3
Z80_addw: int  # 203
Z80_and: int  # 81
Z80_andw: int  # 207
Z80_bit: int  # 82
Z80_btest: int  # 237
Z80_call: int  # 83
Z80_calr: int  # 212
Z80_ccf: int  # 84
Z80_cp: int  # 85
Z80_cpd: int  # 86
Z80_cpdr: int  # 87
Z80_cpi: int  # 88
Z80_cpir: int  # 89
Z80_cpl: int  # 90
Z80_cplw: int  # 198
Z80_cpw: int  # 210
Z80_ddir: int  # 211
Z80_dec: int  # 91
Z80_di: int  # 24
Z80_divuw: int  # 229
Z80_djnz: int  # 92
Z80_ei: int  # 25
Z80_ex: int  # 93
Z80_exall: int  # 217
Z80_exts: int  # 235
Z80_extsw: int  # 236
Z80_exx: int  # 94
Z80_exxx: int  # 215
Z80_exxy: int  # 216
Z80_halt: int  # 95
Z80_im: int  # 96
Z80_in: int  # 27
Z80_in0: int  # 139
Z80_ina: int  # 233
Z80_inaw: int  # 231
Z80_inc: int  # 97
Z80_ind: int  # 98
Z80_indr: int  # 99
Z80_indrw: int  # 245
Z80_indw: int  # 244
Z80_ini: int  # 100
Z80_inir: int  # 101
Z80_inirw: int  # 243
Z80_iniw: int  # 242
Z80_inp: int  # 136
Z80_inw: int  # 200
Z80_jp: int  # 102
Z80_jr: int  # 103
Z80_ld: int  # 104
Z80_ldctl: int  # 213
Z80_ldd: int  # 105
Z80_lddr: int  # 106
Z80_lddrw: int  # 241
Z80_lddw: int  # 240
Z80_ldi: int  # 107
Z80_ldir: int  # 108
Z80_ldirw: int  # 239
Z80_ldiw: int  # 238
Z80_ldw: int  # 202
Z80_mlt: int  # 140
Z80_mtest: int  # 214
Z80_multuw: int  # 228
Z80_multw: int  # 227
Z80_neg: int  # 109
Z80_negw: int  # 234
Z80_or: int  # 110
Z80_orw: int  # 209
Z80_otdm: int  # 143
Z80_otdmr: int  # 144
Z80_otdr: int  # 111
Z80_otdrw: int  # 249
Z80_otim: int  # 141
Z80_otimr: int  # 142
Z80_otir: int  # 112
Z80_otirw: int  # 247
Z80_out: int  # 48
Z80_out0: int  # 145
Z80_outa: int  # 232
Z80_outaw: int  # 230
Z80_outd: int  # 113
Z80_outdw: int  # 248
Z80_outi: int  # 114
Z80_outiw: int  # 246
Z80_outp: int  # 137
Z80_outw: int  # 201
Z80_pop: int  # 50
Z80_push: int  # 51
Z80_res: int  # 115
Z80_resc: int  # 219
Z80_ret: int  # 116
Z80_reti: int  # 117
Z80_retn: int  # 118
Z80_rl: int  # 119
Z80_rla: int  # 120
Z80_rlc: int  # 121
Z80_rlca: int  # 122
Z80_rlcw: int  # 220
Z80_rld: int  # 123
Z80_rlw: int  # 222
Z80_rr: int  # 124
Z80_rra: int  # 125
Z80_rrc: int  # 126
Z80_rrca: int  # 127
Z80_rrcw: int  # 221
Z80_rrd: int  # 128
Z80_rrw: int  # 223
Z80_sbc: int  # 130
Z80_sbcw: int  # 206
Z80_scf: int  # 129
Z80_set: int  # 131
Z80_setc: int  # 218
Z80_sla: int  # 132
Z80_slaw: int  # 224
Z80_slp: int  # 146
Z80_sra: int  # 133
Z80_sraw: int  # 225
Z80_srl: int  # 134
Z80_srlw: int  # 226
Z80_srr: int  # 138
Z80_sub: int  # 74
Z80_subw: int  # 204
Z80_swap: int  # 199
Z80_tst: int  # 147
Z80_tstio: int  # 148
Z80_xor: int  # 135
Z80_xorw: int  # 208
Z8_adc: int  # 1
Z8_add: int  # 2
Z8_and: int  # 3
Z8_call: int  # 4
Z8_ccf: int  # 5
Z8_clr: int  # 6
Z8_com: int  # 7
Z8_cp: int  # 8
Z8_da: int  # 9
Z8_dec: int  # 10
Z8_decw: int  # 11
Z8_di: int  # 12
Z8_djnz: int  # 13
Z8_ei: int  # 14
Z8_halt: int  # 15
Z8_inc: int  # 16
Z8_incw: int  # 17
Z8_iret: int  # 18
Z8_jp: int  # 19
Z8_jpcond: int  # 20
Z8_jr: int  # 21
Z8_jrcond: int  # 22
Z8_last: int  # 50
Z8_ld: int  # 23
Z8_ldc: int  # 24
Z8_ldci: int  # 25
Z8_lde: int  # 26
Z8_ldei: int  # 27
Z8_nop: int  # 28
Z8_null: int  # 0
Z8_or: int  # 29
Z8_pop: int  # 30
Z8_push: int  # 31
Z8_rcf: int  # 32
Z8_ret: int  # 33
Z8_rl: int  # 34
Z8_rlc: int  # 35
Z8_rr: int  # 36
Z8_rrc: int  # 37
Z8_sbc: int  # 38
Z8_scf: int  # 39
Z8_sra: int  # 40
Z8_srp: int  # 41
Z8_stop: int  # 42
Z8_sub: int  # 43
Z8_swap: int  # 44
Z8_tcm: int  # 46
Z8_tm: int  # 45
Z8_wdh: int  # 48
Z8_wdt: int  # 49
Z8_xor: int  # 47
annotations: _Feature  # _Feature((3, 7, 0, 'beta', 1), None, 16777216)
fr_add: int  # 1
fr_add2: int  # 2
fr_addc: int  # 3
fr_addn: int  # 4
fr_addn2: int  # 5
fr_addsp: int  # 89
fr_and: int  # 11
fr_andb: int  # 13
fr_andccr: int  # 86
fr_andh: int  # 12
fr_asr: int  # 42
fr_asr2: int  # 43
fr_bandh: int  # 21
fr_bandl: int  # 20
fr_bc: int  # 64
fr_beorh: int  # 25
fr_beorl: int  # 24
fr_beq: int  # 62
fr_bge: int  # 71
fr_bgt: int  # 73
fr_bhi: int  # 75
fr_ble: int  # 72
fr_bls: int  # 74
fr_blt: int  # 70
fr_bn: int  # 66
fr_bnc: int  # 65
fr_bne: int  # 63
fr_bno: int  # 61
fr_bnv: int  # 69
fr_borh: int  # 23
fr_borl: int  # 22
fr_bp: int  # 67
fr_bra: int  # 60
fr_btsth: int  # 27
fr_btstl: int  # 26
fr_bv: int  # 68
fr_call: int  # 55
fr_cmp: int  # 9
fr_cmp2: int  # 10
fr_copld: int  # 82
fr_copop: int  # 81
fr_copst: int  # 83
fr_copsv: int  # 84
fr_div0s: int  # 32
fr_div0u: int  # 33
fr_div1: int  # 34
fr_div2: int  # 35
fr_div3: int  # 36
fr_div4s: int  # 37
fr_dmov: int  # 76
fr_dmovb: int  # 78
fr_dmovh: int  # 77
fr_enter: int  # 98
fr_eor: int  # 17
fr_eorb: int  # 19
fr_eorh: int  # 18
fr_extsb: int  # 90
fr_extsh: int  # 92
fr_extub: int  # 91
fr_extuh: int  # 93
fr_int: int  # 57
fr_inte: int  # 58
fr_jmp: int  # 54
fr_last: int  # 101
fr_ld: int  # 47
fr_ldi_20: int  # 45
fr_ldi_32: int  # 44
fr_ldi_8: int  # 46
fr_ldm0: int  # 94
fr_ldm1: int  # 95
fr_ldres: int  # 79
fr_ldub: int  # 49
fr_lduh: int  # 48
fr_leave: int  # 99
fr_lsl: int  # 38
fr_lsl2: int  # 39
fr_lsr: int  # 40
fr_lsr2: int  # 41
fr_mov: int  # 53
fr_mul: int  # 28
fr_mulh: int  # 30
fr_mulu: int  # 29
fr_muluh: int  # 31
fr_nop: int  # 85
fr_null: int  # 0
fr_or: int  # 14
fr_orb: int  # 16
fr_orccr: int  # 87
fr_orh: int  # 15
fr_ret: int  # 56
fr_reti: int  # 59
fr_st: int  # 50
fr_stb: int  # 52
fr_sth: int  # 51
fr_stilm: int  # 88
fr_stm0: int  # 96
fr_stm1: int  # 97
fr_stres: int  # 80
fr_sub: int  # 6
fr_subc: int  # 7
fr_subn: int  # 8
fr_xchb: int  # 100
ida_idaapi: module
j_a_hardware: int  # 207
j_a_invokeignored: int  # 205
j_a_invokesuper: int  # 203
j_a_invokevirtualobject: int  # 204
j_a_software: int  # 206
j_aaload: int  # 50
j_aastore: int  # 83
j_aconst_null: int  # 1
j_aload: int  # 25
j_aload_0: int  # 42
j_aload_1: int  # 43
j_aload_2: int  # 44
j_aload_3: int  # 45
j_anewarray: int  # 189
j_anewarray_quick: int  # 222
j_areturn: int  # 176
j_arraylength: int  # 190
j_astore: int  # 58
j_astore_0: int  # 75
j_astore_1: int  # 76
j_astore_2: int  # 77
j_astore_3: int  # 78
j_athrow: int  # 191
j_baload: int  # 51
j_bastore: int  # 84
j_bipush: int  # 16
j_breakpoint: int  # 202
j_caload: int  # 52
j_castore: int  # 85
j_checkcast: int  # 192
j_checkcast_quick: int  # 224
j_d2f: int  # 144
j_d2i: int  # 142
j_d2l: int  # 143
j_dadd: int  # 99
j_daload: int  # 49
j_dastore: int  # 82
j_dcmpg: int  # 152
j_dcmpl: int  # 151
j_dconst_0: int  # 14
j_dconst_1: int  # 15
j_ddiv: int  # 111
j_dload: int  # 24
j_dload_0: int  # 38
j_dload_1: int  # 39
j_dload_2: int  # 40
j_dload_3: int  # 41
j_dmul: int  # 107
j_dneg: int  # 119
j_drem: int  # 115
j_dreturn: int  # 175
j_dstore: int  # 57
j_dstore_0: int  # 71
j_dstore_1: int  # 72
j_dstore_2: int  # 73
j_dstore_3: int  # 74
j_dsub: int  # 103
j_dup: int  # 89
j_dup2: int  # 92
j_dup2_x1: int  # 93
j_dup2_x2: int  # 94
j_dup_x1: int  # 90
j_dup_x2: int  # 91
j_f2d: int  # 141
j_f2i: int  # 139
j_f2l: int  # 140
j_fadd: int  # 98
j_faload: int  # 48
j_fastore: int  # 81
j_fcmpg: int  # 150
j_fcmpl: int  # 149
j_fconst_0: int  # 11
j_fconst_1: int  # 12
j_fconst_2: int  # 13
j_fdiv: int  # 110
j_fload: int  # 23
j_fload_0: int  # 34
j_fload_1: int  # 35
j_fload_2: int  # 36
j_fload_3: int  # 37
j_fmul: int  # 106
j_fneg: int  # 118
j_frem: int  # 114
j_freturn: int  # 174
j_fstore: int  # 56
j_fstore_0: int  # 67
j_fstore_1: int  # 68
j_fstore_2: int  # 69
j_fstore_3: int  # 70
j_fsub: int  # 102
j_getfield: int  # 180
j_getfield2_quick: int  # 208
j_getfield_quick: int  # 206
j_getfield_quick_w: int  # 227
j_getstatic: int  # 178
j_getstatic2_quick: int  # 212
j_getstatic_quick: int  # 210
j_goto: int  # 167
j_goto_w: int  # 200
j_i2b: int  # 145
j_i2c: int  # 146
j_i2d: int  # 135
j_i2f: int  # 134
j_i2l: int  # 133
j_i2s: int  # 147
j_iadd: int  # 96
j_iaload: int  # 46
j_iand: int  # 126
j_iastore: int  # 79
j_iconst_0: int  # 3
j_iconst_1: int  # 4
j_iconst_2: int  # 5
j_iconst_3: int  # 6
j_iconst_4: int  # 7
j_iconst_5: int  # 8
j_iconst_m1: int  # 2
j_idiv: int  # 108
j_if_acmpeq: int  # 165
j_if_acmpne: int  # 166
j_if_icmpeq: int  # 159
j_if_icmpge: int  # 162
j_if_icmpgt: int  # 163
j_if_icmple: int  # 164
j_if_icmplt: int  # 161
j_if_icmpne: int  # 160
j_ifeq: int  # 153
j_ifge: int  # 156
j_ifgt: int  # 157
j_ifle: int  # 158
j_iflt: int  # 155
j_ifne: int  # 154
j_ifnonnull: int  # 199
j_ifnull: int  # 198
j_iinc: int  # 132
j_iload: int  # 21
j_iload_0: int  # 26
j_iload_1: int  # 27
j_iload_2: int  # 28
j_iload_3: int  # 29
j_imul: int  # 104
j_ineg: int  # 116
j_instanceof: int  # 193
j_instanceof_quick: int  # 225
j_invokedynamic: int  # 186
j_invokeignored_quick: int  # 220
j_invokeinterface: int  # 185
j_invokeinterface_quick: int  # 218
j_invokenonvirtual_quick: int  # 215
j_invokespecial: int  # 183
j_invokestatic: int  # 184
j_invokestatic_quick: int  # 217
j_invokesuper_quick: int  # 216
j_invokevirtual: int  # 182
j_invokevirtual_quick: int  # 214
j_invokevirtual_quick_w: int  # 226
j_invokevirtualobject_quick: int  # 219
j_ior: int  # 128
j_irem: int  # 112
j_ireturn: int  # 172
j_ishl: int  # 120
j_ishr: int  # 122
j_istore: int  # 54
j_istore_0: int  # 59
j_istore_1: int  # 60
j_istore_2: int  # 61
j_istore_3: int  # 62
j_isub: int  # 100
j_iushr: int  # 124
j_ixor: int  # 130
j_jsr: int  # 168
j_jsr_w: int  # 201
j_l2d: int  # 138
j_l2f: int  # 137
j_l2i: int  # 136
j_ladd: int  # 97
j_laload: int  # 47
j_land: int  # 127
j_last: int  # 208
j_lastnorm: int  # 203
j_lastore: int  # 80
j_lcmp: int  # 148
j_lconst_0: int  # 9
j_lconst_1: int  # 10
j_ldc: int  # 18
j_ldc2w: int  # 20
j_ldc2w_quick: int  # 205
j_ldc_quick: int  # 203
j_ldcw: int  # 19
j_ldcw_quick: int  # 204
j_ldiv: int  # 109
j_lload: int  # 22
j_lload_0: int  # 30
j_lload_1: int  # 31
j_lload_2: int  # 32
j_lload_3: int  # 33
j_lmul: int  # 105
j_lneg: int  # 117
j_lookupswitch: int  # 171
j_lor: int  # 129
j_lrem: int  # 113
j_lreturn: int  # 173
j_lshl: int  # 121
j_lshr: int  # 123
j_lstore: int  # 55
j_lstore_0: int  # 63
j_lstore_1: int  # 64
j_lstore_2: int  # 65
j_lstore_3: int  # 66
j_lsub: int  # 101
j_lushr: int  # 125
j_lxor: int  # 131
j_monitorenter: int  # 194
j_monitorexit: int  # 195
j_multianewarray: int  # 197
j_multianewarray_quick: int  # 223
j_new: int  # 187
j_new_quick: int  # 221
j_newarray: int  # 188
j_nop: int  # 0
j_pop: int  # 87
j_pop2: int  # 88
j_putfield: int  # 181
j_putfield2_quick: int  # 209
j_putfield_quick: int  # 207
j_putfield_quick_w: int  # 228
j_putstatic: int  # 179
j_putstatic2_quick: int  # 213
j_putstatic_quick: int  # 211
j_quick_last: int  # 229
j_ret: int  # 169
j_return: int  # 177
j_saload: int  # 53
j_sastore: int  # 86
j_sipush: int  # 17
j_swap: int  # 95
j_tableswitch: int  # 170
j_wide: int  # 196
m32r_add: int  # 1
m32r_add3: int  # 2
m32r_addi: int  # 3
m32r_addv: int  # 4
m32r_addv3: int  # 5
m32r_addx: int  # 6
m32r_and: int  # 7
m32r_and3: int  # 8
m32r_bc: int  # 9
m32r_bclr: int  # 132
m32r_beq: int  # 10
m32r_beqz: int  # 11
m32r_bgez: int  # 12
m32r_bgtz: int  # 13
m32r_bl: int  # 14
m32r_blez: int  # 15
m32r_bltz: int  # 16
m32r_bnc: int  # 17
m32r_bne: int  # 18
m32r_bnez: int  # 19
m32r_bra: int  # 20
m32r_bset: int  # 131
m32r_btst: int  # 133
m32r_clrpsw: int  # 135
m32r_cmp: int  # 21
m32r_cmpi: int  # 22
m32r_cmpu: int  # 23
m32r_cmpui: int  # 24
m32r_div: int  # 25
m32r_divu: int  # 26
m32r_fadd: int  # 119
m32r_fcmp: int  # 129
m32r_fcmpe: int  # 130
m32r_fdiv: int  # 122
m32r_fmadd: int  # 123
m32r_fmsub: int  # 124
m32r_fmul: int  # 121
m32r_fsub: int  # 120
m32r_ftoi: int  # 127
m32r_ftos: int  # 128
m32r_itof: int  # 125
m32r_jl: int  # 27
m32r_jmp: int  # 28
m32r_last: int  # 136
m32r_ld: int  # 29
m32r_ld24: int  # 30
m32r_ldb: int  # 31
m32r_ldh: int  # 32
m32r_ldi: int  # 33
m32r_ldub: int  # 34
m32r_lduh: int  # 35
m32r_lock: int  # 36
m32r_machi: int  # 37
m32r_maclo: int  # 38
m32r_macwhi: int  # 39
m32r_macwlo: int  # 40
m32r_mul: int  # 41
m32r_mulhi: int  # 42
m32r_mullo: int  # 43
m32r_mulwhi: int  # 44
m32r_mulwlo: int  # 45
m32r_mv: int  # 46
m32r_mvfachi: int  # 47
m32r_mvfaclo: int  # 48
m32r_mvfacmi: int  # 49
m32r_mvfc: int  # 50
m32r_mvtachi: int  # 51
m32r_mvtaclo: int  # 52
m32r_mvtc: int  # 53
m32r_neg: int  # 54
m32r_nop: int  # 55
m32r_not: int  # 56
m32r_null: int  # 0
m32r_or: int  # 57
m32r_or3: int  # 58
m32r_pop: int  # 60
m32r_push: int  # 59
m32r_rac: int  # 61
m32r_rach: int  # 62
m32r_rem: int  # 63
m32r_remu: int  # 64
m32r_rte: int  # 65
m32r_seth: int  # 66
m32r_setpsw: int  # 134
m32r_sll: int  # 67
m32r_sll3: int  # 68
m32r_slli: int  # 69
m32r_sra: int  # 70
m32r_sra3: int  # 71
m32r_srai: int  # 72
m32r_srl: int  # 73
m32r_srl3: int  # 74
m32r_srli: int  # 75
m32r_st: int  # 76
m32r_stb: int  # 77
m32r_sth: int  # 78
m32r_sub: int  # 79
m32r_subv: int  # 80
m32r_subx: int  # 81
m32r_trap: int  # 82
m32r_unlock: int  # 83
m32r_utof: int  # 126
m32r_xor: int  # 84
m32r_xor3: int  # 85
m32rx_bcl: int  # 86
m32rx_bncl: int  # 87
m32rx_cmpeq: int  # 88
m32rx_cmpz: int  # 89
m32rx_divh: int  # 90
m32rx_jc: int  # 91
m32rx_jnc: int  # 92
m32rx_machi: int  # 93
m32rx_maclh1: int  # 116
m32rx_maclo: int  # 94
m32rx_macwhi: int  # 95
m32rx_macwlo: int  # 96
m32rx_macwu1: int  # 113
m32rx_msblo: int  # 114
m32rx_mulhi: int  # 97
m32rx_mullo: int  # 98
m32rx_mulwhi: int  # 99
m32rx_mulwlo: int  # 100
m32rx_mulwu1: int  # 115
m32rx_mvfachi: int  # 101
m32rx_mvfaclo: int  # 102
m32rx_mvfacmi: int  # 103
m32rx_mvtachi: int  # 104
m32rx_mvtaclo: int  # 105
m32rx_pcmpbz: int  # 111
m32rx_rac: int  # 106
m32rx_rach: int  # 107
m32rx_sadd: int  # 112
m32rx_sat: int  # 110
m32rx_satb: int  # 108
m32rx_sath: int  # 109
m32rx_sc: int  # 117
m32rx_snc: int  # 118
m740_adc: int  # 1
m740_and: int  # 2
m740_asl: int  # 3
m740_bbc: int  # 4
m740_bbs: int  # 5
m740_bcc: int  # 6
m740_bcs: int  # 7
m740_beq: int  # 8
m740_bit: int  # 9
m740_bmi: int  # 10
m740_bne: int  # 11
m740_bpl: int  # 12
m740_bra: int  # 13
m740_brk: int  # 14
m740_bvc: int  # 15
m740_bvs: int  # 16
m740_clb: int  # 17
m740_clc: int  # 18
m740_cld: int  # 19
m740_cli: int  # 20
m740_clt: int  # 21
m740_clv: int  # 22
m740_cmp: int  # 23
m740_com: int  # 24
m740_cpx: int  # 25
m740_cpy: int  # 26
m740_dec: int  # 27
m740_dex: int  # 28
m740_dey: int  # 29
m740_div: int  # 30
m740_eor: int  # 31
m740_inc: int  # 32
m740_inx: int  # 33
m740_iny: int  # 34
m740_jmp: int  # 35
m740_jsr: int  # 36
m740_last: int  # 72
m740_lda: int  # 37
m740_ldm: int  # 38
m740_ldx: int  # 39
m740_ldy: int  # 40
m740_lsr: int  # 41
m740_mul: int  # 42
m740_nop: int  # 43
m740_null: int  # 0
m740_ora: int  # 44
m740_pha: int  # 45
m740_php: int  # 46
m740_pla: int  # 47
m740_plp: int  # 48
m740_rol: int  # 49
m740_ror: int  # 50
m740_rrf: int  # 51
m740_rti: int  # 52
m740_rts: int  # 53
m740_sbc: int  # 54
m740_seb: int  # 55
m740_sec: int  # 56
m740_sed: int  # 57
m740_sei: int  # 58
m740_set: int  # 59
m740_sta: int  # 60
m740_stp: int  # 61
m740_stx: int  # 62
m740_sty: int  # 63
m740_tax: int  # 64
m740_tay: int  # 65
m740_tst: int  # 66
m740_tsx: int  # 67
m740_txa: int  # 68
m740_txs: int  # 69
m740_tya: int  # 70
m740_wit: int  # 71
m7700_adc: int  # 1
m7700_and: int  # 2
m7700_asl: int  # 3
m7700_bbc: int  # 4
m7700_bbs: int  # 5
m7700_bcc: int  # 6
m7700_bcs: int  # 7
m7700_beq: int  # 8
m7700_bmi: int  # 9
m7700_bne: int  # 10
m7700_bpl: int  # 11
m7700_bra: int  # 12
m7700_brk: int  # 13
m7700_bvc: int  # 14
m7700_bvs: int  # 15
m7700_clb: int  # 16
m7700_clc: int  # 17
m7700_cli: int  # 18
m7700_clm: int  # 19
m7700_clp: int  # 20
m7700_clv: int  # 21
m7700_cmp: int  # 22
m7700_cpx: int  # 23
m7700_cpy: int  # 24
m7700_dec: int  # 25
m7700_dex: int  # 26
m7700_dey: int  # 27
m7700_div: int  # 28
m7700_eor: int  # 29
m7700_inc: int  # 30
m7700_inx: int  # 31
m7700_iny: int  # 32
m7700_jmp: int  # 33
m7700_jsr: int  # 34
m7700_last: int  # 109
m7700_lda: int  # 35
m7700_ldm: int  # 36
m7700_ldt: int  # 37
m7700_ldx: int  # 38
m7700_ldy: int  # 39
m7700_lsr: int  # 40
m7700_mpy: int  # 41
m7700_mvn: int  # 42
m7700_mvp: int  # 43
m7700_nop: int  # 44
m7700_null: int  # 0
m7700_ora: int  # 45
m7700_pea: int  # 46
m7700_pei: int  # 47
m7700_per: int  # 48
m7700_pha: int  # 49
m7700_phb: int  # 50
m7700_phd: int  # 51
m7700_phg: int  # 52
m7700_php: int  # 53
m7700_pht: int  # 54
m7700_phx: int  # 55
m7700_phy: int  # 56
m7700_pla: int  # 57
m7700_plb: int  # 58
m7700_pld: int  # 59
m7700_plp: int  # 60
m7700_plt: int  # 61
m7700_plx: int  # 62
m7700_ply: int  # 63
m7700_psh: int  # 64
m7700_pul: int  # 65
m7700_rla: int  # 66
m7700_rol: int  # 67
m7700_ror: int  # 68
m7700_rti: int  # 69
m7700_rtl: int  # 70
m7700_rts: int  # 71
m7700_sbc: int  # 72
m7700_seb: int  # 73
m7700_sec: int  # 74
m7700_sei: int  # 75
m7700_sem: int  # 76
m7700_sep: int  # 77
m7700_sta: int  # 78
m7700_stp: int  # 79
m7700_stx: int  # 80
m7700_sty: int  # 81
m7700_tad: int  # 82
m7700_tas: int  # 83
m7700_tax: int  # 84
m7700_tay: int  # 85
m7700_tbd: int  # 86
m7700_tbs: int  # 87
m7700_tbx: int  # 88
m7700_tby: int  # 89
m7700_tda: int  # 90
m7700_tdb: int  # 91
m7700_tsa: int  # 92
m7700_tsb: int  # 93
m7700_tsx: int  # 94
m7700_txa: int  # 95
m7700_txb: int  # 96
m7700_txs: int  # 97
m7700_txy: int  # 98
m7700_tya: int  # 99
m7700_tyb: int  # 100
m7700_tyx: int  # 101
m7700_wit: int  # 102
m7700_xab: int  # 103
m7750_asr: int  # 104
m7750_divs: int  # 105
m7750_exts: int  # 106
m7750_extz: int  # 107
m7750_mpys: int  # 108
m7900_abs: int  # 1
m7900_absd: int  # 2
m7900_adc: int  # 3
m7900_adcb: int  # 4
m7900_adcd: int  # 5
m7900_add: int  # 6
m7900_addb: int  # 7
m7900_addd: int  # 8
m7900_addm: int  # 9
m7900_addmb: int  # 10
m7900_addmd: int  # 11
m7900_adds: int  # 12
m7900_addx: int  # 13
m7900_addy: int  # 14
m7900_and: int  # 15
m7900_andb: int  # 16
m7900_andm: int  # 17
m7900_andmb: int  # 18
m7900_andmd: int  # 19
m7900_asl: int  # 20
m7900_asldn: int  # 22
m7900_asln: int  # 21
m7900_asr: int  # 23
m7900_asrdn: int  # 25
m7900_asrn: int  # 24
m7900_bbc: int  # 26
m7900_bbcb: int  # 27
m7900_bbs: int  # 28
m7900_bbsb: int  # 29
m7900_bcc: int  # 30
m7900_bcs: int  # 31
m7900_beq: int  # 32
m7900_bge: int  # 33
m7900_bgt: int  # 34
m7900_bgtu: int  # 35
m7900_ble: int  # 36
m7900_bleu: int  # 37
m7900_blt: int  # 38
m7900_bmi: int  # 39
m7900_bne: int  # 40
m7900_bpl: int  # 41
m7900_bra: int  # 42
m7900_bral: int  # 43
m7900_brk: int  # 44
m7900_bsc: int  # 45
m7900_bsr: int  # 46
m7900_bss: int  # 47
m7900_bvc: int  # 48
m7900_bvs: int  # 49
m7900_cbeq: int  # 50
m7900_cbeqb: int  # 51
m7900_cbne: int  # 52
m7900_cbneb: int  # 53
m7900_clc: int  # 54
m7900_cli: int  # 55
m7900_clm: int  # 56
m7900_clp: int  # 57
m7900_clr: int  # 58
m7900_clrb: int  # 59
m7900_clrm: int  # 60
m7900_clrmb: int  # 61
m7900_clrx: int  # 62
m7900_clry: int  # 63
m7900_clv: int  # 64
m7900_cmp: int  # 65
m7900_cmpb: int  # 66
m7900_cmpd: int  # 67
m7900_cmpm: int  # 68
m7900_cmpmb: int  # 69
m7900_cmpmd: int  # 70
m7900_cpx: int  # 71
m7900_cpy: int  # 72
m7900_debne: int  # 73
m7900_dec: int  # 74
m7900_dex: int  # 75
m7900_dey: int  # 76
m7900_div: int  # 77
m7900_divs: int  # 78
m7900_dxbne: int  # 79
m7900_dybne: int  # 80
m7900_eor: int  # 81
m7900_eorb: int  # 82
m7900_eorm: int  # 83
m7900_eormb: int  # 84
m7900_eormd: int  # 85
m7900_exts: int  # 86
m7900_extsd: int  # 87
m7900_extz: int  # 88
m7900_extzd: int  # 89
m7900_inc: int  # 90
m7900_inx: int  # 91
m7900_iny: int  # 92
m7900_jmp: int  # 93
m7900_jmpl: int  # 94
m7900_jsr: int  # 95
m7900_jsrl: int  # 96
m7900_last: int  # 207
m7900_lda: int  # 97
m7900_ldab: int  # 98
m7900_ldad: int  # 99
m7900_lddn: int  # 100
m7900_ldt: int  # 101
m7900_ldx: int  # 102
m7900_ldxb: int  # 103
m7900_ldy: int  # 104
m7900_ldyb: int  # 105
m7900_lsr: int  # 106
m7900_lsrdn: int  # 108
m7900_lsrn: int  # 107
m7900_movm: int  # 109
m7900_movmb: int  # 110
m7900_movr: int  # 111
m7900_movrb: int  # 112
m7900_mpy: int  # 113
m7900_mpys: int  # 114
m7900_mvn: int  # 115
m7900_mvp: int  # 116
m7900_neg: int  # 117
m7900_negd: int  # 118
m7900_nop: int  # 119
m7900_null: int  # 0
m7900_ora: int  # 120
m7900_orab: int  # 121
m7900_oram: int  # 122
m7900_oramb: int  # 123
m7900_oramd: int  # 124
m7900_pea: int  # 125
m7900_pei: int  # 126
m7900_per: int  # 127
m7900_pha: int  # 128
m7900_phb: int  # 129
m7900_phd: int  # 130
m7900_phdn: int  # 131
m7900_phg: int  # 132
m7900_phldn: int  # 133
m7900_php: int  # 134
m7900_pht: int  # 135
m7900_phx: int  # 136
m7900_phy: int  # 137
m7900_pla: int  # 138
m7900_plb: int  # 139
m7900_pld: int  # 140
m7900_pldn: int  # 141
m7900_plp: int  # 142
m7900_plt: int  # 143
m7900_plx: int  # 144
m7900_ply: int  # 145
m7900_psh: int  # 146
m7900_pul: int  # 147
m7900_rla: int  # 148
m7900_rmpa: int  # 149
m7900_rol: int  # 150
m7900_roldn: int  # 152
m7900_roln: int  # 151
m7900_ror: int  # 153
m7900_rordn: int  # 155
m7900_rorn: int  # 154
m7900_rti: int  # 156
m7900_rtl: int  # 157
m7900_rtld: int  # 158
m7900_rts: int  # 159
m7900_rtsdn: int  # 160
m7900_sbc: int  # 161
m7900_sbcb: int  # 162
m7900_sbcd: int  # 163
m7900_sec: int  # 164
m7900_sei: int  # 165
m7900_sem: int  # 166
m7900_sep: int  # 167
m7900_sta: int  # 168
m7900_stab: int  # 169
m7900_stad: int  # 170
m7900_stp: int  # 171
m7900_stx: int  # 172
m7900_sty: int  # 173
m7900_sub: int  # 174
m7900_subb: int  # 175
m7900_subd: int  # 176
m7900_subm: int  # 177
m7900_submb: int  # 178
m7900_submd: int  # 179
m7900_subs: int  # 180
m7900_subx: int  # 181
m7900_suby: int  # 182
m7900_tadn: int  # 183
m7900_tas: int  # 184
m7900_tax: int  # 185
m7900_tay: int  # 186
m7900_tbdn: int  # 187
m7900_tbs: int  # 188
m7900_tbx: int  # 189
m7900_tby: int  # 190
m7900_tdan: int  # 191
m7900_tdbn: int  # 192
m7900_tds: int  # 193
m7900_tsa: int  # 194
m7900_tsb: int  # 195
m7900_tsd: int  # 196
m7900_tsx: int  # 197
m7900_txa: int  # 198
m7900_txb: int  # 199
m7900_txs: int  # 200
m7900_txy: int  # 201
m7900_tya: int  # 202
m7900_tyb: int  # 203
m7900_tyx: int  # 204
m7900_wit: int  # 205
m7900_xab: int  # 206
mc8_1: int  # 136
mc8_2: int  # 137
mc8_ab: int  # 2
mc8_aba: int  # 1
mc8_adc: int  # 3
mc8_add: int  # 4
mc8_addd: int  # 5
mc8_aim: int  # 139
mc8_ais: int  # 6
mc8_aix: int  # 7
mc8_and: int  # 8
mc8_andcc: int  # 9
mc8_asr: int  # 10
mc8_bcc: int  # 11
mc8_bclr: int  # 12
mc8_bcs: int  # 13
mc8_beq: int  # 14
mc8_bge: int  # 15
mc8_bgnd: int  # 143
mc8_bgt: int  # 16
mc8_bhcc: int  # 17
mc8_bhcs: int  # 18
mc8_bhi: int  # 19
mc8_bhs: int  # 20
mc8_bih: int  # 21
mc8_bil: int  # 22
mc8_bit: int  # 23
mc8_ble: int  # 24
mc8_blo: int  # 25
mc8_bls: int  # 26
mc8_blt: int  # 27
mc8_bmc: int  # 28
mc8_bmi: int  # 29
mc8_bms: int  # 30
mc8_bne: int  # 31
mc8_bpl: int  # 32
mc8_bra: int  # 33
mc8_brclr: int  # 34
mc8_brn: int  # 35
mc8_brset: int  # 36
mc8_bset: int  # 37
mc8_bsr: int  # 38
mc8_bvc: int  # 39
mc8_bvs: int  # 40
mc8_call: int  # 144
mc8_cba: int  # 41
mc8_cbeq: int  # 42
mc8_clc: int  # 43
mc8_cli: int  # 44
mc8_clr: int  # 45
mc8_clv: int  # 46
mc8_cmp: int  # 47
mc8_com: int  # 48
mc8_cp: int  # 49
mc8_cpd: int  # 50
mc8_cphx: int  # 51
mc8_cpx: int  # 52
mc8_cwai: int  # 53
mc8_daa: int  # 54
mc8_dbnz: int  # 55
mc8_de: int  # 56
mc8_dec: int  # 57
mc8_des: int  # 58
mc8_div: int  # 59
mc8_eim: int  # 141
mc8_eor: int  # 60
mc8_exg: int  # 61
mc8_fdiv: int  # 62
mc8_idiv: int  # 63
mc8_in: int  # 64
mc8_inc: int  # 65
mc8_ins: int  # 66
mc8_jmp: int  # 67
mc8_jsr: int  # 68
mc8_last: int  # 148
mc8_ld: int  # 69
mc8_lda: int  # 70
mc8_ldd: int  # 71
mc8_ldhx: int  # 72
mc8_lds: int  # 73
mc8_ldx: int  # 74
mc8_lea: int  # 75
mc8_lsl: int  # 76
mc8_lsld: int  # 77
mc8_lsr: int  # 78
mc8_lsrd: int  # 79
mc8_mov: int  # 80
mc8_mul: int  # 81
mc8_neg: int  # 82
mc8_nop: int  # 83
mc8_nsa: int  # 84
mc8_null: int  # 0
mc8_oim: int  # 140
mc8_ora: int  # 85
mc8_orcc: int  # 86
mc8_os9: int  # 138
mc8_psh: int  # 87
mc8_psha: int  # 88
mc8_pshb: int  # 89
mc8_pshh: int  # 90
mc8_pshx: int  # 91
mc8_pul: int  # 92
mc8_pula: int  # 93
mc8_pulb: int  # 94
mc8_pulh: int  # 95
mc8_pulx: int  # 96
mc8_rol: int  # 97
mc8_ror: int  # 98
mc8_rsp: int  # 99
mc8_rtc: int  # 145
mc8_rti: int  # 100
mc8_rts: int  # 101
mc8_sba: int  # 102
mc8_sbc: int  # 103
mc8_sec: int  # 104
mc8_sei: int  # 105
mc8_sev: int  # 106
mc8_sex: int  # 107
mc8_skip1: int  # 146
mc8_skip2: int  # 147
mc8_slp: int  # 108
mc8_st: int  # 109
mc8_sta: int  # 110
mc8_std: int  # 111
mc8_sthx: int  # 112
mc8_stop: int  # 113
mc8_sts: int  # 114
mc8_stx: int  # 115
mc8_sub: int  # 116
mc8_subd: int  # 117
mc8_swi: int  # 118
mc8_sync: int  # 119
mc8_tab: int  # 120
mc8_tap: int  # 121
mc8_tax: int  # 122
mc8_tba: int  # 123
mc8_test: int  # 124
mc8_tfr: int  # 125
mc8_tim: int  # 142
mc8_tpa: int  # 126
mc8_ts: int  # 127
mc8_tst: int  # 128
mc8_tsx: int  # 129
mc8_txa: int  # 130
mc8_txs: int  # 131
mc8_tys: int  # 132
mc8_wai: int  # 133
mc8_wait: int  # 134
mc8_xgd: int  # 135
mc_abcd: int  # 1
mc_add: int  # 2
mc_adda: int  # 3
mc_addi: int  # 4
mc_addq: int  # 5
mc_addx: int  # 6
mc_and: int  # 7
mc_andi: int  # 8
mc_asl: int  # 9
mc_asr: int  # 10
mc_atrap: int  # 189
mc_b: int  # 11
mc_bchg: int  # 12
mc_bclr: int  # 13
mc_bfchg: int  # 15
mc_bfclr: int  # 16
mc_bfexts: int  # 19
mc_bfextu: int  # 18
mc_bfffo: int  # 20
mc_bfins: int  # 21
mc_bfset: int  # 17
mc_bftst: int  # 14
mc_bgnd: int  # 22
mc_bitrev: int  # 190
mc_bkpt: int  # 23
mc_bra: int  # 24
mc_bset: int  # 25
mc_bsr: int  # 26
mc_btst: int  # 27
mc_byterev: int  # 191
mc_callm: int  # 28
mc_cas: int  # 29
mc_cas2: int  # 30
mc_chk: int  # 31
mc_chk2: int  # 32
mc_cinv: int  # 33
mc_clr: int  # 34
mc_cmp: int  # 35
mc_cmp2: int  # 36
mc_cmpa: int  # 37
mc_cmpi: int  # 38
mc_cmpm: int  # 39
mc_cpush: int  # 40
mc_db: int  # 41
mc_divs: int  # 42
mc_divsl: int  # 43
mc_divu: int  # 44
mc_divul: int  # 45
mc_eor: int  # 46
mc_eori: int  # 47
mc_exg: int  # 48
mc_ext: int  # 49
mc_extb: int  # 50
mc_fabs: int  # 51
mc_facos: int  # 52
mc_fadd: int  # 53
mc_fasin: int  # 54
mc_fatan: int  # 55
mc_fatanh: int  # 56
mc_fb: int  # 57
mc_fcmp: int  # 58
mc_fcos: int  # 59
mc_fcosh: int  # 60
mc_fdabs: int  # 61
mc_fdadd: int  # 62
mc_fdb: int  # 63
mc_fddiv: int  # 64
mc_fdiv: int  # 65
mc_fdmove: int  # 66
mc_fdmul: int  # 67
mc_fdneg: int  # 68
mc_fdsqrt: int  # 69
mc_fdsub: int  # 70
mc_fetox: int  # 71
mc_fetoxm1: int  # 72
mc_ff1: int  # 192
mc_fgetexp: int  # 73
mc_fgetman: int  # 74
mc_fint: int  # 75
mc_fintrz: int  # 76
mc_flog10: int  # 78
mc_flog2: int  # 77
mc_flogn: int  # 79
mc_flognp1: int  # 80
mc_fmod: int  # 81
mc_fmove: int  # 82
mc_fmovecr: int  # 83
mc_fmovem: int  # 84
mc_fmul: int  # 85
mc_fneg: int  # 86
mc_fnop: int  # 87
mc_frem: int  # 88
mc_frestore: int  # 89
mc_fs: int  # 90
mc_fsabs: int  # 91
mc_fsadd: int  # 92
mc_fsave: int  # 93
mc_fscale: int  # 94
mc_fsdiv: int  # 95
mc_fsgldiv: int  # 96
mc_fsglmul: int  # 97
mc_fsin: int  # 98
mc_fsincos: int  # 99
mc_fsinh: int  # 100
mc_fsmove: int  # 101
mc_fsmul: int  # 102
mc_fsneg: int  # 103
mc_fsqrt: int  # 104
mc_fssqrt: int  # 105
mc_fssub: int  # 106
mc_fsub: int  # 107
mc_ftan: int  # 108
mc_ftanh: int  # 109
mc_ftentox: int  # 110
mc_ftrap: int  # 111
mc_ftst: int  # 112
mc_ftwotox: int  # 113
mc_halt: int  # 114
mc_illegal: int  # 115
mc_intouch: int  # 193
mc_jmp: int  # 116
mc_jsr: int  # 117
mc_last: int  # 205
mc_lea: int  # 118
mc_link: int  # 119
mc_lpstop: int  # 120
mc_lsl: int  # 121
mc_lsr: int  # 122
mc_maaac: int  # 199
mc_mac: int  # 123
mc_macl: int  # 124
mc_masac: int  # 200
mc_mov3q: int  # 194
mc_movclr: int  # 198
mc_move: int  # 125
mc_move16: int  # 126
mc_movea: int  # 127
mc_movec: int  # 128
mc_movem: int  # 129
mc_movep: int  # 130
mc_moveq: int  # 131
mc_moves: int  # 132
mc_msaac: int  # 201
mc_msac: int  # 133
mc_msacl: int  # 134
mc_mssac: int  # 202
mc_muls: int  # 135
mc_mulu: int  # 136
mc_mvs: int  # 195
mc_mvz: int  # 196
mc_nbcd: int  # 137
mc_neg: int  # 138
mc_negx: int  # 139
mc_nop: int  # 140
mc_not: int  # 141
mc_null: int  # 0
mc_or: int  # 142
mc_ori: int  # 143
mc_pack: int  # 144
mc_pb: int  # 146
mc_pdb: int  # 147
mc_pea: int  # 145
mc_pflush: int  # 148
mc_pflushr: int  # 149
mc_ploadr: int  # 150
mc_ploadw: int  # 151
mc_pmove: int  # 152
mc_prestore: int  # 153
mc_ps: int  # 155
mc_psave: int  # 154
mc_ptestr: int  # 156
mc_ptestw: int  # 157
mc_ptrap: int  # 158
mc_pulse: int  # 159
mc_pvalid: int  # 160
mc_remsl: int  # 203
mc_remul: int  # 204
mc_reset: int  # 165
mc_rol: int  # 161
mc_ror: int  # 162
mc_roxl: int  # 163
mc_roxr: int  # 164
mc_rtd: int  # 166
mc_rte: int  # 167
mc_rtm: int  # 168
mc_rtr: int  # 169
mc_rts: int  # 170
mc_s: int  # 172
mc_sats: int  # 197
mc_sbcd: int  # 171
mc_stop: int  # 173
mc_sub: int  # 174
mc_suba: int  # 175
mc_subi: int  # 176
mc_subq: int  # 177
mc_subx: int  # 178
mc_swap: int  # 179
mc_tas: int  # 180
mc_tbl: int  # 181
mc_trap: int  # 182
mc_trapv: int  # 183
mc_tst: int  # 184
mc_unlk: int  # 185
mc_unpk: int  # 186
mc_wddata: int  # 187
mc_wdebug: int  # 188
mn102_add: int  # 1
mn102_addc: int  # 2
mn102_addnf: int  # 3
mn102_and: int  # 4
mn102_asr: int  # 5
mn102_bcc: int  # 6
mn102_bccx: int  # 7
mn102_bclr: int  # 8
mn102_bcs: int  # 9
mn102_bcsx: int  # 10
mn102_beq: int  # 11
mn102_beqx: int  # 12
mn102_bge: int  # 13
mn102_bgex: int  # 14
mn102_bgt: int  # 15
mn102_bgtx: int  # 16
mn102_bhi: int  # 17
mn102_bhix: int  # 18
mn102_ble: int  # 19
mn102_blex: int  # 20
mn102_bls: int  # 21
mn102_blsx: int  # 22
mn102_blt: int  # 23
mn102_bltx: int  # 24
mn102_bnc: int  # 25
mn102_bncx: int  # 26
mn102_bne: int  # 27
mn102_bnex: int  # 28
mn102_bns: int  # 29
mn102_bnsx: int  # 30
mn102_bra: int  # 31
mn102_bset: int  # 32
mn102_btst: int  # 33
mn102_bvc: int  # 34
mn102_bvcx: int  # 35
mn102_bvs: int  # 36
mn102_bvsx: int  # 37
mn102_cmp: int  # 38
mn102_divu: int  # 39
mn102_ext: int  # 40
mn102_extx: int  # 41
mn102_extxb: int  # 42
mn102_extxbu: int  # 43
mn102_extxu: int  # 44
mn102_jmp: int  # 45
mn102_jsr: int  # 46
mn102_last: int  # 70
mn102_lsr: int  # 47
mn102_mov: int  # 48
mn102_movb: int  # 49
mn102_movbu: int  # 50
mn102_movx: int  # 51
mn102_mul: int  # 52
mn102_mulq: int  # 53
mn102_mulqh: int  # 54
mn102_mulql: int  # 55
mn102_mulu: int  # 56
mn102_nop: int  # 57
mn102_not: int  # 58
mn102_null: int  # 0
mn102_or: int  # 59
mn102_pxst: int  # 60
mn102_rol: int  # 61
mn102_ror: int  # 62
mn102_rti: int  # 63
mn102_rts: int  # 64
mn102_sub: int  # 65
mn102_subc: int  # 66
mn102_tbnz: int  # 67
mn102_tbz: int  # 68
mn102_xor: int  # 69
pdp_absd: int  # 89
pdp_adc: int  # 37
pdp_add: int  # 53
pdp_addd: int  # 93
pdp_ash: int  # 57
pdp_ashc: int  # 58
pdp_asl: int  # 43
pdp_asr: int  # 42
pdp_bcc: int  # 71
pdp_bcs: int  # 72
pdp_beq: int  # 26
pdp_bge: int  # 27
pdp_bgt: int  # 29
pdp_bhi: int  # 67
pdp_bic: int  # 51
pdp_bis: int  # 52
pdp_bit: int  # 50
pdp_ble: int  # 30
pdp_blos: int  # 68
pdp_blt: int  # 28
pdp_bmi: int  # 66
pdp_bne: int  # 25
pdp_bpl: int  # 65
pdp_bpt: int  # 4
pdp_br: int  # 24
pdp_bvc: int  # 69
pdp_bvs: int  # 70
pdp_call: int  # 105
pdp_ccc: int  # 17
pdp_cfcc: int  # 79
pdp_clc: int  # 13
pdp_cln: int  # 16
pdp_clr: int  # 32
pdp_clrd: int  # 87
pdp_clv: int  # 14
pdp_clz: int  # 15
pdp_cmp: int  # 49
pdp_cmpd: int  # 96
pdp_com: int  # 33
pdp_compcc: int  # 107
pdp_dec: int  # 35
pdp_div: int  # 56
pdp_divd: int  # 98
pdp_emt: int  # 73
pdp_fadd: int  # 60
pdp_fdiv: int  # 63
pdp_fmul: int  # 62
pdp_fsub: int  # 61
pdp_halt: int  # 1
pdp_inc: int  # 34
pdp_iot: int  # 5
pdp_jmp: int  # 9
pdp_jsr: int  # 31
pdp_last: int  # 108
pdp_ldcfd: int  # 104
pdp_ldcif: int  # 103
pdp_ldd: int  # 94
pdp_ldexp: int  # 102
pdp_ldfps: int  # 84
pdp_mark: int  # 44
pdp_mfpd: int  # 76
pdp_mfpi: int  # 45
pdp_mfps: int  # 78
pdp_mfpt: int  # 8
pdp_modd: int  # 92
pdp_mov: int  # 48
pdp_mtpd: int  # 77
pdp_mtpi: int  # 46
pdp_mtps: int  # 75
pdp_mul: int  # 55
pdp_muld: int  # 91
pdp_neg: int  # 36
pdp_negd: int  # 90
pdp_nop: int  # 12
pdp_null: int  # 0
pdp_reset: int  # 6
pdp_return: int  # 106
pdp_rol: int  # 41
pdp_ror: int  # 40
pdp_rti: int  # 3
pdp_rts: int  # 10
pdp_rtt: int  # 7
pdp_sbc: int  # 38
pdp_scc: int  # 22
pdp_sec: int  # 18
pdp_sen: int  # 21
pdp_setd: int  # 82
pdp_setf: int  # 80
pdp_seti: int  # 81
pdp_setl: int  # 83
pdp_sev: int  # 19
pdp_sez: int  # 20
pdp_sob: int  # 64
pdp_spl: int  # 11
pdp_stcdf: int  # 101
pdp_stcdi: int  # 100
pdp_std: int  # 97
pdp_stexp: int  # 99
pdp_stfps: int  # 85
pdp_stst: int  # 86
pdp_sub: int  # 54
pdp_subd: int  # 95
pdp_swab: int  # 23
pdp_sxt: int  # 47
pdp_trap: int  # 74
pdp_tst: int  # 39
pdp_tstd: int  # 88
pdp_wait: int  # 2
pdp_xor: int  # 59
s39_a: int  # 1
s39_ad: int  # 2
s39_adb: int  # 3
s39_adbr: int  # 4
s39_adr: int  # 5
s39_adtr: int  # 6
s39_adtra: int  # 7
s39_ae: int  # 8
s39_aeb: int  # 9
s39_aebr: int  # 10
s39_aer: int  # 11
s39_afi: int  # 12
s39_ag: int  # 13
s39_agf: int  # 14
s39_agfi: int  # 15
s39_agfr: int  # 16
s39_agh: int  # 17
s39_aghi: int  # 18
s39_aghik: int  # 19
s39_agr: int  # 20
s39_agrk: int  # 21
s39_agsi: int  # 22
s39_ah: int  # 23
s39_ahhhr: int  # 24
s39_ahhlr: int  # 25
s39_ahi: int  # 26
s39_ahik: int  # 27
s39_ahy: int  # 28
s39_aih: int  # 29
s39_al: int  # 30
s39_alc: int  # 31
s39_alcg: int  # 32
s39_alcgr: int  # 33
s39_alcr: int  # 34
s39_alfi: int  # 35
s39_alg: int  # 36
s39_algf: int  # 37
s39_algfi: int  # 38
s39_algfr: int  # 39
s39_alghsik: int  # 40
s39_algr: int  # 41
s39_algrk: int  # 42
s39_algsi: int  # 43
s39_alhhhr: int  # 44
s39_alhhlr: int  # 45
s39_alhsik: int  # 46
s39_alr: int  # 47
s39_alrk: int  # 48
s39_alsi: int  # 49
s39_alsih: int  # 50
s39_alsihn: int  # 51
s39_aly: int  # 52
s39_ap: int  # 53
s39_ar: int  # 54
s39_ark: int  # 55
s39_asi: int  # 56
s39_au: int  # 57
s39_aur: int  # 58
s39_aw: int  # 59
s39_awr: int  # 60
s39_axbr: int  # 61
s39_axr: int  # 62
s39_axtr: int  # 63
s39_axtra: int  # 64
s39_ay: int  # 65
s39_b: int  # 66
s39_bakr: int  # 95
s39_bal: int  # 96
s39_balr: int  # 97
s39_bas: int  # 98
s39_basr: int  # 99
s39_bassm: int  # 100
s39_bc: int  # 101
s39_bcr: int  # 102
s39_bct: int  # 103
s39_bctg: int  # 104
s39_bctgr: int  # 105
s39_bctr: int  # 106
s39_be: int  # 74
s39_ber: int  # 88
s39_bh: int  # 68
s39_bhe: int  # 76
s39_bher: int  # 90
s39_bhr: int  # 82
s39_bi: int  # 107
s39_bic: int  # 122
s39_bie: int  # 115
s39_bih: int  # 109
s39_bihe: int  # 117
s39_bil: int  # 111
s39_bile: int  # 119
s39_bilh: int  # 113
s39_bine: int  # 114
s39_binh: int  # 120
s39_binhe: int  # 112
s39_binl: int  # 118
s39_binle: int  # 110
s39_binlh: int  # 116
s39_bino: int  # 121
s39_bio: int  # 108
s39_bl: int  # 70
s39_ble: int  # 78
s39_bler: int  # 92
s39_blh: int  # 72
s39_blhr: int  # 86
s39_blr: int  # 84
s39_bne: int  # 73
s39_bner: int  # 87
s39_bnh: int  # 79
s39_bnhe: int  # 71
s39_bnher: int  # 85
s39_bnhr: int  # 93
s39_bnl: int  # 77
s39_bnle: int  # 69
s39_bnler: int  # 83
s39_bnlh: int  # 75
s39_bnlhr: int  # 89
s39_bnlr: int  # 91
s39_bno: int  # 80
s39_bnor: int  # 94
s39_bo: int  # 67
s39_bor: int  # 81
s39_bpp: int  # 123
s39_bprp: int  # 124
s39_br: int  # 125
s39_bras: int  # 126
s39_brasl: int  # 127
s39_brc: int  # 128
s39_brcl: int  # 129
s39_brct: int  # 130
s39_brctg: int  # 131
s39_brcth: int  # 132
s39_brxh: int  # 133
s39_brxhg: int  # 134
s39_brxle: int  # 135
s39_brxlg: int  # 136
s39_bsa: int  # 137
s39_bsg: int  # 138
s39_bsm: int  # 139
s39_bxh: int  # 140
s39_bxhg: int  # 141
s39_bxle: int  # 142
s39_bxleg: int  # 143
s39_c: int  # 144
s39_cd: int  # 145
s39_cdb: int  # 146
s39_cdbr: int  # 147
s39_cdfbr: int  # 148
s39_cdfbra: int  # 149
s39_cdfr: int  # 150
s39_cdftr: int  # 151
s39_cdgbr: int  # 152
s39_cdgbra: int  # 153
s39_cdgr: int  # 154
s39_cdgtr: int  # 155
s39_cdgtra: int  # 156
s39_cdlfbr: int  # 157
s39_cdlftr: int  # 158
s39_cdlgbr: int  # 159
s39_cdlgtr: int  # 160
s39_cdpt: int  # 161
s39_cdr: int  # 162
s39_cds: int  # 163
s39_cdsg: int  # 164
s39_cdstr: int  # 165
s39_cdsy: int  # 166
s39_cdtr: int  # 167
s39_cdutr: int  # 168
s39_cdzt: int  # 169
s39_ce: int  # 170
s39_ceb: int  # 171
s39_cebr: int  # 172
s39_cedtr: int  # 173
s39_cefbr: int  # 174
s39_cefbra: int  # 175
s39_cefr: int  # 176
s39_cegbr: int  # 177
s39_cegbra: int  # 178
s39_cegr: int  # 179
s39_celfbr: int  # 180
s39_celgbr: int  # 181
s39_cer: int  # 182
s39_cextr: int  # 183
s39_cfc: int  # 184
s39_cfdbr: int  # 185
s39_cfdbra: int  # 186
s39_cfdr: int  # 187
s39_cfdtr: int  # 188
s39_cfebr: int  # 189
s39_cfebra: int  # 190
s39_cfer: int  # 191
s39_cfi: int  # 192
s39_cfxbr: int  # 193
s39_cfxbra: int  # 194
s39_cfxr: int  # 195
s39_cfxtr: int  # 196
s39_cg: int  # 197
s39_cgdbr: int  # 198
s39_cgdbra: int  # 199
s39_cgdr: int  # 200
s39_cgdtr: int  # 201
s39_cgdtra: int  # 202
s39_cgebr: int  # 203
s39_cgebra: int  # 204
s39_cger: int  # 205
s39_cgf: int  # 206
s39_cgfi: int  # 207
s39_cgfr: int  # 208
s39_cgfrl: int  # 209
s39_cgh: int  # 210
s39_cghi: int  # 211
s39_cghrl: int  # 212
s39_cghsi: int  # 213
s39_cgib: int  # 214
s39_cgibh: int  # 215
s39_cgible: int  # 220
s39_cgiblh: int  # 217
s39_cgibnhe: int  # 216
s39_cgibnl: int  # 219
s39_cgibnlh: int  # 218
s39_cgij: int  # 221
s39_cgijh: int  # 222
s39_cgijle: int  # 227
s39_cgijlh: int  # 224
s39_cgijnhe: int  # 223
s39_cgijnl: int  # 226
s39_cgijnlh: int  # 225
s39_cgit: int  # 228
s39_cgith: int  # 229
s39_cgitle: int  # 234
s39_cgitlh: int  # 231
s39_cgitnhe: int  # 230
s39_cgitnl: int  # 233
s39_cgitnlh: int  # 232
s39_cgr: int  # 235
s39_cgrb: int  # 236
s39_cgrbh: int  # 237
s39_cgrble: int  # 242
s39_cgrblh: int  # 239
s39_cgrbnhe: int  # 238
s39_cgrbnl: int  # 241
s39_cgrbnlh: int  # 240
s39_cgrj: int  # 243
s39_cgrjh: int  # 244
s39_cgrjle: int  # 249
s39_cgrjlh: int  # 246
s39_cgrjnhe: int  # 245
s39_cgrjnl: int  # 248
s39_cgrjnlh: int  # 247
s39_cgrl: int  # 250
s39_cgrt: int  # 251
s39_cgrth: int  # 252
s39_cgrtle: int  # 257
s39_cgrtlh: int  # 254
s39_cgrtnhe: int  # 253
s39_cgrtnl: int  # 256
s39_cgrtnlh: int  # 255
s39_cgxbr: int  # 258
s39_cgxbra: int  # 259
s39_cgxr: int  # 260
s39_cgxtr: int  # 261
s39_cgxtra: int  # 262
s39_ch: int  # 263
s39_chf: int  # 264
s39_chhr: int  # 265
s39_chhsi: int  # 266
s39_chi: int  # 267
s39_chlr: int  # 268
s39_chrl: int  # 269
s39_chsi: int  # 270
s39_chy: int  # 271
s39_cib: int  # 272
s39_cibh: int  # 273
s39_cible: int  # 278
s39_ciblh: int  # 275
s39_cibnhe: int  # 274
s39_cibnl: int  # 277
s39_cibnlh: int  # 276
s39_cih: int  # 279
s39_cij: int  # 280
s39_cijh: int  # 281
s39_cijle: int  # 286
s39_cijlh: int  # 283
s39_cijnhe: int  # 282
s39_cijnl: int  # 285
s39_cijnlh: int  # 284
s39_cit: int  # 287
s39_cith: int  # 288
s39_citle: int  # 293
s39_citlh: int  # 290
s39_citnhe: int  # 289
s39_citnl: int  # 292
s39_citnlh: int  # 291
s39_cksm: int  # 294
s39_cl: int  # 295
s39_clc: int  # 296
s39_clcl: int  # 297
s39_clcle: int  # 298
s39_clclu: int  # 299
s39_clfdbr: int  # 300
s39_clfdtr: int  # 301
s39_clfebr: int  # 302
s39_clfhsi: int  # 303
s39_clfi: int  # 304
s39_clfit: int  # 305
s39_clfith: int  # 306
s39_clfitle: int  # 311
s39_clfitlh: int  # 308
s39_clfitnhe: int  # 307
s39_clfitnl: int  # 310
s39_clfitnlh: int  # 309
s39_clfxbr: int  # 312
s39_clfxtr: int  # 313
s39_clg: int  # 314
s39_clgdbr: int  # 315
s39_clgdtr: int  # 316
s39_clgebr: int  # 317
s39_clgf: int  # 318
s39_clgfi: int  # 319
s39_clgfr: int  # 320
s39_clgfrl: int  # 321
s39_clghrl: int  # 322
s39_clghsi: int  # 323
s39_clgib: int  # 324
s39_clgibh: int  # 325
s39_clgible: int  # 330
s39_clgiblh: int  # 327
s39_clgibnhe: int  # 326
s39_clgibnl: int  # 329
s39_clgibnlh: int  # 328
s39_clgij: int  # 331
s39_clgijh: int  # 332
s39_clgijle: int  # 337
s39_clgijlh: int  # 334
s39_clgijnhe: int  # 333
s39_clgijnl: int  # 336
s39_clgijnlh: int  # 335
s39_clgit: int  # 338
s39_clgith: int  # 339
s39_clgitle: int  # 344
s39_clgitlh: int  # 341
s39_clgitnhe: int  # 340
s39_clgitnl: int  # 343
s39_clgitnlh: int  # 342
s39_clgr: int  # 345
s39_clgrb: int  # 346
s39_clgrbh: int  # 347
s39_clgrble: int  # 352
s39_clgrblh: int  # 349
s39_clgrbnhe: int  # 348
s39_clgrbnl: int  # 351
s39_clgrbnlh: int  # 350
s39_clgrj: int  # 353
s39_clgrjh: int  # 354
s39_clgrjle: int  # 359
s39_clgrjlh: int  # 356
s39_clgrjnhe: int  # 355
s39_clgrjnl: int  # 358
s39_clgrjnlh: int  # 357
s39_clgrl: int  # 360
s39_clgrt: int  # 361
s39_clgrth: int  # 362
s39_clgrtle: int  # 367
s39_clgrtlh: int  # 364
s39_clgrtnhe: int  # 363
s39_clgrtnl: int  # 366
s39_clgrtnlh: int  # 365
s39_clgt: int  # 368
s39_clgth: int  # 369
s39_clgtle: int  # 374
s39_clgtlh: int  # 371
s39_clgtnhe: int  # 370
s39_clgtnl: int  # 373
s39_clgtnlh: int  # 372
s39_clgxbr: int  # 375
s39_clgxtr: int  # 376
s39_clhf: int  # 377
s39_clhhr: int  # 378
s39_clhhsi: int  # 379
s39_clhlr: int  # 380
s39_clhrl: int  # 381
s39_cli: int  # 382
s39_clib: int  # 383
s39_clibh: int  # 384
s39_clible: int  # 389
s39_cliblh: int  # 386
s39_clibnhe: int  # 385
s39_clibnl: int  # 388
s39_clibnlh: int  # 387
s39_clih: int  # 390
s39_clij: int  # 391
s39_clijh: int  # 392
s39_clijle: int  # 397
s39_clijlh: int  # 394
s39_clijnhe: int  # 393
s39_clijnl: int  # 396
s39_clijnlh: int  # 395
s39_cliy: int  # 398
s39_clm: int  # 399
s39_clmh: int  # 400
s39_clmy: int  # 401
s39_clr: int  # 402
s39_clrb: int  # 403
s39_clrbh: int  # 404
s39_clrble: int  # 409
s39_clrblh: int  # 406
s39_clrbnhe: int  # 405
s39_clrbnl: int  # 408
s39_clrbnlh: int  # 407
s39_clrj: int  # 410
s39_clrjh: int  # 411
s39_clrjle: int  # 416
s39_clrjlh: int  # 413
s39_clrjnhe: int  # 412
s39_clrjnl: int  # 415
s39_clrjnlh: int  # 414
s39_clrl: int  # 417
s39_clrt: int  # 418
s39_clrth: int  # 419
s39_clrtle: int  # 424
s39_clrtlh: int  # 421
s39_clrtnhe: int  # 420
s39_clrtnl: int  # 423
s39_clrtnlh: int  # 422
s39_clst: int  # 425
s39_clt: int  # 426
s39_clth: int  # 427
s39_cltle: int  # 432
s39_cltlh: int  # 429
s39_cltnhe: int  # 428
s39_cltnl: int  # 431
s39_cltnlh: int  # 430
s39_cly: int  # 433
s39_cmpsc: int  # 434
s39_cp: int  # 435
s39_cpdt: int  # 436
s39_cpsdr: int  # 437
s39_cpxt: int  # 438
s39_cpya: int  # 439
s39_cr: int  # 440
s39_crb: int  # 441
s39_crbh: int  # 442
s39_crble: int  # 447
s39_crblh: int  # 444
s39_crbnhe: int  # 443
s39_crbnl: int  # 446
s39_crbnlh: int  # 445
s39_crdte: int  # 448
s39_crj: int  # 449
s39_crjh: int  # 450
s39_crjle: int  # 455
s39_crjlh: int  # 452
s39_crjnhe: int  # 451
s39_crjnl: int  # 454
s39_crjnlh: int  # 453
s39_crl: int  # 456
s39_crt: int  # 457
s39_crth: int  # 458
s39_crtle: int  # 463
s39_crtlh: int  # 460
s39_crtnhe: int  # 459
s39_crtnl: int  # 462
s39_crtnlh: int  # 461
s39_cs: int  # 464
s39_csch: int  # 465
s39_csdtr: int  # 466
s39_csg: int  # 467
s39_csp: int  # 468
s39_cspg: int  # 469
s39_csst: int  # 470
s39_csxtr: int  # 471
s39_csy: int  # 472
s39_cu12: int  # 473
s39_cu14: int  # 474
s39_cu21: int  # 475
s39_cu24: int  # 476
s39_cu41: int  # 477
s39_cu42: int  # 478
s39_cudtr: int  # 479
s39_cuse: int  # 480
s39_cutfu: int  # 481
s39_cuutf: int  # 482
s39_cuxtr: int  # 483
s39_cvb: int  # 484
s39_cvbg: int  # 485
s39_cvby: int  # 486
s39_cvd: int  # 487
s39_cvdg: int  # 488
s39_cvdy: int  # 489
s39_cxbr: int  # 490
s39_cxfbr: int  # 491
s39_cxfbra: int  # 492
s39_cxfr: int  # 493
s39_cxftr: int  # 494
s39_cxgbr: int  # 495
s39_cxgbra: int  # 496
s39_cxgr: int  # 497
s39_cxgtr: int  # 498
s39_cxgtra: int  # 499
s39_cxlfbr: int  # 500
s39_cxlftr: int  # 501
s39_cxlgbr: int  # 502
s39_cxlgtr: int  # 503
s39_cxpt: int  # 504
s39_cxr: int  # 505
s39_cxstr: int  # 506
s39_cxtr: int  # 507
s39_cxutr: int  # 508
s39_cxzt: int  # 509
s39_cy: int  # 510
s39_czdt: int  # 511
s39_czxt: int  # 512
s39_d: int  # 513
s39_dd: int  # 514
s39_ddb: int  # 515
s39_ddbr: int  # 516
s39_ddr: int  # 517
s39_ddtr: int  # 518
s39_ddtra: int  # 519
s39_de: int  # 520
s39_deb: int  # 521
s39_debr: int  # 522
s39_der: int  # 523
s39_dfltcc: int  # 524
s39_diag: int  # 525
s39_didbr: int  # 526
s39_diebr: int  # 527
s39_dl: int  # 528
s39_dlg: int  # 529
s39_dlgr: int  # 530
s39_dlr: int  # 531
s39_dp: int  # 532
s39_dr: int  # 533
s39_dsg: int  # 534
s39_dsgf: int  # 535
s39_dsgfr: int  # 536
s39_dsgr: int  # 537
s39_dxbr: int  # 538
s39_dxr: int  # 539
s39_dxtr: int  # 540
s39_dxtra: int  # 541
s39_ear: int  # 542
s39_ecag: int  # 543
s39_ecctr: int  # 544
s39_ecpga: int  # 545
s39_ectg: int  # 546
s39_ed: int  # 547
s39_edmk: int  # 548
s39_eedtr: int  # 549
s39_eextr: int  # 550
s39_efpc: int  # 551
s39_epair: int  # 552
s39_epar: int  # 553
s39_epctr: int  # 554
s39_epsw: int  # 555
s39_ereg: int  # 556
s39_eregg: int  # 557
s39_esair: int  # 558
s39_esar: int  # 559
s39_esdtr: int  # 560
s39_esea: int  # 561
s39_esta: int  # 562
s39_esxtr: int  # 563
s39_etnd: int  # 564
s39_ex: int  # 565
s39_exrl: int  # 566
s39_fidbr: int  # 567
s39_fidbra: int  # 568
s39_fidr: int  # 569
s39_fidtr: int  # 570
s39_fiebr: int  # 571
s39_fiebra: int  # 572
s39_fier: int  # 573
s39_fixbr: int  # 574
s39_fixbra: int  # 575
s39_fixr: int  # 576
s39_fixtr: int  # 577
s39_flogr: int  # 578
s39_hdr: int  # 579
s39_her: int  # 580
s39_hsch: int  # 581
s39_iac: int  # 582
s39_ic: int  # 583
s39_icm: int  # 584
s39_icmh: int  # 585
s39_icmy: int  # 586
s39_icy: int  # 587
s39_idte: int  # 588
s39_iedtr: int  # 589
s39_iextr: int  # 590
s39_iihf: int  # 591
s39_iihh: int  # 592
s39_iihl: int  # 593
s39_iilf: int  # 594
s39_iilh: int  # 595
s39_iill: int  # 596
s39_ipk: int  # 597
s39_ipm: int  # 598
s39_ipte: int  # 599
s39_irbm: int  # 600
s39_iske: int  # 601
s39_ivsk: int  # 602
s39_j: int  # 603
s39_je: int  # 611
s39_jg: int  # 618
s39_jge: int  # 626
s39_jgh: int  # 620
s39_jghe: int  # 628
s39_jgl: int  # 622
s39_jgle: int  # 630
s39_jglh: int  # 624
s39_jgne: int  # 625
s39_jgnh: int  # 631
s39_jgnhe: int  # 623
s39_jgnl: int  # 629
s39_jgnle: int  # 621
s39_jgnlh: int  # 627
s39_jgno: int  # 632
s39_jgo: int  # 619
s39_jh: int  # 605
s39_jhe: int  # 613
s39_jl: int  # 607
s39_jle: int  # 615
s39_jlh: int  # 609
s39_jne: int  # 610
s39_jnh: int  # 616
s39_jnhe: int  # 608
s39_jnl: int  # 614
s39_jnle: int  # 606
s39_jnlh: int  # 612
s39_jno: int  # 617
s39_jo: int  # 604
s39_kdb: int  # 633
s39_kdbr: int  # 634
s39_kdsa: int  # 635
s39_kdtr: int  # 636
s39_keb: int  # 637
s39_kebr: int  # 638
s39_kimd: int  # 639
s39_klmd: int  # 640
s39_km: int  # 641
s39_kma: int  # 642
s39_kmac: int  # 643
s39_kmc: int  # 644
s39_kmctr: int  # 645
s39_kmf: int  # 646
s39_kmo: int  # 647
s39_kxbr: int  # 648
s39_kxtr: int  # 649
s39_l: int  # 650
s39_la: int  # 651
s39_laa: int  # 652
s39_laag: int  # 653
s39_laal: int  # 654
s39_laalg: int  # 655
s39_lae: int  # 656
s39_laey: int  # 657
s39_lam: int  # 658
s39_lamy: int  # 659
s39_lan: int  # 660
s39_lang: int  # 661
s39_lao: int  # 662
s39_laog: int  # 663
s39_larl: int  # 664
s39_lasp: int  # 665
s39_last: int  # 2209
s39_lat: int  # 666
s39_lax: int  # 667
s39_laxg: int  # 668
s39_lay: int  # 669
s39_lb: int  # 670
s39_lbh: int  # 671
s39_lbr: int  # 672
s39_lcbb: int  # 673
s39_lcctl: int  # 674
s39_lcdbr: int  # 675
s39_lcdfr: int  # 676
s39_lcdr: int  # 677
s39_lcebr: int  # 678
s39_lcer: int  # 679
s39_lcgfr: int  # 680
s39_lcgr: int  # 681
s39_lcr: int  # 682
s39_lctl: int  # 683
s39_lctlg: int  # 684
s39_lcxbr: int  # 685
s39_lcxr: int  # 686
s39_ld: int  # 687
s39_lde: int  # 688
s39_ldeb: int  # 689
s39_ldebr: int  # 690
s39_lder: int  # 691
s39_ldetr: int  # 692
s39_ldgr: int  # 693
s39_ldr: int  # 694
s39_ldrv: int  # 695
s39_ldxbr: int  # 696
s39_ldxbra: int  # 697
s39_ldxr: int  # 698
s39_ldxtr: int  # 699
s39_ldy: int  # 700
s39_le: int  # 701
s39_ledbr: int  # 702
s39_ledbra: int  # 703
s39_ledr: int  # 704
s39_ledtr: int  # 705
s39_ler: int  # 706
s39_lerv: int  # 707
s39_lexbr: int  # 708
s39_lexbra: int  # 709
s39_lexr: int  # 710
s39_ley: int  # 711
s39_lfas: int  # 712
s39_lfh: int  # 713
s39_lfhat: int  # 714
s39_lfpc: int  # 715
s39_lg: int  # 716
s39_lgat: int  # 717
s39_lgb: int  # 718
s39_lgbr: int  # 719
s39_lgdr: int  # 720
s39_lgf: int  # 721
s39_lgfi: int  # 722
s39_lgfr: int  # 723
s39_lgfrl: int  # 724
s39_lgg: int  # 725
s39_lgh: int  # 726
s39_lghi: int  # 727
s39_lghr: int  # 728
s39_lghrl: int  # 729
s39_lgr: int  # 730
s39_lgrl: int  # 731
s39_lgsc: int  # 732
s39_lh: int  # 733
s39_lhh: int  # 734
s39_lhi: int  # 735
s39_lhr: int  # 736
s39_lhrl: int  # 737
s39_lhy: int  # 738
s39_llc: int  # 739
s39_llch: int  # 740
s39_llcr: int  # 741
s39_llgc: int  # 742
s39_llgcr: int  # 743
s39_llgf: int  # 744
s39_llgfat: int  # 745
s39_llgfr: int  # 746
s39_llgfrl: int  # 747
s39_llgfsg: int  # 748
s39_llgh: int  # 749
s39_llghr: int  # 750
s39_llghrl: int  # 751
s39_llgt: int  # 752
s39_llgtat: int  # 753
s39_llgtr: int  # 754
s39_llh: int  # 755
s39_llhh: int  # 756
s39_llhr: int  # 757
s39_llhrl: int  # 758
s39_llihf: int  # 759
s39_llihh: int  # 760
s39_llihl: int  # 761
s39_llilf: int  # 762
s39_llilh: int  # 763
s39_llill: int  # 764
s39_llzrgf: int  # 765
s39_lm: int  # 766
s39_lmd: int  # 767
s39_lmg: int  # 768
s39_lmh: int  # 769
s39_lmy: int  # 770
s39_lndbr: int  # 771
s39_lndfr: int  # 772
s39_lndr: int  # 773
s39_lnebr: int  # 774
s39_lner: int  # 775
s39_lngfr: int  # 776
s39_lngr: int  # 777
s39_lnr: int  # 778
s39_lnxbr: int  # 779
s39_lnxr: int  # 780
s39_loc: int  # 781
s39_loce: int  # 789
s39_locfh: int  # 796
s39_locfhe: int  # 804
s39_locfhh: int  # 798
s39_locfhhe: int  # 806
s39_locfhl: int  # 800
s39_locfhle: int  # 808
s39_locfhlh: int  # 802
s39_locfhne: int  # 803
s39_locfhnh: int  # 809
s39_locfhnhe: int  # 801
s39_locfhnl: int  # 807
s39_locfhnle: int  # 799
s39_locfhnlh: int  # 805
s39_locfhno: int  # 810
s39_locfho: int  # 797
s39_locfhr: int  # 811
s39_locfhre: int  # 819
s39_locfhrh: int  # 813
s39_locfhrhe: int  # 821
s39_locfhrl: int  # 815
s39_locfhrle: int  # 823
s39_locfhrlh: int  # 817
s39_locfhrne: int  # 818
s39_locfhrnh: int  # 824
s39_locfhrnhe: int  # 816
s39_locfhrnl: int  # 822
s39_locfhrnle: int  # 814
s39_locfhrnlh: int  # 820
s39_locfhrno: int  # 825
s39_locfhro: int  # 812
s39_locg: int  # 826
s39_locge: int  # 834
s39_locgh: int  # 828
s39_locghe: int  # 836
s39_locghi: int  # 841
s39_locghie: int  # 849
s39_locghih: int  # 843
s39_locghihe: int  # 851
s39_locghil: int  # 845
s39_locghile: int  # 853
s39_locghilh: int  # 847
s39_locghine: int  # 848
s39_locghinh: int  # 854
s39_locghinhe: int  # 846
s39_locghinl: int  # 852
s39_locghinle: int  # 844
s39_locghinlh: int  # 850
s39_locghino: int  # 855
s39_locghio: int  # 842
s39_locgl: int  # 830
s39_locgle: int  # 838
s39_locglh: int  # 832
s39_locgne: int  # 833
s39_locgnh: int  # 839
s39_locgnhe: int  # 831
s39_locgnl: int  # 837
s39_locgnle: int  # 829
s39_locgnlh: int  # 835
s39_locgno: int  # 840
s39_locgo: int  # 827
s39_locgr: int  # 856
s39_locgre: int  # 864
s39_locgrh: int  # 858
s39_locgrhe: int  # 866
s39_locgrl: int  # 860
s39_locgrle: int  # 868
s39_locgrlh: int  # 862
s39_locgrne: int  # 863
s39_locgrnh: int  # 869
s39_locgrnhe: int  # 861
s39_locgrnl: int  # 867
s39_locgrnle: int  # 859
s39_locgrnlh: int  # 865
s39_locgrno: int  # 870
s39_locgro: int  # 857
s39_loch: int  # 783
s39_loche: int  # 791
s39_lochhi: int  # 871
s39_lochhie: int  # 879
s39_lochhih: int  # 873
s39_lochhihe: int  # 881
s39_lochhil: int  # 875
s39_lochhile: int  # 883
s39_lochhilh: int  # 877
s39_lochhine: int  # 878
s39_lochhinh: int  # 884
s39_lochhinhe: int  # 876
s39_lochhinl: int  # 882
s39_lochhinle: int  # 874
s39_lochhinlh: int  # 880
s39_lochhino: int  # 885
s39_lochhio: int  # 872
s39_lochi: int  # 886
s39_lochie: int  # 894
s39_lochih: int  # 888
s39_lochihe: int  # 896
s39_lochil: int  # 890
s39_lochile: int  # 898
s39_lochilh: int  # 892
s39_lochine: int  # 893
s39_lochinh: int  # 899
s39_lochinhe: int  # 891
s39_lochinl: int  # 897
s39_lochinle: int  # 889
s39_lochinlh: int  # 895
s39_lochino: int  # 900
s39_lochio: int  # 887
s39_locl: int  # 785
s39_locle: int  # 793
s39_loclh: int  # 787
s39_locne: int  # 788
s39_locnh: int  # 794
s39_locnhe: int  # 786
s39_locnl: int  # 792
s39_locnle: int  # 784
s39_locnlh: int  # 790
s39_locno: int  # 795
s39_loco: int  # 782
s39_locr: int  # 901
s39_locre: int  # 909
s39_locrh: int  # 903
s39_locrhe: int  # 911
s39_locrl: int  # 905
s39_locrle: int  # 913
s39_locrlh: int  # 907
s39_locrne: int  # 908
s39_locrnh: int  # 914
s39_locrnhe: int  # 906
s39_locrnl: int  # 912
s39_locrnle: int  # 904
s39_locrnlh: int  # 910
s39_locrno: int  # 915
s39_locro: int  # 902
s39_lpctl: int  # 916
s39_lpd: int  # 917
s39_lpdbr: int  # 918
s39_lpdfr: int  # 919
s39_lpdg: int  # 920
s39_lpdr: int  # 921
s39_lpebr: int  # 922
s39_lper: int  # 923
s39_lpgfr: int  # 924
s39_lpgr: int  # 925
s39_lpp: int  # 926
s39_lpq: int  # 927
s39_lpr: int  # 928
s39_lpsw: int  # 929
s39_lpswe: int  # 930
s39_lptea: int  # 931
s39_lpxbr: int  # 932
s39_lpxr: int  # 933
s39_lr: int  # 934
s39_lra: int  # 935
s39_lrag: int  # 936
s39_lray: int  # 937
s39_lrdr: int  # 938
s39_lrer: int  # 939
s39_lrl: int  # 940
s39_lrv: int  # 941
s39_lrvg: int  # 942
s39_lrvgr: int  # 943
s39_lrvh: int  # 944
s39_lrvr: int  # 945
s39_lsctl: int  # 946
s39_lt: int  # 947
s39_ltdbr: int  # 948
s39_ltdr: int  # 949
s39_ltdtr: int  # 950
s39_ltebr: int  # 951
s39_lter: int  # 952
s39_ltg: int  # 953
s39_ltgf: int  # 954
s39_ltgfr: int  # 955
s39_ltgr: int  # 956
s39_ltr: int  # 957
s39_ltxbr: int  # 958
s39_ltxr: int  # 959
s39_ltxtr: int  # 960
s39_lura: int  # 961
s39_lurag: int  # 962
s39_lxd: int  # 963
s39_lxdb: int  # 964
s39_lxdbr: int  # 965
s39_lxdr: int  # 966
s39_lxdtr: int  # 967
s39_lxe: int  # 968
s39_lxeb: int  # 969
s39_lxebr: int  # 970
s39_lxer: int  # 971
s39_lxr: int  # 972
s39_ly: int  # 973
s39_lzdr: int  # 974
s39_lzer: int  # 975
s39_lzrf: int  # 976
s39_lzrg: int  # 977
s39_lzxr: int  # 978
s39_m: int  # 979
s39_mad: int  # 980
s39_madb: int  # 981
s39_madbr: int  # 982
s39_madr: int  # 983
s39_mae: int  # 984
s39_maeb: int  # 985
s39_maebr: int  # 986
s39_maer: int  # 987
s39_may: int  # 988
s39_mayh: int  # 989
s39_mayhr: int  # 990
s39_mayl: int  # 991
s39_maylr: int  # 992
s39_mayr: int  # 993
s39_mc: int  # 994
s39_md: int  # 995
s39_mdb: int  # 996
s39_mdbr: int  # 997
s39_mde: int  # 998
s39_mdeb: int  # 999
s39_mdebr: int  # 1000
s39_mder: int  # 1001
s39_mdr: int  # 1002
s39_mdtr: int  # 1003
s39_mdtra: int  # 1004
s39_me: int  # 1005
s39_mee: int  # 1006
s39_meeb: int  # 1007
s39_meebr: int  # 1008
s39_meer: int  # 1009
s39_mer: int  # 1010
s39_mfy: int  # 1011
s39_mg: int  # 1012
s39_mgh: int  # 1013
s39_mghi: int  # 1014
s39_mgrk: int  # 1015
s39_mh: int  # 1016
s39_mhi: int  # 1017
s39_mhy: int  # 1018
s39_ml: int  # 1019
s39_mlg: int  # 1020
s39_mlgr: int  # 1021
s39_mlr: int  # 1022
s39_mp: int  # 1023
s39_mr: int  # 1024
s39_ms: int  # 1025
s39_msc: int  # 1026
s39_msch: int  # 1027
s39_msd: int  # 1028
s39_msdb: int  # 1029
s39_msdbr: int  # 1030
s39_msdr: int  # 1031
s39_mse: int  # 1032
s39_mseb: int  # 1033
s39_msebr: int  # 1034
s39_mser: int  # 1035
s39_msfi: int  # 1036
s39_msg: int  # 1037
s39_msgc: int  # 1038
s39_msgf: int  # 1039
s39_msgfi: int  # 1040
s39_msgfr: int  # 1041
s39_msgr: int  # 1042
s39_msgrkc: int  # 1043
s39_msr: int  # 1044
s39_msrkc: int  # 1045
s39_msta: int  # 1046
s39_msy: int  # 1047
s39_mvc: int  # 1048
s39_mvcdk: int  # 1049
s39_mvcin: int  # 1050
s39_mvck: int  # 1051
s39_mvcl: int  # 1052
s39_mvcle: int  # 1053
s39_mvclu: int  # 1054
s39_mvcos: int  # 1055
s39_mvcp: int  # 1056
s39_mvcrl: int  # 1057
s39_mvcs: int  # 1058
s39_mvcsk: int  # 1059
s39_mvghi: int  # 1060
s39_mvhhi: int  # 1061
s39_mvhi: int  # 1062
s39_mvi: int  # 1063
s39_mviy: int  # 1064
s39_mvn: int  # 1065
s39_mvo: int  # 1066
s39_mvpg: int  # 1067
s39_mvst: int  # 1068
s39_mvz: int  # 1069
s39_mxbr: int  # 1070
s39_mxd: int  # 1071
s39_mxdb: int  # 1072
s39_mxdbr: int  # 1073
s39_mxdr: int  # 1074
s39_mxr: int  # 1075
s39_mxtr: int  # 1076
s39_mxtra: int  # 1077
s39_my: int  # 1078
s39_myh: int  # 1079
s39_myhr: int  # 1080
s39_myl: int  # 1081
s39_mylr: int  # 1082
s39_myr: int  # 1083
s39_n: int  # 1084
s39_nc: int  # 1085
s39_ncgrk: int  # 1086
s39_ncrk: int  # 1087
s39_ng: int  # 1088
s39_ngr: int  # 1089
s39_ngrk: int  # 1090
s39_ni: int  # 1091
s39_niai: int  # 1092
s39_nihf: int  # 1093
s39_nihh: int  # 1094
s39_nihl: int  # 1095
s39_nilf: int  # 1096
s39_nilh: int  # 1097
s39_nill: int  # 1098
s39_niy: int  # 1099
s39_nngrk: int  # 1100
s39_nnrk: int  # 1101
s39_nogrk: int  # 1102
s39_nop: int  # 1103
s39_nopr: int  # 1104
s39_nork: int  # 1105
s39_nr: int  # 1106
s39_nrk: int  # 1107
s39_ntstg: int  # 1108
s39_null: int  # 0
s39_nxgrk: int  # 1109
s39_nxrk: int  # 1110
s39_ny: int  # 1111
s39_o: int  # 1112
s39_oc: int  # 1113
s39_ocgrk: int  # 1114
s39_ocrk: int  # 1115
s39_og: int  # 1116
s39_ogr: int  # 1117
s39_ogrk: int  # 1118
s39_oi: int  # 1119
s39_oihf: int  # 1120
s39_oihh: int  # 1121
s39_oihl: int  # 1122
s39_oilf: int  # 1123
s39_oilh: int  # 1124
s39_oill: int  # 1125
s39_oiy: int  # 1126
s39_or: int  # 1127
s39_ork: int  # 1128
s39_oy: int  # 1129
s39_pack: int  # 1130
s39_palb: int  # 1131
s39_pc: int  # 1132
s39_pcc: int  # 1133
s39_pckmo: int  # 1134
s39_pfd: int  # 1135
s39_pfdrl: int  # 1136
s39_pfmf: int  # 1137
s39_pfpo: int  # 1138
s39_pgin: int  # 1139
s39_pgout: int  # 1140
s39_pka: int  # 1141
s39_pku: int  # 1142
s39_plo: int  # 1143
s39_popcnt: int  # 1144
s39_ppa: int  # 1145
s39_ppno: int  # 1146
s39_pr: int  # 1147
s39_prno: int  # 1148
s39_pt: int  # 1149
s39_ptf: int  # 1150
s39_ptff: int  # 1151
s39_pti: int  # 1152
s39_ptlb: int  # 1153
s39_qadtr: int  # 1154
s39_qaxtr: int  # 1155
s39_qctri: int  # 1156
s39_qsi: int  # 1157
s39_rchp: int  # 1158
s39_risbg: int  # 1159
s39_risbgn: int  # 1160
s39_risbhg: int  # 1161
s39_risblg: int  # 1162
s39_rll: int  # 1163
s39_rllg: int  # 1164
s39_rnsbg: int  # 1165
s39_rosbg: int  # 1166
s39_rp: int  # 1167
s39_rrbe: int  # 1168
s39_rrbm: int  # 1169
s39_rrdtr: int  # 1170
s39_rrxtr: int  # 1171
s39_rsch: int  # 1172
s39_rxsbg: int  # 1173
s39_s: int  # 1174
s39_sac: int  # 1175
s39_sacf: int  # 1176
s39_sal: int  # 1177
s39_sam24: int  # 1178
s39_sam31: int  # 1179
s39_sam64: int  # 1180
s39_sar: int  # 1181
s39_scctr: int  # 1182
s39_schm: int  # 1183
s39_sck: int  # 1184
s39_sckc: int  # 1185
s39_sckpf: int  # 1186
s39_sd: int  # 1187
s39_sdb: int  # 1188
s39_sdbr: int  # 1189
s39_sdr: int  # 1190
s39_sdtr: int  # 1191
s39_sdtra: int  # 1192
s39_se: int  # 1193
s39_seb: int  # 1194
s39_sebr: int  # 1195
s39_selgr: int  # 1196
s39_selgre: int  # 1204
s39_selgrh: int  # 1198
s39_selgrhe: int  # 1206
s39_selgrl: int  # 1200
s39_selgrle: int  # 1208
s39_selgrlh: int  # 1202
s39_selgrne: int  # 1203
s39_selgrnh: int  # 1209
s39_selgrnhe: int  # 1201
s39_selgrnl: int  # 1207
s39_selgrnle: int  # 1199
s39_selgrnlh: int  # 1205
s39_selgrno: int  # 1210
s39_selgro: int  # 1197
s39_selhhhr: int  # 1211
s39_selhhhre: int  # 1219
s39_selhhhrh: int  # 1213
s39_selhhhrhe: int  # 1221
s39_selhhhrl: int  # 1215
s39_selhhhrle: int  # 1223
s39_selhhhrlh: int  # 1217
s39_selhhhrne: int  # 1218
s39_selhhhrnh: int  # 1224
s39_selhhhrnhe: int  # 1216
s39_selhhhrnl: int  # 1222
s39_selhhhrnle: int  # 1214
s39_selhhhrnlh: int  # 1220
s39_selhhhrno: int  # 1225
s39_selhhhro: int  # 1212
s39_selr: int  # 1226
s39_selre: int  # 1234
s39_selrh: int  # 1228
s39_selrhe: int  # 1236
s39_selrl: int  # 1230
s39_selrle: int  # 1238
s39_selrlh: int  # 1232
s39_selrne: int  # 1233
s39_selrnh: int  # 1239
s39_selrnhe: int  # 1231
s39_selrnl: int  # 1237
s39_selrnle: int  # 1229
s39_selrnlh: int  # 1235
s39_selrno: int  # 1240
s39_selro: int  # 1227
s39_ser: int  # 1241
s39_sfasr: int  # 1242
s39_sfpc: int  # 1243
s39_sg: int  # 1244
s39_sgf: int  # 1245
s39_sgfr: int  # 1246
s39_sgh: int  # 1247
s39_sgr: int  # 1248
s39_sgrk: int  # 1249
s39_sh: int  # 1250
s39_shhhr: int  # 1251
s39_shhlr: int  # 1252
s39_shy: int  # 1253
s39_sie: int  # 1254
s39_siga: int  # 1255
s39_sigp: int  # 1256
s39_sl: int  # 1257
s39_sla: int  # 1258
s39_slag: int  # 1259
s39_slak: int  # 1260
s39_slb: int  # 1261
s39_slbg: int  # 1262
s39_slbgr: int  # 1263
s39_slbr: int  # 1264
s39_slda: int  # 1265
s39_sldl: int  # 1266
s39_sldt: int  # 1267
s39_slfi: int  # 1268
s39_slg: int  # 1269
s39_slgf: int  # 1270
s39_slgfi: int  # 1271
s39_slgfr: int  # 1272
s39_slgr: int  # 1273
s39_slgrk: int  # 1274
s39_slhhhr: int  # 1275
s39_slhhlr: int  # 1276
s39_sll: int  # 1277
s39_sllg: int  # 1278
s39_sllk: int  # 1279
s39_slr: int  # 1280
s39_slrk: int  # 1281
s39_slxt: int  # 1282
s39_sly: int  # 1283
s39_sortl: int  # 1284
s39_sp: int  # 1285
s39_spctr: int  # 1286
s39_spka: int  # 1287
s39_spm: int  # 1288
s39_spt: int  # 1289
s39_spx: int  # 1290
s39_sqd: int  # 1291
s39_sqdb: int  # 1292
s39_sqdbr: int  # 1293
s39_sqdr: int  # 1294
s39_sqe: int  # 1295
s39_sqeb: int  # 1296
s39_sqebr: int  # 1297
s39_sqer: int  # 1298
s39_sqxbr: int  # 1299
s39_sqxr: int  # 1300
s39_sr: int  # 1301
s39_sra: int  # 1302
s39_srag: int  # 1303
s39_srak: int  # 1304
s39_srda: int  # 1305
s39_srdl: int  # 1306
s39_srdt: int  # 1307
s39_srk: int  # 1308
s39_srl: int  # 1309
s39_srlg: int  # 1310
s39_srlk: int  # 1311
s39_srnm: int  # 1312
s39_srnmb: int  # 1313
s39_srnmt: int  # 1314
s39_srp: int  # 1315
s39_srst: int  # 1316
s39_srstu: int  # 1317
s39_srxt: int  # 1318
s39_ssair: int  # 1319
s39_ssar: int  # 1320
s39_ssch: int  # 1321
s39_sske: int  # 1322
s39_ssm: int  # 1323
s39_st: int  # 1324
s39_stam: int  # 1325
s39_stamy: int  # 1326
s39_stap: int  # 1327
s39_stc: int  # 1328
s39_stch: int  # 1329
s39_stck: int  # 1330
s39_stckc: int  # 1331
s39_stcke: int  # 1332
s39_stckf: int  # 1333
s39_stcm: int  # 1334
s39_stcmh: int  # 1335
s39_stcmy: int  # 1336
s39_stcps: int  # 1337
s39_stcrw: int  # 1338
s39_stctg: int  # 1339
s39_stctl: int  # 1340
s39_stcy: int  # 1341
s39_std: int  # 1342
s39_stdrv: int  # 1343
s39_stdy: int  # 1344
s39_ste: int  # 1345
s39_sterv: int  # 1346
s39_stey: int  # 1347
s39_stfh: int  # 1348
s39_stfl: int  # 1349
s39_stfle: int  # 1350
s39_stfpc: int  # 1351
s39_stg: int  # 1352
s39_stgrl: int  # 1353
s39_stgsc: int  # 1354
s39_sth: int  # 1355
s39_sthh: int  # 1356
s39_sthrl: int  # 1357
s39_sthy: int  # 1358
s39_stidp: int  # 1359
s39_stm: int  # 1360
s39_stmg: int  # 1361
s39_stmh: int  # 1362
s39_stmy: int  # 1363
s39_stnsm: int  # 1364
s39_stoc: int  # 1365
s39_stoce: int  # 1373
s39_stocfh: int  # 1380
s39_stocfhe: int  # 1388
s39_stocfhh: int  # 1382
s39_stocfhhe: int  # 1390
s39_stocfhl: int  # 1384
s39_stocfhle: int  # 1392
s39_stocfhlh: int  # 1386
s39_stocfhne: int  # 1387
s39_stocfhnh: int  # 1393
s39_stocfhnhe: int  # 1385
s39_stocfhnl: int  # 1391
s39_stocfhnle: int  # 1383
s39_stocfhnlh: int  # 1389
s39_stocfhno: int  # 1394
s39_stocfho: int  # 1381
s39_stocg: int  # 1395
s39_stocge: int  # 1403
s39_stocgh: int  # 1397
s39_stocghe: int  # 1405
s39_stocgl: int  # 1399
s39_stocgle: int  # 1407
s39_stocglh: int  # 1401
s39_stocgne: int  # 1402
s39_stocgnh: int  # 1408
s39_stocgnhe: int  # 1400
s39_stocgnl: int  # 1406
s39_stocgnle: int  # 1398
s39_stocgnlh: int  # 1404
s39_stocgno: int  # 1409
s39_stocgo: int  # 1396
s39_stoch: int  # 1367
s39_stoche: int  # 1375
s39_stocl: int  # 1369
s39_stocle: int  # 1377
s39_stoclh: int  # 1371
s39_stocne: int  # 1372
s39_stocnh: int  # 1378
s39_stocnhe: int  # 1370
s39_stocnl: int  # 1376
s39_stocnle: int  # 1368
s39_stocnlh: int  # 1374
s39_stocno: int  # 1379
s39_stoco: int  # 1366
s39_stosm: int  # 1410
s39_stpq: int  # 1411
s39_stpt: int  # 1412
s39_stpx: int  # 1413
s39_strag: int  # 1414
s39_strl: int  # 1415
s39_strv: int  # 1416
s39_strvg: int  # 1417
s39_strvh: int  # 1418
s39_stsch: int  # 1419
s39_stsi: int  # 1420
s39_stura: int  # 1421
s39_sturg: int  # 1422
s39_sty: int  # 1423
s39_su: int  # 1424
s39_sur: int  # 1425
s39_svc: int  # 1426
s39_sw: int  # 1427
s39_swr: int  # 1428
s39_sxbr: int  # 1429
s39_sxr: int  # 1430
s39_sxtr: int  # 1431
s39_sxtra: int  # 1432
s39_sy: int  # 1433
s39_tabort: int  # 1434
s39_tam: int  # 1435
s39_tar: int  # 1436
s39_tb: int  # 1437
s39_tbdr: int  # 1438
s39_tbedr: int  # 1439
s39_tbegin: int  # 1440
s39_tbeginc: int  # 1441
s39_tcdb: int  # 1442
s39_tceb: int  # 1443
s39_tcxb: int  # 1444
s39_tdcdt: int  # 1445
s39_tdcet: int  # 1446
s39_tdcxt: int  # 1447
s39_tdgdt: int  # 1448
s39_tdget: int  # 1449
s39_tdgxt: int  # 1450
s39_tend: int  # 1451
s39_thder: int  # 1452
s39_thdr: int  # 1453
s39_tm: int  # 1454
s39_tmhh: int  # 1455
s39_tmhl: int  # 1456
s39_tmlh: int  # 1457
s39_tmll: int  # 1458
s39_tmy: int  # 1459
s39_tp: int  # 1460
s39_tpei: int  # 1461
s39_tpi: int  # 1462
s39_tprot: int  # 1463
s39_tr: int  # 1464
s39_trace: int  # 1465
s39_tracg: int  # 1466
s39_trap2: int  # 1467
s39_trap4: int  # 1468
s39_tre: int  # 1469
s39_troo: int  # 1470
s39_trot: int  # 1471
s39_trt: int  # 1472
s39_trte: int  # 1473
s39_trto: int  # 1474
s39_trtr: int  # 1475
s39_trtre: int  # 1476
s39_trtt: int  # 1477
s39_ts: int  # 1478
s39_tsch: int  # 1479
s39_unpk: int  # 1480
s39_unpka: int  # 1481
s39_unpku: int  # 1482
s39_upt: int  # 1483
s39_va: int  # 1484
s39_vab: int  # 1485
s39_vac: int  # 1486
s39_vacc: int  # 1487
s39_vaccb: int  # 1488
s39_vaccc: int  # 1489
s39_vacccq: int  # 1490
s39_vaccf: int  # 1491
s39_vaccg: int  # 1492
s39_vacch: int  # 1493
s39_vaccq: int  # 1494
s39_vacq: int  # 1495
s39_vaf: int  # 1496
s39_vag: int  # 1497
s39_vah: int  # 1498
s39_vap: int  # 1499
s39_vaq: int  # 1500
s39_vavg: int  # 1501
s39_vavgb: int  # 1502
s39_vavgf: int  # 1503
s39_vavgg: int  # 1504
s39_vavgh: int  # 1505
s39_vavgl: int  # 1506
s39_vavglb: int  # 1507
s39_vavglf: int  # 1508
s39_vavglg: int  # 1509
s39_vavglh: int  # 1510
s39_vbperm: int  # 1511
s39_vcdg: int  # 1512
s39_vcdgb: int  # 1513
s39_vcdlg: int  # 1514
s39_vcdlgb: int  # 1515
s39_vcefb: int  # 1516
s39_vcelfb: int  # 1517
s39_vceq: int  # 1518
s39_vceqb: int  # 1519
s39_vceqbs: int  # 1520
s39_vceqf: int  # 1521
s39_vceqfs: int  # 1522
s39_vceqg: int  # 1523
s39_vceqgs: int  # 1524
s39_vceqh: int  # 1525
s39_vceqhs: int  # 1526
s39_vcfeb: int  # 1527
s39_vcfpl: int  # 1528
s39_vcfps: int  # 1529
s39_vcgd: int  # 1530
s39_vcgdb: int  # 1531
s39_vch: int  # 1532
s39_vchb: int  # 1533
s39_vchbs: int  # 1534
s39_vchf: int  # 1535
s39_vchfs: int  # 1536
s39_vchg: int  # 1537
s39_vchgs: int  # 1538
s39_vchh: int  # 1539
s39_vchhs: int  # 1540
s39_vchl: int  # 1541
s39_vchlb: int  # 1542
s39_vchlbs: int  # 1543
s39_vchlf: int  # 1544
s39_vchlfs: int  # 1545
s39_vchlg: int  # 1546
s39_vchlgs: int  # 1547
s39_vchlh: int  # 1548
s39_vchlhs: int  # 1549
s39_vcksm: int  # 1550
s39_vclfeb: int  # 1551
s39_vclfp: int  # 1552
s39_vclgd: int  # 1553
s39_vclgdb: int  # 1554
s39_vclz: int  # 1555
s39_vclzb: int  # 1556
s39_vclzf: int  # 1557
s39_vclzg: int  # 1558
s39_vclzh: int  # 1559
s39_vcp: int  # 1560
s39_vcsfp: int  # 1561
s39_vctz: int  # 1562
s39_vctzb: int  # 1563
s39_vctzf: int  # 1564
s39_vctzg: int  # 1565
s39_vctzh: int  # 1566
s39_vcvb: int  # 1567
s39_vcvbg: int  # 1568
s39_vcvd: int  # 1569
s39_vcvdg: int  # 1570
s39_vdp: int  # 1571
s39_vec: int  # 1572
s39_vecb: int  # 1573
s39_vecf: int  # 1574
s39_vecg: int  # 1575
s39_vech: int  # 1576
s39_vecl: int  # 1577
s39_veclb: int  # 1578
s39_veclf: int  # 1579
s39_veclg: int  # 1580
s39_veclh: int  # 1581
s39_verim: int  # 1582
s39_verimb: int  # 1583
s39_verimf: int  # 1584
s39_verimg: int  # 1585
s39_verimh: int  # 1586
s39_verll: int  # 1587
s39_verllb: int  # 1588
s39_verllf: int  # 1589
s39_verllg: int  # 1590
s39_verllh: int  # 1591
s39_verllv: int  # 1592
s39_verllvb: int  # 1593
s39_verllvf: int  # 1594
s39_verllvg: int  # 1595
s39_verllvh: int  # 1596
s39_vesl: int  # 1597
s39_veslb: int  # 1598
s39_veslf: int  # 1599
s39_veslg: int  # 1600
s39_veslh: int  # 1601
s39_veslv: int  # 1602
s39_veslvb: int  # 1603
s39_veslvf: int  # 1604
s39_veslvg: int  # 1605
s39_veslvh: int  # 1606
s39_vesra: int  # 1607
s39_vesrab: int  # 1608
s39_vesraf: int  # 1609
s39_vesrag: int  # 1610
s39_vesrah: int  # 1611
s39_vesrav: int  # 1612
s39_vesravb: int  # 1613
s39_vesravf: int  # 1614
s39_vesravg: int  # 1615
s39_vesravh: int  # 1616
s39_vesrl: int  # 1617
s39_vesrlb: int  # 1618
s39_vesrlf: int  # 1619
s39_vesrlg: int  # 1620
s39_vesrlh: int  # 1621
s39_vesrlv: int  # 1622
s39_vesrlvb: int  # 1623
s39_vesrlvf: int  # 1624
s39_vesrlvg: int  # 1625
s39_vesrlvh: int  # 1626
s39_vfa: int  # 1627
s39_vfadb: int  # 1628
s39_vfae: int  # 1629
s39_vfaeb: int  # 1630
s39_vfaebs: int  # 1631
s39_vfaef: int  # 1632
s39_vfaefs: int  # 1633
s39_vfaeh: int  # 1634
s39_vfaehs: int  # 1635
s39_vfaezb: int  # 1636
s39_vfaezbs: int  # 1637
s39_vfaezf: int  # 1638
s39_vfaezfs: int  # 1639
s39_vfaezh: int  # 1640
s39_vfaezhs: int  # 1641
s39_vfasb: int  # 1642
s39_vfce: int  # 1643
s39_vfcedb: int  # 1644
s39_vfcedbs: int  # 1645
s39_vfcesb: int  # 1646
s39_vfcesbs: int  # 1647
s39_vfch: int  # 1648
s39_vfchdb: int  # 1649
s39_vfchdbs: int  # 1650
s39_vfche: int  # 1651
s39_vfchedb: int  # 1652
s39_vfchedbs: int  # 1653
s39_vfchesb: int  # 1654
s39_vfchesbs: int  # 1655
s39_vfchsb: int  # 1656
s39_vfchsbs: int  # 1657
s39_vfd: int  # 1658
s39_vfddb: int  # 1659
s39_vfdsb: int  # 1660
s39_vfee: int  # 1661
s39_vfeeb: int  # 1662
s39_vfeebs: int  # 1663
s39_vfeef: int  # 1664
s39_vfeefs: int  # 1665
s39_vfeeh: int  # 1666
s39_vfeehs: int  # 1667
s39_vfeezb: int  # 1668
s39_vfeezbs: int  # 1669
s39_vfeezf: int  # 1670
s39_vfeezfs: int  # 1671
s39_vfeezh: int  # 1672
s39_vfeezhs: int  # 1673
s39_vfene: int  # 1674
s39_vfeneb: int  # 1675
s39_vfenebs: int  # 1676
s39_vfenef: int  # 1677
s39_vfenefs: int  # 1678
s39_vfeneh: int  # 1679
s39_vfenehs: int  # 1680
s39_vfenezb: int  # 1681
s39_vfenezbs: int  # 1682
s39_vfenezf: int  # 1683
s39_vfenezfs: int  # 1684
s39_vfenezh: int  # 1685
s39_vfenezhs: int  # 1686
s39_vfi: int  # 1687
s39_vfidb: int  # 1688
s39_vfisb: int  # 1689
s39_vfkedb: int  # 1690
s39_vfkedbs: int  # 1691
s39_vfkesb: int  # 1692
s39_vfkesbs: int  # 1693
s39_vfkhdb: int  # 1694
s39_vfkhdbs: int  # 1695
s39_vfkhedb: int  # 1696
s39_vfkhedbs: int  # 1697
s39_vfkhesb: int  # 1698
s39_vfkhesbs: int  # 1699
s39_vfkhsb: int  # 1700
s39_vfkhsbs: int  # 1701
s39_vflcdb: int  # 1702
s39_vflcsb: int  # 1703
s39_vfll: int  # 1704
s39_vflls: int  # 1705
s39_vflndb: int  # 1706
s39_vflnsb: int  # 1707
s39_vflpdb: int  # 1708
s39_vflpsb: int  # 1709
s39_vflr: int  # 1710
s39_vflrd: int  # 1711
s39_vfm: int  # 1712
s39_vfma: int  # 1713
s39_vfmadb: int  # 1714
s39_vfmasb: int  # 1715
s39_vfmax: int  # 1716
s39_vfmaxdb: int  # 1717
s39_vfmaxsb: int  # 1718
s39_vfmdb: int  # 1719
s39_vfmin: int  # 1720
s39_vfmindb: int  # 1721
s39_vfminsb: int  # 1722
s39_vfms: int  # 1723
s39_vfmsb: int  # 1724
s39_vfmsdb: int  # 1725
s39_vfmssb: int  # 1726
s39_vfnma: int  # 1727
s39_vfnmadb: int  # 1728
s39_vfnmasb: int  # 1729
s39_vfnms: int  # 1730
s39_vfnmsdb: int  # 1731
s39_vfnmssb: int  # 1732
s39_vfpso: int  # 1733
s39_vfpsodb: int  # 1734
s39_vfpsosb: int  # 1735
s39_vfs: int  # 1736
s39_vfsdb: int  # 1737
s39_vfsq: int  # 1738
s39_vfsqdb: int  # 1739
s39_vfsqsb: int  # 1740
s39_vfssb: int  # 1741
s39_vftci: int  # 1742
s39_vftcidb: int  # 1743
s39_vftcisb: int  # 1744
s39_vgbm: int  # 1745
s39_vgef: int  # 1746
s39_vgeg: int  # 1747
s39_vgfm: int  # 1748
s39_vgfma: int  # 1749
s39_vgfmab: int  # 1750
s39_vgfmaf: int  # 1751
s39_vgfmag: int  # 1752
s39_vgfmah: int  # 1753
s39_vgfmb: int  # 1754
s39_vgfmf: int  # 1755
s39_vgfmg: int  # 1756
s39_vgfmh: int  # 1757
s39_vgm: int  # 1758
s39_vgmb: int  # 1759
s39_vgmf: int  # 1760
s39_vgmg: int  # 1761
s39_vgmh: int  # 1762
s39_vistr: int  # 1763
s39_vistrb: int  # 1764
s39_vistrbs: int  # 1765
s39_vistrf: int  # 1766
s39_vistrfs: int  # 1767
s39_vistrh: int  # 1768
s39_vistrhs: int  # 1769
s39_vl: int  # 1770
s39_vlbb: int  # 1771
s39_vlbr: int  # 1772
s39_vlbrf: int  # 1773
s39_vlbrg: int  # 1774
s39_vlbrh: int  # 1775
s39_vlbrq: int  # 1776
s39_vlbrrep: int  # 1777
s39_vlbrrepf: int  # 1778
s39_vlbrrepg: int  # 1779
s39_vlbrreph: int  # 1780
s39_vlc: int  # 1781
s39_vlcb: int  # 1782
s39_vlcf: int  # 1783
s39_vlcg: int  # 1784
s39_vlch: int  # 1785
s39_vlde: int  # 1786
s39_vldeb: int  # 1787
s39_vleb: int  # 1788
s39_vlebrf: int  # 1789
s39_vlebrg: int  # 1790
s39_vlebrh: int  # 1791
s39_vled: int  # 1792
s39_vledb: int  # 1793
s39_vlef: int  # 1794
s39_vleg: int  # 1795
s39_vleh: int  # 1796
s39_vleib: int  # 1797
s39_vleif: int  # 1798
s39_vleig: int  # 1799
s39_vleih: int  # 1800
s39_vler: int  # 1801
s39_vlerf: int  # 1802
s39_vlerg: int  # 1803
s39_vlerh: int  # 1804
s39_vlgv: int  # 1805
s39_vlgvb: int  # 1806
s39_vlgvf: int  # 1807
s39_vlgvg: int  # 1808
s39_vlgvh: int  # 1809
s39_vlip: int  # 1810
s39_vll: int  # 1811
s39_vllebrz: int  # 1812
s39_vllebrze: int  # 1813
s39_vllebrzf: int  # 1814
s39_vllebrzg: int  # 1815
s39_vllebrzh: int  # 1816
s39_vllez: int  # 1817
s39_vllezb: int  # 1818
s39_vllezf: int  # 1819
s39_vllezg: int  # 1820
s39_vllezh: int  # 1821
s39_vllezlf: int  # 1822
s39_vlm: int  # 1823
s39_vlp: int  # 1824
s39_vlpb: int  # 1825
s39_vlpf: int  # 1826
s39_vlpg: int  # 1827
s39_vlph: int  # 1828
s39_vlr: int  # 1829
s39_vlrep: int  # 1830
s39_vlrepb: int  # 1831
s39_vlrepf: int  # 1832
s39_vlrepg: int  # 1833
s39_vlreph: int  # 1834
s39_vlrl: int  # 1835
s39_vlrlr: int  # 1836
s39_vlvg: int  # 1837
s39_vlvgb: int  # 1838
s39_vlvgf: int  # 1839
s39_vlvgg: int  # 1840
s39_vlvgh: int  # 1841
s39_vlvgp: int  # 1842
s39_vmae: int  # 1843
s39_vmaeb: int  # 1844
s39_vmaef: int  # 1845
s39_vmaeh: int  # 1846
s39_vmah: int  # 1847
s39_vmahb: int  # 1848
s39_vmahf: int  # 1849
s39_vmahh: int  # 1850
s39_vmal: int  # 1851
s39_vmalb: int  # 1852
s39_vmale: int  # 1853
s39_vmaleb: int  # 1854
s39_vmalef: int  # 1855
s39_vmaleh: int  # 1856
s39_vmalf: int  # 1857
s39_vmalh: int  # 1858
s39_vmalhb: int  # 1859
s39_vmalhf: int  # 1860
s39_vmalhh: int  # 1861
s39_vmalhw: int  # 1862
s39_vmalo: int  # 1863
s39_vmalob: int  # 1864
s39_vmalof: int  # 1865
s39_vmaloh: int  # 1866
s39_vmao: int  # 1867
s39_vmaob: int  # 1868
s39_vmaof: int  # 1869
s39_vmaoh: int  # 1870
s39_vme: int  # 1871
s39_vmeb: int  # 1872
s39_vmef: int  # 1873
s39_vmeh: int  # 1874
s39_vmh: int  # 1875
s39_vmhb: int  # 1876
s39_vmhf: int  # 1877
s39_vmhh: int  # 1878
s39_vml: int  # 1879
s39_vmlb: int  # 1880
s39_vmle: int  # 1881
s39_vmleb: int  # 1882
s39_vmlef: int  # 1883
s39_vmleh: int  # 1884
s39_vmlf: int  # 1885
s39_vmlh: int  # 1886
s39_vmlhb: int  # 1887
s39_vmlhf: int  # 1888
s39_vmlhh: int  # 1889
s39_vmlhw: int  # 1890
s39_vmlo: int  # 1891
s39_vmlob: int  # 1892
s39_vmlof: int  # 1893
s39_vmloh: int  # 1894
s39_vmn: int  # 1895
s39_vmnb: int  # 1896
s39_vmnf: int  # 1897
s39_vmng: int  # 1898
s39_vmnh: int  # 1899
s39_vmnl: int  # 1900
s39_vmnlb: int  # 1901
s39_vmnlf: int  # 1902
s39_vmnlg: int  # 1903
s39_vmnlh: int  # 1904
s39_vmo: int  # 1905
s39_vmob: int  # 1906
s39_vmof: int  # 1907
s39_vmoh: int  # 1908
s39_vmp: int  # 1909
s39_vmrh: int  # 1910
s39_vmrhb: int  # 1911
s39_vmrhf: int  # 1912
s39_vmrhg: int  # 1913
s39_vmrhh: int  # 1914
s39_vmrl: int  # 1915
s39_vmrlb: int  # 1916
s39_vmrlf: int  # 1917
s39_vmrlg: int  # 1918
s39_vmrlh: int  # 1919
s39_vmsl: int  # 1920
s39_vmslg: int  # 1921
s39_vmsp: int  # 1922
s39_vmx: int  # 1923
s39_vmxb: int  # 1924
s39_vmxf: int  # 1925
s39_vmxg: int  # 1926
s39_vmxh: int  # 1927
s39_vmxl: int  # 1928
s39_vmxlb: int  # 1929
s39_vmxlf: int  # 1930
s39_vmxlg: int  # 1931
s39_vmxlh: int  # 1932
s39_vn: int  # 1933
s39_vnc: int  # 1934
s39_vnn: int  # 1935
s39_vno: int  # 1936
s39_vnot: int  # 1937
s39_vnx: int  # 1938
s39_vo: int  # 1939
s39_voc: int  # 1940
s39_vone: int  # 1941
s39_vpdi: int  # 1942
s39_vperm: int  # 1943
s39_vpk: int  # 1944
s39_vpkf: int  # 1945
s39_vpkg: int  # 1946
s39_vpkh: int  # 1947
s39_vpkls: int  # 1948
s39_vpklsf: int  # 1949
s39_vpklsfs: int  # 1950
s39_vpklsg: int  # 1951
s39_vpklsgs: int  # 1952
s39_vpklsh: int  # 1953
s39_vpklshs: int  # 1954
s39_vpks: int  # 1955
s39_vpksf: int  # 1956
s39_vpksfs: int  # 1957
s39_vpksg: int  # 1958
s39_vpksgs: int  # 1959
s39_vpksh: int  # 1960
s39_vpkshs: int  # 1961
s39_vpkz: int  # 1962
s39_vpopct: int  # 1963
s39_vpopctb: int  # 1964
s39_vpopctf: int  # 1965
s39_vpopctg: int  # 1966
s39_vpopcth: int  # 1967
s39_vpsop: int  # 1968
s39_vrep: int  # 1969
s39_vrepb: int  # 1970
s39_vrepf: int  # 1971
s39_vrepg: int  # 1972
s39_vreph: int  # 1973
s39_vrepi: int  # 1974
s39_vrepib: int  # 1975
s39_vrepif: int  # 1976
s39_vrepig: int  # 1977
s39_vrepih: int  # 1978
s39_vrp: int  # 1979
s39_vs: int  # 1980
s39_vsb: int  # 1981
s39_vsbcbi: int  # 1982
s39_vsbcbiq: int  # 1983
s39_vsbi: int  # 1984
s39_vsbiq: int  # 1985
s39_vscbi: int  # 1986
s39_vscbib: int  # 1987
s39_vscbif: int  # 1988
s39_vscbig: int  # 1989
s39_vscbih: int  # 1990
s39_vscbiq: int  # 1991
s39_vscef: int  # 1992
s39_vsceg: int  # 1993
s39_vsdp: int  # 1994
s39_vseg: int  # 1995
s39_vsegb: int  # 1996
s39_vsegf: int  # 1997
s39_vsegh: int  # 1998
s39_vsel: int  # 1999
s39_vsf: int  # 2000
s39_vsg: int  # 2001
s39_vsh: int  # 2002
s39_vsl: int  # 2003
s39_vslb: int  # 2004
s39_vsld: int  # 2005
s39_vsldb: int  # 2006
s39_vsp: int  # 2007
s39_vsq: int  # 2008
s39_vsra: int  # 2009
s39_vsrab: int  # 2010
s39_vsrd: int  # 2011
s39_vsrl: int  # 2012
s39_vsrlb: int  # 2013
s39_vsrp: int  # 2014
s39_vst: int  # 2015
s39_vstbr: int  # 2016
s39_vstbrf: int  # 2017
s39_vstbrg: int  # 2018
s39_vstbrh: int  # 2019
s39_vstbrq: int  # 2020
s39_vsteb: int  # 2021
s39_vstebrf: int  # 2022
s39_vstebrg: int  # 2023
s39_vstebrh: int  # 2024
s39_vstef: int  # 2025
s39_vsteg: int  # 2026
s39_vsteh: int  # 2027
s39_vster: int  # 2028
s39_vsterf: int  # 2029
s39_vsterg: int  # 2030
s39_vsterh: int  # 2031
s39_vstl: int  # 2032
s39_vstm: int  # 2033
s39_vstrc: int  # 2034
s39_vstrcb: int  # 2035
s39_vstrcbs: int  # 2036
s39_vstrcf: int  # 2037
s39_vstrcfs: int  # 2038
s39_vstrch: int  # 2039
s39_vstrchs: int  # 2040
s39_vstrczb: int  # 2041
s39_vstrczbs: int  # 2042
s39_vstrczf: int  # 2043
s39_vstrczfs: int  # 2044
s39_vstrczh: int  # 2045
s39_vstrczhs: int  # 2046
s39_vstrl: int  # 2047
s39_vstrlr: int  # 2048
s39_vstrs: int  # 2049
s39_vstrsb: int  # 2050
s39_vstrsf: int  # 2051
s39_vstrsh: int  # 2052
s39_vstrszb: int  # 2053
s39_vstrszf: int  # 2054
s39_vstrszh: int  # 2055
s39_vsum: int  # 2056
s39_vsumb: int  # 2057
s39_vsumg: int  # 2058
s39_vsumgf: int  # 2059
s39_vsumgh: int  # 2060
s39_vsumh: int  # 2061
s39_vsumq: int  # 2062
s39_vsumqf: int  # 2063
s39_vsumqg: int  # 2064
s39_vtm: int  # 2065
s39_vtp: int  # 2066
s39_vuph: int  # 2067
s39_vuphb: int  # 2068
s39_vuphf: int  # 2069
s39_vuphh: int  # 2070
s39_vupkz: int  # 2071
s39_vupl: int  # 2072
s39_vuplb: int  # 2073
s39_vuplf: int  # 2074
s39_vuplh: int  # 2075
s39_vuplhb: int  # 2076
s39_vuplhf: int  # 2077
s39_vuplhh: int  # 2078
s39_vuplhw: int  # 2079
s39_vupll: int  # 2080
s39_vupllb: int  # 2081
s39_vupllf: int  # 2082
s39_vupllh: int  # 2083
s39_vx: int  # 2208
s39_vzero: int  # 2084
s39_wcdgb: int  # 2085
s39_wcdlgb: int  # 2086
s39_wcefb: int  # 2087
s39_wcelfb: int  # 2088
s39_wcfeb: int  # 2089
s39_wcgdb: int  # 2090
s39_wclfeb: int  # 2091
s39_wclgdb: int  # 2092
s39_wfadb: int  # 2093
s39_wfasb: int  # 2094
s39_wfaxb: int  # 2095
s39_wfc: int  # 2096
s39_wfcdb: int  # 2097
s39_wfcedb: int  # 2098
s39_wfcedbs: int  # 2099
s39_wfcesb: int  # 2100
s39_wfcesbs: int  # 2101
s39_wfcexb: int  # 2102
s39_wfcexbs: int  # 2103
s39_wfchdb: int  # 2104
s39_wfchdbs: int  # 2105
s39_wfchedb: int  # 2106
s39_wfchedbs: int  # 2107
s39_wfchesb: int  # 2108
s39_wfchesbs: int  # 2109
s39_wfchexb: int  # 2110
s39_wfchexbs: int  # 2111
s39_wfchsb: int  # 2112
s39_wfchsbs: int  # 2113
s39_wfchxb: int  # 2114
s39_wfchxbs: int  # 2115
s39_wfcsb: int  # 2116
s39_wfcxb: int  # 2117
s39_wfddb: int  # 2118
s39_wfdsb: int  # 2119
s39_wfdxb: int  # 2120
s39_wfidb: int  # 2121
s39_wfisb: int  # 2122
s39_wfixb: int  # 2123
s39_wfk: int  # 2124
s39_wfkdb: int  # 2125
s39_wfkedb: int  # 2126
s39_wfkedbs: int  # 2127
s39_wfkesb: int  # 2128
s39_wfkesbs: int  # 2129
s39_wfkexb: int  # 2130
s39_wfkexbs: int  # 2131
s39_wfkhdb: int  # 2132
s39_wfkhdbs: int  # 2133
s39_wfkhedb: int  # 2134
s39_wfkhedbs: int  # 2135
s39_wfkhesb: int  # 2136
s39_wfkhesbs: int  # 2137
s39_wfkhexb: int  # 2138
s39_wfkhexbs: int  # 2139
s39_wfkhsb: int  # 2140
s39_wfkhsbs: int  # 2141
s39_wfkhxb: int  # 2142
s39_wfkhxbs: int  # 2143
s39_wfksb: int  # 2144
s39_wfkxb: int  # 2145
s39_wflcdb: int  # 2146
s39_wflcsb: int  # 2147
s39_wflcxb: int  # 2148
s39_wflld: int  # 2149
s39_wflls: int  # 2150
s39_wflndb: int  # 2151
s39_wflnsb: int  # 2152
s39_wflnxb: int  # 2153
s39_wflpdb: int  # 2154
s39_wflpsb: int  # 2155
s39_wflpxb: int  # 2156
s39_wflrd: int  # 2157
s39_wflrx: int  # 2158
s39_wfmadb: int  # 2159
s39_wfmasb: int  # 2160
s39_wfmaxb: int  # 2161
s39_wfmaxdb: int  # 2162
s39_wfmaxsb: int  # 2163
s39_wfmaxxb: int  # 2164
s39_wfmdb: int  # 2165
s39_wfmindb: int  # 2166
s39_wfminsb: int  # 2167
s39_wfminxb: int  # 2168
s39_wfmsb: int  # 2169
s39_wfmsdb: int  # 2170
s39_wfmssb: int  # 2171
s39_wfmsxb: int  # 2172
s39_wfmxb: int  # 2173
s39_wfnmadb: int  # 2174
s39_wfnmasb: int  # 2175
s39_wfnmaxb: int  # 2176
s39_wfnmsdb: int  # 2177
s39_wfnmssb: int  # 2178
s39_wfnmsxb: int  # 2179
s39_wfpsodb: int  # 2180
s39_wfpsosb: int  # 2181
s39_wfpsoxb: int  # 2182
s39_wfsdb: int  # 2183
s39_wfsqdb: int  # 2184
s39_wfsqsb: int  # 2185
s39_wfsqxb: int  # 2186
s39_wfssb: int  # 2187
s39_wfsxb: int  # 2188
s39_wftcidb: int  # 2189
s39_wftcisb: int  # 2190
s39_wftcixb: int  # 2191
s39_wldeb: int  # 2192
s39_wledb: int  # 2193
s39_x: int  # 2194
s39_xc: int  # 2195
s39_xg: int  # 2196
s39_xgr: int  # 2197
s39_xgrk: int  # 2198
s39_xi: int  # 2199
s39_xihf: int  # 2200
s39_xilf: int  # 2201
s39_xiy: int  # 2202
s39_xr: int  # 2203
s39_xrk: int  # 2204
s39_xsch: int  # 2205
s39_xy: int  # 2206
s39_zap: int  # 2207
st9_adc: int  # 9
st9_adcw: int  # 10
st9_add: int  # 7
st9_addw: int  # 8
st9_ald: int  # 103
st9_aldw: int  # 104
st9_and: int  # 15
st9_andw: int  # 16
st9_band: int  # 67
st9_bcpl: int  # 64
st9_bld: int  # 66
st9_bor: int  # 68
st9_bres: int  # 63
st9_bset: int  # 62
st9_btjf: int  # 79
st9_btjt: int  # 80
st9_btset: int  # 65
st9_bxor: int  # 69
st9_call: int  # 77
st9_calls: int  # 78
st9_ccf: int  # 95
st9_clr: int  # 41
st9_cp: int  # 21
st9_cpjfi: int  # 83
st9_cpjti: int  # 84
st9_cpl: int  # 42
st9_cpw: int  # 22
st9_da: int  # 44
st9_dec: int  # 29
st9_decw: int  # 30
st9_di: int  # 92
st9_div: int  # 60
st9_divws: int  # 61
st9_djnz: int  # 81
st9_dwjnz: int  # 82
st9_ei: int  # 91
st9_eret: int  # 102
st9_etrap: int  # 101
st9_ext: int  # 90
st9_halt: int  # 100
st9_inc: int  # 27
st9_incw: int  # 28
st9_iret: int  # 72
st9_jp: int  # 75
st9_jpcc: int  # 74
st9_jps: int  # 76
st9_jrcc: int  # 73
st9_last: int  # 105
st9_ld: int  # 1
st9_lddd: int  # 6
st9_lddp: int  # 5
st9_ldpd: int  # 4
st9_ldpp: int  # 3
st9_ldw: int  # 2
st9_link: int  # 55
st9_linku: int  # 57
st9_mul: int  # 59
st9_nop: int  # 98
st9_null: int  # 0
st9_or: int  # 17
st9_orw: int  # 18
st9_pea: int  # 47
st9_peau: int  # 52
st9_pop: int  # 48
st9_popu: int  # 53
st9_popuw: int  # 54
st9_popw: int  # 49
st9_push: int  # 45
st9_pushu: int  # 50
st9_pushuw: int  # 51
st9_pushw: int  # 46
st9_rcf: int  # 94
st9_ret: int  # 70
st9_rets: int  # 71
st9_rlc: int  # 37
st9_rlcw: int  # 38
st9_rol: int  # 40
st9_ror: int  # 39
st9_rrc: int  # 35
st9_rrcw: int  # 36
st9_sbc: int  # 13
st9_sbcw: int  # 14
st9_scf: int  # 93
st9_sdm: int  # 97
st9_sla: int  # 31
st9_slaw: int  # 32
st9_spm: int  # 96
st9_spp: int  # 89
st9_sra: int  # 33
st9_sraw: int  # 34
st9_srp: int  # 86
st9_srp0: int  # 87
st9_srp1: int  # 88
st9_sub: int  # 11
st9_subw: int  # 12
st9_swap: int  # 43
st9_tcm: int  # 25
st9_tcmw: int  # 26
st9_tm: int  # 23
st9_tmw: int  # 24
st9_unlink: int  # 56
st9_unlinku: int  # 58
st9_wfi: int  # 99
st9_xch: int  # 85
st9_xor: int  # 19
st9_xorw: int  # 20
weakref: module
xScale_mar: int  # 78
xScale_mia: int  # 72
xScale_miabb: int  # 74
xScale_miabt: int  # 75
xScale_miaph: int  # 73
xScale_miatb: int  # 76
xScale_miatt: int  # 77
xScale_mra: int  # 79